#
# spec file for package texlive-specs-m
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define texlive_version  2023
%define texlive_previous 2022
%define texlive_release  20230311
%define texlive_noarch   201
%define biber_version    2.18

#!BuildIgnore:          texlive
#!BuildIgnore:          texlive-scripts
#!BuildIgnore:          texlive-scripts-extra
#!BuildIgnore:          texlive-scripts-bin
#!BuildIgnore:          texlive-scripts-extra-bin
#!BuildIgnore:          texlive-gsftopk
#!BuildIgnore:          texlive-gsftopk-bin
#!BuildIgnore:          texlive-kpathsea
#!BuildIgnore:          texlive-kpathsea-bin

%global _varlib         %{_localstatedir}/lib
%global _libexecdir     %{_prefix}/lib

%define _texmfdistdir   %{_datadir}/texmf
%if 0%{texlive_version} >= 2013
%define _texmfmaindir   %{_texmfdistdir}
%define _texmfdirs      %{_texmfdistdir}
%else
%define _texmfmaindir   %{_libexecdir}/texmf
%define _texmfdirs      \{%{_texmfdistdir},%{_texmfmaindir}\}
%endif

%define _texmfconfdir   %{_sysconfdir}/texmf
%define _texmfvardir    %{_varlib}/texmf
%define _texmfcache     %{_localstatedir}/cache/texmf
%define _fontcache      %{_texmfcache}/fonts
#
%define _x11bin         %{_prefix}/bin
%define _x11lib         %{_libdir}
%define _x11data        %{_datadir}/X11
%define _x11inc         %{_includedir}
%define _appdefdir      %{_x11data}/app-defaults

Name:           texlive-specs-m
Version:        2023
Release:        0
BuildRequires:  ed
BuildRequires:  fontconfig
BuildRequires:  fontpackages-devel
BuildRequires:  mkfontdir
BuildRequires:  mkfontscale
BuildRequires:  t1utils
BuildRequires:  texlive-filesystem
BuildRequires:  xorg-x11-fonts-core
BuildRequires:  xz
BuildArch:      noarch
Summary:        Meta package for m
License:        Apache-1.0 and BSD-3-Clause and GFDL-1.3-or-later and GPL-2.0-or-later and LGPL-2.1-or-later and LPPL-1.0 and LPPL-1.3c and OFL-1.1 and SUSE-Public-Domain and SUSE-TeX
URL:            https://build.opensuse.org/package/show/Publishing:TeXLive/Meta
Group:          Productivity/Publishing/TeX/Base
Source0:        texlive-specs-m-rpmlintrc

%description
Meta package to build tons of noarch texlive packages.

%package -n texlive-ionumbers
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.3svn33457
Release:        0
License:        GPL-2.0-or-later
Summary:        Restyle numbers in maths mode
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ionumbers-doc >= %{texlive_version}
Provides:       tex(ionumbers.sty)
Requires:       tex(keyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source1:        ionumbers.tar.xz
Source2:        ionumbers.doc.tar.xz

%description -n texlive-ionumbers
'ionumbers' stands for 'input/output numbers'. The package
restyles numbers in maths mode. If a number in the input file
is written, e.g., as $3,231.44$ as commonly used in English
texts, the package is able to restyle it to be output as
$3\,231{,}44$ as commonly used in German texts (and vice
versa). This may be useful, for example, if you have a large
table and want to include it in texts with different output
conventions without the need to change the table. The package
can also automatically group digits left of the decimal
separator (thousands) and right of the decimal separator
(thousandths) in triplets without the need of specifing commas
(English) or points (German) as separators. E.g., the input
$1234.567890$ can be output as $1\,234.\,567\,890$. Finally, an
e starts the exponent of the number. For example, $21e6$ may be
output as $26\times10\,^{6}$.

%package -n texlive-ionumbers-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.3svn33457
Release:        0
Summary:        Documentation for texlive-ionumbers
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ionumbers and texlive-alldocumentation)

%description -n texlive-ionumbers-doc
This package includes the documentation for texlive-ionumbers

%post -n texlive-ionumbers
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ionumbers
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ionumbers
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ionumbers-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/ionumbers/COPYING
%{_texmfdistdir}/doc/latex/ionumbers/Makefile
%{_texmfdistdir}/doc/latex/ionumbers/README
%{_texmfdistdir}/doc/latex/ionumbers/ionumbers.pdf
%{_texmfdistdir}/doc/latex/ionumbers/ionumbers_test.pdf
%{_texmfdistdir}/doc/latex/ionumbers/ionumbers_test.tex

%files -n texlive-ionumbers
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/ionumbers/ionumbers.sty

%package -n texlive-iopart-num
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn15878
Release:        0
License:        LPPL-1.0
Summary:        Numeric citation style for IOP journals
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-iopart-num-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source3:        iopart-num.tar.xz
Source4:        iopart-num.doc.tar.xz

%description -n texlive-iopart-num
A BibTeX style providing numeric citation in Harvard-like
format. Intended for use with Institute of Physics (IOP)
journals, including Journal of Physics.

%package -n texlive-iopart-num-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn15878
Release:        0
Summary:        Documentation for texlive-iopart-num
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iopart-num and texlive-alldocumentation)

%description -n texlive-iopart-num-doc
This package includes the documentation for texlive-iopart-num

%post -n texlive-iopart-num
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-iopart-num
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-iopart-num
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-iopart-num-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/bibtex/iopart-num/README
%{_texmfdistdir}/doc/bibtex/iopart-num/iopart-num.bib
%{_texmfdistdir}/doc/bibtex/iopart-num/iopart-num.pdf
%{_texmfdistdir}/doc/bibtex/iopart-num/iopart-num.tex

%files -n texlive-iopart-num
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/iopart-num/iopart-num.bst

%package -n texlive-ipaex
Version:        %{texlive_version}.%{texlive_noarch}.svn61719
Release:        0
License:        LPPL-1.0
Summary:        IPA (Japanese) fonts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-ipaex-fonts >= %{texlive_version}
Suggests:       texlive-ipaex-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source5:        ipaex.tar.xz
Source6:        ipaex.doc.tar.xz

%description -n texlive-ipaex
The fonts provide fixed-width glyphs for Kana and Kanji
characters, proportional width glyphs for Western characters.

%package -n texlive-ipaex-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn61719
Release:        0
Summary:        Documentation for texlive-ipaex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ipaex and texlive-alldocumentation)

%description -n texlive-ipaex-doc
This package includes the documentation for texlive-ipaex

%package -n texlive-ipaex-fonts
Version:        %{texlive_version}.%{texlive_noarch}.svn61719
Release:        0
Summary:        Severed fonts for texlive-ipaex
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-ipaex-fonts
The  separated fonts package for texlive-ipaex

%post -n texlive-ipaex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ipaex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ipaex
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-ipaex-fonts

%files -n texlive-ipaex-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/ipaex/IPA_Font_License_Agreement_v1.0.txt
%{_texmfdistdir}/doc/fonts/ipaex/README
%{_texmfdistdir}/doc/fonts/ipaex/Readme_IPAexfont00401.txt
%{_texmfdistdir}/doc/fonts/ipaex/Readme_IPAfont00303.txt

%files -n texlive-ipaex
%defattr(-,root,root,755)
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipaexg.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipaexm.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipag.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipagp.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipam.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/ipaex/ipamp.ttf

%files -n texlive-ipaex-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-ipaex
%{_datadir}/fontconfig/conf.avail/58-texlive-ipaex.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex/fonts.scale
%{_datadir}/fonts/texlive-ipaex/ipaexg.ttf
%{_datadir}/fonts/texlive-ipaex/ipaexm.ttf
%{_datadir}/fonts/texlive-ipaex/ipag.ttf
%{_datadir}/fonts/texlive-ipaex/ipagp.ttf
%{_datadir}/fonts/texlive-ipaex/ipam.ttf
%{_datadir}/fonts/texlive-ipaex/ipamp.ttf

%package -n texlive-ipaex-type1
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5svn47700
Release:        0
License:        LPPL-1.0
Summary:        IPAex fonts converted to Type-1 format Unicode subfonts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-ipaex-type1-fonts >= %{texlive_version}
Suggests:       texlive-ipaex-type1-doc >= %{texlive_version}
Provides:       tex(c70ipxg.fd)
Provides:       tex(c70ipxga.fd)
Provides:       tex(c70ipxm.fd)
Provides:       tex(c70ipxma.fd)
Provides:       tex(ipaex-type1.map)
Provides:       tex(ipaex-type1.sty)
Provides:       tex(ipxg-r-ly1.tfm)
Provides:       tex(ipxg-r-ot1.tfm)
Provides:       tex(ipxg-r-t1.tfm)
Provides:       tex(ipxg-r-ts1.tfm)
Provides:       tex(ipxg-r-u00.tfm)
Provides:       tex(ipxg-r-u01.tfm)
Provides:       tex(ipxg-r-u02.tfm)
Provides:       tex(ipxg-r-u0200.tfm)
Provides:       tex(ipxg-r-u0201.tfm)
Provides:       tex(ipxg-r-u0202.tfm)
Provides:       tex(ipxg-r-u0203.tfm)
Provides:       tex(ipxg-r-u0204.tfm)
Provides:       tex(ipxg-r-u0205.tfm)
Provides:       tex(ipxg-r-u0206.tfm)
Provides:       tex(ipxg-r-u0207.tfm)
Provides:       tex(ipxg-r-u0208.tfm)
Provides:       tex(ipxg-r-u0209.tfm)
Provides:       tex(ipxg-r-u020a.tfm)
Provides:       tex(ipxg-r-u020b.tfm)
Provides:       tex(ipxg-r-u020d.tfm)
Provides:       tex(ipxg-r-u020e.tfm)
Provides:       tex(ipxg-r-u020f.tfm)
Provides:       tex(ipxg-r-u0212.tfm)
Provides:       tex(ipxg-r-u0213.tfm)
Provides:       tex(ipxg-r-u0214.tfm)
Provides:       tex(ipxg-r-u0215.tfm)
Provides:       tex(ipxg-r-u0216.tfm)
Provides:       tex(ipxg-r-u0217.tfm)
Provides:       tex(ipxg-r-u0218.tfm)
Provides:       tex(ipxg-r-u0219.tfm)
Provides:       tex(ipxg-r-u021c.tfm)
Provides:       tex(ipxg-r-u021d.tfm)
Provides:       tex(ipxg-r-u021e.tfm)
Provides:       tex(ipxg-r-u021f.tfm)
Provides:       tex(ipxg-r-u0221.tfm)
Provides:       tex(ipxg-r-u0222.tfm)
Provides:       tex(ipxg-r-u0223.tfm)
Provides:       tex(ipxg-r-u0226.tfm)
Provides:       tex(ipxg-r-u0228.tfm)
Provides:       tex(ipxg-r-u0229.tfm)
Provides:       tex(ipxg-r-u022a.tfm)
Provides:       tex(ipxg-r-u022b.tfm)
Provides:       tex(ipxg-r-u022c.tfm)
Provides:       tex(ipxg-r-u022d.tfm)
Provides:       tex(ipxg-r-u0231.tfm)
Provides:       tex(ipxg-r-u0233.tfm)
Provides:       tex(ipxg-r-u0234.tfm)
Provides:       tex(ipxg-r-u0235.tfm)
Provides:       tex(ipxg-r-u0236.tfm)
Provides:       tex(ipxg-r-u0237.tfm)
Provides:       tex(ipxg-r-u0238.tfm)
Provides:       tex(ipxg-r-u023a.tfm)
Provides:       tex(ipxg-r-u023c.tfm)
Provides:       tex(ipxg-r-u023d.tfm)
Provides:       tex(ipxg-r-u023f.tfm)
Provides:       tex(ipxg-r-u0240.tfm)
Provides:       tex(ipxg-r-u0241.tfm)
Provides:       tex(ipxg-r-u0243.tfm)
Provides:       tex(ipxg-r-u0246.tfm)
Provides:       tex(ipxg-r-u0247.tfm)
Provides:       tex(ipxg-r-u0248.tfm)
Provides:       tex(ipxg-r-u024a.tfm)
Provides:       tex(ipxg-r-u024b.tfm)
Provides:       tex(ipxg-r-u024c.tfm)
Provides:       tex(ipxg-r-u024d.tfm)
Provides:       tex(ipxg-r-u024e.tfm)
Provides:       tex(ipxg-r-u0250.tfm)
Provides:       tex(ipxg-r-u0251.tfm)
Provides:       tex(ipxg-r-u0252.tfm)
Provides:       tex(ipxg-r-u0254.tfm)
Provides:       tex(ipxg-r-u0255.tfm)
Provides:       tex(ipxg-r-u0257.tfm)
Provides:       tex(ipxg-r-u0259.tfm)
Provides:       tex(ipxg-r-u025a.tfm)
Provides:       tex(ipxg-r-u025b.tfm)
Provides:       tex(ipxg-r-u025c.tfm)
Provides:       tex(ipxg-r-u025d.tfm)
Provides:       tex(ipxg-r-u025e.tfm)
Provides:       tex(ipxg-r-u025f.tfm)
Provides:       tex(ipxg-r-u0260.tfm)
Provides:       tex(ipxg-r-u0262.tfm)
Provides:       tex(ipxg-r-u0263.tfm)
Provides:       tex(ipxg-r-u0264.tfm)
Provides:       tex(ipxg-r-u0266.tfm)
Provides:       tex(ipxg-r-u0267.tfm)
Provides:       tex(ipxg-r-u0268.tfm)
Provides:       tex(ipxg-r-u0269.tfm)
Provides:       tex(ipxg-r-u026a.tfm)
Provides:       tex(ipxg-r-u026c.tfm)
Provides:       tex(ipxg-r-u026e.tfm)
Provides:       tex(ipxg-r-u026f.tfm)
Provides:       tex(ipxg-r-u0270.tfm)
Provides:       tex(ipxg-r-u0271.tfm)
Provides:       tex(ipxg-r-u0273.tfm)
Provides:       tex(ipxg-r-u0274.tfm)
Provides:       tex(ipxg-r-u0276.tfm)
Provides:       tex(ipxg-r-u0277.tfm)
Provides:       tex(ipxg-r-u0279.tfm)
Provides:       tex(ipxg-r-u027a.tfm)
Provides:       tex(ipxg-r-u027b.tfm)
Provides:       tex(ipxg-r-u027c.tfm)
Provides:       tex(ipxg-r-u027d.tfm)
Provides:       tex(ipxg-r-u027e.tfm)
Provides:       tex(ipxg-r-u027f.tfm)
Provides:       tex(ipxg-r-u0280.tfm)
Provides:       tex(ipxg-r-u0282.tfm)
Provides:       tex(ipxg-r-u0283.tfm)
Provides:       tex(ipxg-r-u0284.tfm)
Provides:       tex(ipxg-r-u0285.tfm)
Provides:       tex(ipxg-r-u0286.tfm)
Provides:       tex(ipxg-r-u0289.tfm)
Provides:       tex(ipxg-r-u028a.tfm)
Provides:       tex(ipxg-r-u028b.tfm)
Provides:       tex(ipxg-r-u028d.tfm)
Provides:       tex(ipxg-r-u028e.tfm)
Provides:       tex(ipxg-r-u028f.tfm)
Provides:       tex(ipxg-r-u0292.tfm)
Provides:       tex(ipxg-r-u0294.tfm)
Provides:       tex(ipxg-r-u0295.tfm)
Provides:       tex(ipxg-r-u0296.tfm)
Provides:       tex(ipxg-r-u0297.tfm)
Provides:       tex(ipxg-r-u0298.tfm)
Provides:       tex(ipxg-r-u029a.tfm)
Provides:       tex(ipxg-r-u029d.tfm)
Provides:       tex(ipxg-r-u029e.tfm)
Provides:       tex(ipxg-r-u029f.tfm)
Provides:       tex(ipxg-r-u02a0.tfm)
Provides:       tex(ipxg-r-u02a1.tfm)
Provides:       tex(ipxg-r-u02a3.tfm)
Provides:       tex(ipxg-r-u02a4.tfm)
Provides:       tex(ipxg-r-u02a5.tfm)
Provides:       tex(ipxg-r-u02a6.tfm)
Provides:       tex(ipxg-r-u02f8.tfm)
Provides:       tex(ipxg-r-u03.tfm)
Provides:       tex(ipxg-r-u04.tfm)
Provides:       tex(ipxg-r-u1e.tfm)
Provides:       tex(ipxg-r-u1f.tfm)
Provides:       tex(ipxg-r-u20.tfm)
Provides:       tex(ipxg-r-u21.tfm)
Provides:       tex(ipxg-r-u22.tfm)
Provides:       tex(ipxg-r-u23.tfm)
Provides:       tex(ipxg-r-u24.tfm)
Provides:       tex(ipxg-r-u25.tfm)
Provides:       tex(ipxg-r-u26.tfm)
Provides:       tex(ipxg-r-u27.tfm)
Provides:       tex(ipxg-r-u29.tfm)
Provides:       tex(ipxg-r-u2e.tfm)
Provides:       tex(ipxg-r-u2f.tfm)
Provides:       tex(ipxg-r-u30.tfm)
Provides:       tex(ipxg-r-u31.tfm)
Provides:       tex(ipxg-r-u32.tfm)
Provides:       tex(ipxg-r-u33.tfm)
Provides:       tex(ipxg-r-u34.tfm)
Provides:       tex(ipxg-r-u35.tfm)
Provides:       tex(ipxg-r-u36.tfm)
Provides:       tex(ipxg-r-u37.tfm)
Provides:       tex(ipxg-r-u38.tfm)
Provides:       tex(ipxg-r-u39.tfm)
Provides:       tex(ipxg-r-u3a.tfm)
Provides:       tex(ipxg-r-u3b.tfm)
Provides:       tex(ipxg-r-u3c.tfm)
Provides:       tex(ipxg-r-u3d.tfm)
Provides:       tex(ipxg-r-u3e.tfm)
Provides:       tex(ipxg-r-u3f.tfm)
Provides:       tex(ipxg-r-u40.tfm)
Provides:       tex(ipxg-r-u41.tfm)
Provides:       tex(ipxg-r-u42.tfm)
Provides:       tex(ipxg-r-u43.tfm)
Provides:       tex(ipxg-r-u44.tfm)
Provides:       tex(ipxg-r-u45.tfm)
Provides:       tex(ipxg-r-u46.tfm)
Provides:       tex(ipxg-r-u47.tfm)
Provides:       tex(ipxg-r-u48.tfm)
Provides:       tex(ipxg-r-u49.tfm)
Provides:       tex(ipxg-r-u4a.tfm)
Provides:       tex(ipxg-r-u4b.tfm)
Provides:       tex(ipxg-r-u4c.tfm)
Provides:       tex(ipxg-r-u4d.tfm)
Provides:       tex(ipxg-r-u4e.tfm)
Provides:       tex(ipxg-r-u4f.tfm)
Provides:       tex(ipxg-r-u50.tfm)
Provides:       tex(ipxg-r-u51.tfm)
Provides:       tex(ipxg-r-u52.tfm)
Provides:       tex(ipxg-r-u53.tfm)
Provides:       tex(ipxg-r-u54.tfm)
Provides:       tex(ipxg-r-u55.tfm)
Provides:       tex(ipxg-r-u56.tfm)
Provides:       tex(ipxg-r-u57.tfm)
Provides:       tex(ipxg-r-u58.tfm)
Provides:       tex(ipxg-r-u59.tfm)
Provides:       tex(ipxg-r-u5a.tfm)
Provides:       tex(ipxg-r-u5b.tfm)
Provides:       tex(ipxg-r-u5c.tfm)
Provides:       tex(ipxg-r-u5d.tfm)
Provides:       tex(ipxg-r-u5e.tfm)
Provides:       tex(ipxg-r-u5f.tfm)
Provides:       tex(ipxg-r-u60.tfm)
Provides:       tex(ipxg-r-u61.tfm)
Provides:       tex(ipxg-r-u62.tfm)
Provides:       tex(ipxg-r-u63.tfm)
Provides:       tex(ipxg-r-u64.tfm)
Provides:       tex(ipxg-r-u65.tfm)
Provides:       tex(ipxg-r-u66.tfm)
Provides:       tex(ipxg-r-u67.tfm)
Provides:       tex(ipxg-r-u68.tfm)
Provides:       tex(ipxg-r-u69.tfm)
Provides:       tex(ipxg-r-u6a.tfm)
Provides:       tex(ipxg-r-u6b.tfm)
Provides:       tex(ipxg-r-u6c.tfm)
Provides:       tex(ipxg-r-u6d.tfm)
Provides:       tex(ipxg-r-u6e.tfm)
Provides:       tex(ipxg-r-u6f.tfm)
Provides:       tex(ipxg-r-u70.tfm)
Provides:       tex(ipxg-r-u71.tfm)
Provides:       tex(ipxg-r-u72.tfm)
Provides:       tex(ipxg-r-u73.tfm)
Provides:       tex(ipxg-r-u74.tfm)
Provides:       tex(ipxg-r-u75.tfm)
Provides:       tex(ipxg-r-u76.tfm)
Provides:       tex(ipxg-r-u77.tfm)
Provides:       tex(ipxg-r-u78.tfm)
Provides:       tex(ipxg-r-u79.tfm)
Provides:       tex(ipxg-r-u7a.tfm)
Provides:       tex(ipxg-r-u7b.tfm)
Provides:       tex(ipxg-r-u7c.tfm)
Provides:       tex(ipxg-r-u7d.tfm)
Provides:       tex(ipxg-r-u7e.tfm)
Provides:       tex(ipxg-r-u7f.tfm)
Provides:       tex(ipxg-r-u80.tfm)
Provides:       tex(ipxg-r-u81.tfm)
Provides:       tex(ipxg-r-u82.tfm)
Provides:       tex(ipxg-r-u83.tfm)
Provides:       tex(ipxg-r-u84.tfm)
Provides:       tex(ipxg-r-u85.tfm)
Provides:       tex(ipxg-r-u86.tfm)
Provides:       tex(ipxg-r-u87.tfm)
Provides:       tex(ipxg-r-u88.tfm)
Provides:       tex(ipxg-r-u89.tfm)
Provides:       tex(ipxg-r-u8a.tfm)
Provides:       tex(ipxg-r-u8b.tfm)
Provides:       tex(ipxg-r-u8c.tfm)
Provides:       tex(ipxg-r-u8d.tfm)
Provides:       tex(ipxg-r-u8e.tfm)
Provides:       tex(ipxg-r-u8f.tfm)
Provides:       tex(ipxg-r-u90.tfm)
Provides:       tex(ipxg-r-u91.tfm)
Provides:       tex(ipxg-r-u92.tfm)
Provides:       tex(ipxg-r-u93.tfm)
Provides:       tex(ipxg-r-u94.tfm)
Provides:       tex(ipxg-r-u95.tfm)
Provides:       tex(ipxg-r-u96.tfm)
Provides:       tex(ipxg-r-u97.tfm)
Provides:       tex(ipxg-r-u98.tfm)
Provides:       tex(ipxg-r-u99.tfm)
Provides:       tex(ipxg-r-u9a.tfm)
Provides:       tex(ipxg-r-u9b.tfm)
Provides:       tex(ipxg-r-u9c.tfm)
Provides:       tex(ipxg-r-u9d.tfm)
Provides:       tex(ipxg-r-u9e.tfm)
Provides:       tex(ipxg-r-u9f.tfm)
Provides:       tex(ipxg-r-uf0.tfm)
Provides:       tex(ipxg-r-uf8.tfm)
Provides:       tex(ipxg-r-uf9.tfm)
Provides:       tex(ipxg-r-ufa.tfm)
Provides:       tex(ipxg-r-ufe.tfm)
Provides:       tex(ipxg-r-uff.tfm)
Provides:       tex(ipxg-ro-ly1.tfm)
Provides:       tex(ipxg-ro-ot1.tfm)
Provides:       tex(ipxg-ro-t1.tfm)
Provides:       tex(ipxg-ro-ts1.tfm)
Provides:       tex(ipxg-ro-u00.tfm)
Provides:       tex(ipxg-ro-u01.tfm)
Provides:       tex(ipxg-ro-u02.tfm)
Provides:       tex(ipxg-ro-u0200.tfm)
Provides:       tex(ipxg-ro-u0201.tfm)
Provides:       tex(ipxg-ro-u0202.tfm)
Provides:       tex(ipxg-ro-u0203.tfm)
Provides:       tex(ipxg-ro-u0204.tfm)
Provides:       tex(ipxg-ro-u0205.tfm)
Provides:       tex(ipxg-ro-u0206.tfm)
Provides:       tex(ipxg-ro-u0207.tfm)
Provides:       tex(ipxg-ro-u0208.tfm)
Provides:       tex(ipxg-ro-u0209.tfm)
Provides:       tex(ipxg-ro-u020a.tfm)
Provides:       tex(ipxg-ro-u020b.tfm)
Provides:       tex(ipxg-ro-u020d.tfm)
Provides:       tex(ipxg-ro-u020e.tfm)
Provides:       tex(ipxg-ro-u020f.tfm)
Provides:       tex(ipxg-ro-u0212.tfm)
Provides:       tex(ipxg-ro-u0213.tfm)
Provides:       tex(ipxg-ro-u0214.tfm)
Provides:       tex(ipxg-ro-u0215.tfm)
Provides:       tex(ipxg-ro-u0216.tfm)
Provides:       tex(ipxg-ro-u0217.tfm)
Provides:       tex(ipxg-ro-u0218.tfm)
Provides:       tex(ipxg-ro-u0219.tfm)
Provides:       tex(ipxg-ro-u021c.tfm)
Provides:       tex(ipxg-ro-u021d.tfm)
Provides:       tex(ipxg-ro-u021e.tfm)
Provides:       tex(ipxg-ro-u021f.tfm)
Provides:       tex(ipxg-ro-u0221.tfm)
Provides:       tex(ipxg-ro-u0222.tfm)
Provides:       tex(ipxg-ro-u0223.tfm)
Provides:       tex(ipxg-ro-u0226.tfm)
Provides:       tex(ipxg-ro-u0228.tfm)
Provides:       tex(ipxg-ro-u0229.tfm)
Provides:       tex(ipxg-ro-u022a.tfm)
Provides:       tex(ipxg-ro-u022b.tfm)
Provides:       tex(ipxg-ro-u022c.tfm)
Provides:       tex(ipxg-ro-u022d.tfm)
Provides:       tex(ipxg-ro-u0231.tfm)
Provides:       tex(ipxg-ro-u0233.tfm)
Provides:       tex(ipxg-ro-u0234.tfm)
Provides:       tex(ipxg-ro-u0235.tfm)
Provides:       tex(ipxg-ro-u0236.tfm)
Provides:       tex(ipxg-ro-u0237.tfm)
Provides:       tex(ipxg-ro-u0238.tfm)
Provides:       tex(ipxg-ro-u023a.tfm)
Provides:       tex(ipxg-ro-u023c.tfm)
Provides:       tex(ipxg-ro-u023d.tfm)
Provides:       tex(ipxg-ro-u023f.tfm)
Provides:       tex(ipxg-ro-u0240.tfm)
Provides:       tex(ipxg-ro-u0241.tfm)
Provides:       tex(ipxg-ro-u0243.tfm)
Provides:       tex(ipxg-ro-u0246.tfm)
Provides:       tex(ipxg-ro-u0247.tfm)
Provides:       tex(ipxg-ro-u0248.tfm)
Provides:       tex(ipxg-ro-u024a.tfm)
Provides:       tex(ipxg-ro-u024b.tfm)
Provides:       tex(ipxg-ro-u024c.tfm)
Provides:       tex(ipxg-ro-u024d.tfm)
Provides:       tex(ipxg-ro-u024e.tfm)
Provides:       tex(ipxg-ro-u0250.tfm)
Provides:       tex(ipxg-ro-u0251.tfm)
Provides:       tex(ipxg-ro-u0252.tfm)
Provides:       tex(ipxg-ro-u0254.tfm)
Provides:       tex(ipxg-ro-u0255.tfm)
Provides:       tex(ipxg-ro-u0257.tfm)
Provides:       tex(ipxg-ro-u0259.tfm)
Provides:       tex(ipxg-ro-u025a.tfm)
Provides:       tex(ipxg-ro-u025b.tfm)
Provides:       tex(ipxg-ro-u025c.tfm)
Provides:       tex(ipxg-ro-u025d.tfm)
Provides:       tex(ipxg-ro-u025e.tfm)
Provides:       tex(ipxg-ro-u025f.tfm)
Provides:       tex(ipxg-ro-u0260.tfm)
Provides:       tex(ipxg-ro-u0262.tfm)
Provides:       tex(ipxg-ro-u0263.tfm)
Provides:       tex(ipxg-ro-u0264.tfm)
Provides:       tex(ipxg-ro-u0266.tfm)
Provides:       tex(ipxg-ro-u0267.tfm)
Provides:       tex(ipxg-ro-u0268.tfm)
Provides:       tex(ipxg-ro-u0269.tfm)
Provides:       tex(ipxg-ro-u026a.tfm)
Provides:       tex(ipxg-ro-u026c.tfm)
Provides:       tex(ipxg-ro-u026e.tfm)
Provides:       tex(ipxg-ro-u026f.tfm)
Provides:       tex(ipxg-ro-u0270.tfm)
Provides:       tex(ipxg-ro-u0271.tfm)
Provides:       tex(ipxg-ro-u0273.tfm)
Provides:       tex(ipxg-ro-u0274.tfm)
Provides:       tex(ipxg-ro-u0276.tfm)
Provides:       tex(ipxg-ro-u0277.tfm)
Provides:       tex(ipxg-ro-u0279.tfm)
Provides:       tex(ipxg-ro-u027a.tfm)
Provides:       tex(ipxg-ro-u027b.tfm)
Provides:       tex(ipxg-ro-u027c.tfm)
Provides:       tex(ipxg-ro-u027d.tfm)
Provides:       tex(ipxg-ro-u027e.tfm)
Provides:       tex(ipxg-ro-u027f.tfm)
Provides:       tex(ipxg-ro-u0280.tfm)
Provides:       tex(ipxg-ro-u0282.tfm)
Provides:       tex(ipxg-ro-u0283.tfm)
Provides:       tex(ipxg-ro-u0284.tfm)
Provides:       tex(ipxg-ro-u0285.tfm)
Provides:       tex(ipxg-ro-u0286.tfm)
Provides:       tex(ipxg-ro-u0289.tfm)
Provides:       tex(ipxg-ro-u028a.tfm)
Provides:       tex(ipxg-ro-u028b.tfm)
Provides:       tex(ipxg-ro-u028d.tfm)
Provides:       tex(ipxg-ro-u028e.tfm)
Provides:       tex(ipxg-ro-u028f.tfm)
Provides:       tex(ipxg-ro-u0292.tfm)
Provides:       tex(ipxg-ro-u0294.tfm)
Provides:       tex(ipxg-ro-u0295.tfm)
Provides:       tex(ipxg-ro-u0296.tfm)
Provides:       tex(ipxg-ro-u0297.tfm)
Provides:       tex(ipxg-ro-u0298.tfm)
Provides:       tex(ipxg-ro-u029a.tfm)
Provides:       tex(ipxg-ro-u029d.tfm)
Provides:       tex(ipxg-ro-u029e.tfm)
Provides:       tex(ipxg-ro-u029f.tfm)
Provides:       tex(ipxg-ro-u02a0.tfm)
Provides:       tex(ipxg-ro-u02a1.tfm)
Provides:       tex(ipxg-ro-u02a3.tfm)
Provides:       tex(ipxg-ro-u02a4.tfm)
Provides:       tex(ipxg-ro-u02a5.tfm)
Provides:       tex(ipxg-ro-u02a6.tfm)
Provides:       tex(ipxg-ro-u02f8.tfm)
Provides:       tex(ipxg-ro-u03.tfm)
Provides:       tex(ipxg-ro-u04.tfm)
Provides:       tex(ipxg-ro-u1e.tfm)
Provides:       tex(ipxg-ro-u1f.tfm)
Provides:       tex(ipxg-ro-u20.tfm)
Provides:       tex(ipxg-ro-u21.tfm)
Provides:       tex(ipxg-ro-u22.tfm)
Provides:       tex(ipxg-ro-u23.tfm)
Provides:       tex(ipxg-ro-u24.tfm)
Provides:       tex(ipxg-ro-u25.tfm)
Provides:       tex(ipxg-ro-u26.tfm)
Provides:       tex(ipxg-ro-u27.tfm)
Provides:       tex(ipxg-ro-u29.tfm)
Provides:       tex(ipxg-ro-u2e.tfm)
Provides:       tex(ipxg-ro-u2f.tfm)
Provides:       tex(ipxg-ro-u30.tfm)
Provides:       tex(ipxg-ro-u31.tfm)
Provides:       tex(ipxg-ro-u32.tfm)
Provides:       tex(ipxg-ro-u33.tfm)
Provides:       tex(ipxg-ro-u34.tfm)
Provides:       tex(ipxg-ro-u35.tfm)
Provides:       tex(ipxg-ro-u36.tfm)
Provides:       tex(ipxg-ro-u37.tfm)
Provides:       tex(ipxg-ro-u38.tfm)
Provides:       tex(ipxg-ro-u39.tfm)
Provides:       tex(ipxg-ro-u3a.tfm)
Provides:       tex(ipxg-ro-u3b.tfm)
Provides:       tex(ipxg-ro-u3c.tfm)
Provides:       tex(ipxg-ro-u3d.tfm)
Provides:       tex(ipxg-ro-u3e.tfm)
Provides:       tex(ipxg-ro-u3f.tfm)
Provides:       tex(ipxg-ro-u40.tfm)
Provides:       tex(ipxg-ro-u41.tfm)
Provides:       tex(ipxg-ro-u42.tfm)
Provides:       tex(ipxg-ro-u43.tfm)
Provides:       tex(ipxg-ro-u44.tfm)
Provides:       tex(ipxg-ro-u45.tfm)
Provides:       tex(ipxg-ro-u46.tfm)
Provides:       tex(ipxg-ro-u47.tfm)
Provides:       tex(ipxg-ro-u48.tfm)
Provides:       tex(ipxg-ro-u49.tfm)
Provides:       tex(ipxg-ro-u4a.tfm)
Provides:       tex(ipxg-ro-u4b.tfm)
Provides:       tex(ipxg-ro-u4c.tfm)
Provides:       tex(ipxg-ro-u4d.tfm)
Provides:       tex(ipxg-ro-u4e.tfm)
Provides:       tex(ipxg-ro-u4f.tfm)
Provides:       tex(ipxg-ro-u50.tfm)
Provides:       tex(ipxg-ro-u51.tfm)
Provides:       tex(ipxg-ro-u52.tfm)
Provides:       tex(ipxg-ro-u53.tfm)
Provides:       tex(ipxg-ro-u54.tfm)
Provides:       tex(ipxg-ro-u55.tfm)
Provides:       tex(ipxg-ro-u56.tfm)
Provides:       tex(ipxg-ro-u57.tfm)
Provides:       tex(ipxg-ro-u58.tfm)
Provides:       tex(ipxg-ro-u59.tfm)
Provides:       tex(ipxg-ro-u5a.tfm)
Provides:       tex(ipxg-ro-u5b.tfm)
Provides:       tex(ipxg-ro-u5c.tfm)
Provides:       tex(ipxg-ro-u5d.tfm)
Provides:       tex(ipxg-ro-u5e.tfm)
Provides:       tex(ipxg-ro-u5f.tfm)
Provides:       tex(ipxg-ro-u60.tfm)
Provides:       tex(ipxg-ro-u61.tfm)
Provides:       tex(ipxg-ro-u62.tfm)
Provides:       tex(ipxg-ro-u63.tfm)
Provides:       tex(ipxg-ro-u64.tfm)
Provides:       tex(ipxg-ro-u65.tfm)
Provides:       tex(ipxg-ro-u66.tfm)
Provides:       tex(ipxg-ro-u67.tfm)
Provides:       tex(ipxg-ro-u68.tfm)
Provides:       tex(ipxg-ro-u69.tfm)
Provides:       tex(ipxg-ro-u6a.tfm)
Provides:       tex(ipxg-ro-u6b.tfm)
Provides:       tex(ipxg-ro-u6c.tfm)
Provides:       tex(ipxg-ro-u6d.tfm)
Provides:       tex(ipxg-ro-u6e.tfm)
Provides:       tex(ipxg-ro-u6f.tfm)
Provides:       tex(ipxg-ro-u70.tfm)
Provides:       tex(ipxg-ro-u71.tfm)
Provides:       tex(ipxg-ro-u72.tfm)
Provides:       tex(ipxg-ro-u73.tfm)
Provides:       tex(ipxg-ro-u74.tfm)
Provides:       tex(ipxg-ro-u75.tfm)
Provides:       tex(ipxg-ro-u76.tfm)
Provides:       tex(ipxg-ro-u77.tfm)
Provides:       tex(ipxg-ro-u78.tfm)
Provides:       tex(ipxg-ro-u79.tfm)
Provides:       tex(ipxg-ro-u7a.tfm)
Provides:       tex(ipxg-ro-u7b.tfm)
Provides:       tex(ipxg-ro-u7c.tfm)
Provides:       tex(ipxg-ro-u7d.tfm)
Provides:       tex(ipxg-ro-u7e.tfm)
Provides:       tex(ipxg-ro-u7f.tfm)
Provides:       tex(ipxg-ro-u80.tfm)
Provides:       tex(ipxg-ro-u81.tfm)
Provides:       tex(ipxg-ro-u82.tfm)
Provides:       tex(ipxg-ro-u83.tfm)
Provides:       tex(ipxg-ro-u84.tfm)
Provides:       tex(ipxg-ro-u85.tfm)
Provides:       tex(ipxg-ro-u86.tfm)
Provides:       tex(ipxg-ro-u87.tfm)
Provides:       tex(ipxg-ro-u88.tfm)
Provides:       tex(ipxg-ro-u89.tfm)
Provides:       tex(ipxg-ro-u8a.tfm)
Provides:       tex(ipxg-ro-u8b.tfm)
Provides:       tex(ipxg-ro-u8c.tfm)
Provides:       tex(ipxg-ro-u8d.tfm)
Provides:       tex(ipxg-ro-u8e.tfm)
Provides:       tex(ipxg-ro-u8f.tfm)
Provides:       tex(ipxg-ro-u90.tfm)
Provides:       tex(ipxg-ro-u91.tfm)
Provides:       tex(ipxg-ro-u92.tfm)
Provides:       tex(ipxg-ro-u93.tfm)
Provides:       tex(ipxg-ro-u94.tfm)
Provides:       tex(ipxg-ro-u95.tfm)
Provides:       tex(ipxg-ro-u96.tfm)
Provides:       tex(ipxg-ro-u97.tfm)
Provides:       tex(ipxg-ro-u98.tfm)
Provides:       tex(ipxg-ro-u99.tfm)
Provides:       tex(ipxg-ro-u9a.tfm)
Provides:       tex(ipxg-ro-u9b.tfm)
Provides:       tex(ipxg-ro-u9c.tfm)
Provides:       tex(ipxg-ro-u9d.tfm)
Provides:       tex(ipxg-ro-u9e.tfm)
Provides:       tex(ipxg-ro-u9f.tfm)
Provides:       tex(ipxg-ro-uf8.tfm)
Provides:       tex(ipxg-ro-uf9.tfm)
Provides:       tex(ipxg-ro-ufa.tfm)
Provides:       tex(ipxg-ro-ufe.tfm)
Provides:       tex(ipxg-ro-uff.tfm)
Provides:       tex(ipxm-r-ly1.tfm)
Provides:       tex(ipxm-r-ot1.tfm)
Provides:       tex(ipxm-r-t1.tfm)
Provides:       tex(ipxm-r-ts1.tfm)
Provides:       tex(ipxm-r-u00.tfm)
Provides:       tex(ipxm-r-u01.tfm)
Provides:       tex(ipxm-r-u02.tfm)
Provides:       tex(ipxm-r-u0200.tfm)
Provides:       tex(ipxm-r-u0201.tfm)
Provides:       tex(ipxm-r-u0202.tfm)
Provides:       tex(ipxm-r-u0203.tfm)
Provides:       tex(ipxm-r-u0204.tfm)
Provides:       tex(ipxm-r-u0205.tfm)
Provides:       tex(ipxm-r-u0206.tfm)
Provides:       tex(ipxm-r-u0207.tfm)
Provides:       tex(ipxm-r-u0208.tfm)
Provides:       tex(ipxm-r-u0209.tfm)
Provides:       tex(ipxm-r-u020a.tfm)
Provides:       tex(ipxm-r-u020b.tfm)
Provides:       tex(ipxm-r-u020d.tfm)
Provides:       tex(ipxm-r-u020e.tfm)
Provides:       tex(ipxm-r-u020f.tfm)
Provides:       tex(ipxm-r-u0212.tfm)
Provides:       tex(ipxm-r-u0213.tfm)
Provides:       tex(ipxm-r-u0214.tfm)
Provides:       tex(ipxm-r-u0215.tfm)
Provides:       tex(ipxm-r-u0216.tfm)
Provides:       tex(ipxm-r-u0217.tfm)
Provides:       tex(ipxm-r-u0218.tfm)
Provides:       tex(ipxm-r-u0219.tfm)
Provides:       tex(ipxm-r-u021c.tfm)
Provides:       tex(ipxm-r-u021d.tfm)
Provides:       tex(ipxm-r-u021e.tfm)
Provides:       tex(ipxm-r-u021f.tfm)
Provides:       tex(ipxm-r-u0221.tfm)
Provides:       tex(ipxm-r-u0222.tfm)
Provides:       tex(ipxm-r-u0223.tfm)
Provides:       tex(ipxm-r-u0226.tfm)
Provides:       tex(ipxm-r-u0228.tfm)
Provides:       tex(ipxm-r-u0229.tfm)
Provides:       tex(ipxm-r-u022a.tfm)
Provides:       tex(ipxm-r-u022b.tfm)
Provides:       tex(ipxm-r-u022c.tfm)
Provides:       tex(ipxm-r-u022d.tfm)
Provides:       tex(ipxm-r-u0231.tfm)
Provides:       tex(ipxm-r-u0233.tfm)
Provides:       tex(ipxm-r-u0234.tfm)
Provides:       tex(ipxm-r-u0235.tfm)
Provides:       tex(ipxm-r-u0236.tfm)
Provides:       tex(ipxm-r-u0237.tfm)
Provides:       tex(ipxm-r-u0238.tfm)
Provides:       tex(ipxm-r-u023a.tfm)
Provides:       tex(ipxm-r-u023c.tfm)
Provides:       tex(ipxm-r-u023d.tfm)
Provides:       tex(ipxm-r-u023f.tfm)
Provides:       tex(ipxm-r-u0240.tfm)
Provides:       tex(ipxm-r-u0241.tfm)
Provides:       tex(ipxm-r-u0243.tfm)
Provides:       tex(ipxm-r-u0246.tfm)
Provides:       tex(ipxm-r-u0247.tfm)
Provides:       tex(ipxm-r-u0248.tfm)
Provides:       tex(ipxm-r-u024a.tfm)
Provides:       tex(ipxm-r-u024b.tfm)
Provides:       tex(ipxm-r-u024c.tfm)
Provides:       tex(ipxm-r-u024d.tfm)
Provides:       tex(ipxm-r-u024e.tfm)
Provides:       tex(ipxm-r-u0250.tfm)
Provides:       tex(ipxm-r-u0251.tfm)
Provides:       tex(ipxm-r-u0252.tfm)
Provides:       tex(ipxm-r-u0254.tfm)
Provides:       tex(ipxm-r-u0255.tfm)
Provides:       tex(ipxm-r-u0257.tfm)
Provides:       tex(ipxm-r-u0259.tfm)
Provides:       tex(ipxm-r-u025a.tfm)
Provides:       tex(ipxm-r-u025b.tfm)
Provides:       tex(ipxm-r-u025c.tfm)
Provides:       tex(ipxm-r-u025d.tfm)
Provides:       tex(ipxm-r-u025e.tfm)
Provides:       tex(ipxm-r-u025f.tfm)
Provides:       tex(ipxm-r-u0260.tfm)
Provides:       tex(ipxm-r-u0262.tfm)
Provides:       tex(ipxm-r-u0263.tfm)
Provides:       tex(ipxm-r-u0264.tfm)
Provides:       tex(ipxm-r-u0266.tfm)
Provides:       tex(ipxm-r-u0267.tfm)
Provides:       tex(ipxm-r-u0268.tfm)
Provides:       tex(ipxm-r-u0269.tfm)
Provides:       tex(ipxm-r-u026a.tfm)
Provides:       tex(ipxm-r-u026c.tfm)
Provides:       tex(ipxm-r-u026e.tfm)
Provides:       tex(ipxm-r-u026f.tfm)
Provides:       tex(ipxm-r-u0270.tfm)
Provides:       tex(ipxm-r-u0271.tfm)
Provides:       tex(ipxm-r-u0273.tfm)
Provides:       tex(ipxm-r-u0274.tfm)
Provides:       tex(ipxm-r-u0276.tfm)
Provides:       tex(ipxm-r-u0277.tfm)
Provides:       tex(ipxm-r-u0279.tfm)
Provides:       tex(ipxm-r-u027a.tfm)
Provides:       tex(ipxm-r-u027b.tfm)
Provides:       tex(ipxm-r-u027c.tfm)
Provides:       tex(ipxm-r-u027d.tfm)
Provides:       tex(ipxm-r-u027e.tfm)
Provides:       tex(ipxm-r-u027f.tfm)
Provides:       tex(ipxm-r-u0280.tfm)
Provides:       tex(ipxm-r-u0282.tfm)
Provides:       tex(ipxm-r-u0283.tfm)
Provides:       tex(ipxm-r-u0284.tfm)
Provides:       tex(ipxm-r-u0285.tfm)
Provides:       tex(ipxm-r-u0286.tfm)
Provides:       tex(ipxm-r-u0289.tfm)
Provides:       tex(ipxm-r-u028a.tfm)
Provides:       tex(ipxm-r-u028b.tfm)
Provides:       tex(ipxm-r-u028d.tfm)
Provides:       tex(ipxm-r-u028e.tfm)
Provides:       tex(ipxm-r-u028f.tfm)
Provides:       tex(ipxm-r-u0292.tfm)
Provides:       tex(ipxm-r-u0294.tfm)
Provides:       tex(ipxm-r-u0295.tfm)
Provides:       tex(ipxm-r-u0296.tfm)
Provides:       tex(ipxm-r-u0297.tfm)
Provides:       tex(ipxm-r-u0298.tfm)
Provides:       tex(ipxm-r-u029a.tfm)
Provides:       tex(ipxm-r-u029d.tfm)
Provides:       tex(ipxm-r-u029e.tfm)
Provides:       tex(ipxm-r-u029f.tfm)
Provides:       tex(ipxm-r-u02a0.tfm)
Provides:       tex(ipxm-r-u02a1.tfm)
Provides:       tex(ipxm-r-u02a3.tfm)
Provides:       tex(ipxm-r-u02a4.tfm)
Provides:       tex(ipxm-r-u02a5.tfm)
Provides:       tex(ipxm-r-u02a6.tfm)
Provides:       tex(ipxm-r-u02f8.tfm)
Provides:       tex(ipxm-r-u03.tfm)
Provides:       tex(ipxm-r-u04.tfm)
Provides:       tex(ipxm-r-u1e.tfm)
Provides:       tex(ipxm-r-u1f.tfm)
Provides:       tex(ipxm-r-u20.tfm)
Provides:       tex(ipxm-r-u21.tfm)
Provides:       tex(ipxm-r-u22.tfm)
Provides:       tex(ipxm-r-u23.tfm)
Provides:       tex(ipxm-r-u24.tfm)
Provides:       tex(ipxm-r-u25.tfm)
Provides:       tex(ipxm-r-u26.tfm)
Provides:       tex(ipxm-r-u27.tfm)
Provides:       tex(ipxm-r-u29.tfm)
Provides:       tex(ipxm-r-u2e.tfm)
Provides:       tex(ipxm-r-u2f.tfm)
Provides:       tex(ipxm-r-u30.tfm)
Provides:       tex(ipxm-r-u31.tfm)
Provides:       tex(ipxm-r-u32.tfm)
Provides:       tex(ipxm-r-u33.tfm)
Provides:       tex(ipxm-r-u34.tfm)
Provides:       tex(ipxm-r-u35.tfm)
Provides:       tex(ipxm-r-u36.tfm)
Provides:       tex(ipxm-r-u37.tfm)
Provides:       tex(ipxm-r-u38.tfm)
Provides:       tex(ipxm-r-u39.tfm)
Provides:       tex(ipxm-r-u3a.tfm)
Provides:       tex(ipxm-r-u3b.tfm)
Provides:       tex(ipxm-r-u3c.tfm)
Provides:       tex(ipxm-r-u3d.tfm)
Provides:       tex(ipxm-r-u3e.tfm)
Provides:       tex(ipxm-r-u3f.tfm)
Provides:       tex(ipxm-r-u40.tfm)
Provides:       tex(ipxm-r-u41.tfm)
Provides:       tex(ipxm-r-u42.tfm)
Provides:       tex(ipxm-r-u43.tfm)
Provides:       tex(ipxm-r-u44.tfm)
Provides:       tex(ipxm-r-u45.tfm)
Provides:       tex(ipxm-r-u46.tfm)
Provides:       tex(ipxm-r-u47.tfm)
Provides:       tex(ipxm-r-u48.tfm)
Provides:       tex(ipxm-r-u49.tfm)
Provides:       tex(ipxm-r-u4a.tfm)
Provides:       tex(ipxm-r-u4b.tfm)
Provides:       tex(ipxm-r-u4c.tfm)
Provides:       tex(ipxm-r-u4d.tfm)
Provides:       tex(ipxm-r-u4e.tfm)
Provides:       tex(ipxm-r-u4f.tfm)
Provides:       tex(ipxm-r-u50.tfm)
Provides:       tex(ipxm-r-u51.tfm)
Provides:       tex(ipxm-r-u52.tfm)
Provides:       tex(ipxm-r-u53.tfm)
Provides:       tex(ipxm-r-u54.tfm)
Provides:       tex(ipxm-r-u55.tfm)
Provides:       tex(ipxm-r-u56.tfm)
Provides:       tex(ipxm-r-u57.tfm)
Provides:       tex(ipxm-r-u58.tfm)
Provides:       tex(ipxm-r-u59.tfm)
Provides:       tex(ipxm-r-u5a.tfm)
Provides:       tex(ipxm-r-u5b.tfm)
Provides:       tex(ipxm-r-u5c.tfm)
Provides:       tex(ipxm-r-u5d.tfm)
Provides:       tex(ipxm-r-u5e.tfm)
Provides:       tex(ipxm-r-u5f.tfm)
Provides:       tex(ipxm-r-u60.tfm)
Provides:       tex(ipxm-r-u61.tfm)
Provides:       tex(ipxm-r-u62.tfm)
Provides:       tex(ipxm-r-u63.tfm)
Provides:       tex(ipxm-r-u64.tfm)
Provides:       tex(ipxm-r-u65.tfm)
Provides:       tex(ipxm-r-u66.tfm)
Provides:       tex(ipxm-r-u67.tfm)
Provides:       tex(ipxm-r-u68.tfm)
Provides:       tex(ipxm-r-u69.tfm)
Provides:       tex(ipxm-r-u6a.tfm)
Provides:       tex(ipxm-r-u6b.tfm)
Provides:       tex(ipxm-r-u6c.tfm)
Provides:       tex(ipxm-r-u6d.tfm)
Provides:       tex(ipxm-r-u6e.tfm)
Provides:       tex(ipxm-r-u6f.tfm)
Provides:       tex(ipxm-r-u70.tfm)
Provides:       tex(ipxm-r-u71.tfm)
Provides:       tex(ipxm-r-u72.tfm)
Provides:       tex(ipxm-r-u73.tfm)
Provides:       tex(ipxm-r-u74.tfm)
Provides:       tex(ipxm-r-u75.tfm)
Provides:       tex(ipxm-r-u76.tfm)
Provides:       tex(ipxm-r-u77.tfm)
Provides:       tex(ipxm-r-u78.tfm)
Provides:       tex(ipxm-r-u79.tfm)
Provides:       tex(ipxm-r-u7a.tfm)
Provides:       tex(ipxm-r-u7b.tfm)
Provides:       tex(ipxm-r-u7c.tfm)
Provides:       tex(ipxm-r-u7d.tfm)
Provides:       tex(ipxm-r-u7e.tfm)
Provides:       tex(ipxm-r-u7f.tfm)
Provides:       tex(ipxm-r-u80.tfm)
Provides:       tex(ipxm-r-u81.tfm)
Provides:       tex(ipxm-r-u82.tfm)
Provides:       tex(ipxm-r-u83.tfm)
Provides:       tex(ipxm-r-u84.tfm)
Provides:       tex(ipxm-r-u85.tfm)
Provides:       tex(ipxm-r-u86.tfm)
Provides:       tex(ipxm-r-u87.tfm)
Provides:       tex(ipxm-r-u88.tfm)
Provides:       tex(ipxm-r-u89.tfm)
Provides:       tex(ipxm-r-u8a.tfm)
Provides:       tex(ipxm-r-u8b.tfm)
Provides:       tex(ipxm-r-u8c.tfm)
Provides:       tex(ipxm-r-u8d.tfm)
Provides:       tex(ipxm-r-u8e.tfm)
Provides:       tex(ipxm-r-u8f.tfm)
Provides:       tex(ipxm-r-u90.tfm)
Provides:       tex(ipxm-r-u91.tfm)
Provides:       tex(ipxm-r-u92.tfm)
Provides:       tex(ipxm-r-u93.tfm)
Provides:       tex(ipxm-r-u94.tfm)
Provides:       tex(ipxm-r-u95.tfm)
Provides:       tex(ipxm-r-u96.tfm)
Provides:       tex(ipxm-r-u97.tfm)
Provides:       tex(ipxm-r-u98.tfm)
Provides:       tex(ipxm-r-u99.tfm)
Provides:       tex(ipxm-r-u9a.tfm)
Provides:       tex(ipxm-r-u9b.tfm)
Provides:       tex(ipxm-r-u9c.tfm)
Provides:       tex(ipxm-r-u9d.tfm)
Provides:       tex(ipxm-r-u9e.tfm)
Provides:       tex(ipxm-r-u9f.tfm)
Provides:       tex(ipxm-r-uf0.tfm)
Provides:       tex(ipxm-r-uf8.tfm)
Provides:       tex(ipxm-r-uf9.tfm)
Provides:       tex(ipxm-r-ufa.tfm)
Provides:       tex(ipxm-r-ufe.tfm)
Provides:       tex(ipxm-r-uff.tfm)
Provides:       tex(ipxm-ro-ly1.tfm)
Provides:       tex(ipxm-ro-ot1.tfm)
Provides:       tex(ipxm-ro-t1.tfm)
Provides:       tex(ipxm-ro-ts1.tfm)
Provides:       tex(ipxm-ro-u00.tfm)
Provides:       tex(ipxm-ro-u01.tfm)
Provides:       tex(ipxm-ro-u02.tfm)
Provides:       tex(ipxm-ro-u0200.tfm)
Provides:       tex(ipxm-ro-u0201.tfm)
Provides:       tex(ipxm-ro-u0202.tfm)
Provides:       tex(ipxm-ro-u0203.tfm)
Provides:       tex(ipxm-ro-u0204.tfm)
Provides:       tex(ipxm-ro-u0205.tfm)
Provides:       tex(ipxm-ro-u0206.tfm)
Provides:       tex(ipxm-ro-u0207.tfm)
Provides:       tex(ipxm-ro-u0208.tfm)
Provides:       tex(ipxm-ro-u0209.tfm)
Provides:       tex(ipxm-ro-u020a.tfm)
Provides:       tex(ipxm-ro-u020b.tfm)
Provides:       tex(ipxm-ro-u020d.tfm)
Provides:       tex(ipxm-ro-u020e.tfm)
Provides:       tex(ipxm-ro-u020f.tfm)
Provides:       tex(ipxm-ro-u0212.tfm)
Provides:       tex(ipxm-ro-u0213.tfm)
Provides:       tex(ipxm-ro-u0214.tfm)
Provides:       tex(ipxm-ro-u0215.tfm)
Provides:       tex(ipxm-ro-u0216.tfm)
Provides:       tex(ipxm-ro-u0217.tfm)
Provides:       tex(ipxm-ro-u0218.tfm)
Provides:       tex(ipxm-ro-u0219.tfm)
Provides:       tex(ipxm-ro-u021c.tfm)
Provides:       tex(ipxm-ro-u021d.tfm)
Provides:       tex(ipxm-ro-u021e.tfm)
Provides:       tex(ipxm-ro-u021f.tfm)
Provides:       tex(ipxm-ro-u0221.tfm)
Provides:       tex(ipxm-ro-u0222.tfm)
Provides:       tex(ipxm-ro-u0223.tfm)
Provides:       tex(ipxm-ro-u0226.tfm)
Provides:       tex(ipxm-ro-u0228.tfm)
Provides:       tex(ipxm-ro-u0229.tfm)
Provides:       tex(ipxm-ro-u022a.tfm)
Provides:       tex(ipxm-ro-u022b.tfm)
Provides:       tex(ipxm-ro-u022c.tfm)
Provides:       tex(ipxm-ro-u022d.tfm)
Provides:       tex(ipxm-ro-u0231.tfm)
Provides:       tex(ipxm-ro-u0233.tfm)
Provides:       tex(ipxm-ro-u0234.tfm)
Provides:       tex(ipxm-ro-u0235.tfm)
Provides:       tex(ipxm-ro-u0236.tfm)
Provides:       tex(ipxm-ro-u0237.tfm)
Provides:       tex(ipxm-ro-u0238.tfm)
Provides:       tex(ipxm-ro-u023a.tfm)
Provides:       tex(ipxm-ro-u023c.tfm)
Provides:       tex(ipxm-ro-u023d.tfm)
Provides:       tex(ipxm-ro-u023f.tfm)
Provides:       tex(ipxm-ro-u0240.tfm)
Provides:       tex(ipxm-ro-u0241.tfm)
Provides:       tex(ipxm-ro-u0243.tfm)
Provides:       tex(ipxm-ro-u0246.tfm)
Provides:       tex(ipxm-ro-u0247.tfm)
Provides:       tex(ipxm-ro-u0248.tfm)
Provides:       tex(ipxm-ro-u024a.tfm)
Provides:       tex(ipxm-ro-u024b.tfm)
Provides:       tex(ipxm-ro-u024c.tfm)
Provides:       tex(ipxm-ro-u024d.tfm)
Provides:       tex(ipxm-ro-u024e.tfm)
Provides:       tex(ipxm-ro-u0250.tfm)
Provides:       tex(ipxm-ro-u0251.tfm)
Provides:       tex(ipxm-ro-u0252.tfm)
Provides:       tex(ipxm-ro-u0254.tfm)
Provides:       tex(ipxm-ro-u0255.tfm)
Provides:       tex(ipxm-ro-u0257.tfm)
Provides:       tex(ipxm-ro-u0259.tfm)
Provides:       tex(ipxm-ro-u025a.tfm)
Provides:       tex(ipxm-ro-u025b.tfm)
Provides:       tex(ipxm-ro-u025c.tfm)
Provides:       tex(ipxm-ro-u025d.tfm)
Provides:       tex(ipxm-ro-u025e.tfm)
Provides:       tex(ipxm-ro-u025f.tfm)
Provides:       tex(ipxm-ro-u0260.tfm)
Provides:       tex(ipxm-ro-u0262.tfm)
Provides:       tex(ipxm-ro-u0263.tfm)
Provides:       tex(ipxm-ro-u0264.tfm)
Provides:       tex(ipxm-ro-u0266.tfm)
Provides:       tex(ipxm-ro-u0267.tfm)
Provides:       tex(ipxm-ro-u0268.tfm)
Provides:       tex(ipxm-ro-u0269.tfm)
Provides:       tex(ipxm-ro-u026a.tfm)
Provides:       tex(ipxm-ro-u026c.tfm)
Provides:       tex(ipxm-ro-u026e.tfm)
Provides:       tex(ipxm-ro-u026f.tfm)
Provides:       tex(ipxm-ro-u0270.tfm)
Provides:       tex(ipxm-ro-u0271.tfm)
Provides:       tex(ipxm-ro-u0273.tfm)
Provides:       tex(ipxm-ro-u0274.tfm)
Provides:       tex(ipxm-ro-u0276.tfm)
Provides:       tex(ipxm-ro-u0277.tfm)
Provides:       tex(ipxm-ro-u0279.tfm)
Provides:       tex(ipxm-ro-u027a.tfm)
Provides:       tex(ipxm-ro-u027b.tfm)
Provides:       tex(ipxm-ro-u027c.tfm)
Provides:       tex(ipxm-ro-u027d.tfm)
Provides:       tex(ipxm-ro-u027e.tfm)
Provides:       tex(ipxm-ro-u027f.tfm)
Provides:       tex(ipxm-ro-u0280.tfm)
Provides:       tex(ipxm-ro-u0282.tfm)
Provides:       tex(ipxm-ro-u0283.tfm)
Provides:       tex(ipxm-ro-u0284.tfm)
Provides:       tex(ipxm-ro-u0285.tfm)
Provides:       tex(ipxm-ro-u0286.tfm)
Provides:       tex(ipxm-ro-u0289.tfm)
Provides:       tex(ipxm-ro-u028a.tfm)
Provides:       tex(ipxm-ro-u028b.tfm)
Provides:       tex(ipxm-ro-u028d.tfm)
Provides:       tex(ipxm-ro-u028e.tfm)
Provides:       tex(ipxm-ro-u028f.tfm)
Provides:       tex(ipxm-ro-u0292.tfm)
Provides:       tex(ipxm-ro-u0294.tfm)
Provides:       tex(ipxm-ro-u0295.tfm)
Provides:       tex(ipxm-ro-u0296.tfm)
Provides:       tex(ipxm-ro-u0297.tfm)
Provides:       tex(ipxm-ro-u0298.tfm)
Provides:       tex(ipxm-ro-u029a.tfm)
Provides:       tex(ipxm-ro-u029d.tfm)
Provides:       tex(ipxm-ro-u029e.tfm)
Provides:       tex(ipxm-ro-u029f.tfm)
Provides:       tex(ipxm-ro-u02a0.tfm)
Provides:       tex(ipxm-ro-u02a1.tfm)
Provides:       tex(ipxm-ro-u02a3.tfm)
Provides:       tex(ipxm-ro-u02a4.tfm)
Provides:       tex(ipxm-ro-u02a5.tfm)
Provides:       tex(ipxm-ro-u02a6.tfm)
Provides:       tex(ipxm-ro-u02f8.tfm)
Provides:       tex(ipxm-ro-u03.tfm)
Provides:       tex(ipxm-ro-u04.tfm)
Provides:       tex(ipxm-ro-u1e.tfm)
Provides:       tex(ipxm-ro-u1f.tfm)
Provides:       tex(ipxm-ro-u20.tfm)
Provides:       tex(ipxm-ro-u21.tfm)
Provides:       tex(ipxm-ro-u22.tfm)
Provides:       tex(ipxm-ro-u23.tfm)
Provides:       tex(ipxm-ro-u24.tfm)
Provides:       tex(ipxm-ro-u25.tfm)
Provides:       tex(ipxm-ro-u26.tfm)
Provides:       tex(ipxm-ro-u27.tfm)
Provides:       tex(ipxm-ro-u29.tfm)
Provides:       tex(ipxm-ro-u2e.tfm)
Provides:       tex(ipxm-ro-u2f.tfm)
Provides:       tex(ipxm-ro-u30.tfm)
Provides:       tex(ipxm-ro-u31.tfm)
Provides:       tex(ipxm-ro-u32.tfm)
Provides:       tex(ipxm-ro-u33.tfm)
Provides:       tex(ipxm-ro-u34.tfm)
Provides:       tex(ipxm-ro-u35.tfm)
Provides:       tex(ipxm-ro-u36.tfm)
Provides:       tex(ipxm-ro-u37.tfm)
Provides:       tex(ipxm-ro-u38.tfm)
Provides:       tex(ipxm-ro-u39.tfm)
Provides:       tex(ipxm-ro-u3a.tfm)
Provides:       tex(ipxm-ro-u3b.tfm)
Provides:       tex(ipxm-ro-u3c.tfm)
Provides:       tex(ipxm-ro-u3d.tfm)
Provides:       tex(ipxm-ro-u3e.tfm)
Provides:       tex(ipxm-ro-u3f.tfm)
Provides:       tex(ipxm-ro-u40.tfm)
Provides:       tex(ipxm-ro-u41.tfm)
Provides:       tex(ipxm-ro-u42.tfm)
Provides:       tex(ipxm-ro-u43.tfm)
Provides:       tex(ipxm-ro-u44.tfm)
Provides:       tex(ipxm-ro-u45.tfm)
Provides:       tex(ipxm-ro-u46.tfm)
Provides:       tex(ipxm-ro-u47.tfm)
Provides:       tex(ipxm-ro-u48.tfm)
Provides:       tex(ipxm-ro-u49.tfm)
Provides:       tex(ipxm-ro-u4a.tfm)
Provides:       tex(ipxm-ro-u4b.tfm)
Provides:       tex(ipxm-ro-u4c.tfm)
Provides:       tex(ipxm-ro-u4d.tfm)
Provides:       tex(ipxm-ro-u4e.tfm)
Provides:       tex(ipxm-ro-u4f.tfm)
Provides:       tex(ipxm-ro-u50.tfm)
Provides:       tex(ipxm-ro-u51.tfm)
Provides:       tex(ipxm-ro-u52.tfm)
Provides:       tex(ipxm-ro-u53.tfm)
Provides:       tex(ipxm-ro-u54.tfm)
Provides:       tex(ipxm-ro-u55.tfm)
Provides:       tex(ipxm-ro-u56.tfm)
Provides:       tex(ipxm-ro-u57.tfm)
Provides:       tex(ipxm-ro-u58.tfm)
Provides:       tex(ipxm-ro-u59.tfm)
Provides:       tex(ipxm-ro-u5a.tfm)
Provides:       tex(ipxm-ro-u5b.tfm)
Provides:       tex(ipxm-ro-u5c.tfm)
Provides:       tex(ipxm-ro-u5d.tfm)
Provides:       tex(ipxm-ro-u5e.tfm)
Provides:       tex(ipxm-ro-u5f.tfm)
Provides:       tex(ipxm-ro-u60.tfm)
Provides:       tex(ipxm-ro-u61.tfm)
Provides:       tex(ipxm-ro-u62.tfm)
Provides:       tex(ipxm-ro-u63.tfm)
Provides:       tex(ipxm-ro-u64.tfm)
Provides:       tex(ipxm-ro-u65.tfm)
Provides:       tex(ipxm-ro-u66.tfm)
Provides:       tex(ipxm-ro-u67.tfm)
Provides:       tex(ipxm-ro-u68.tfm)
Provides:       tex(ipxm-ro-u69.tfm)
Provides:       tex(ipxm-ro-u6a.tfm)
Provides:       tex(ipxm-ro-u6b.tfm)
Provides:       tex(ipxm-ro-u6c.tfm)
Provides:       tex(ipxm-ro-u6d.tfm)
Provides:       tex(ipxm-ro-u6e.tfm)
Provides:       tex(ipxm-ro-u6f.tfm)
Provides:       tex(ipxm-ro-u70.tfm)
Provides:       tex(ipxm-ro-u71.tfm)
Provides:       tex(ipxm-ro-u72.tfm)
Provides:       tex(ipxm-ro-u73.tfm)
Provides:       tex(ipxm-ro-u74.tfm)
Provides:       tex(ipxm-ro-u75.tfm)
Provides:       tex(ipxm-ro-u76.tfm)
Provides:       tex(ipxm-ro-u77.tfm)
Provides:       tex(ipxm-ro-u78.tfm)
Provides:       tex(ipxm-ro-u79.tfm)
Provides:       tex(ipxm-ro-u7a.tfm)
Provides:       tex(ipxm-ro-u7b.tfm)
Provides:       tex(ipxm-ro-u7c.tfm)
Provides:       tex(ipxm-ro-u7d.tfm)
Provides:       tex(ipxm-ro-u7e.tfm)
Provides:       tex(ipxm-ro-u7f.tfm)
Provides:       tex(ipxm-ro-u80.tfm)
Provides:       tex(ipxm-ro-u81.tfm)
Provides:       tex(ipxm-ro-u82.tfm)
Provides:       tex(ipxm-ro-u83.tfm)
Provides:       tex(ipxm-ro-u84.tfm)
Provides:       tex(ipxm-ro-u85.tfm)
Provides:       tex(ipxm-ro-u86.tfm)
Provides:       tex(ipxm-ro-u87.tfm)
Provides:       tex(ipxm-ro-u88.tfm)
Provides:       tex(ipxm-ro-u89.tfm)
Provides:       tex(ipxm-ro-u8a.tfm)
Provides:       tex(ipxm-ro-u8b.tfm)
Provides:       tex(ipxm-ro-u8c.tfm)
Provides:       tex(ipxm-ro-u8d.tfm)
Provides:       tex(ipxm-ro-u8e.tfm)
Provides:       tex(ipxm-ro-u8f.tfm)
Provides:       tex(ipxm-ro-u90.tfm)
Provides:       tex(ipxm-ro-u91.tfm)
Provides:       tex(ipxm-ro-u92.tfm)
Provides:       tex(ipxm-ro-u93.tfm)
Provides:       tex(ipxm-ro-u94.tfm)
Provides:       tex(ipxm-ro-u95.tfm)
Provides:       tex(ipxm-ro-u96.tfm)
Provides:       tex(ipxm-ro-u97.tfm)
Provides:       tex(ipxm-ro-u98.tfm)
Provides:       tex(ipxm-ro-u99.tfm)
Provides:       tex(ipxm-ro-u9a.tfm)
Provides:       tex(ipxm-ro-u9b.tfm)
Provides:       tex(ipxm-ro-u9c.tfm)
Provides:       tex(ipxm-ro-u9d.tfm)
Provides:       tex(ipxm-ro-u9e.tfm)
Provides:       tex(ipxm-ro-u9f.tfm)
Provides:       tex(ipxm-ro-uf8.tfm)
Provides:       tex(ipxm-ro-uf9.tfm)
Provides:       tex(ipxm-ro-ufa.tfm)
Provides:       tex(ipxm-ro-ufe.tfm)
Provides:       tex(ipxm-ro-uff.tfm)
Provides:       tex(ipxt1-ly1.enc)
Provides:       tex(ipxt1-ot1.enc)
Provides:       tex(ipxt1-t1.enc)
Provides:       tex(ipxt1-ts1.enc)
Provides:       tex(ipxt1-u00.enc)
Provides:       tex(ipxt1-u01.enc)
Provides:       tex(ipxt1-u02.enc)
Provides:       tex(ipxt1-u0200.enc)
Provides:       tex(ipxt1-u0201.enc)
Provides:       tex(ipxt1-u0202.enc)
Provides:       tex(ipxt1-u0203.enc)
Provides:       tex(ipxt1-u0204.enc)
Provides:       tex(ipxt1-u0205.enc)
Provides:       tex(ipxt1-u0206.enc)
Provides:       tex(ipxt1-u0207.enc)
Provides:       tex(ipxt1-u0208.enc)
Provides:       tex(ipxt1-u0209.enc)
Provides:       tex(ipxt1-u020a.enc)
Provides:       tex(ipxt1-u020b.enc)
Provides:       tex(ipxt1-u020d.enc)
Provides:       tex(ipxt1-u020e.enc)
Provides:       tex(ipxt1-u020f.enc)
Provides:       tex(ipxt1-u0212.enc)
Provides:       tex(ipxt1-u0213.enc)
Provides:       tex(ipxt1-u0214.enc)
Provides:       tex(ipxt1-u0215.enc)
Provides:       tex(ipxt1-u0216.enc)
Provides:       tex(ipxt1-u0217.enc)
Provides:       tex(ipxt1-u0218.enc)
Provides:       tex(ipxt1-u0219.enc)
Provides:       tex(ipxt1-u021c.enc)
Provides:       tex(ipxt1-u021d.enc)
Provides:       tex(ipxt1-u021e.enc)
Provides:       tex(ipxt1-u021f.enc)
Provides:       tex(ipxt1-u0221.enc)
Provides:       tex(ipxt1-u0222.enc)
Provides:       tex(ipxt1-u0223.enc)
Provides:       tex(ipxt1-u0226.enc)
Provides:       tex(ipxt1-u0228.enc)
Provides:       tex(ipxt1-u0229.enc)
Provides:       tex(ipxt1-u022a.enc)
Provides:       tex(ipxt1-u022b.enc)
Provides:       tex(ipxt1-u022c.enc)
Provides:       tex(ipxt1-u022d.enc)
Provides:       tex(ipxt1-u0231.enc)
Provides:       tex(ipxt1-u0233.enc)
Provides:       tex(ipxt1-u0234.enc)
Provides:       tex(ipxt1-u0235.enc)
Provides:       tex(ipxt1-u0236.enc)
Provides:       tex(ipxt1-u0237.enc)
Provides:       tex(ipxt1-u0238.enc)
Provides:       tex(ipxt1-u023a.enc)
Provides:       tex(ipxt1-u023c.enc)
Provides:       tex(ipxt1-u023d.enc)
Provides:       tex(ipxt1-u023f.enc)
Provides:       tex(ipxt1-u0240.enc)
Provides:       tex(ipxt1-u0241.enc)
Provides:       tex(ipxt1-u0243.enc)
Provides:       tex(ipxt1-u0246.enc)
Provides:       tex(ipxt1-u0247.enc)
Provides:       tex(ipxt1-u0248.enc)
Provides:       tex(ipxt1-u024a.enc)
Provides:       tex(ipxt1-u024b.enc)
Provides:       tex(ipxt1-u024c.enc)
Provides:       tex(ipxt1-u024d.enc)
Provides:       tex(ipxt1-u024e.enc)
Provides:       tex(ipxt1-u0250.enc)
Provides:       tex(ipxt1-u0251.enc)
Provides:       tex(ipxt1-u0252.enc)
Provides:       tex(ipxt1-u0254.enc)
Provides:       tex(ipxt1-u0255.enc)
Provides:       tex(ipxt1-u0257.enc)
Provides:       tex(ipxt1-u0259.enc)
Provides:       tex(ipxt1-u025a.enc)
Provides:       tex(ipxt1-u025b.enc)
Provides:       tex(ipxt1-u025c.enc)
Provides:       tex(ipxt1-u025d.enc)
Provides:       tex(ipxt1-u025e.enc)
Provides:       tex(ipxt1-u025f.enc)
Provides:       tex(ipxt1-u0260.enc)
Provides:       tex(ipxt1-u0262.enc)
Provides:       tex(ipxt1-u0263.enc)
Provides:       tex(ipxt1-u0264.enc)
Provides:       tex(ipxt1-u0266.enc)
Provides:       tex(ipxt1-u0267.enc)
Provides:       tex(ipxt1-u0268.enc)
Provides:       tex(ipxt1-u0269.enc)
Provides:       tex(ipxt1-u026a.enc)
Provides:       tex(ipxt1-u026c.enc)
Provides:       tex(ipxt1-u026e.enc)
Provides:       tex(ipxt1-u026f.enc)
Provides:       tex(ipxt1-u0270.enc)
Provides:       tex(ipxt1-u0271.enc)
Provides:       tex(ipxt1-u0273.enc)
Provides:       tex(ipxt1-u0274.enc)
Provides:       tex(ipxt1-u0276.enc)
Provides:       tex(ipxt1-u0277.enc)
Provides:       tex(ipxt1-u0279.enc)
Provides:       tex(ipxt1-u027a.enc)
Provides:       tex(ipxt1-u027b.enc)
Provides:       tex(ipxt1-u027c.enc)
Provides:       tex(ipxt1-u027d.enc)
Provides:       tex(ipxt1-u027e.enc)
Provides:       tex(ipxt1-u027f.enc)
Provides:       tex(ipxt1-u0280.enc)
Provides:       tex(ipxt1-u0282.enc)
Provides:       tex(ipxt1-u0283.enc)
Provides:       tex(ipxt1-u0284.enc)
Provides:       tex(ipxt1-u0285.enc)
Provides:       tex(ipxt1-u0286.enc)
Provides:       tex(ipxt1-u0289.enc)
Provides:       tex(ipxt1-u028a.enc)
Provides:       tex(ipxt1-u028b.enc)
Provides:       tex(ipxt1-u028d.enc)
Provides:       tex(ipxt1-u028e.enc)
Provides:       tex(ipxt1-u028f.enc)
Provides:       tex(ipxt1-u0292.enc)
Provides:       tex(ipxt1-u0294.enc)
Provides:       tex(ipxt1-u0295.enc)
Provides:       tex(ipxt1-u0296.enc)
Provides:       tex(ipxt1-u0297.enc)
Provides:       tex(ipxt1-u0298.enc)
Provides:       tex(ipxt1-u029a.enc)
Provides:       tex(ipxt1-u029d.enc)
Provides:       tex(ipxt1-u029e.enc)
Provides:       tex(ipxt1-u029f.enc)
Provides:       tex(ipxt1-u02a0.enc)
Provides:       tex(ipxt1-u02a1.enc)
Provides:       tex(ipxt1-u02a3.enc)
Provides:       tex(ipxt1-u02a4.enc)
Provides:       tex(ipxt1-u02a5.enc)
Provides:       tex(ipxt1-u02a6.enc)
Provides:       tex(ipxt1-u02f8.enc)
Provides:       tex(ipxt1-u03.enc)
Provides:       tex(ipxt1-u04.enc)
Provides:       tex(ipxt1-u1e.enc)
Provides:       tex(ipxt1-u1f.enc)
Provides:       tex(ipxt1-u20.enc)
Provides:       tex(ipxt1-u21.enc)
Provides:       tex(ipxt1-u22.enc)
Provides:       tex(ipxt1-u23.enc)
Provides:       tex(ipxt1-u24.enc)
Provides:       tex(ipxt1-u25.enc)
Provides:       tex(ipxt1-u26.enc)
Provides:       tex(ipxt1-u27.enc)
Provides:       tex(ipxt1-u29.enc)
Provides:       tex(ipxt1-u2e.enc)
Provides:       tex(ipxt1-u2f.enc)
Provides:       tex(ipxt1-u30.enc)
Provides:       tex(ipxt1-u31.enc)
Provides:       tex(ipxt1-u32.enc)
Provides:       tex(ipxt1-u33.enc)
Provides:       tex(ipxt1-u34.enc)
Provides:       tex(ipxt1-u35.enc)
Provides:       tex(ipxt1-u36.enc)
Provides:       tex(ipxt1-u37.enc)
Provides:       tex(ipxt1-u38.enc)
Provides:       tex(ipxt1-u39.enc)
Provides:       tex(ipxt1-u3a.enc)
Provides:       tex(ipxt1-u3b.enc)
Provides:       tex(ipxt1-u3c.enc)
Provides:       tex(ipxt1-u3d.enc)
Provides:       tex(ipxt1-u3e.enc)
Provides:       tex(ipxt1-u3f.enc)
Provides:       tex(ipxt1-u40.enc)
Provides:       tex(ipxt1-u41.enc)
Provides:       tex(ipxt1-u42.enc)
Provides:       tex(ipxt1-u43.enc)
Provides:       tex(ipxt1-u44.enc)
Provides:       tex(ipxt1-u45.enc)
Provides:       tex(ipxt1-u46.enc)
Provides:       tex(ipxt1-u47.enc)
Provides:       tex(ipxt1-u48.enc)
Provides:       tex(ipxt1-u49.enc)
Provides:       tex(ipxt1-u4a.enc)
Provides:       tex(ipxt1-u4b.enc)
Provides:       tex(ipxt1-u4c.enc)
Provides:       tex(ipxt1-u4d.enc)
Provides:       tex(ipxt1-u4e.enc)
Provides:       tex(ipxt1-u4f.enc)
Provides:       tex(ipxt1-u50.enc)
Provides:       tex(ipxt1-u51.enc)
Provides:       tex(ipxt1-u52.enc)
Provides:       tex(ipxt1-u53.enc)
Provides:       tex(ipxt1-u54.enc)
Provides:       tex(ipxt1-u55.enc)
Provides:       tex(ipxt1-u56.enc)
Provides:       tex(ipxt1-u57.enc)
Provides:       tex(ipxt1-u58.enc)
Provides:       tex(ipxt1-u59.enc)
Provides:       tex(ipxt1-u5a.enc)
Provides:       tex(ipxt1-u5b.enc)
Provides:       tex(ipxt1-u5c.enc)
Provides:       tex(ipxt1-u5d.enc)
Provides:       tex(ipxt1-u5e.enc)
Provides:       tex(ipxt1-u5f.enc)
Provides:       tex(ipxt1-u60.enc)
Provides:       tex(ipxt1-u61.enc)
Provides:       tex(ipxt1-u62.enc)
Provides:       tex(ipxt1-u63.enc)
Provides:       tex(ipxt1-u64.enc)
Provides:       tex(ipxt1-u65.enc)
Provides:       tex(ipxt1-u66.enc)
Provides:       tex(ipxt1-u67.enc)
Provides:       tex(ipxt1-u68.enc)
Provides:       tex(ipxt1-u69.enc)
Provides:       tex(ipxt1-u6a.enc)
Provides:       tex(ipxt1-u6b.enc)
Provides:       tex(ipxt1-u6c.enc)
Provides:       tex(ipxt1-u6d.enc)
Provides:       tex(ipxt1-u6e.enc)
Provides:       tex(ipxt1-u6f.enc)
Provides:       tex(ipxt1-u70.enc)
Provides:       tex(ipxt1-u71.enc)
Provides:       tex(ipxt1-u72.enc)
Provides:       tex(ipxt1-u73.enc)
Provides:       tex(ipxt1-u74.enc)
Provides:       tex(ipxt1-u75.enc)
Provides:       tex(ipxt1-u76.enc)
Provides:       tex(ipxt1-u77.enc)
Provides:       tex(ipxt1-u78.enc)
Provides:       tex(ipxt1-u79.enc)
Provides:       tex(ipxt1-u7a.enc)
Provides:       tex(ipxt1-u7b.enc)
Provides:       tex(ipxt1-u7c.enc)
Provides:       tex(ipxt1-u7d.enc)
Provides:       tex(ipxt1-u7e.enc)
Provides:       tex(ipxt1-u7f.enc)
Provides:       tex(ipxt1-u80.enc)
Provides:       tex(ipxt1-u81.enc)
Provides:       tex(ipxt1-u82.enc)
Provides:       tex(ipxt1-u83.enc)
Provides:       tex(ipxt1-u84.enc)
Provides:       tex(ipxt1-u85.enc)
Provides:       tex(ipxt1-u86.enc)
Provides:       tex(ipxt1-u87.enc)
Provides:       tex(ipxt1-u88.enc)
Provides:       tex(ipxt1-u89.enc)
Provides:       tex(ipxt1-u8a.enc)
Provides:       tex(ipxt1-u8b.enc)
Provides:       tex(ipxt1-u8c.enc)
Provides:       tex(ipxt1-u8d.enc)
Provides:       tex(ipxt1-u8e.enc)
Provides:       tex(ipxt1-u8f.enc)
Provides:       tex(ipxt1-u90.enc)
Provides:       tex(ipxt1-u91.enc)
Provides:       tex(ipxt1-u92.enc)
Provides:       tex(ipxt1-u93.enc)
Provides:       tex(ipxt1-u94.enc)
Provides:       tex(ipxt1-u95.enc)
Provides:       tex(ipxt1-u96.enc)
Provides:       tex(ipxt1-u97.enc)
Provides:       tex(ipxt1-u98.enc)
Provides:       tex(ipxt1-u99.enc)
Provides:       tex(ipxt1-u9a.enc)
Provides:       tex(ipxt1-u9b.enc)
Provides:       tex(ipxt1-u9c.enc)
Provides:       tex(ipxt1-u9d.enc)
Provides:       tex(ipxt1-u9e.enc)
Provides:       tex(ipxt1-u9f.enc)
Provides:       tex(ipxt1-uf0.enc)
Provides:       tex(ipxt1-uf8.enc)
Provides:       tex(ipxt1-uf9.enc)
Provides:       tex(ipxt1-ufa.enc)
Provides:       tex(ipxt1-ufe.enc)
Provides:       tex(ipxt1-uff.enc)
Provides:       tex(ly1ipxg.fd)
Provides:       tex(ly1ipxm.fd)
Provides:       tex(ot1ipxg.fd)
Provides:       tex(ot1ipxm.fd)
Provides:       tex(t1ipxg.fd)
Provides:       tex(t1ipxm.fd)
Provides:       tex(ts1ipxg.fd)
Provides:       tex(ts1ipxm.fd)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source7:        ipaex-type1.tar.xz
Source8:        ipaex-type1.doc.tar.xz

%description -n texlive-ipaex-type1
The package contains the IPAex Fonts converted into Unicode
subfonts in Type1 format, which is most suitable for use with
the CJK package. Font conversion was done with ttf2pt1.

%package -n texlive-ipaex-type1-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5svn47700
Release:        0
Summary:        Documentation for texlive-ipaex-type1
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ipaex-type1 and texlive-alldocumentation)
Provides:       locale(texlive-ipaex-type1-doc:ja;en)

%description -n texlive-ipaex-type1-doc
This package includes the documentation for texlive-ipaex-type1

%package -n texlive-ipaex-type1-fonts
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5svn47700
Release:        0
Summary:        Severed fonts for texlive-ipaex-type1
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-ipaex-type1-fonts
The  separated fonts package for texlive-ipaex-type1

%post -n texlive-ipaex-type1
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap ipaex-type1.map' >> /var/run/texlive/run-updmap

%postun -n texlive-ipaex-type1
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap ipaex-type1.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-ipaex-type1
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-ipaex-type1-fonts

%files -n texlive-ipaex-type1-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/ipaex-type1/LICENSE
%{_texmfdistdir}/doc/fonts/ipaex-type1/README-ja.md
%{_texmfdistdir}/doc/fonts/ipaex-type1/README.md
%{_texmfdistdir}/doc/fonts/ipaex-type1/sample-ipaex-type1.pdf
%{_texmfdistdir}/doc/fonts/ipaex-type1/sample-ipaex-type1.tex

%files -n texlive-ipaex-type1
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-ly1.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-ot1.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-t1.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-ts1.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u00.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u01.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0200.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0201.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0202.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0203.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0204.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0205.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0206.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0207.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0208.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0209.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u020a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u020b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u020d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u020e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u020f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0212.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0213.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0214.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0215.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0216.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0217.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0218.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0219.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u021c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u021d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u021e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u021f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0221.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0222.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0223.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0226.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0228.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0229.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u022a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u022b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u022c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u022d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0231.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0233.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0234.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0235.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0236.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0237.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0238.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u023a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u023c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u023d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u023f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0240.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0241.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0243.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0246.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0247.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0248.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u024a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u024b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u024c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u024d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u024e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0250.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0251.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0252.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0254.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0255.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0257.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0259.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u025f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0260.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0262.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0263.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0264.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0266.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0267.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0268.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0269.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u026a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u026c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u026e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u026f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0270.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0271.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0273.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0274.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0276.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0277.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0279.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u027f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0280.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0282.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0283.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0284.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0285.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0286.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0289.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u028a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u028b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u028d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u028e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u028f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0292.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0294.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0295.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0296.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0297.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u0298.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u029a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u029d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u029e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u029f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a0.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a1.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a3.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a4.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a5.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02a6.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u02f8.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u03.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u04.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u1e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u1f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u20.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u21.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u22.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u23.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u24.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u25.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u26.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u27.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u29.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u2e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u2f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u30.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u31.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u32.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u33.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u34.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u35.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u36.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u37.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u38.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u39.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u3f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u40.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u41.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u42.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u43.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u44.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u45.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u46.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u47.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u48.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u49.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u4f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u50.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u51.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u52.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u53.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u54.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u55.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u56.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u57.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u58.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u59.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u5f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u60.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u61.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u62.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u63.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u64.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u65.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u66.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u67.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u68.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u69.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u6f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u70.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u71.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u72.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u73.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u74.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u75.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u76.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u77.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u78.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u79.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u7f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u80.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u81.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u82.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u83.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u84.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u85.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u86.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u87.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u88.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u89.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u8f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u90.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u91.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u92.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u93.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u94.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u95.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u96.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u97.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u98.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u99.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9a.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9b.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9c.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9d.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9e.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-u9f.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-uf0.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-uf8.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-uf9.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-ufa.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-ufe.enc
%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1/ipxt1-uff.enc
%{_texmfdistdir}/fonts/map/dvips/ipaex-type1/ipaex-type1.map
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u00.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u01.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0200.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0201.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0202.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0203.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0204.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0205.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0206.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0207.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0208.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0209.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u020a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u020b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u020d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u020e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u020f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0212.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0213.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0214.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0215.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0216.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0217.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0218.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0219.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u021c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u021d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u021e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u021f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0221.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0222.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0223.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0226.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0228.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0229.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u022a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u022b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u022c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u022d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0231.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0233.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0234.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0235.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0236.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0237.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0238.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u023a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u023c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u023d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u023f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0240.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0241.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0243.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0246.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0247.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0248.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u024a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u024b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u024c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u024d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u024e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0250.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0251.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0252.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0254.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0255.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0257.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0259.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u025f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0260.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0262.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0263.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0264.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0266.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0267.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0268.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0269.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u026a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u026c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u026e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u026f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0270.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0271.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0273.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0274.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0276.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0277.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0279.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u027f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0280.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0282.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0283.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0284.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0285.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0286.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0289.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u028a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u028b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u028d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u028e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u028f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0292.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0294.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0295.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0296.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0297.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u0298.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u029a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u029d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u029e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u029f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a3.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a4.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a5.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02a6.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u02f8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u03.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u04.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u1e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u1f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u20.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u21.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u22.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u23.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u24.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u25.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u26.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u27.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u29.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u2e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u2f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u30.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u31.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u32.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u33.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u34.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u35.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u36.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u37.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u38.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u39.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u3f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u40.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u41.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u42.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u43.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u44.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u45.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u46.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u47.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u48.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u49.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u4f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u50.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u51.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u52.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u53.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u54.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u55.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u56.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u57.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u58.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u59.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u5f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u60.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u61.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u62.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u63.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u64.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u65.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u66.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u67.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u68.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u69.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u6f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u70.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u71.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u72.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u73.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u74.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u75.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u76.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u77.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u78.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u79.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u7f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u80.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u81.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u82.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u83.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u84.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u85.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u86.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u87.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u88.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u89.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u8f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u90.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u91.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u92.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u93.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u94.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u95.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u96.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u97.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u98.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u99.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-u9f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-uf0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-uf8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-uf9.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-ufa.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-ufe.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-r-uff.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u00.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u01.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0200.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0201.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0202.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0203.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0204.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0205.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0206.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0207.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0208.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0209.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u020a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u020b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u020d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u020e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u020f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0212.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0213.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0214.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0215.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0216.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0217.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0218.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0219.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u021c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u021d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u021e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u021f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0221.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0222.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0223.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0226.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0228.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0229.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u022a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u022b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u022c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u022d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0231.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0233.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0234.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0235.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0236.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0237.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0238.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u023a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u023c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u023d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u023f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0240.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0241.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0243.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0246.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0247.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0248.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u024a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u024b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u024c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u024d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u024e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0250.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0251.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0252.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0254.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0255.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0257.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0259.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u025f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0260.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0262.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0263.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0264.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0266.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0267.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0268.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0269.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u026a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u026c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u026e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u026f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0270.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0271.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0273.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0274.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0276.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0277.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0279.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u027f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0280.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0282.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0283.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0284.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0285.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0286.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0289.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u028a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u028b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u028d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u028e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u028f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0292.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0294.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0295.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0296.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0297.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u0298.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u029a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u029d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u029e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u029f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a3.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a4.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a5.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02a6.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u02f8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u03.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u04.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u1e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u1f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u20.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u21.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u22.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u23.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u24.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u25.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u26.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u27.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u29.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u2e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u2f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u30.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u31.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u32.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u33.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u34.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u35.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u36.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u37.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u38.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u39.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u3f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u40.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u41.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u42.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u43.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u44.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u45.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u46.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u47.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u48.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u49.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u4f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u50.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u51.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u52.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u53.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u54.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u55.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u56.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u57.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u58.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u59.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u5f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u60.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u61.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u62.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u63.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u64.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u65.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u66.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u67.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u68.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u69.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u6f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u70.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u71.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u72.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u73.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u74.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u75.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u76.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u77.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u78.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u79.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u7f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u80.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u81.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u82.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u83.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u84.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u85.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u86.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u87.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u88.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u89.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u8f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u90.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u91.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u92.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u93.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u94.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u95.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u96.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u97.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u98.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u99.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-u9f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-uf8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-uf9.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-ufa.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-ufe.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxg-ro-uff.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u00.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u01.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0200.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0201.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0202.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0203.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0204.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0205.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0206.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0207.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0208.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0209.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u020a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u020b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u020d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u020e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u020f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0212.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0213.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0214.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0215.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0216.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0217.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0218.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0219.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u021c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u021d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u021e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u021f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0221.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0222.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0223.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0226.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0228.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0229.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u022a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u022b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u022c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u022d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0231.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0233.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0234.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0235.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0236.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0237.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0238.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u023a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u023c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u023d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u023f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0240.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0241.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0243.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0246.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0247.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0248.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u024a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u024b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u024c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u024d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u024e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0250.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0251.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0252.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0254.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0255.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0257.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0259.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u025f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0260.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0262.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0263.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0264.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0266.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0267.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0268.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0269.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u026a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u026c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u026e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u026f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0270.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0271.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0273.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0274.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0276.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0277.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0279.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u027f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0280.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0282.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0283.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0284.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0285.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0286.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0289.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u028a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u028b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u028d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u028e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u028f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0292.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0294.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0295.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0296.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0297.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u0298.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u029a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u029d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u029e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u029f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a3.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a4.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a5.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02a6.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u02f8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u03.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u04.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u1e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u1f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u20.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u21.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u22.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u23.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u24.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u25.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u26.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u27.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u29.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u2e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u2f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u30.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u31.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u32.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u33.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u34.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u35.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u36.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u37.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u38.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u39.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u3f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u40.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u41.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u42.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u43.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u44.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u45.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u46.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u47.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u48.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u49.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u4f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u50.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u51.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u52.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u53.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u54.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u55.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u56.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u57.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u58.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u59.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u5f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u60.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u61.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u62.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u63.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u64.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u65.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u66.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u67.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u68.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u69.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u6f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u70.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u71.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u72.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u73.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u74.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u75.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u76.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u77.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u78.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u79.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u7f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u80.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u81.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u82.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u83.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u84.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u85.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u86.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u87.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u88.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u89.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u8f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u90.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u91.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u92.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u93.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u94.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u95.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u96.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u97.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u98.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u99.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-u9f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-uf0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-uf8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-uf9.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-ufa.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-ufe.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-r-uff.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u00.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u01.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0200.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0201.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0202.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0203.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0204.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0205.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0206.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0207.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0208.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0209.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u020a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u020b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u020d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u020e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u020f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0212.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0213.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0214.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0215.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0216.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0217.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0218.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0219.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u021c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u021d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u021e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u021f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0221.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0222.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0223.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0226.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0228.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0229.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u022a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u022b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u022c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u022d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0231.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0233.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0234.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0235.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0236.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0237.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0238.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u023a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u023c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u023d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u023f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0240.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0241.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0243.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0246.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0247.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0248.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u024a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u024b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u024c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u024d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u024e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0250.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0251.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0252.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0254.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0255.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0257.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0259.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u025f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0260.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0262.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0263.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0264.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0266.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0267.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0268.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0269.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u026a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u026c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u026e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u026f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0270.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0271.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0273.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0274.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0276.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0277.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0279.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u027f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0280.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0282.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0283.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0284.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0285.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0286.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0289.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u028a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u028b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u028d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u028e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u028f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0292.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0294.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0295.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0296.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0297.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u0298.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u029a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u029d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u029e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u029f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a0.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a1.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a3.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a4.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a5.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02a6.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u02f8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u03.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u04.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u1e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u1f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u20.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u21.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u22.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u23.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u24.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u25.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u26.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u27.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u29.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u2e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u2f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u30.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u31.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u32.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u33.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u34.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u35.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u36.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u37.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u38.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u39.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u3f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u40.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u41.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u42.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u43.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u44.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u45.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u46.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u47.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u48.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u49.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u4f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u50.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u51.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u52.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u53.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u54.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u55.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u56.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u57.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u58.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u59.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u5f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u60.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u61.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u62.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u63.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u64.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u65.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u66.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u67.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u68.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u69.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u6f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u70.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u71.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u72.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u73.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u74.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u75.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u76.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u77.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u78.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u79.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u7f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u80.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u81.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u82.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u83.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u84.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u85.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u86.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u87.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u88.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u89.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u8f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u90.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u91.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u92.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u93.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u94.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u95.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u96.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u97.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u98.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u99.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9a.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9b.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9c.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9d.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9e.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-u9f.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-uf8.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-uf9.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-ufa.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-ufe.tfm
%{_texmfdistdir}/fonts/tfm/public/ipaex-type1/ipxm-ro-uff.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-ly1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-ot1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-t1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-ts1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u00.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u01.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0200.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0201.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0202.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0203.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0204.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0205.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0206.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0207.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0208.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0209.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u020a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u020b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u020d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u020e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u020f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0212.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0213.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0214.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0215.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0216.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0217.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0218.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0219.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u021c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u021d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u021e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u021f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0221.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0222.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0223.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0226.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0228.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0229.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u022a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u022b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u022c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u022d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0231.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0233.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0234.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0235.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0236.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0237.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0238.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u023a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u023c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u023d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u023f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0240.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0241.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0243.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0246.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0247.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0248.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u024a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u024b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u024c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u024d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u024e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0250.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0251.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0252.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0254.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0255.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0257.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0259.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u025f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0260.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0262.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0263.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0264.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0266.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0267.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0268.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0269.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u026a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u026c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u026e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u026f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0270.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0271.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0273.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0274.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0276.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0277.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0279.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u027f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0280.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0282.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0283.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0284.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0285.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0286.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0289.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u028a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u028b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u028d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u028e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u028f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0292.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0294.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0295.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0296.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0297.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u0298.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u029a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u029d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u029e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u029f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a0.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a3.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a4.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a5.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02a6.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u02f8.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u03.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u04.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u1e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u1f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u20.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u21.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u22.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u23.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u24.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u25.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u26.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u27.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u29.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u2e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u2f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u30.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u31.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u32.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u33.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u34.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u35.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u36.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u37.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u38.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u39.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u3f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u40.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u41.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u42.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u43.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u44.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u45.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u46.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u47.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u48.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u49.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u4f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u50.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u51.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u52.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u53.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u54.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u55.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u56.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u57.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u58.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u59.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u5f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u60.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u61.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u62.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u63.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u64.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u65.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u66.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u67.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u68.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u69.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u6f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u70.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u71.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u72.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u73.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u74.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u75.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u76.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u77.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u78.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u79.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u7f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u80.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u81.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u82.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u83.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u84.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u85.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u86.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u87.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u88.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u89.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u8f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u90.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u91.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u92.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u93.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u94.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u95.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u96.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u97.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u98.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u99.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-u9f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-uf0.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-uf8.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-uf9.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-ufa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-ufe.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxg-r-uff.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-ly1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-ot1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-t1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-ts1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u00.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u01.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0200.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0201.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0202.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0203.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0204.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0205.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0206.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0207.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0208.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0209.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u020a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u020b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u020d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u020e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u020f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0212.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0213.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0214.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0215.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0216.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0217.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0218.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0219.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u021c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u021d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u021e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u021f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0221.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0222.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0223.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0226.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0228.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0229.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u022a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u022b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u022c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u022d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0231.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0233.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0234.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0235.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0236.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0237.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0238.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u023a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u023c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u023d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u023f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0240.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0241.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0243.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0246.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0247.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0248.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u024a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u024b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u024c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u024d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u024e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0250.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0251.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0252.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0254.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0255.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0257.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0259.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u025f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0260.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0262.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0263.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0264.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0266.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0267.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0268.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0269.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u026a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u026c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u026e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u026f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0270.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0271.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0273.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0274.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0276.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0277.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0279.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u027f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0280.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0282.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0283.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0284.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0285.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0286.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0289.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u028a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u028b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u028d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u028e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u028f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0292.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0294.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0295.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0296.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0297.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u0298.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u029a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u029d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u029e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u029f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a0.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a1.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a3.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a4.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a5.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02a6.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u02f8.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u03.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u04.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u1e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u1f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u20.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u21.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u22.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u23.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u24.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u25.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u26.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u27.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u29.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u2e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u2f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u30.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u31.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u32.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u33.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u34.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u35.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u36.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u37.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u38.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u39.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u3f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u40.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u41.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u42.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u43.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u44.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u45.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u46.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u47.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u48.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u49.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u4f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u50.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u51.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u52.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u53.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u54.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u55.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u56.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u57.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u58.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u59.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u5f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u60.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u61.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u62.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u63.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u64.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u65.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u66.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u67.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u68.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u69.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u6f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u70.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u71.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u72.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u73.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u74.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u75.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u76.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u77.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u78.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u79.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u7f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u80.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u81.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u82.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u83.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u84.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u85.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u86.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u87.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u88.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u89.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u8f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u90.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u91.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u92.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u93.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u94.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u95.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u96.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u97.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u98.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u99.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9b.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9c.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9d.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9e.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-u9f.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-uf0.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-uf8.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-uf9.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-ufa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-ufe.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/ipaex-type1/ipxm-r-uff.pfb
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxg.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxg.fdx
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxga.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxga.fdx
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxm.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxm.fdx
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxma.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/c70ipxma.fdx
%{_texmfdistdir}/tex/latex/ipaex-type1/ipaex-type1.sty
%{_texmfdistdir}/tex/latex/ipaex-type1/ly1ipxg.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/ly1ipxm.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/ot1ipxg.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/ot1ipxm.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/t1ipxg.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/t1ipxm.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/ts1ipxg.fd
%{_texmfdistdir}/tex/latex/ipaex-type1/ts1ipxm.fd

%files -n texlive-ipaex-type1-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-ipaex-type1
%{_datadir}/fontconfig/conf.avail/58-texlive-ipaex-type1.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex-type1/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex-type1/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-ipaex-type1/fonts.scale
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-ly1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-ot1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-t1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-ts1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u00.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u01.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0200.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0201.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0202.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0203.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0204.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0205.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0206.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0207.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0208.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0209.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u020a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u020b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u020d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u020e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u020f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0212.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0213.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0214.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0215.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0216.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0217.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0218.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0219.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u021c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u021d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u021e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u021f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0221.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0222.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0223.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0226.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0228.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0229.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u022a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u022b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u022c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u022d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0231.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0233.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0234.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0235.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0236.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0237.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0238.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u023a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u023c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u023d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u023f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0240.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0241.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0243.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0246.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0247.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0248.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u024a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u024b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u024c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u024d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u024e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0250.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0251.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0252.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0254.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0255.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0257.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0259.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u025f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0260.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0262.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0263.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0264.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0266.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0267.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0268.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0269.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u026a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u026c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u026e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u026f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0270.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0271.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0273.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0274.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0276.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0277.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0279.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u027f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0280.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0282.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0283.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0284.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0285.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0286.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0289.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u028a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u028b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u028d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u028e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u028f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0292.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0294.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0295.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0296.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0297.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u0298.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u029a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u029d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u029e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u029f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a0.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a3.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a4.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a5.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02a6.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u02f8.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u03.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u04.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u1e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u1f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u20.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u21.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u22.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u23.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u24.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u25.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u26.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u27.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u29.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u2e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u2f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u30.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u31.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u32.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u33.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u34.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u35.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u36.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u37.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u38.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u39.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u3f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u40.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u41.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u42.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u43.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u44.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u45.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u46.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u47.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u48.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u49.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u4f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u50.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u51.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u52.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u53.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u54.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u55.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u56.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u57.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u58.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u59.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u5f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u60.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u61.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u62.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u63.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u64.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u65.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u66.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u67.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u68.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u69.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u6f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u70.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u71.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u72.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u73.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u74.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u75.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u76.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u77.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u78.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u79.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u7f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u80.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u81.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u82.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u83.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u84.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u85.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u86.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u87.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u88.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u89.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u8f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u90.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u91.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u92.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u93.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u94.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u95.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u96.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u97.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u98.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u99.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-u9f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-uf0.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-uf8.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-uf9.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-ufa.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-ufe.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxg-r-uff.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-ly1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-ot1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-t1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-ts1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u00.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u01.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0200.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0201.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0202.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0203.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0204.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0205.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0206.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0207.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0208.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0209.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u020a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u020b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u020d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u020e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u020f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0212.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0213.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0214.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0215.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0216.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0217.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0218.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0219.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u021c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u021d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u021e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u021f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0221.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0222.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0223.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0226.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0228.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0229.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u022a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u022b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u022c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u022d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0231.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0233.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0234.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0235.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0236.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0237.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0238.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u023a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u023c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u023d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u023f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0240.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0241.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0243.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0246.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0247.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0248.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u024a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u024b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u024c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u024d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u024e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0250.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0251.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0252.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0254.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0255.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0257.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0259.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u025f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0260.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0262.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0263.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0264.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0266.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0267.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0268.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0269.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u026a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u026c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u026e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u026f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0270.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0271.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0273.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0274.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0276.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0277.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0279.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u027f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0280.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0282.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0283.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0284.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0285.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0286.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0289.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u028a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u028b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u028d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u028e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u028f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0292.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0294.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0295.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0296.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0297.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u0298.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u029a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u029d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u029e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u029f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a0.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a1.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a3.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a4.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a5.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02a6.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u02f8.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u03.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u04.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u1e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u1f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u20.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u21.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u22.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u23.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u24.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u25.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u26.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u27.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u29.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u2e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u2f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u30.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u31.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u32.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u33.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u34.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u35.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u36.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u37.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u38.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u39.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u3f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u40.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u41.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u42.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u43.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u44.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u45.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u46.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u47.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u48.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u49.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u4f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u50.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u51.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u52.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u53.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u54.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u55.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u56.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u57.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u58.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u59.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u5f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u60.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u61.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u62.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u63.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u64.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u65.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u66.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u67.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u68.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u69.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u6f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u70.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u71.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u72.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u73.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u74.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u75.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u76.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u77.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u78.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u79.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u7f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u80.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u81.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u82.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u83.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u84.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u85.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u86.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u87.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u88.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u89.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u8f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u90.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u91.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u92.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u93.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u94.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u95.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u96.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u97.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u98.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u99.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9a.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9b.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9c.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9d.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9e.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-u9f.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-uf0.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-uf8.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-uf9.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-ufa.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-ufe.pfb
%{_datadir}/fonts/texlive-ipaex-type1/ipxm-r-uff.pfb

%package -n texlive-is-bst
Version:        %{texlive_version}.%{texlive_noarch}.2.03svn52623
Release:        0
License:        LPPL-1.0
Summary:        Extended versions of standard BibTeX styles
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-is-bst-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source9:        is-bst.tar.xz
Source10:       is-bst.doc.tar.xz

%description -n texlive-is-bst
The bundle contains an extended version (xbtxbst.doc) of the
source of the standard BibTeX styles, together with
corresponding versions of the standard styles. The styles offer
support for CODEN, ISBN, ISSN, LCCN, and PRICE fields, extended
PAGES fields, the PERIODICAL entry, and extended citation label
suffixing.

%package -n texlive-is-bst-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.03svn52623
Release:        0
Summary:        Documentation for texlive-is-bst
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-is-bst and texlive-alldocumentation)

%description -n texlive-is-bst-doc
This package includes the documentation for texlive-is-bst

%post -n texlive-is-bst
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-is-bst
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-is-bst
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-is-bst-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/bibtex/is-bst/xbtxbst.doc

%files -n texlive-is-bst
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/is-bst/is-abbrv.bst
%{_texmfdistdir}/bibtex/bst/is-bst/is-alpha.bst
%{_texmfdistdir}/bibtex/bst/is-bst/is-plain.bst
%{_texmfdistdir}/bibtex/bst/is-bst/is-unsrt.bst

%package -n texlive-iscram
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn45801
Release:        0
License:        LPPL-1.0
Summary:        A LaTeX class to publish article to ISCRAM conferences
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-iscram-doc >= %{texlive_version}
Provides:       tex(iscram.cls)
Requires:       tex(article.cls)
Requires:       tex(booktabs.sty)
Requires:       tex(caption.sty)
Requires:       tex(etex.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(float.sty)
Requires:       tex(microtype.sty)
Requires:       tex(newtxmath.sty)
Requires:       tex(newtxtext.sty)
Requires:       tex(nowidow.sty)
Requires:       tex(pgfopts.sty)
Requires:       tex(titlesec.sty)
Requires:       tex(url.sty)
Requires:       tex(xcolor.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source11:       iscram.tar.xz
Source12:       iscram.doc.tar.xz

%description -n texlive-iscram
LaTeX class to publish article to ISCRAM (International
Conference on Information Systems for Crisis Response and
Management).

%package -n texlive-iscram-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn45801
Release:        0
Summary:        Documentation for texlive-iscram
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iscram and texlive-alldocumentation)

%description -n texlive-iscram-doc
This package includes the documentation for texlive-iscram

%post -n texlive-iscram
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-iscram
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-iscram
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-iscram-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/iscram/HMI.pdf
%{_texmfdistdir}/doc/latex/iscram/README
%{_texmfdistdir}/doc/latex/iscram/iscram-class-doc.bib
%{_texmfdistdir}/doc/latex/iscram/iscram-class-doc.pdf
%{_texmfdistdir}/doc/latex/iscram/iscram-class-doc.tex

%files -n texlive-iscram
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/iscram/iscram.cls

%package -n texlive-iso
Version:        %{texlive_version}.%{texlive_noarch}.2.4svn15878
Release:        0
License:        LPPL-1.0
Summary:        Generic ISO standards typesetting macros
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-iso-doc >= %{texlive_version}
Provides:       tex(askincv1.sty)
Provides:       tex(iso10.clo)
Provides:       tex(iso11.clo)
Provides:       tex(iso9.clo)
Provides:       tex(isov2.cls)
Requires:       tex(url.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source13:       iso.tar.xz
Source14:       iso.doc.tar.xz

%description -n texlive-iso
Generic class and package files for typesetting ISO
International Standard documents. Several standard documents
have been printed by ISO from camera-ready copy prepared using
LaTeX and these files. The class makes use of the isorot
package, rather than use other mechanisms directly.

%package -n texlive-iso-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.4svn15878
Release:        0
Summary:        Documentation for texlive-iso
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iso and texlive-alldocumentation)

%description -n texlive-iso-doc
This package includes the documentation for texlive-iso

%post -n texlive-iso
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-iso
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-iso
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-iso-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/iso/README
%{_texmfdistdir}/doc/latex/iso/iso4ht.pdf
%{_texmfdistdir}/doc/latex/iso/isoe.pdf
%{_texmfdistdir}/doc/latex/iso/isofwdbp.tex
%{_texmfdistdir}/doc/latex/iso/isoman.pdf
%{_texmfdistdir}/doc/latex/iso/isoman.tex
%{_texmfdistdir}/doc/latex/iso/trfwd1.tex
%{_texmfdistdir}/doc/latex/iso/tspasfwdbp.tex

%files -n texlive-iso
%defattr(-,root,root,755)
%{_texmfdistdir}/makeindex/iso/iso.ist
%{_texmfdistdir}/tex/latex/iso/askincv1.sty
%{_texmfdistdir}/tex/latex/iso/iso10.clo
%{_texmfdistdir}/tex/latex/iso/iso11.clo
%{_texmfdistdir}/tex/latex/iso/iso9.clo
%{_texmfdistdir}/tex/latex/iso/isov2.4ht
%{_texmfdistdir}/tex/latex/iso/isov2.cls

%package -n texlive-iso10303
Version:        %{texlive_version}.%{texlive_noarch}.1.5svn15878
Release:        0
License:        LPPL-1.0
Summary:        Typesetting the STEP standards
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-iso10303-doc >= %{texlive_version}
Provides:       tex(aicv1.sty)
Provides:       tex(apendint.tex)
Provides:       tex(apmpspec.tex)
Provides:       tex(apmptbl.tex)
Provides:       tex(apmptempl.tex)
Provides:       tex(apsstempl.tex)
Provides:       tex(apv12.sty)
Provides:       tex(atsv11.sty)
Provides:       tex(bpfap1.tex)
Provides:       tex(bpfap10.tex)
Provides:       tex(bpfap11.tex)
Provides:       tex(bpfap12.tex)
Provides:       tex(bpfap13.tex)
Provides:       tex(bpfap14.tex)
Provides:       tex(bpfap15.tex)
Provides:       tex(bpfap16.tex)
Provides:       tex(bpfap2.tex)
Provides:       tex(bpfap3.tex)
Provides:       tex(bpfap4.tex)
Provides:       tex(bpfap5.tex)
Provides:       tex(bpfap6.tex)
Provides:       tex(bpfap7.tex)
Provides:       tex(bpfap8.tex)
Provides:       tex(bpfap9.tex)
Provides:       tex(bpfats1.tex)
Provides:       tex(bpfats10.tex)
Provides:       tex(bpfats11.tex)
Provides:       tex(bpfats12.tex)
Provides:       tex(bpfats14.tex)
Provides:       tex(bpfats2.tex)
Provides:       tex(bpfats3.tex)
Provides:       tex(bpfats4.tex)
Provides:       tex(bpfats5.tex)
Provides:       tex(bpfats6.tex)
Provides:       tex(bpfats7.tex)
Provides:       tex(bpfats8.tex)
Provides:       tex(bpfats9.tex)
Provides:       tex(bpfir1.tex)
Provides:       tex(bpfir2.tex)
Provides:       tex(bpfir3.tex)
Provides:       tex(bpfs1.tex)
Provides:       tex(bpfs2.tex)
Provides:       tex(bpfs3.tex)
Provides:       tex(irv12.sty)
Provides:       tex(stepman.tex)
Provides:       tex(stepv13.sty)
Provides:       tex(stppdlst.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source15:       iso10303.tar.xz
Source16:       iso10303.doc.tar.xz

%description -n texlive-iso10303
Class and package files building on iso for typesetting the ISO
10303 (STEP) standards. Standard documents prepared using these
packages have been published by ISO.

%package -n texlive-iso10303-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.5svn15878
Release:        0
Summary:        Documentation for texlive-iso10303
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iso10303 and texlive-alldocumentation)

%description -n texlive-iso10303-doc
This package includes the documentation for texlive-iso10303

%post -n texlive-iso10303
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-iso10303
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-iso10303
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-iso10303-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/iso10303/README
%{_texmfdistdir}/doc/latex/iso10303/step4ht.pdf
%{_texmfdistdir}/doc/latex/iso10303/stepe.pdf
%{_texmfdistdir}/doc/latex/iso10303/stepman.pdf

%files -n texlive-iso10303
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/iso10303/aicv1.sty
%{_texmfdistdir}/tex/latex/iso10303/apendint.tex
%{_texmfdistdir}/tex/latex/iso10303/apmpspec.tex
%{_texmfdistdir}/tex/latex/iso10303/apmptbl.tex
%{_texmfdistdir}/tex/latex/iso10303/apmptempl.tex
%{_texmfdistdir}/tex/latex/iso10303/apsstempl.tex
%{_texmfdistdir}/tex/latex/iso10303/apv12.sty
%{_texmfdistdir}/tex/latex/iso10303/atsv11.sty
%{_texmfdistdir}/tex/latex/iso10303/bpfap1.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap10.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap11.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap12.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap13.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap14.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap15.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap16.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap2.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap3.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap4.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap5.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap6.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap7.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap8.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfap9.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats1.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats10.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats11.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats12.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats14.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats2.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats3.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats4.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats5.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats6.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats7.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats8.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfats9.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfir1.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfir2.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfir3.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfs1.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfs2.tex
%{_texmfdistdir}/tex/latex/iso10303/bpfs3.tex
%{_texmfdistdir}/tex/latex/iso10303/irv12.sty
%{_texmfdistdir}/tex/latex/iso10303/stepman.tex
%{_texmfdistdir}/tex/latex/iso10303/stepv13.4ht
%{_texmfdistdir}/tex/latex/iso10303/stepv13.sty
%{_texmfdistdir}/tex/latex/iso10303/stppdlst.tex

%package -n texlive-isodate
Version:        %{texlive_version}.%{texlive_noarch}.2.28svn16613
Release:        0
License:        LPPL-1.0
Summary:        Tune the output format of dates according to language
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isodate-doc >= %{texlive_version}
Provides:       tex(isodate.sty)
Provides:       tex(isodateo.sty)
Requires:       tex(calc.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(substr.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source17:       isodate.tar.xz
Source18:       isodate.doc.tar.xz

%description -n texlive-isodate
This package provides ten output formats of the commands
\today, \printdate, \printdateTeX, and \daterange (partly
language dependent). Formats available are: ISO (yyyy-mm-dd),
numeric (e.g. dd.\,mm.~yyyy), short (e.g. dd.\,mm.\,yy), TeX
(yyyy/mm/dd), original (e.g. dd. mmm yyyy), short original
(e.g. dd. mmm yy), as well as numerical formats with Roman
numerals for the month. The commands \printdate and
\printdateTeX print any date. The command \daterange prints a
date range and leaves out unnecessary year or month entries.
This package supports German (old and new rules), Austrian, US
English, British English, French, Danish, Swedish, and
Norwegian.

%package -n texlive-isodate-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.28svn16613
Release:        0
Summary:        Documentation for texlive-isodate
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isodate and texlive-alldocumentation)

%description -n texlive-isodate-doc
This package includes the documentation for texlive-isodate

%post -n texlive-isodate
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isodate
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isodate
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isodate-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isodate/ChangeLog
%{_texmfdistdir}/doc/latex/isodate/README
%{_texmfdistdir}/doc/latex/isodate/getversion.tex
%{_texmfdistdir}/doc/latex/isodate/isodate.pdf
%{_texmfdistdir}/doc/latex/isodate/isodate.xml
%{_texmfdistdir}/doc/latex/isodate/isodateo.pdf
%{_texmfdistdir}/doc/latex/isodate/testdate.pdf
%{_texmfdistdir}/doc/latex/isodate/testdate.tex
%{_texmfdistdir}/doc/latex/isodate/testisodate_without_babel.tex

%files -n texlive-isodate
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isodate/danish.idf
%{_texmfdistdir}/tex/latex/isodate/english.idf
%{_texmfdistdir}/tex/latex/isodate/french.idf
%{_texmfdistdir}/tex/latex/isodate/german.idf
%{_texmfdistdir}/tex/latex/isodate/isodate.sty
%{_texmfdistdir}/tex/latex/isodate/isodateo.sty
%{_texmfdistdir}/tex/latex/isodate/italian.idf
%{_texmfdistdir}/tex/latex/isodate/norsk.idf
%{_texmfdistdir}/tex/latex/isodate/swedish.idf

%package -n texlive-isodoc
Version:        %{texlive_version}.%{texlive_noarch}.1.14svn59709
Release:        0
License:        LPPL-1.0
Summary:        A LaTeX class for typesetting letters and invoices
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isodoc-doc >= %{texlive_version}
Provides:       tex(isodoc.cls)
Requires:       tex(calc.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(forarray.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(longtable.sty)
Requires:       tex(memhfixc.sty)
Requires:       tex(memoir.cls)
Requires:       tex(tabularx.sty)
Requires:       tex(textpos.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source19:       isodoc.tar.xz
Source20:       isodoc.doc.tar.xz

%description -n texlive-isodoc
The isodoc class can be used for the preparation of letters and
invoices (and, in the future, similar documents). Documents are
set up with options, thus making the class easily adaptable to
user's wishes and extensible for other document types. The
class is based on the NTG brief class by Victor Eijkhout, which
implements the NEN1026 standard.

%package -n texlive-isodoc-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.14svn59709
Release:        0
Summary:        Documentation for texlive-isodoc
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isodoc and texlive-alldocumentation)

%description -n texlive-isodoc-doc
This package includes the documentation for texlive-isodoc

%post -n texlive-isodoc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isodoc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isodoc
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isodoc-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isodoc/README.md
%{_texmfdistdir}/doc/latex/isodoc/isodoc.pdf

%files -n texlive-isodoc
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isodoc/isodoc.cls

%package -n texlive-isomath
Version:        %{texlive_version}.%{texlive_noarch}.0.0.6.1svn27654
Release:        0
License:        LPPL-1.0
Summary:        Mathematics style for science and technology
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isomath-doc >= %{texlive_version}
Provides:       tex(isomath.sty)
Requires:       tex(fixmath.sty)
Requires:       tex(kvoptions.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source21:       isomath.tar.xz
Source22:       isomath.doc.tar.xz

%description -n texlive-isomath
The package provides tools for a mathematical style that
conforms to the International Standard ISO 80000-2 and is
common in science and technology. It changes the default shape
of capital Greek letters to italic, sets up bold italic and
sans-serif bold italic math alphabets with Latin and Greek
characters, and defines macros for markup of vector, matrix and
tensor symbols.

%package -n texlive-isomath-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.6.1svn27654
Release:        0
Summary:        Documentation for texlive-isomath
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isomath and texlive-alldocumentation)

%description -n texlive-isomath-doc
This package includes the documentation for texlive-isomath

%post -n texlive-isomath
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isomath
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isomath
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isomath-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isomath/README.html
%{_texmfdistdir}/doc/latex/isomath/README.txt
%{_texmfdistdir}/doc/latex/isomath/isomath-test.pdf
%{_texmfdistdir}/doc/latex/isomath/isomath-test.tex
%{_texmfdistdir}/doc/latex/isomath/isomath.html
%{_texmfdistdir}/doc/latex/isomath/isomath.pdf
%{_texmfdistdir}/doc/latex/isomath/isomath.sty.html
%{_texmfdistdir}/doc/latex/isomath/isomath.sty.txt
%{_texmfdistdir}/doc/latex/isomath/isomath.txt

%files -n texlive-isomath
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isomath/isomath.sty

%package -n texlive-isonums
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn17362
Release:        0
License:        LPPL-1.0
Summary:        Display numbers in maths mode according to ISO 31-0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isonums-doc >= %{texlive_version}
Provides:       tex(isonums.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source23:       isonums.tar.xz
Source24:       isonums.doc.tar.xz

%description -n texlive-isonums
The package makes a quick hack to ziffer to display numbers in
maths mode according to ISO 31-0, regardless of input format
(European $1.235,7$ or Anglo-American $1,235.7$). The options
[euro, anglo] control the global input format. Default input
format is anglo. Documentation is included as comments to the
text source.

%package -n texlive-isonums-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn17362
Release:        0
Summary:        Documentation for texlive-isonums
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isonums and texlive-alldocumentation)

%description -n texlive-isonums-doc
This package includes the documentation for texlive-isonums

%post -n texlive-isonums
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isonums
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isonums
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isonums-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isonums/isonums.pdf
%{_texmfdistdir}/doc/latex/isonums/isonums.tex

%files -n texlive-isonums
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isonums/isonums.sty

%package -n texlive-isopt
Version:        %{texlive_version}.%{texlive_noarch}.0.0.01svn45509
Release:        0
License:        LPPL-1.0
Summary:        Writing a TeX length with a space between number and unit
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isopt-doc >= %{texlive_version}
Provides:       tex(isopt.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source25:       isopt.tar.xz
Source26:       isopt.doc.tar.xz

%description -n texlive-isopt
Writing a TeX length with \the writes the value and the unit
without a space. Package isopt provides a macro \ISO which
inserts a user defined space between number and unit.

%package -n texlive-isopt-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.01svn45509
Release:        0
Summary:        Documentation for texlive-isopt
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isopt and texlive-alldocumentation)

%description -n texlive-isopt-doc
This package includes the documentation for texlive-isopt

%post -n texlive-isopt
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isopt
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isopt
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isopt-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isopt/Changes
%{_texmfdistdir}/doc/latex/isopt/README.md
%{_texmfdistdir}/doc/latex/isopt/isopt-doc.bib
%{_texmfdistdir}/doc/latex/isopt/isopt-doc.pdf
%{_texmfdistdir}/doc/latex/isopt/isopt-doc.tex

%files -n texlive-isopt
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isopt/isopt.sty

%package -n texlive-isorot
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
License:        LPPL-1.0
Summary:        Rotation of document elements
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isorot-doc >= %{texlive_version}
Provides:       tex(isorot.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(lscape.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source27:       isorot.tar.xz
Source28:       isorot.doc.tar.xz

%description -n texlive-isorot
The package is for rotation of document elements. It is a
combination of the lscape package and an extension of the
rotating package. The package is designed for use with the iso
class but may be used with any normal class.

%package -n texlive-isorot-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
Summary:        Documentation for texlive-isorot
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isorot and texlive-alldocumentation)

%description -n texlive-isorot-doc
This package includes the documentation for texlive-isorot

%post -n texlive-isorot
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isorot
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isorot
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isorot-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isorot/README
%{_texmfdistdir}/doc/latex/isorot/rotman.pdf
%{_texmfdistdir}/doc/latex/isorot/rotman.tex

%files -n texlive-isorot
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isorot/isorot.sty

%package -n texlive-isotope
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3svn23711
Release:        0
License:        LPPL-1.0
Summary:        A package for typesetting isotopes
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-isotope-doc >= %{texlive_version}
Provides:       tex(isotope.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source29:       isotope.tar.xz
Source30:       isotope.doc.tar.xz

%description -n texlive-isotope
The package provides a command \isotope for setting the atomic
weight and atomic number indications of isotopes. (The naive
way of doing the job with (La)TeX mathematics commands produces
an unsatisfactory result.)

%package -n texlive-isotope-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3svn23711
Release:        0
Summary:        Documentation for texlive-isotope
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-isotope and texlive-alldocumentation)

%description -n texlive-isotope-doc
This package includes the documentation for texlive-isotope

%post -n texlive-isotope
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-isotope
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-isotope
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-isotope-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/isotope/README

%files -n texlive-isotope
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/isotope/isotope.sty

%package -n texlive-issuulinks
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn25742
Release:        0
License:        LPPL-1.0
Summary:        Produce external links instead of internal ones
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-issuulinks-doc >= %{texlive_version}
Provides:       tex(issuulinks.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source31:       issuulinks.tar.xz
Source32:       issuulinks.doc.tar.xz

%description -n texlive-issuulinks
The PDF visualizer http://issuu.com/ISSUU is a popular service
which shows PDF documents "a page a time". Due to the way it is
implemented, internal links in these documents are not allowed.
Instead, they must be converted to external ones in the form
http://issuu.com/action/page?page=PAGENUMBER. The package
patches hyperref to produce external links in the required form
instead of internal links created by \ref, \cite and other
commands. Since the package redefines the internals of
hyperref, it must be loaded it AFTER hyperref.

%package -n texlive-issuulinks-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn25742
Release:        0
Summary:        Documentation for texlive-issuulinks
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-issuulinks and texlive-alldocumentation)

%description -n texlive-issuulinks-doc
This package includes the documentation for texlive-issuulinks

%post -n texlive-issuulinks
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-issuulinks
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-issuulinks
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-issuulinks-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/issuulinks/Makefile
%{_texmfdistdir}/doc/latex/issuulinks/README
%{_texmfdistdir}/doc/latex/issuulinks/issuulinks.pdf
%{_texmfdistdir}/doc/latex/issuulinks/sample.pdf
%{_texmfdistdir}/doc/latex/issuulinks/sample.tex

%files -n texlive-issuulinks
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/issuulinks/issuulinks.sty

%package -n texlive-istgame
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn62946
Release:        0
License:        LPPL-1.0
Summary:        Draw Game Trees with TikZ
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-istgame-doc >= %{texlive_version}
Provides:       tex(istgame.sty)
Requires:       tex(expl3.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source33:       istgame.tar.xz
Source34:       istgame.doc.tar.xz

%description -n texlive-istgame
This LaTeX package provides macros based on TikZ to draw a game
tree. The main idea underlying its core macros is the
completion of a whole tree by using a sequence of simple
'parent-child' tree structures, with no longer nested relations
involved (like the use of 'grandchildren' or
'great-grandchildren'). Using this package you can draw a game
tree as easily as drawing a game tree with pen and paper. This
package depends on expl3, TikZ, and xparse. The 'ist' prefix
stands for "it's a simple tree" or "In-Sung's simple tree."

%package -n texlive-istgame-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn62946
Release:        0
Summary:        Documentation for texlive-istgame
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-istgame and texlive-alldocumentation)

%description -n texlive-istgame-doc
This package includes the documentation for texlive-istgame

%post -n texlive-istgame
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-istgame
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-istgame
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-istgame-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/istgame/README.txt
%{_texmfdistdir}/doc/latex/istgame/istgame-doc-v2.1.tex
%{_texmfdistdir}/doc/latex/istgame/istgame-doc.pdf
%{_texmfdistdir}/doc/latex/istgame/istgame-doc.tex
%{_texmfdistdir}/doc/latex/istgame/istgame.ist

%files -n texlive-istgame
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/istgame/istgame.sty

%package -n texlive-itnumpar
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn15878
Release:        0
License:        LPPL-1.0
Summary:        Spell numbers in words (Italian)
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-itnumpar-doc >= %{texlive_version}
Provides:       tex(itnumpar.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source35:       itnumpar.tar.xz
Source36:       itnumpar.doc.tar.xz

%description -n texlive-itnumpar
Sometimes we need to say "Capitolo primo" or "Capitolo uno"
instead of "Capitolo 1", that is, spelling the number in words
instead of the usual digit form. This package provides support
for spelling out numbers in Italian words, both in cardinal and
in ordinal form.

%package -n texlive-itnumpar-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn15878
Release:        0
Summary:        Documentation for texlive-itnumpar
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-itnumpar and texlive-alldocumentation)

%description -n texlive-itnumpar-doc
This package includes the documentation for texlive-itnumpar

%post -n texlive-itnumpar
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-itnumpar
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-itnumpar
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-itnumpar-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/itnumpar/README
%{_texmfdistdir}/doc/latex/itnumpar/itnumpar.pdf

%files -n texlive-itnumpar
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/itnumpar/itnumpar.sty

%package -n texlive-iwhdp
Version:        %{texlive_version}.%{texlive_noarch}.0.0.50svn37552
Release:        0
License:        LPPL-1.0
Summary:        Halle Institute for Economic Research (IWH) Discussion Papers
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-iwhdp-doc >= %{texlive_version}
Provides:       tex(iwhdp.cls)
Requires:       tex(amsfonts.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(array.sty)
Requires:       tex(babel.sty)
Requires:       tex(booktabs.sty)
Requires:       tex(color.sty)
Requires:       tex(csquotes.sty)
Requires:       tex(datenumber.sty)
Requires:       tex(dcolumn.sty)
Requires:       tex(float.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(footmisc.sty)
Requires:       tex(geometry.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(lineno.sty)
Requires:       tex(lmodern.sty)
Requires:       tex(longtable.sty)
Requires:       tex(lscape.sty)
Requires:       tex(microtype.sty)
Requires:       tex(multicol.sty)
Requires:       tex(pdfpages.sty)
Requires:       tex(pifont.sty)
Requires:       tex(rotating.sty)
Requires:       tex(sansmath.sty)
Requires:       tex(setspace.sty)
Requires:       tex(suffix.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(textpos.sty)
Requires:       tex(universalis.sty)
Requires:       tex(wallpaper.sty)
Requires:       tex(xifthen.sty)
Requires:       tex(xspace.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source37:       iwhdp.tar.xz
Source38:       iwhdp.doc.tar.xz

%description -n texlive-iwhdp
The document class is for creating Discussion Papers of the
Halle Institute for Economic Research (IWH) in Halle, Germany.
The class offers options for both English and German texts.

%package -n texlive-iwhdp-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.50svn37552
Release:        0
Summary:        Documentation for texlive-iwhdp
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iwhdp and texlive-alldocumentation)
Provides:       locale(texlive-iwhdp-doc:de)

%description -n texlive-iwhdp-doc
This package includes the documentation for texlive-iwhdp

%post -n texlive-iwhdp
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-iwhdp
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-iwhdp
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-iwhdp-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/iwhdp/Back_2015.pdf
%{_texmfdistdir}/doc/latex/iwhdp/Deckblatt_2015.pdf
%{_texmfdistdir}/doc/latex/iwhdp/README
%{_texmfdistdir}/doc/latex/iwhdp/iwhdp_Manual.bib
%{_texmfdistdir}/doc/latex/iwhdp/iwhdp_Manual.pdf
%{_texmfdistdir}/doc/latex/iwhdp/iwhdp_Manual.tex
%{_texmfdistdir}/doc/latex/iwhdp/iwhdp_paper.bib
%{_texmfdistdir}/doc/latex/iwhdp/iwhdp_paper.tex

%files -n texlive-iwhdp
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/iwhdp/iwhdp.cls

%package -n texlive-iwona
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19611
Release:        0
License:        LPPL-1.3c
Summary:        A two-element sans-serif font
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-iwona-fonts >= %{texlive_version}
Suggests:       texlive-iwona-doc >= %{texlive_version}
Provides:       tex(cs-iwona-sc.enc)
Provides:       tex(cs-iwona.enc)
Provides:       tex(cs-iwonab-sc.tfm)
Provides:       tex(cs-iwonab.tfm)
Provides:       tex(cs-iwonabi-sc.tfm)
Provides:       tex(cs-iwonabi.tfm)
Provides:       tex(cs-iwonacb-sc.tfm)
Provides:       tex(cs-iwonacb.tfm)
Provides:       tex(cs-iwonacbi-sc.tfm)
Provides:       tex(cs-iwonacbi.tfm)
Provides:       tex(cs-iwonach-sc.tfm)
Provides:       tex(cs-iwonach.tfm)
Provides:       tex(cs-iwonachi-sc.tfm)
Provides:       tex(cs-iwonachi.tfm)
Provides:       tex(cs-iwonacl-sc.tfm)
Provides:       tex(cs-iwonacl.tfm)
Provides:       tex(cs-iwonacli-sc.tfm)
Provides:       tex(cs-iwonacli.tfm)
Provides:       tex(cs-iwonacm-sc.tfm)
Provides:       tex(cs-iwonacm.tfm)
Provides:       tex(cs-iwonacmi-sc.tfm)
Provides:       tex(cs-iwonacmi.tfm)
Provides:       tex(cs-iwonacr-sc.tfm)
Provides:       tex(cs-iwonacr.tfm)
Provides:       tex(cs-iwonacri-sc.tfm)
Provides:       tex(cs-iwonacri.tfm)
Provides:       tex(cs-iwonah-sc.tfm)
Provides:       tex(cs-iwonah.tfm)
Provides:       tex(cs-iwonahi-sc.tfm)
Provides:       tex(cs-iwonahi.tfm)
Provides:       tex(cs-iwonal-sc.tfm)
Provides:       tex(cs-iwonal.tfm)
Provides:       tex(cs-iwonali-sc.tfm)
Provides:       tex(cs-iwonali.tfm)
Provides:       tex(cs-iwonam-sc.tfm)
Provides:       tex(cs-iwonam.tfm)
Provides:       tex(cs-iwonami-sc.tfm)
Provides:       tex(cs-iwonami.tfm)
Provides:       tex(cs-iwonar-sc.tfm)
Provides:       tex(cs-iwonar.tfm)
Provides:       tex(cs-iwonari-sc.tfm)
Provides:       tex(cs-iwonari.tfm)
Provides:       tex(ec-iwona-sc.enc)
Provides:       tex(ec-iwona.enc)
Provides:       tex(ec-iwonab-sc.tfm)
Provides:       tex(ec-iwonab.tfm)
Provides:       tex(ec-iwonabi-sc.tfm)
Provides:       tex(ec-iwonabi.tfm)
Provides:       tex(ec-iwonacb-sc.tfm)
Provides:       tex(ec-iwonacb.tfm)
Provides:       tex(ec-iwonacbi-sc.tfm)
Provides:       tex(ec-iwonacbi.tfm)
Provides:       tex(ec-iwonach-sc.tfm)
Provides:       tex(ec-iwonach.tfm)
Provides:       tex(ec-iwonachi-sc.tfm)
Provides:       tex(ec-iwonachi.tfm)
Provides:       tex(ec-iwonacl-sc.tfm)
Provides:       tex(ec-iwonacl.tfm)
Provides:       tex(ec-iwonacli-sc.tfm)
Provides:       tex(ec-iwonacli.tfm)
Provides:       tex(ec-iwonacm-sc.tfm)
Provides:       tex(ec-iwonacm.tfm)
Provides:       tex(ec-iwonacmi-sc.tfm)
Provides:       tex(ec-iwonacmi.tfm)
Provides:       tex(ec-iwonacr-sc.tfm)
Provides:       tex(ec-iwonacr.tfm)
Provides:       tex(ec-iwonacri-sc.tfm)
Provides:       tex(ec-iwonacri.tfm)
Provides:       tex(ec-iwonah-sc.tfm)
Provides:       tex(ec-iwonah.tfm)
Provides:       tex(ec-iwonahi-sc.tfm)
Provides:       tex(ec-iwonahi.tfm)
Provides:       tex(ec-iwonal-sc.tfm)
Provides:       tex(ec-iwonal.tfm)
Provides:       tex(ec-iwonali-sc.tfm)
Provides:       tex(ec-iwonali.tfm)
Provides:       tex(ec-iwonam-sc.tfm)
Provides:       tex(ec-iwonam.tfm)
Provides:       tex(ec-iwonami-sc.tfm)
Provides:       tex(ec-iwonami.tfm)
Provides:       tex(ec-iwonar-sc.tfm)
Provides:       tex(ec-iwonar.tfm)
Provides:       tex(ec-iwonari-sc.tfm)
Provides:       tex(ec-iwonari.tfm)
Provides:       tex(ex-iwona.enc)
Provides:       tex(ex-iwonab.tfm)
Provides:       tex(ex-iwonacb.tfm)
Provides:       tex(ex-iwonach.tfm)
Provides:       tex(ex-iwonacl.tfm)
Provides:       tex(ex-iwonacm.tfm)
Provides:       tex(ex-iwonacr.tfm)
Provides:       tex(ex-iwonah.tfm)
Provides:       tex(ex-iwonal.tfm)
Provides:       tex(ex-iwonam.tfm)
Provides:       tex(ex-iwonar.tfm)
Provides:       tex(greek-iwona.enc)
Provides:       tex(greek-iwonab.tfm)
Provides:       tex(greek-iwonabi.tfm)
Provides:       tex(greek-iwonacb.tfm)
Provides:       tex(greek-iwonacbi.tfm)
Provides:       tex(greek-iwonach.tfm)
Provides:       tex(greek-iwonachi.tfm)
Provides:       tex(greek-iwonacl.tfm)
Provides:       tex(greek-iwonacli.tfm)
Provides:       tex(greek-iwonacm.tfm)
Provides:       tex(greek-iwonacmi.tfm)
Provides:       tex(greek-iwonacr.tfm)
Provides:       tex(greek-iwonacri.tfm)
Provides:       tex(greek-iwonah.tfm)
Provides:       tex(greek-iwonahi.tfm)
Provides:       tex(greek-iwonal.tfm)
Provides:       tex(greek-iwonali.tfm)
Provides:       tex(greek-iwonam.tfm)
Provides:       tex(greek-iwonami.tfm)
Provides:       tex(greek-iwonar.tfm)
Provides:       tex(greek-iwonari.tfm)
Provides:       tex(il2iwona.fd)
Provides:       tex(il2iwonac.fd)
Provides:       tex(il2iwonal.fd)
Provides:       tex(il2iwonalc.fd)
Provides:       tex(iwona-cs.map)
Provides:       tex(iwona-ec.map)
Provides:       tex(iwona-ex.map)
Provides:       tex(iwona-greek.map)
Provides:       tex(iwona-l7x.map)
Provides:       tex(iwona-math.tex)
Provides:       tex(iwona-mi.map)
Provides:       tex(iwona-qx.map)
Provides:       tex(iwona-rm.map)
Provides:       tex(iwona-sy.map)
Provides:       tex(iwona-t2a.map)
Provides:       tex(iwona-t2b.map)
Provides:       tex(iwona-t2c.map)
Provides:       tex(iwona-t5.map)
Provides:       tex(iwona-texnansi.map)
Provides:       tex(iwona-ts1.map)
Provides:       tex(iwona-wncy.map)
Provides:       tex(iwona.map)
Provides:       tex(iwona.sty)
Provides:       tex(l7x-iwona-sc.enc)
Provides:       tex(l7x-iwona.enc)
Provides:       tex(l7x-iwonab-sc.tfm)
Provides:       tex(l7x-iwonab.tfm)
Provides:       tex(l7x-iwonabi-sc.tfm)
Provides:       tex(l7x-iwonabi.tfm)
Provides:       tex(l7x-iwonacb-sc.tfm)
Provides:       tex(l7x-iwonacb.tfm)
Provides:       tex(l7x-iwonacbi-sc.tfm)
Provides:       tex(l7x-iwonacbi.tfm)
Provides:       tex(l7x-iwonach-sc.tfm)
Provides:       tex(l7x-iwonach.tfm)
Provides:       tex(l7x-iwonachi-sc.tfm)
Provides:       tex(l7x-iwonachi.tfm)
Provides:       tex(l7x-iwonacl-sc.tfm)
Provides:       tex(l7x-iwonacl.tfm)
Provides:       tex(l7x-iwonacli-sc.tfm)
Provides:       tex(l7x-iwonacli.tfm)
Provides:       tex(l7x-iwonacm-sc.tfm)
Provides:       tex(l7x-iwonacm.tfm)
Provides:       tex(l7x-iwonacmi-sc.tfm)
Provides:       tex(l7x-iwonacmi.tfm)
Provides:       tex(l7x-iwonacr-sc.tfm)
Provides:       tex(l7x-iwonacr.tfm)
Provides:       tex(l7x-iwonacri-sc.tfm)
Provides:       tex(l7x-iwonacri.tfm)
Provides:       tex(l7x-iwonah-sc.tfm)
Provides:       tex(l7x-iwonah.tfm)
Provides:       tex(l7x-iwonahi-sc.tfm)
Provides:       tex(l7x-iwonahi.tfm)
Provides:       tex(l7x-iwonal-sc.tfm)
Provides:       tex(l7x-iwonal.tfm)
Provides:       tex(l7x-iwonali-sc.tfm)
Provides:       tex(l7x-iwonali.tfm)
Provides:       tex(l7x-iwonam-sc.tfm)
Provides:       tex(l7x-iwonam.tfm)
Provides:       tex(l7x-iwonami-sc.tfm)
Provides:       tex(l7x-iwonami.tfm)
Provides:       tex(l7x-iwonar-sc.tfm)
Provides:       tex(l7x-iwonar.tfm)
Provides:       tex(l7x-iwonari-sc.tfm)
Provides:       tex(l7x-iwonari.tfm)
Provides:       tex(l7xiwona.fd)
Provides:       tex(l7xiwonac.fd)
Provides:       tex(l7xiwonal.fd)
Provides:       tex(l7xiwonalc.fd)
Provides:       tex(ly1iwona.fd)
Provides:       tex(ly1iwonac.fd)
Provides:       tex(ly1iwonal.fd)
Provides:       tex(ly1iwonalc.fd)
Provides:       tex(mi-iwona.enc)
Provides:       tex(mi-iwonabi.tfm)
Provides:       tex(mi-iwonacbi.tfm)
Provides:       tex(mi-iwonachi.tfm)
Provides:       tex(mi-iwonacli.tfm)
Provides:       tex(mi-iwonacmi.tfm)
Provides:       tex(mi-iwonacri.tfm)
Provides:       tex(mi-iwonahi.tfm)
Provides:       tex(mi-iwonali.tfm)
Provides:       tex(mi-iwonami.tfm)
Provides:       tex(mi-iwonari.tfm)
Provides:       tex(omliwona.fd)
Provides:       tex(omliwonac.fd)
Provides:       tex(omliwonal.fd)
Provides:       tex(omliwonalc.fd)
Provides:       tex(omsiwona.fd)
Provides:       tex(omsiwonac.fd)
Provides:       tex(omsiwonal.fd)
Provides:       tex(omsiwonalc.fd)
Provides:       tex(omxiwona.fd)
Provides:       tex(omxiwonac.fd)
Provides:       tex(omxiwonal.fd)
Provides:       tex(omxiwonalc.fd)
Provides:       tex(ot1iwona.fd)
Provides:       tex(ot1iwonac.fd)
Provides:       tex(ot1iwonacm.fd)
Provides:       tex(ot1iwonal.fd)
Provides:       tex(ot1iwonalc.fd)
Provides:       tex(ot1iwonalcm.fd)
Provides:       tex(ot1iwonalm.fd)
Provides:       tex(ot1iwonam.fd)
Provides:       tex(ot2iwona.fd)
Provides:       tex(ot2iwonac.fd)
Provides:       tex(ot2iwonal.fd)
Provides:       tex(ot2iwonalc.fd)
Provides:       tex(ot4iwona.fd)
Provides:       tex(ot4iwonac.fd)
Provides:       tex(ot4iwonal.fd)
Provides:       tex(ot4iwonalc.fd)
Provides:       tex(qx-iwona-sc.enc)
Provides:       tex(qx-iwona.enc)
Provides:       tex(qx-iwonab-sc.tfm)
Provides:       tex(qx-iwonab.tfm)
Provides:       tex(qx-iwonabi-sc.tfm)
Provides:       tex(qx-iwonabi.tfm)
Provides:       tex(qx-iwonacb-sc.tfm)
Provides:       tex(qx-iwonacb.tfm)
Provides:       tex(qx-iwonacbi-sc.tfm)
Provides:       tex(qx-iwonacbi.tfm)
Provides:       tex(qx-iwonach-sc.tfm)
Provides:       tex(qx-iwonach.tfm)
Provides:       tex(qx-iwonachi-sc.tfm)
Provides:       tex(qx-iwonachi.tfm)
Provides:       tex(qx-iwonacl-sc.tfm)
Provides:       tex(qx-iwonacl.tfm)
Provides:       tex(qx-iwonacli-sc.tfm)
Provides:       tex(qx-iwonacli.tfm)
Provides:       tex(qx-iwonacm-sc.tfm)
Provides:       tex(qx-iwonacm.tfm)
Provides:       tex(qx-iwonacmi-sc.tfm)
Provides:       tex(qx-iwonacmi.tfm)
Provides:       tex(qx-iwonacr-sc.tfm)
Provides:       tex(qx-iwonacr.tfm)
Provides:       tex(qx-iwonacri-sc.tfm)
Provides:       tex(qx-iwonacri.tfm)
Provides:       tex(qx-iwonah-sc.tfm)
Provides:       tex(qx-iwonah.tfm)
Provides:       tex(qx-iwonahi-sc.tfm)
Provides:       tex(qx-iwonahi.tfm)
Provides:       tex(qx-iwonal-sc.tfm)
Provides:       tex(qx-iwonal.tfm)
Provides:       tex(qx-iwonali-sc.tfm)
Provides:       tex(qx-iwonali.tfm)
Provides:       tex(qx-iwonam-sc.tfm)
Provides:       tex(qx-iwonam.tfm)
Provides:       tex(qx-iwonami-sc.tfm)
Provides:       tex(qx-iwonami.tfm)
Provides:       tex(qx-iwonar-sc.tfm)
Provides:       tex(qx-iwonar.tfm)
Provides:       tex(qx-iwonari-sc.tfm)
Provides:       tex(qx-iwonari.tfm)
Provides:       tex(qxiwona.fd)
Provides:       tex(qxiwonac.fd)
Provides:       tex(qxiwonal.fd)
Provides:       tex(qxiwonalc.fd)
Provides:       tex(rm-iwona-sc.enc)
Provides:       tex(rm-iwona.enc)
Provides:       tex(rm-iwonab-sc.tfm)
Provides:       tex(rm-iwonab.tfm)
Provides:       tex(rm-iwonabi-sc.tfm)
Provides:       tex(rm-iwonabi.tfm)
Provides:       tex(rm-iwonacb-sc.tfm)
Provides:       tex(rm-iwonacb.tfm)
Provides:       tex(rm-iwonacbi-sc.tfm)
Provides:       tex(rm-iwonacbi.tfm)
Provides:       tex(rm-iwonach-sc.tfm)
Provides:       tex(rm-iwonach.tfm)
Provides:       tex(rm-iwonachi-sc.tfm)
Provides:       tex(rm-iwonachi.tfm)
Provides:       tex(rm-iwonacl-sc.tfm)
Provides:       tex(rm-iwonacl.tfm)
Provides:       tex(rm-iwonacli-sc.tfm)
Provides:       tex(rm-iwonacli.tfm)
Provides:       tex(rm-iwonacm-sc.tfm)
Provides:       tex(rm-iwonacm.tfm)
Provides:       tex(rm-iwonacmi-sc.tfm)
Provides:       tex(rm-iwonacmi.tfm)
Provides:       tex(rm-iwonacr-sc.tfm)
Provides:       tex(rm-iwonacr.tfm)
Provides:       tex(rm-iwonacri-sc.tfm)
Provides:       tex(rm-iwonacri.tfm)
Provides:       tex(rm-iwonah-sc.tfm)
Provides:       tex(rm-iwonah.tfm)
Provides:       tex(rm-iwonahi-sc.tfm)
Provides:       tex(rm-iwonahi.tfm)
Provides:       tex(rm-iwonal-sc.tfm)
Provides:       tex(rm-iwonal.tfm)
Provides:       tex(rm-iwonali-sc.tfm)
Provides:       tex(rm-iwonali.tfm)
Provides:       tex(rm-iwonam-sc.tfm)
Provides:       tex(rm-iwonam.tfm)
Provides:       tex(rm-iwonami-sc.tfm)
Provides:       tex(rm-iwonami.tfm)
Provides:       tex(rm-iwonar-sc.tfm)
Provides:       tex(rm-iwonar.tfm)
Provides:       tex(rm-iwonari-sc.tfm)
Provides:       tex(rm-iwonari.tfm)
Provides:       tex(sy-iwona.enc)
Provides:       tex(sy-iwonabz.tfm)
Provides:       tex(sy-iwonacbz.tfm)
Provides:       tex(sy-iwonachz.tfm)
Provides:       tex(sy-iwonaclz.tfm)
Provides:       tex(sy-iwonacmz.tfm)
Provides:       tex(sy-iwonacrz.tfm)
Provides:       tex(sy-iwonahz.tfm)
Provides:       tex(sy-iwonalz.tfm)
Provides:       tex(sy-iwonamz.tfm)
Provides:       tex(sy-iwonarz.tfm)
Provides:       tex(t1iwona.fd)
Provides:       tex(t1iwonac.fd)
Provides:       tex(t1iwonal.fd)
Provides:       tex(t1iwonalc.fd)
Provides:       tex(t2a-iwona.enc)
Provides:       tex(t2a-iwonab.tfm)
Provides:       tex(t2a-iwonabi.tfm)
Provides:       tex(t2a-iwonacb.tfm)
Provides:       tex(t2a-iwonacbi.tfm)
Provides:       tex(t2a-iwonach.tfm)
Provides:       tex(t2a-iwonachi.tfm)
Provides:       tex(t2a-iwonacl.tfm)
Provides:       tex(t2a-iwonacli.tfm)
Provides:       tex(t2a-iwonacm.tfm)
Provides:       tex(t2a-iwonacmi.tfm)
Provides:       tex(t2a-iwonacr.tfm)
Provides:       tex(t2a-iwonacri.tfm)
Provides:       tex(t2a-iwonah.tfm)
Provides:       tex(t2a-iwonahi.tfm)
Provides:       tex(t2a-iwonal.tfm)
Provides:       tex(t2a-iwonali.tfm)
Provides:       tex(t2a-iwonam.tfm)
Provides:       tex(t2a-iwonami.tfm)
Provides:       tex(t2a-iwonar.tfm)
Provides:       tex(t2a-iwonari.tfm)
Provides:       tex(t2aiwona.fd)
Provides:       tex(t2aiwonac.fd)
Provides:       tex(t2aiwonal.fd)
Provides:       tex(t2aiwonalc.fd)
Provides:       tex(t2b-iwona.enc)
Provides:       tex(t2b-iwonab.tfm)
Provides:       tex(t2b-iwonabi.tfm)
Provides:       tex(t2b-iwonacb.tfm)
Provides:       tex(t2b-iwonacbi.tfm)
Provides:       tex(t2b-iwonach.tfm)
Provides:       tex(t2b-iwonachi.tfm)
Provides:       tex(t2b-iwonacl.tfm)
Provides:       tex(t2b-iwonacli.tfm)
Provides:       tex(t2b-iwonacm.tfm)
Provides:       tex(t2b-iwonacmi.tfm)
Provides:       tex(t2b-iwonacr.tfm)
Provides:       tex(t2b-iwonacri.tfm)
Provides:       tex(t2b-iwonah.tfm)
Provides:       tex(t2b-iwonahi.tfm)
Provides:       tex(t2b-iwonal.tfm)
Provides:       tex(t2b-iwonali.tfm)
Provides:       tex(t2b-iwonam.tfm)
Provides:       tex(t2b-iwonami.tfm)
Provides:       tex(t2b-iwonar.tfm)
Provides:       tex(t2b-iwonari.tfm)
Provides:       tex(t2biwona.fd)
Provides:       tex(t2biwonac.fd)
Provides:       tex(t2biwonal.fd)
Provides:       tex(t2biwonalc.fd)
Provides:       tex(t2c-iwona.enc)
Provides:       tex(t2c-iwonab.tfm)
Provides:       tex(t2c-iwonabi.tfm)
Provides:       tex(t2c-iwonacb.tfm)
Provides:       tex(t2c-iwonacbi.tfm)
Provides:       tex(t2c-iwonach.tfm)
Provides:       tex(t2c-iwonachi.tfm)
Provides:       tex(t2c-iwonacl.tfm)
Provides:       tex(t2c-iwonacli.tfm)
Provides:       tex(t2c-iwonacm.tfm)
Provides:       tex(t2c-iwonacmi.tfm)
Provides:       tex(t2c-iwonacr.tfm)
Provides:       tex(t2c-iwonacri.tfm)
Provides:       tex(t2c-iwonah.tfm)
Provides:       tex(t2c-iwonahi.tfm)
Provides:       tex(t2c-iwonal.tfm)
Provides:       tex(t2c-iwonali.tfm)
Provides:       tex(t2c-iwonam.tfm)
Provides:       tex(t2c-iwonami.tfm)
Provides:       tex(t2c-iwonar.tfm)
Provides:       tex(t2c-iwonari.tfm)
Provides:       tex(t2ciwona.fd)
Provides:       tex(t2ciwonac.fd)
Provides:       tex(t2ciwonal.fd)
Provides:       tex(t2ciwonalc.fd)
Provides:       tex(t5-iwona-sc.enc)
Provides:       tex(t5-iwona.enc)
Provides:       tex(t5-iwonab-sc.tfm)
Provides:       tex(t5-iwonab.tfm)
Provides:       tex(t5-iwonabi-sc.tfm)
Provides:       tex(t5-iwonabi.tfm)
Provides:       tex(t5-iwonacb-sc.tfm)
Provides:       tex(t5-iwonacb.tfm)
Provides:       tex(t5-iwonacbi-sc.tfm)
Provides:       tex(t5-iwonacbi.tfm)
Provides:       tex(t5-iwonach-sc.tfm)
Provides:       tex(t5-iwonach.tfm)
Provides:       tex(t5-iwonachi-sc.tfm)
Provides:       tex(t5-iwonachi.tfm)
Provides:       tex(t5-iwonacl-sc.tfm)
Provides:       tex(t5-iwonacl.tfm)
Provides:       tex(t5-iwonacli-sc.tfm)
Provides:       tex(t5-iwonacli.tfm)
Provides:       tex(t5-iwonacm-sc.tfm)
Provides:       tex(t5-iwonacm.tfm)
Provides:       tex(t5-iwonacmi-sc.tfm)
Provides:       tex(t5-iwonacmi.tfm)
Provides:       tex(t5-iwonacr-sc.tfm)
Provides:       tex(t5-iwonacr.tfm)
Provides:       tex(t5-iwonacri-sc.tfm)
Provides:       tex(t5-iwonacri.tfm)
Provides:       tex(t5-iwonah-sc.tfm)
Provides:       tex(t5-iwonah.tfm)
Provides:       tex(t5-iwonahi-sc.tfm)
Provides:       tex(t5-iwonahi.tfm)
Provides:       tex(t5-iwonal-sc.tfm)
Provides:       tex(t5-iwonal.tfm)
Provides:       tex(t5-iwonali-sc.tfm)
Provides:       tex(t5-iwonali.tfm)
Provides:       tex(t5-iwonam-sc.tfm)
Provides:       tex(t5-iwonam.tfm)
Provides:       tex(t5-iwonami-sc.tfm)
Provides:       tex(t5-iwonami.tfm)
Provides:       tex(t5-iwonar-sc.tfm)
Provides:       tex(t5-iwonar.tfm)
Provides:       tex(t5-iwonari-sc.tfm)
Provides:       tex(t5-iwonari.tfm)
Provides:       tex(t5iwona.fd)
Provides:       tex(t5iwonac.fd)
Provides:       tex(t5iwonal.fd)
Provides:       tex(t5iwonalc.fd)
Provides:       tex(texnansi-iwona-sc.enc)
Provides:       tex(texnansi-iwona.enc)
Provides:       tex(texnansi-iwonab-sc.tfm)
Provides:       tex(texnansi-iwonab.tfm)
Provides:       tex(texnansi-iwonabi-sc.tfm)
Provides:       tex(texnansi-iwonabi.tfm)
Provides:       tex(texnansi-iwonacb-sc.tfm)
Provides:       tex(texnansi-iwonacb.tfm)
Provides:       tex(texnansi-iwonacbi-sc.tfm)
Provides:       tex(texnansi-iwonacbi.tfm)
Provides:       tex(texnansi-iwonach-sc.tfm)
Provides:       tex(texnansi-iwonach.tfm)
Provides:       tex(texnansi-iwonachi-sc.tfm)
Provides:       tex(texnansi-iwonachi.tfm)
Provides:       tex(texnansi-iwonacl-sc.tfm)
Provides:       tex(texnansi-iwonacl.tfm)
Provides:       tex(texnansi-iwonacli-sc.tfm)
Provides:       tex(texnansi-iwonacli.tfm)
Provides:       tex(texnansi-iwonacm-sc.tfm)
Provides:       tex(texnansi-iwonacm.tfm)
Provides:       tex(texnansi-iwonacmi-sc.tfm)
Provides:       tex(texnansi-iwonacmi.tfm)
Provides:       tex(texnansi-iwonacr-sc.tfm)
Provides:       tex(texnansi-iwonacr.tfm)
Provides:       tex(texnansi-iwonacri-sc.tfm)
Provides:       tex(texnansi-iwonacri.tfm)
Provides:       tex(texnansi-iwonah-sc.tfm)
Provides:       tex(texnansi-iwonah.tfm)
Provides:       tex(texnansi-iwonahi-sc.tfm)
Provides:       tex(texnansi-iwonahi.tfm)
Provides:       tex(texnansi-iwonal-sc.tfm)
Provides:       tex(texnansi-iwonal.tfm)
Provides:       tex(texnansi-iwonali-sc.tfm)
Provides:       tex(texnansi-iwonali.tfm)
Provides:       tex(texnansi-iwonam-sc.tfm)
Provides:       tex(texnansi-iwonam.tfm)
Provides:       tex(texnansi-iwonami-sc.tfm)
Provides:       tex(texnansi-iwonami.tfm)
Provides:       tex(texnansi-iwonar-sc.tfm)
Provides:       tex(texnansi-iwonar.tfm)
Provides:       tex(texnansi-iwonari-sc.tfm)
Provides:       tex(texnansi-iwonari.tfm)
Provides:       tex(ts1-iwona.enc)
Provides:       tex(ts1-iwonab.tfm)
Provides:       tex(ts1-iwonabi.tfm)
Provides:       tex(ts1-iwonacb.tfm)
Provides:       tex(ts1-iwonacbi.tfm)
Provides:       tex(ts1-iwonach.tfm)
Provides:       tex(ts1-iwonachi.tfm)
Provides:       tex(ts1-iwonacl.tfm)
Provides:       tex(ts1-iwonacli.tfm)
Provides:       tex(ts1-iwonacm.tfm)
Provides:       tex(ts1-iwonacmi.tfm)
Provides:       tex(ts1-iwonacr.tfm)
Provides:       tex(ts1-iwonacri.tfm)
Provides:       tex(ts1-iwonah.tfm)
Provides:       tex(ts1-iwonahi.tfm)
Provides:       tex(ts1-iwonal.tfm)
Provides:       tex(ts1-iwonali.tfm)
Provides:       tex(ts1-iwonam.tfm)
Provides:       tex(ts1-iwonami.tfm)
Provides:       tex(ts1-iwonar.tfm)
Provides:       tex(ts1-iwonari.tfm)
Provides:       tex(ts1iwona.fd)
Provides:       tex(ts1iwonac.fd)
Provides:       tex(ts1iwonal.fd)
Provides:       tex(ts1iwonalc.fd)
Provides:       tex(wncy-iwona.enc)
Provides:       tex(wncy-iwonab.tfm)
Provides:       tex(wncy-iwonabi.tfm)
Provides:       tex(wncy-iwonacb.tfm)
Provides:       tex(wncy-iwonacbi.tfm)
Provides:       tex(wncy-iwonach.tfm)
Provides:       tex(wncy-iwonachi.tfm)
Provides:       tex(wncy-iwonacl.tfm)
Provides:       tex(wncy-iwonacli.tfm)
Provides:       tex(wncy-iwonacm.tfm)
Provides:       tex(wncy-iwonacmi.tfm)
Provides:       tex(wncy-iwonacr.tfm)
Provides:       tex(wncy-iwonacri.tfm)
Provides:       tex(wncy-iwonah.tfm)
Provides:       tex(wncy-iwonahi.tfm)
Provides:       tex(wncy-iwonal.tfm)
Provides:       tex(wncy-iwonali.tfm)
Provides:       tex(wncy-iwonam.tfm)
Provides:       tex(wncy-iwonami.tfm)
Provides:       tex(wncy-iwonar.tfm)
Provides:       tex(wncy-iwonari.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source39:       iwona.tar.xz
Source40:       iwona.doc.tar.xz

%description -n texlive-iwona
Iwona is a two-element sans-serif typeface. It was created as
an alternative version of the Kurier typeface, which was
designed in 1975 for a diploma in typeface design at the Warsaw
Academy of Fine Arts under the supervision of Roman
Tomaszewski. This distribution contains a significantly
extended set of characters covering the following modern
alphabets: latin (including Vietnamese), Cyrillic and Greek as
well as a number of additional symbols (including mathematical
symbols). The fonts are prepared in Type 1 and OpenType
formats. For use with TeX the following encoding files have
been prepared: T1 (ec), T2 (abc), and OT2--Cyrillic, T5
(Vietnamese), OT4, QX, texansi and nonstandard (IL2 for the
Czech fonts), as well as supporting macros and files defining
fonts for LaTeX.

%package -n texlive-iwona-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19611
Release:        0
Summary:        Documentation for texlive-iwona
License:        LPPL-1.3c
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-iwona and texlive-alldocumentation)

%description -n texlive-iwona-doc
This package includes the documentation for texlive-iwona

%package -n texlive-iwona-fonts
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19611
Release:        0
Summary:        Severed fonts for texlive-iwona
License:        LPPL-1.3c
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-iwona-fonts
The  separated fonts package for texlive-iwona

%post -n texlive-iwona
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap iwona.map' >> /var/run/texlive/run-updmap

%postun -n texlive-iwona
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap iwona.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-iwona
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-iwona-fonts

%files -n texlive-iwona-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/iwona/00readme.eng
%{_texmfdistdir}/doc/fonts/iwona/00readme.pol
%{_texmfdistdir}/doc/fonts/iwona/GUST-FONT-LICENSE.txt
%{_texmfdistdir}/doc/fonts/iwona/iwona-info-src.zip
%{_texmfdistdir}/doc/fonts/iwona/iwona-info.pdf
%{_texmfdistdir}/doc/fonts/iwona/iwona-latex-cyr.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-latex-math.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-latex-pl.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-latex-t2a.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-latex-t5.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-mathtest.tex
%{_texmfdistdir}/doc/fonts/iwona/iwona-table.tex
%{_texmfdistdir}/doc/fonts/iwona/manifest.txt

%files -n texlive-iwona
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonab.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonabi.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacb.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacbi.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonach.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonachi.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacl.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacli.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacm.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacmi.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacr.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonacri.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonah.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonahi.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonal.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonali.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonam.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonami.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonar.afm
%{_texmfdistdir}/fonts/afm/nowacki/iwona/iwonari.afm
%{_texmfdistdir}/fonts/enc/dvips/iwona/cs-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/cs-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/ec-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/ec-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/ex-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/greek-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/l7x-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/l7x-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/mi-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/qx-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/qx-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/rm-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/rm-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/sy-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/t2a-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/t2b-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/t2c-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/t5-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/t5-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/texnansi-iwona-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/texnansi-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/ts1-iwona.enc
%{_texmfdistdir}/fonts/enc/dvips/iwona/wncy-iwona.enc
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-cs.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-ec.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-ex.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-greek.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-l7x.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-mi.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-qx.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-rm.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-sy.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-t2a.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-t2b.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-t2c.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-t5.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-texnansi.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-ts1.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona-wncy.map
%{_texmfdistdir}/fonts/map/dvips/iwona/iwona.map
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/Iwona-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/Iwona-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/Iwona-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/Iwona-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCond-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCond-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCond-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCond-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondHeavy-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondHeavy-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondLight-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondLight-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondMedium-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaCondMedium-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaHeavy-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaHeavy-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaLight-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaLight-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaMedium-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/iwona/IwonaMedium-Regular.otf
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/cs-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ec-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ex-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/greek-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/l7x-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/mi-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/qx-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/rm-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonabz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonacbz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonachz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonaclz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonacmz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonacrz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonahz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonalz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonamz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/sy-iwonarz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2a-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2b-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t2c-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/t5-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonab-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonabi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonach-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonachi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonah-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonahi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonal-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonali-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonam-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonami-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonar-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonari-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/texnansi-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/ts1-iwonari.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonab.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonabi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonach.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonachi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonacri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonah.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonahi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonal.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonali.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonam.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonami.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonar.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/iwona/wncy-iwonari.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonab.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonabi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacbi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonach.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonachi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacl.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacli.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacm.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacr.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonacri.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonah.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonahi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonal.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonali.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonam.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonami.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonar.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/iwona/iwonari.pfb
%{_texmfdistdir}/tex/latex/iwona/il2iwona.fd
%{_texmfdistdir}/tex/latex/iwona/il2iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/il2iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/il2iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/iwona.sty
%{_texmfdistdir}/tex/latex/iwona/l7xiwona.fd
%{_texmfdistdir}/tex/latex/iwona/l7xiwonac.fd
%{_texmfdistdir}/tex/latex/iwona/l7xiwonal.fd
%{_texmfdistdir}/tex/latex/iwona/l7xiwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/ly1iwona.fd
%{_texmfdistdir}/tex/latex/iwona/ly1iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/ly1iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/ly1iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/omliwona.fd
%{_texmfdistdir}/tex/latex/iwona/omliwonac.fd
%{_texmfdistdir}/tex/latex/iwona/omliwonal.fd
%{_texmfdistdir}/tex/latex/iwona/omliwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/omsiwona.fd
%{_texmfdistdir}/tex/latex/iwona/omsiwonac.fd
%{_texmfdistdir}/tex/latex/iwona/omsiwonal.fd
%{_texmfdistdir}/tex/latex/iwona/omsiwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/omxiwona.fd
%{_texmfdistdir}/tex/latex/iwona/omxiwonac.fd
%{_texmfdistdir}/tex/latex/iwona/omxiwonal.fd
%{_texmfdistdir}/tex/latex/iwona/omxiwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwona.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonacm.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonalcm.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonalm.fd
%{_texmfdistdir}/tex/latex/iwona/ot1iwonam.fd
%{_texmfdistdir}/tex/latex/iwona/ot2iwona.fd
%{_texmfdistdir}/tex/latex/iwona/ot2iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/ot2iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/ot2iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/ot4iwona.fd
%{_texmfdistdir}/tex/latex/iwona/ot4iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/ot4iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/ot4iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/qxiwona.fd
%{_texmfdistdir}/tex/latex/iwona/qxiwonac.fd
%{_texmfdistdir}/tex/latex/iwona/qxiwonal.fd
%{_texmfdistdir}/tex/latex/iwona/qxiwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/t1iwona.fd
%{_texmfdistdir}/tex/latex/iwona/t1iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/t1iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/t1iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/t2aiwona.fd
%{_texmfdistdir}/tex/latex/iwona/t2aiwonac.fd
%{_texmfdistdir}/tex/latex/iwona/t2aiwonal.fd
%{_texmfdistdir}/tex/latex/iwona/t2aiwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/t2biwona.fd
%{_texmfdistdir}/tex/latex/iwona/t2biwonac.fd
%{_texmfdistdir}/tex/latex/iwona/t2biwonal.fd
%{_texmfdistdir}/tex/latex/iwona/t2biwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/t2ciwona.fd
%{_texmfdistdir}/tex/latex/iwona/t2ciwonac.fd
%{_texmfdistdir}/tex/latex/iwona/t2ciwonal.fd
%{_texmfdistdir}/tex/latex/iwona/t2ciwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/t5iwona.fd
%{_texmfdistdir}/tex/latex/iwona/t5iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/t5iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/t5iwonalc.fd
%{_texmfdistdir}/tex/latex/iwona/ts1iwona.fd
%{_texmfdistdir}/tex/latex/iwona/ts1iwonac.fd
%{_texmfdistdir}/tex/latex/iwona/ts1iwonal.fd
%{_texmfdistdir}/tex/latex/iwona/ts1iwonalc.fd
%{_texmfdistdir}/tex/plain/iwona/iwona-math.tex

%files -n texlive-iwona-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-iwona
%{_datadir}/fontconfig/conf.avail/58-texlive-iwona.conf
%{_datadir}/fontconfig/conf.avail/55-texlive-iwona.conf
%config %{_sysconfdir}/fonts/conf.d/55-texlive-iwona.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-iwona/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-iwona/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-iwona/fonts.scale
%{_datadir}/fonts/texlive-iwona/Iwona-Bold.otf
%{_datadir}/fonts/texlive-iwona/Iwona-BoldItalic.otf
%{_datadir}/fonts/texlive-iwona/Iwona-Italic.otf
%{_datadir}/fonts/texlive-iwona/Iwona-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaCond-Bold.otf
%{_datadir}/fonts/texlive-iwona/IwonaCond-BoldItalic.otf
%{_datadir}/fonts/texlive-iwona/IwonaCond-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaCond-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondHeavy-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondHeavy-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondLight-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondLight-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondMedium-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaCondMedium-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaHeavy-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaHeavy-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaLight-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaLight-Regular.otf
%{_datadir}/fonts/texlive-iwona/IwonaMedium-Italic.otf
%{_datadir}/fonts/texlive-iwona/IwonaMedium-Regular.otf
%{_datadir}/fonts/texlive-iwona/iwonab.pfb
%{_datadir}/fonts/texlive-iwona/iwonabi.pfb
%{_datadir}/fonts/texlive-iwona/iwonacb.pfb
%{_datadir}/fonts/texlive-iwona/iwonacbi.pfb
%{_datadir}/fonts/texlive-iwona/iwonach.pfb
%{_datadir}/fonts/texlive-iwona/iwonachi.pfb
%{_datadir}/fonts/texlive-iwona/iwonacl.pfb
%{_datadir}/fonts/texlive-iwona/iwonacli.pfb
%{_datadir}/fonts/texlive-iwona/iwonacm.pfb
%{_datadir}/fonts/texlive-iwona/iwonacmi.pfb
%{_datadir}/fonts/texlive-iwona/iwonacr.pfb
%{_datadir}/fonts/texlive-iwona/iwonacri.pfb
%{_datadir}/fonts/texlive-iwona/iwonah.pfb
%{_datadir}/fonts/texlive-iwona/iwonahi.pfb
%{_datadir}/fonts/texlive-iwona/iwonal.pfb
%{_datadir}/fonts/texlive-iwona/iwonali.pfb
%{_datadir}/fonts/texlive-iwona/iwonam.pfb
%{_datadir}/fonts/texlive-iwona/iwonami.pfb
%{_datadir}/fonts/texlive-iwona/iwonar.pfb
%{_datadir}/fonts/texlive-iwona/iwonari.pfb

%package -n texlive-jablantile
Version:        %{texlive_version}.%{texlive_noarch}.svn16364
Release:        0
License:        SUSE-Public-Domain
Summary:        Metafont version of tiles in the style of Slavik Jablan
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jablantile-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source41:       jablantile.tar.xz
Source42:       jablantile.doc.tar.xz

%description -n texlive-jablantile
This is a small Metafont font to implement the modular tiles
described by Slavik Jablan. For an outline of the theoretical
structure of the tiles, see (for example) Jablan's JMM 2006
Exhibit.

%package -n texlive-jablantile-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn16364
Release:        0
Summary:        Documentation for texlive-jablantile
License:        SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jablantile and texlive-alldocumentation)

%description -n texlive-jablantile-doc
This package includes the documentation for texlive-jablantile

%post -n texlive-jablantile
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jablantile
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jablantile
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jablantile-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/jablantile/README
%{_texmfdistdir}/doc/fonts/jablantile/dearjablan.tex
%{_texmfdistdir}/doc/fonts/jablantile/jablantile.pdf

%files -n texlive-jablantile
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/source/public/jablantile/jablantile.mf

%package -n texlive-jacow
Version:        %{texlive_version}.%{texlive_noarch}.2.7svn63060
Release:        0
License:        LPPL-1.0
Summary:        A class for submissions to the proceedings of conferences on JACoW.org
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jacow-doc >= %{texlive_version}
Provides:       tex(jacow.cls)
Requires:       tex(amsmath.sty)
Requires:       tex(article.cls)
Requires:       tex(biblatex.sty)
Requires:       tex(booktabs.sty)
Requires:       tex(caption.sty)
Requires:       tex(cite.sty)
Requires:       tex(csquotes.sty)
Requires:       tex(enumitem.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(fix-cm.sty)
Requires:       tex(flushend.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(footmisc.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(iftex.sty)
Requires:       tex(lmodern.sty)
Requires:       tex(microtype.sty)
Requires:       tex(newtxmath.sty)
Requires:       tex(newtxtt.sty)
Requires:       tex(siunitx.sty)
Requires:       tex(textcase.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(tgtermes.sty)
Requires:       tex(unicode-math.sty)
Requires:       tex(url.sty)
Requires:       tex(xcolor.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source43:       jacow.tar.xz
Source44:       jacow.doc.tar.xz

%description -n texlive-jacow
The jacow class is used for submissions to the proceedings of
conferences on Joint Accelerator Conferences Website (JACoW),
an international collaboration that publishes the proceedings
of accelerator conferences held around the world.

%package -n texlive-jacow-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.7svn63060
Release:        0
Summary:        Documentation for texlive-jacow
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jacow and texlive-alldocumentation)

%description -n texlive-jacow-doc
This package includes the documentation for texlive-jacow

%post -n texlive-jacow
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jacow
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jacow
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jacow-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jacow/JACoW_LaTeX_A4.pdf
%{_texmfdistdir}/doc/latex/jacow/JACoW_LaTeX_A4.tex
%{_texmfdistdir}/doc/latex/jacow/JACoW_LaTeX_Letter.pdf
%{_texmfdistdir}/doc/latex/jacow/JACoW_LaTeX_Letter.tex
%{_texmfdistdir}/doc/latex/jacow/JACpic_mc.pdf
%{_texmfdistdir}/doc/latex/jacow/README
%{_texmfdistdir}/doc/latex/jacow/TeamMeeting2019.jpg
%{_texmfdistdir}/doc/latex/jacow/annexes-A4.tex
%{_texmfdistdir}/doc/latex/jacow/annexes-Letter.tex
%{_texmfdistdir}/doc/latex/jacow/jacow-collaboration.pdf
%{_texmfdistdir}/doc/latex/jacow/jacow-collaboration.tex

%files -n texlive-jacow
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jacow/jacow.cls

%package -n texlive-jadetex
Version:        %{texlive_version}.%{texlive_noarch}.3.13svn63654
Release:        0
License:        LPPL-1.0
Summary:        Macros supporting Jade DSSSL output
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-amsfonts >= %{texlive_version}
#!BuildIgnore: texlive-amsfonts
Requires:       texlive-atbegshi >= %{texlive_version}
#!BuildIgnore: texlive-atbegshi
Requires:       texlive-atveryend >= %{texlive_version}
#!BuildIgnore: texlive-atveryend
Requires:       texlive-auxhook >= %{texlive_version}
#!BuildIgnore: texlive-auxhook
Requires:       texlive-babel >= %{texlive_version}
#!BuildIgnore: texlive-babel
Requires:       texlive-bigintcalc >= %{texlive_version}
#!BuildIgnore: texlive-bigintcalc
Requires:       texlive-bitset >= %{texlive_version}
#!BuildIgnore: texlive-bitset
Requires:       texlive-cm >= %{texlive_version}
#!BuildIgnore: texlive-cm
Requires:       texlive-colortbl >= %{texlive_version}
#!BuildIgnore: texlive-colortbl
Requires:       texlive-cyrillic >= %{texlive_version}
#!BuildIgnore: texlive-cyrillic
Requires:       texlive-dehyph >= %{texlive_version}
#!BuildIgnore: texlive-dehyph
Requires:       texlive-ec >= %{texlive_version}
#!BuildIgnore: texlive-ec
Requires:       texlive-etexcmds >= %{texlive_version}
#!BuildIgnore: texlive-etexcmds
Requires:       texlive-everyshi >= %{texlive_version}
#!BuildIgnore: texlive-everyshi
Requires:       texlive-fancyhdr >= %{texlive_version}
#!BuildIgnore: texlive-fancyhdr
Requires:       texlive-firstaid >= %{texlive_version}
#!BuildIgnore: texlive-firstaid
Requires:       texlive-gettitlestring >= %{texlive_version}
#!BuildIgnore: texlive-gettitlestring
Requires:       texlive-graphics >= %{texlive_version}
#!BuildIgnore: texlive-graphics
Requires:       texlive-graphics-cfg >= %{texlive_version}
#!BuildIgnore: texlive-graphics-cfg
Requires:       texlive-graphics-def >= %{texlive_version}
#!BuildIgnore: texlive-graphics-def
Requires:       texlive-hycolor >= %{texlive_version}
#!BuildIgnore: texlive-hycolor
Requires:       texlive-hyperref >= %{texlive_version}
#!BuildIgnore: texlive-hyperref
Requires:       texlive-hyph-utf8 >= %{texlive_version}
#!BuildIgnore: texlive-hyph-utf8
Requires:       texlive-hyphen-base >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-base
Requires:       texlive-iftex >= %{texlive_version}
#!BuildIgnore: texlive-iftex
Requires:       texlive-infwarerr >= %{texlive_version}
#!BuildIgnore: texlive-infwarerr
Requires:       texlive-intcalc >= %{texlive_version}
#!BuildIgnore: texlive-intcalc
Requires(pre):  texlive-jadetex-bin >= %{texlive_version}
#!BuildIgnore: texlive-jadetex-bin
Requires:       texlive-kvdefinekeys >= %{texlive_version}
#!BuildIgnore: texlive-kvdefinekeys
Requires:       texlive-kvoptions >= %{texlive_version}
#!BuildIgnore: texlive-kvoptions
Requires:       texlive-kvsetkeys >= %{texlive_version}
#!BuildIgnore: texlive-kvsetkeys
Requires:       texlive-l3backend >= %{texlive_version}
#!BuildIgnore: texlive-l3backend
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires:       texlive-l3packages >= %{texlive_version}
#!BuildIgnore: texlive-l3packages
Requires:       texlive-latex >= %{texlive_version}
#!BuildIgnore: texlive-latex
Requires:       texlive-latex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-latex-fonts
Requires:       texlive-latexconfig >= %{texlive_version}
#!BuildIgnore: texlive-latexconfig
Requires:       texlive-letltxmacro >= %{texlive_version}
#!BuildIgnore: texlive-letltxmacro
Requires:       texlive-ltxcmds >= %{texlive_version}
#!BuildIgnore: texlive-ltxcmds
Requires:       texlive-marvosym >= %{texlive_version}
#!BuildIgnore: texlive-marvosym
Requires:       texlive-passivetex >= %{texlive_version}
#!BuildIgnore: texlive-passivetex
Requires:       texlive-pdfescape >= %{texlive_version}
#!BuildIgnore: texlive-pdfescape
Requires:       texlive-pdftex >= %{texlive_version}
#!BuildIgnore: texlive-pdftex
Requires:       texlive-pdftexcmds >= %{texlive_version}
#!BuildIgnore: texlive-pdftexcmds
Requires:       texlive-psnfss >= %{texlive_version}
#!BuildIgnore: texlive-psnfss
Requires:       texlive-refcount >= %{texlive_version}
#!BuildIgnore: texlive-refcount
Requires:       texlive-rerunfilecheck >= %{texlive_version}
#!BuildIgnore: texlive-rerunfilecheck
Requires:       texlive-stmaryrd >= %{texlive_version}
#!BuildIgnore: texlive-stmaryrd
Requires:       texlive-symbol >= %{texlive_version}
#!BuildIgnore: texlive-symbol
Requires:       texlive-tex >= %{texlive_version}
#!BuildIgnore: texlive-tex
Requires:       texlive-tex-ini-files >= %{texlive_version}
#!BuildIgnore: texlive-tex-ini-files
Requires:       texlive-tipa >= %{texlive_version}
#!BuildIgnore: texlive-tipa
Requires:       texlive-tools >= %{texlive_version}
#!BuildIgnore: texlive-tools
Requires:       texlive-ulem >= %{texlive_version}
#!BuildIgnore: texlive-ulem
Requires:       texlive-unicode-data >= %{texlive_version}
#!BuildIgnore: texlive-unicode-data
Requires:       texlive-uniquecounter >= %{texlive_version}
#!BuildIgnore: texlive-uniquecounter
Requires:       texlive-url >= %{texlive_version}
#!BuildIgnore: texlive-url
Requires:       texlive-wasysym >= %{texlive_version}
#!BuildIgnore: texlive-wasysym
Requires:       texlive-zapfding >= %{texlive_version}
#!BuildIgnore: texlive-zapfding
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(language.dat)
Requires(post): tex(language.def)
Requires(post): tex(language.dat.lua)
#!BuildIgnore:  tex(language.dat)
#!BuildIgnore:  tex(language.def)
#!BuildIgnore:  tex(language.dat.lua)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(language.dat)
Requires(postun):tex(language.def)
Requires(postun):tex(language.dat.lua)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jadetex-doc >= %{texlive_version}
Requires(posttrans):texlive-latex >= %{texlive_version}
Requires(posttrans):texlive-colortbl >= %{texlive_version}
Requires(posttrans):texlive-fancyhdr >= %{texlive_version}
Requires(posttrans):texlive-marvosym >= %{texlive_version}
Requires(posttrans):texlive-passivetex >= %{texlive_version}
Requires(posttrans):texlive-psnfss >= %{texlive_version}
Requires(posttrans):texlive-graphics >= %{texlive_version}
Requires(posttrans):texlive-symbol >= %{texlive_version}
Requires(posttrans):texlive-ulem >= %{texlive_version}
Requires(posttrans):texlive-zapfding >= %{texlive_version}
Requires(posttrans):texlive-courier >= %{texlive_version}
Requires(posttrans):texlive-ec >= %{texlive_version}
Requires(posttrans):texlive-helvetic >= %{texlive_version}
Requires(posttrans):texlive-times >= %{texlive_version}
Provides:       tex(dsssl.def)
Provides:       tex(uentities.sty)
Provides:       tex(ut1omlgc.fd)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source45:       jadetex.tar.xz
Source46:       jadetex.doc.tar.xz
Source47:       jadetex_ini.dif

%description -n texlive-jadetex
Macro package on top of LaTeX to typeset TeX output of the Jade
DSSSL implementation.

%package -n texlive-jadetex-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.13svn63654
Release:        0
Summary:        Documentation for texlive-jadetex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jadetex and texlive-alldocumentation)
Provides:       man(jadetex.1)
Provides:       man(pdfjadetex.1)

%description -n texlive-jadetex-doc
This package includes the documentation for texlive-jadetex

%post -n texlive-jadetex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
> /var/run/texlive/run-fmtutil.jadetex
sed -ri 's/^\#\![[= =]]+jadetex\b.*/jadetex pdftex language.dat *jadetex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.pdfjadetex
sed -ri 's/^\#\![[= =]]+pdfjadetex\b.*/pdfjadetex pdftex language.dat *pdfjadetex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :

%postun -n texlive-jadetex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    sed -ri 's/^(jadetex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/jadetex.*
    sed -ri 's/^(pdfjadetex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/pdfjadetex.*
    exit 0
fi

%triggerin -n texlive-jadetex -- texlive-amsfonts
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-amsfonts
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-atveryend
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-atveryend
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-auxhook
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-auxhook
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-babel
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-babel
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-bigintcalc
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-bigintcalc
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-bitset
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-bitset
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-cm
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-cm
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-colortbl
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-colortbl
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-cyrillic
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-cyrillic
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-dehyph
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-dehyph
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-ec
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-ec
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-etexcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-etexcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-everyshi
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-everyshi
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-fancyhdr
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-fancyhdr
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-firstaid
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-firstaid
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-gettitlestring
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-gettitlestring
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-graphics
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-graphics
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-graphics-cfg
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-graphics-cfg
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-graphics-def
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-graphics-def
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-hycolor
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-hycolor
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-hyperref
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-hyperref
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-iftex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-iftex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-infwarerr
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-infwarerr
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-intcalc
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-intcalc
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-kvdefinekeys
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-kvdefinekeys
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-kvoptions
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-kvoptions
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-kvsetkeys
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-kvsetkeys
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-l3backend
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-l3backend
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-l3packages
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-l3packages
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-latex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-latex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-letltxmacro
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-letltxmacro
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-ltxcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-ltxcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-marvosym
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-marvosym
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-passivetex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-passivetex
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-pdfescape
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-pdfescape
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-pdftexcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-pdftexcmds
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-psnfss
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-psnfss
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-refcount
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-refcount
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-rerunfilecheck
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-rerunfilecheck
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-stmaryrd
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-stmaryrd
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-symbol
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-symbol
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-tipa
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-tipa
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-tools
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-tools
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-ulem
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-ulem
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-uniquecounter
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-uniquecounter
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-url
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-url
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-wasysym
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-wasysym
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerin -n texlive-jadetex -- texlive-zapfding
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%triggerun -n texlive-jadetex -- texlive-zapfding
> /var/run/texlive/run-fmtutil.jadetex
> /var/run/texlive/run-fmtutil.pdfjadetex

%posttrans -n texlive-jadetex
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jadetex-doc
%defattr(-,root,root,755)
%{_mandir}/man1/jadetex.1*
%{_mandir}/man1/pdfjadetex.1*
%{_texmfdistdir}/doc/otherformats/jadetex/base/ChangeLog
%{_texmfdistdir}/doc/otherformats/jadetex/base/ChangeLog-old
%{_texmfdistdir}/doc/otherformats/jadetex/base/Makefile
%{_texmfdistdir}/doc/otherformats/jadetex/base/demo.sgm
%{_texmfdistdir}/doc/otherformats/jadetex/base/docbook.dsl
%{_texmfdistdir}/doc/otherformats/jadetex/base/index.html
%{_texmfdistdir}/doc/otherformats/jadetex/base/index.xml
%{_texmfdistdir}/doc/otherformats/jadetex/base/index.xsl
%{_texmfdistdir}/doc/otherformats/jadetex/base/jadetex.cfg
%{_texmfdistdir}/doc/otherformats/jadetex/base/logo.png
%{_texmfdistdir}/doc/otherformats/jadetex/base/releasenotes.dsl
%{_texmfdistdir}/doc/otherformats/jadetex/base/releasenotes.xml

%files -n texlive-jadetex
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/jadetex/base/dsssl.def
%{_texmfdistdir}/tex/jadetex/base/jadetex.ini
%{_texmfdistdir}/tex/jadetex/base/jadetex.ltx
%{_texmfdistdir}/tex/jadetex/base/pdfjadetex.ini
%{_texmfdistdir}/tex/jadetex/base/uentities.sty
%{_texmfdistdir}/tex/jadetex/base/ut1omlgc.fd

%package -n texlive-jamtimes
Version:        %{texlive_version}.%{texlive_noarch}.1.12svn20408
Release:        0
License:        LPPL-1.0
Summary:        Expanded Times Roman fonts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jamtimes-doc >= %{texlive_version}
Provides:       tex(blsy.tfm)
Provides:       tex(jamtimes.sty)
Provides:       tex(jtm.map)
Provides:       tex(jtmb7tv.tfm)
Provides:       tex(jtmb7tv.vf)
Provides:       tex(jtmb8cv.tfm)
Provides:       tex(jtmb8cv.vf)
Provides:       tex(jtmb8rv.tfm)
Provides:       tex(jtmb8tv.tfm)
Provides:       tex(jtmb8tv.vf)
Provides:       tex(jtmbc7tv.tfm)
Provides:       tex(jtmbc7tv.vf)
Provides:       tex(jtmbc8tv.tfm)
Provides:       tex(jtmbc8tv.vf)
Provides:       tex(jtmbi7me.tfm)
Provides:       tex(jtmbi7me.vf)
Provides:       tex(jtmbi7tv.tfm)
Provides:       tex(jtmbi7tv.vf)
Provides:       tex(jtmbi8cv.tfm)
Provides:       tex(jtmbi8cv.vf)
Provides:       tex(jtmbi8rv.tfm)
Provides:       tex(jtmbi8tv.tfm)
Provides:       tex(jtmbi8tv.vf)
Provides:       tex(jtmbo7tv.tfm)
Provides:       tex(jtmbo7tv.vf)
Provides:       tex(jtmbo8cv.tfm)
Provides:       tex(jtmbo8cv.vf)
Provides:       tex(jtmbo8rv.tfm)
Provides:       tex(jtmbo8tv.tfm)
Provides:       tex(jtmbo8tv.vf)
Provides:       tex(jtmr7tc.tfm)
Provides:       tex(jtmr7tc.vf)
Provides:       tex(jtmr7te.tfm)
Provides:       tex(jtmr7te.vf)
Provides:       tex(jtmr7tw.tfm)
Provides:       tex(jtmr7tw.vf)
Provides:       tex(jtmr7ye.tfm)
Provides:       tex(jtmr7ye.vf)
Provides:       tex(jtmr7yoe.tfm)
Provides:       tex(jtmr8cc.tfm)
Provides:       tex(jtmr8cc.vf)
Provides:       tex(jtmr8ce.tfm)
Provides:       tex(jtmr8ce.vf)
Provides:       tex(jtmr8cw.tfm)
Provides:       tex(jtmr8cw.vf)
Provides:       tex(jtmr8rc.tfm)
Provides:       tex(jtmr8re.tfm)
Provides:       tex(jtmr8rw.tfm)
Provides:       tex(jtmr8tc.tfm)
Provides:       tex(jtmr8tc.vf)
Provides:       tex(jtmr8te.tfm)
Provides:       tex(jtmr8te.vf)
Provides:       tex(jtmr8tw.tfm)
Provides:       tex(jtmr8tw.vf)
Provides:       tex(jtmrc7te.tfm)
Provides:       tex(jtmrc7te.vf)
Provides:       tex(jtmrc7tw.tfm)
Provides:       tex(jtmrc7tw.vf)
Provides:       tex(jtmrc8te.tfm)
Provides:       tex(jtmrc8te.vf)
Provides:       tex(jtmrc8tw.tfm)
Provides:       tex(jtmrc8tw.vf)
Provides:       tex(jtmri7me.tfm)
Provides:       tex(jtmri7me.vf)
Provides:       tex(jtmri7te.tfm)
Provides:       tex(jtmri7te.vf)
Provides:       tex(jtmri7tw.tfm)
Provides:       tex(jtmri7tw.vf)
Provides:       tex(jtmri7ze.tfm)
Provides:       tex(jtmri8ce.tfm)
Provides:       tex(jtmri8ce.vf)
Provides:       tex(jtmri8cw.tfm)
Provides:       tex(jtmri8cw.vf)
Provides:       tex(jtmri8re.tfm)
Provides:       tex(jtmri8rw.tfm)
Provides:       tex(jtmri8te.tfm)
Provides:       tex(jtmri8te.vf)
Provides:       tex(jtmri8tw.tfm)
Provides:       tex(jtmri8tw.vf)
Provides:       tex(jtmro7te.tfm)
Provides:       tex(jtmro7te.vf)
Provides:       tex(jtmro7tw.tfm)
Provides:       tex(jtmro7tw.vf)
Provides:       tex(jtmro8ce.tfm)
Provides:       tex(jtmro8ce.vf)
Provides:       tex(jtmro8cw.tfm)
Provides:       tex(jtmro8cw.vf)
Provides:       tex(jtmro8re.tfm)
Provides:       tex(jtmro8rw.tfm)
Provides:       tex(jtmro8te.tfm)
Provides:       tex(jtmro8te.vf)
Provides:       tex(jtmro8tw.tfm)
Provides:       tex(jtmro8tw.vf)
Provides:       tex(omljtm.fd)
Provides:       tex(omsjtm.fd)
Provides:       tex(ot1jtm.fd)
Provides:       tex(ptmb8a.tfm)
Provides:       tex(ptmbi8a.tfm)
Provides:       tex(ptmr8a.tfm)
Provides:       tex(ptmri8a.tfm)
Provides:       tex(rblmi.tfm)
Provides:       tex(t1jtm.fd)
Provides:       tex(ts1jtm.fd)
Requires:       tex(amsfonts.sty)
Requires:       tex(cmmi10.tfm)
Requires:       tex(cmmib10.tfm)
Requires:       tex(cmsy10.tfm)
Requires:       tex(eucal.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source48:       jamtimes.tar.xz
Source49:       jamtimes.doc.tar.xz

%description -n texlive-jamtimes
The package offers LaTeX support for the expanded Times Roman
font, which has been used for many years in the Journal
d'Analyse Mathematique. Mathematics support is based on the
Belleek fonts.

%package -n texlive-jamtimes-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.12svn20408
Release:        0
Summary:        Documentation for texlive-jamtimes
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jamtimes and texlive-alldocumentation)

%description -n texlive-jamtimes-doc
This package includes the documentation for texlive-jamtimes

%post -n texlive-jamtimes
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jamtimes
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jamtimes
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jamtimes-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jamtimes/README
%{_texmfdistdir}/doc/latex/jamtimes/jamtimes.bib
%{_texmfdistdir}/doc/latex/jamtimes/jamtimes.dtx
%{_texmfdistdir}/doc/latex/jamtimes/jamtimes.ins
%{_texmfdistdir}/doc/latex/jamtimes/jamtimes.pdf
%{_texmfdistdir}/doc/latex/jamtimes/mathsample.pdf
%{_texmfdistdir}/doc/latex/jamtimes/mathsample.tex
%{_texmfdistdir}/doc/latex/jamtimes/mathsample_ps.pdf
%{_texmfdistdir}/doc/latex/jamtimes/textsample.pdf
%{_texmfdistdir}/doc/latex/jamtimes/textsample.tex
%{_texmfdistdir}/doc/latex/jamtimes/textsample_ps.pdf

%files -n texlive-jamtimes
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/map/dvips/jamtimes/jtm.map
%{_texmfdistdir}/fonts/tfm/public/jamtimes/blsy.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmb7tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmb8cv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmb8rv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmb8tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbc7tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbc8tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbi7me.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbi7tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbi8cv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbi8rv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbi8tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbo7tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbo8cv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbo8rv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmbo8tv.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr7tc.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr7te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr7tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr7ye.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr7yoe.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8cc.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8ce.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8cw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8rc.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8re.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8rw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8tc.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmr8tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmrc7te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmrc7tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmrc8te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmrc8tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri7me.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri7te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri7tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri7ze.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8ce.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8cw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8re.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8rw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmri8tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro7te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro7tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8ce.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8cw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8re.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8rw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8te.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/jtmro8tw.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/ptmb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/ptmbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/ptmr8a.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/ptmri8a.tfm
%{_texmfdistdir}/fonts/tfm/public/jamtimes/rblmi.tfm
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmb7tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmb8cv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmb8tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbc7tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbc8tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbi7me.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbi7tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbi8cv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbi8tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbo7tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbo8cv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmbo8tv.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr7tc.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr7te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr7tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr7ye.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8cc.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8ce.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8cw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8tc.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmr8tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmrc7te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmrc7tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmrc8te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmrc8tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri7me.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri7te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri7tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri8ce.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri8cw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri8te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmri8tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro7te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro7tw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro8ce.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro8cw.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro8te.vf
%{_texmfdistdir}/fonts/vf/public/jamtimes/jtmro8tw.vf
%{_texmfdistdir}/tex/latex/jamtimes/jamtimes.sty
%{_texmfdistdir}/tex/latex/jamtimes/omljtm.fd
%{_texmfdistdir}/tex/latex/jamtimes/omsjtm.fd
%{_texmfdistdir}/tex/latex/jamtimes/ot1jtm.fd
%{_texmfdistdir}/tex/latex/jamtimes/t1jtm.fd
%{_texmfdistdir}/tex/latex/jamtimes/ts1jtm.fd

%package -n texlive-japanese-mathformulas
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn64678
Release:        0
License:        LPPL-1.0
Summary:        Compiling basic math formulas in Japanese using LuaLaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-japanese-mathformulas-doc >= %{texlive_version}
Provides:       tex(japanese-mathformulas.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(esvect.sty)
Requires:       tex(graphics.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(luatexja-fontspec.sty)
Requires:       tex(luatexja-otf.sty)
Requires:       tex(luatexja.sty)
Requires:       tex(mathtools.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source50:       japanese-mathformulas.tar.xz
Source51:       japanese-mathformulas.doc.tar.xz

%description -n texlive-japanese-mathformulas
This is a style file for compiling basic maths formulas in
Japanese using LuaLaTeX. \NewDocumentCommand allows you to
specify whether the formula should be used within a sentence or
on a new line. The main packages used in
japanese-mathformulas.sty are amsmath, amssymb, siunitx,
ifthen, xparse, TikZ, mathtools, and graphics.

%package -n texlive-japanese-mathformulas-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn64678
Release:        0
Summary:        Documentation for texlive-japanese-mathformulas
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-japanese-mathformulas and texlive-alldocumentation)
Provides:       locale(texlive-japanese-mathformulas-doc:ja)

%description -n texlive-japanese-mathformulas-doc
This package includes the documentation for texlive-japanese-mathformulas

%post -n texlive-japanese-mathformulas
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-japanese-mathformulas
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-japanese-mathformulas
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-japanese-mathformulas-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/lualatex/japanese-mathformulas/README.txt
%{_texmfdistdir}/doc/lualatex/japanese-mathformulas/japanese-mathformulas-sample.pdf
%{_texmfdistdir}/doc/lualatex/japanese-mathformulas/japanese-mathformulas-sample.tex
%{_texmfdistdir}/doc/lualatex/japanese-mathformulas/japanese-mathformulas.pdf
%{_texmfdistdir}/doc/lualatex/japanese-mathformulas/japanese-mathformulas.tex

%files -n texlive-japanese-mathformulas
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/lualatex/japanese-mathformulas/japanese-mathformulas.sty

%package -n texlive-japanese-otf
Version:        %{texlive_version}.%{texlive_noarch}.svn66091
Release:        0
License:        BSD-3-Clause
Summary:        Advanced font selection for platex and its friends
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-japanese-otf-doc >= %{texlive_version}
Provides:       tex(ajmacros.sty)
Provides:       tex(brsgexpgothb-h.tfm)
Provides:       tex(brsgexpgothb-h.vf)
Provides:       tex(brsgexpgothb-v.tfm)
Provides:       tex(brsgexpgothb-v.vf)
Provides:       tex(brsgexpgothbn-h.tfm)
Provides:       tex(brsgexpgothbn-h.vf)
Provides:       tex(brsgexpgothbn-v.tfm)
Provides:       tex(brsgexpgothbn-v.vf)
Provides:       tex(brsgexpgotheb-h.tfm)
Provides:       tex(brsgexpgotheb-h.vf)
Provides:       tex(brsgexpgotheb-v.tfm)
Provides:       tex(brsgexpgotheb-v.vf)
Provides:       tex(brsgexpgothebn-h.tfm)
Provides:       tex(brsgexpgothebn-h.vf)
Provides:       tex(brsgexpgothebn-v.tfm)
Provides:       tex(brsgexpgothebn-v.vf)
Provides:       tex(brsgexpgothr-h.tfm)
Provides:       tex(brsgexpgothr-h.vf)
Provides:       tex(brsgexpgothr-v.tfm)
Provides:       tex(brsgexpgothr-v.vf)
Provides:       tex(brsgexpgothrn-h.tfm)
Provides:       tex(brsgexpgothrn-h.vf)
Provides:       tex(brsgexpgothrn-v.tfm)
Provides:       tex(brsgexpgothrn-v.vf)
Provides:       tex(brsgexpmgothr-h.tfm)
Provides:       tex(brsgexpmgothr-h.vf)
Provides:       tex(brsgexpmgothr-v.tfm)
Provides:       tex(brsgexpmgothr-v.vf)
Provides:       tex(brsgexpmgothrn-h.tfm)
Provides:       tex(brsgexpmgothrn-h.vf)
Provides:       tex(brsgexpmgothrn-v.tfm)
Provides:       tex(brsgexpmgothrn-v.vf)
Provides:       tex(brsgexpminb-h.tfm)
Provides:       tex(brsgexpminb-h.vf)
Provides:       tex(brsgexpminb-v.tfm)
Provides:       tex(brsgexpminb-v.vf)
Provides:       tex(brsgexpminbn-h.tfm)
Provides:       tex(brsgexpminbn-h.vf)
Provides:       tex(brsgexpminbn-v.tfm)
Provides:       tex(brsgexpminbn-v.vf)
Provides:       tex(brsgexpminl-h.tfm)
Provides:       tex(brsgexpminl-h.vf)
Provides:       tex(brsgexpminl-v.tfm)
Provides:       tex(brsgexpminl-v.vf)
Provides:       tex(brsgexpminln-h.tfm)
Provides:       tex(brsgexpminln-h.vf)
Provides:       tex(brsgexpminln-v.tfm)
Provides:       tex(brsgexpminln-v.vf)
Provides:       tex(brsgexpminr-h.tfm)
Provides:       tex(brsgexpminr-h.vf)
Provides:       tex(brsgexpminr-v.tfm)
Provides:       tex(brsgexpminr-v.vf)
Provides:       tex(brsgexpminrn-h.tfm)
Provides:       tex(brsgexpminrn-h.vf)
Provides:       tex(brsgexpminrn-v.tfm)
Provides:       tex(brsgexpminrn-v.vf)
Provides:       tex(brsgnmlgothb-h.tfm)
Provides:       tex(brsgnmlgothb-h.vf)
Provides:       tex(brsgnmlgothb-v.tfm)
Provides:       tex(brsgnmlgothb-v.vf)
Provides:       tex(brsgnmlgothbn-h.tfm)
Provides:       tex(brsgnmlgothbn-h.vf)
Provides:       tex(brsgnmlgothbn-v.tfm)
Provides:       tex(brsgnmlgothbn-v.vf)
Provides:       tex(brsgnmlgotheb-h.tfm)
Provides:       tex(brsgnmlgotheb-h.vf)
Provides:       tex(brsgnmlgotheb-v.tfm)
Provides:       tex(brsgnmlgotheb-v.vf)
Provides:       tex(brsgnmlgothebn-h.tfm)
Provides:       tex(brsgnmlgothebn-h.vf)
Provides:       tex(brsgnmlgothebn-v.tfm)
Provides:       tex(brsgnmlgothebn-v.vf)
Provides:       tex(brsgnmlgothr-h.tfm)
Provides:       tex(brsgnmlgothr-h.vf)
Provides:       tex(brsgnmlgothr-v.tfm)
Provides:       tex(brsgnmlgothr-v.vf)
Provides:       tex(brsgnmlgothrn-h.tfm)
Provides:       tex(brsgnmlgothrn-h.vf)
Provides:       tex(brsgnmlgothrn-v.tfm)
Provides:       tex(brsgnmlgothrn-v.vf)
Provides:       tex(brsgnmlmgothr-h.tfm)
Provides:       tex(brsgnmlmgothr-h.vf)
Provides:       tex(brsgnmlmgothr-v.tfm)
Provides:       tex(brsgnmlmgothr-v.vf)
Provides:       tex(brsgnmlmgothrn-h.tfm)
Provides:       tex(brsgnmlmgothrn-h.vf)
Provides:       tex(brsgnmlmgothrn-v.tfm)
Provides:       tex(brsgnmlmgothrn-v.vf)
Provides:       tex(brsgnmlminb-h.tfm)
Provides:       tex(brsgnmlminb-h.vf)
Provides:       tex(brsgnmlminb-v.tfm)
Provides:       tex(brsgnmlminb-v.vf)
Provides:       tex(brsgnmlminbn-h.tfm)
Provides:       tex(brsgnmlminbn-h.vf)
Provides:       tex(brsgnmlminbn-v.tfm)
Provides:       tex(brsgnmlminbn-v.vf)
Provides:       tex(brsgnmlminl-h.tfm)
Provides:       tex(brsgnmlminl-h.vf)
Provides:       tex(brsgnmlminl-v.tfm)
Provides:       tex(brsgnmlminl-v.vf)
Provides:       tex(brsgnmlminln-h.tfm)
Provides:       tex(brsgnmlminln-h.vf)
Provides:       tex(brsgnmlminln-v.tfm)
Provides:       tex(brsgnmlminln-v.vf)
Provides:       tex(brsgnmlminr-h.tfm)
Provides:       tex(brsgnmlminr-h.vf)
Provides:       tex(brsgnmlminr-v.tfm)
Provides:       tex(brsgnmlminr-v.vf)
Provides:       tex(brsgnmlminrn-h.tfm)
Provides:       tex(brsgnmlminrn-h.vf)
Provides:       tex(brsgnmlminrn-v.tfm)
Provides:       tex(brsgnmlminrn-v.vf)
Provides:       tex(cidcgr0-h.tfm)
Provides:       tex(cidcgr0-h.vf)
Provides:       tex(cidcgr0-v.tfm)
Provides:       tex(cidcgr0-v.vf)
Provides:       tex(cidcgr1-h.tfm)
Provides:       tex(cidcgr1-h.vf)
Provides:       tex(cidcgr1-v.tfm)
Provides:       tex(cidcgr1-v.vf)
Provides:       tex(cidcgr2-h.tfm)
Provides:       tex(cidcgr2-h.vf)
Provides:       tex(cidcgr2-v.tfm)
Provides:       tex(cidcgr2-v.vf)
Provides:       tex(cidcgr3-h.tfm)
Provides:       tex(cidcgr3-h.vf)
Provides:       tex(cidcgr3-v.tfm)
Provides:       tex(cidcgr3-v.vf)
Provides:       tex(cidcgr4-h.tfm)
Provides:       tex(cidcgr4-h.vf)
Provides:       tex(cidcgr4-v.tfm)
Provides:       tex(cidcgr4-v.vf)
Provides:       tex(cidcgr5-h.tfm)
Provides:       tex(cidcgr5-h.vf)
Provides:       tex(cidcgr5-v.tfm)
Provides:       tex(cidcgr5-v.vf)
Provides:       tex(cidcgr6-h.tfm)
Provides:       tex(cidcgr6-h.vf)
Provides:       tex(cidcgr6-v.tfm)
Provides:       tex(cidcgr6-v.vf)
Provides:       tex(cidcgr7-h.tfm)
Provides:       tex(cidcgr7-h.vf)
Provides:       tex(cidcgr7-v.tfm)
Provides:       tex(cidcgr7-v.vf)
Provides:       tex(cidcmr0-h.tfm)
Provides:       tex(cidcmr0-h.vf)
Provides:       tex(cidcmr0-v.tfm)
Provides:       tex(cidcmr0-v.vf)
Provides:       tex(cidcmr1-h.tfm)
Provides:       tex(cidcmr1-h.vf)
Provides:       tex(cidcmr1-v.tfm)
Provides:       tex(cidcmr1-v.vf)
Provides:       tex(cidcmr2-h.tfm)
Provides:       tex(cidcmr2-h.vf)
Provides:       tex(cidcmr2-v.tfm)
Provides:       tex(cidcmr2-v.vf)
Provides:       tex(cidcmr3-h.tfm)
Provides:       tex(cidcmr3-h.vf)
Provides:       tex(cidcmr3-v.tfm)
Provides:       tex(cidcmr3-v.vf)
Provides:       tex(cidcmr4-h.tfm)
Provides:       tex(cidcmr4-h.vf)
Provides:       tex(cidcmr4-v.tfm)
Provides:       tex(cidcmr4-v.vf)
Provides:       tex(cidcmr5-h.tfm)
Provides:       tex(cidcmr5-h.vf)
Provides:       tex(cidcmr5-v.tfm)
Provides:       tex(cidcmr5-v.vf)
Provides:       tex(cidcmr6-h.tfm)
Provides:       tex(cidcmr6-h.vf)
Provides:       tex(cidcmr6-v.tfm)
Provides:       tex(cidcmr6-v.vf)
Provides:       tex(cidcmr7-h.tfm)
Provides:       tex(cidcmr7-h.vf)
Provides:       tex(cidcmr7-v.tfm)
Provides:       tex(cidcmr7-v.vf)
Provides:       tex(cidjgb0-h.tfm)
Provides:       tex(cidjgb0-h.vf)
Provides:       tex(cidjgb0-v.tfm)
Provides:       tex(cidjgb0-v.vf)
Provides:       tex(cidjgb1-h.tfm)
Provides:       tex(cidjgb1-h.vf)
Provides:       tex(cidjgb1-v.tfm)
Provides:       tex(cidjgb1-v.vf)
Provides:       tex(cidjgb2-h.tfm)
Provides:       tex(cidjgb2-h.vf)
Provides:       tex(cidjgb2-v.tfm)
Provides:       tex(cidjgb2-v.vf)
Provides:       tex(cidjgb3-h.tfm)
Provides:       tex(cidjgb3-h.vf)
Provides:       tex(cidjgb3-v.tfm)
Provides:       tex(cidjgb3-v.vf)
Provides:       tex(cidjgb4-h.tfm)
Provides:       tex(cidjgb4-h.vf)
Provides:       tex(cidjgb4-v.tfm)
Provides:       tex(cidjgb4-v.vf)
Provides:       tex(cidjgb5-h.tfm)
Provides:       tex(cidjgb5-h.vf)
Provides:       tex(cidjgb5-v.tfm)
Provides:       tex(cidjgb5-v.vf)
Provides:       tex(cidjge0-h.tfm)
Provides:       tex(cidjge0-h.vf)
Provides:       tex(cidjge0-v.tfm)
Provides:       tex(cidjge0-v.vf)
Provides:       tex(cidjge1-h.tfm)
Provides:       tex(cidjge1-h.vf)
Provides:       tex(cidjge1-v.tfm)
Provides:       tex(cidjge1-v.vf)
Provides:       tex(cidjge2-h.tfm)
Provides:       tex(cidjge2-h.vf)
Provides:       tex(cidjge2-v.tfm)
Provides:       tex(cidjge2-v.vf)
Provides:       tex(cidjge3-h.tfm)
Provides:       tex(cidjge3-h.vf)
Provides:       tex(cidjge3-v.tfm)
Provides:       tex(cidjge3-v.vf)
Provides:       tex(cidjge4-h.tfm)
Provides:       tex(cidjge4-h.vf)
Provides:       tex(cidjge4-v.tfm)
Provides:       tex(cidjge4-v.vf)
Provides:       tex(cidjge5-h.tfm)
Provides:       tex(cidjge5-h.vf)
Provides:       tex(cidjge5-v.tfm)
Provides:       tex(cidjge5-v.vf)
Provides:       tex(cidjgr0-h.tfm)
Provides:       tex(cidjgr0-h.vf)
Provides:       tex(cidjgr0-v.tfm)
Provides:       tex(cidjgr0-v.vf)
Provides:       tex(cidjgr1-h.tfm)
Provides:       tex(cidjgr1-h.vf)
Provides:       tex(cidjgr1-v.tfm)
Provides:       tex(cidjgr1-v.vf)
Provides:       tex(cidjgr2-h.tfm)
Provides:       tex(cidjgr2-h.vf)
Provides:       tex(cidjgr2-v.tfm)
Provides:       tex(cidjgr2-v.vf)
Provides:       tex(cidjgr3-h.tfm)
Provides:       tex(cidjgr3-h.vf)
Provides:       tex(cidjgr3-v.tfm)
Provides:       tex(cidjgr3-v.vf)
Provides:       tex(cidjgr4-h.tfm)
Provides:       tex(cidjgr4-h.vf)
Provides:       tex(cidjgr4-v.tfm)
Provides:       tex(cidjgr4-v.vf)
Provides:       tex(cidjgr5-h.tfm)
Provides:       tex(cidjgr5-h.vf)
Provides:       tex(cidjgr5-v.tfm)
Provides:       tex(cidjgr5-v.vf)
Provides:       tex(cidjmb0-h.tfm)
Provides:       tex(cidjmb0-h.vf)
Provides:       tex(cidjmb0-v.tfm)
Provides:       tex(cidjmb0-v.vf)
Provides:       tex(cidjmb1-h.tfm)
Provides:       tex(cidjmb1-h.vf)
Provides:       tex(cidjmb1-v.tfm)
Provides:       tex(cidjmb1-v.vf)
Provides:       tex(cidjmb2-h.tfm)
Provides:       tex(cidjmb2-h.vf)
Provides:       tex(cidjmb2-v.tfm)
Provides:       tex(cidjmb2-v.vf)
Provides:       tex(cidjmb3-h.tfm)
Provides:       tex(cidjmb3-h.vf)
Provides:       tex(cidjmb3-v.tfm)
Provides:       tex(cidjmb3-v.vf)
Provides:       tex(cidjmb4-h.tfm)
Provides:       tex(cidjmb4-h.vf)
Provides:       tex(cidjmb4-v.tfm)
Provides:       tex(cidjmb4-v.vf)
Provides:       tex(cidjmb5-h.tfm)
Provides:       tex(cidjmb5-h.vf)
Provides:       tex(cidjmb5-v.tfm)
Provides:       tex(cidjmb5-v.vf)
Provides:       tex(cidjmgr0-h.tfm)
Provides:       tex(cidjmgr0-h.vf)
Provides:       tex(cidjmgr0-v.tfm)
Provides:       tex(cidjmgr0-v.vf)
Provides:       tex(cidjmgr1-h.tfm)
Provides:       tex(cidjmgr1-h.vf)
Provides:       tex(cidjmgr1-v.tfm)
Provides:       tex(cidjmgr1-v.vf)
Provides:       tex(cidjmgr2-h.tfm)
Provides:       tex(cidjmgr2-h.vf)
Provides:       tex(cidjmgr2-v.tfm)
Provides:       tex(cidjmgr2-v.vf)
Provides:       tex(cidjmgr3-h.tfm)
Provides:       tex(cidjmgr3-h.vf)
Provides:       tex(cidjmgr3-v.tfm)
Provides:       tex(cidjmgr3-v.vf)
Provides:       tex(cidjmgr4-h.tfm)
Provides:       tex(cidjmgr4-h.vf)
Provides:       tex(cidjmgr4-v.tfm)
Provides:       tex(cidjmgr4-v.vf)
Provides:       tex(cidjmgr5-h.tfm)
Provides:       tex(cidjmgr5-h.vf)
Provides:       tex(cidjmgr5-v.tfm)
Provides:       tex(cidjmgr5-v.vf)
Provides:       tex(cidjml0-h.tfm)
Provides:       tex(cidjml0-h.vf)
Provides:       tex(cidjml0-v.tfm)
Provides:       tex(cidjml0-v.vf)
Provides:       tex(cidjml1-h.tfm)
Provides:       tex(cidjml1-h.vf)
Provides:       tex(cidjml1-v.tfm)
Provides:       tex(cidjml1-v.vf)
Provides:       tex(cidjml2-h.tfm)
Provides:       tex(cidjml2-h.vf)
Provides:       tex(cidjml2-v.tfm)
Provides:       tex(cidjml2-v.vf)
Provides:       tex(cidjml3-h.tfm)
Provides:       tex(cidjml3-h.vf)
Provides:       tex(cidjml3-v.tfm)
Provides:       tex(cidjml3-v.vf)
Provides:       tex(cidjml4-h.tfm)
Provides:       tex(cidjml4-h.vf)
Provides:       tex(cidjml4-v.tfm)
Provides:       tex(cidjml4-v.vf)
Provides:       tex(cidjml5-h.tfm)
Provides:       tex(cidjml5-h.vf)
Provides:       tex(cidjml5-v.tfm)
Provides:       tex(cidjml5-v.vf)
Provides:       tex(cidjmr0-h.tfm)
Provides:       tex(cidjmr0-h.vf)
Provides:       tex(cidjmr0-v.tfm)
Provides:       tex(cidjmr0-v.vf)
Provides:       tex(cidjmr1-h.tfm)
Provides:       tex(cidjmr1-h.vf)
Provides:       tex(cidjmr1-v.tfm)
Provides:       tex(cidjmr1-v.vf)
Provides:       tex(cidjmr2-h.tfm)
Provides:       tex(cidjmr2-h.vf)
Provides:       tex(cidjmr2-v.tfm)
Provides:       tex(cidjmr2-v.vf)
Provides:       tex(cidjmr3-h.tfm)
Provides:       tex(cidjmr3-h.vf)
Provides:       tex(cidjmr3-v.tfm)
Provides:       tex(cidjmr3-v.vf)
Provides:       tex(cidjmr4-h.tfm)
Provides:       tex(cidjmr4-h.vf)
Provides:       tex(cidjmr4-v.tfm)
Provides:       tex(cidjmr4-v.vf)
Provides:       tex(cidjmr5-h.tfm)
Provides:       tex(cidjmr5-h.vf)
Provides:       tex(cidjmr5-v.tfm)
Provides:       tex(cidjmr5-v.vf)
Provides:       tex(cidkgr0-h.tfm)
Provides:       tex(cidkgr0-h.vf)
Provides:       tex(cidkgr0-v.tfm)
Provides:       tex(cidkgr0-v.vf)
Provides:       tex(cidkgr1-h.tfm)
Provides:       tex(cidkgr1-h.vf)
Provides:       tex(cidkgr1-v.tfm)
Provides:       tex(cidkgr1-v.vf)
Provides:       tex(cidkgr2-h.tfm)
Provides:       tex(cidkgr2-h.vf)
Provides:       tex(cidkgr2-v.tfm)
Provides:       tex(cidkgr2-v.vf)
Provides:       tex(cidkgr3-h.tfm)
Provides:       tex(cidkgr3-h.vf)
Provides:       tex(cidkgr3-v.tfm)
Provides:       tex(cidkgr3-v.vf)
Provides:       tex(cidkgr4-h.tfm)
Provides:       tex(cidkgr4-h.vf)
Provides:       tex(cidkgr4-v.tfm)
Provides:       tex(cidkgr4-v.vf)
Provides:       tex(cidkmr0-h.tfm)
Provides:       tex(cidkmr0-h.vf)
Provides:       tex(cidkmr0-v.tfm)
Provides:       tex(cidkmr0-v.vf)
Provides:       tex(cidkmr1-h.tfm)
Provides:       tex(cidkmr1-h.vf)
Provides:       tex(cidkmr1-v.tfm)
Provides:       tex(cidkmr1-v.vf)
Provides:       tex(cidkmr2-h.tfm)
Provides:       tex(cidkmr2-h.vf)
Provides:       tex(cidkmr2-v.tfm)
Provides:       tex(cidkmr2-v.vf)
Provides:       tex(cidkmr3-h.tfm)
Provides:       tex(cidkmr3-h.vf)
Provides:       tex(cidkmr3-v.tfm)
Provides:       tex(cidkmr3-v.vf)
Provides:       tex(cidkmr4-h.tfm)
Provides:       tex(cidkmr4-h.vf)
Provides:       tex(cidkmr4-v.tfm)
Provides:       tex(cidkmr4-v.vf)
Provides:       tex(cidtgr0-h.tfm)
Provides:       tex(cidtgr0-h.vf)
Provides:       tex(cidtgr0-v.tfm)
Provides:       tex(cidtgr0-v.vf)
Provides:       tex(cidtgr1-h.tfm)
Provides:       tex(cidtgr1-h.vf)
Provides:       tex(cidtgr1-v.tfm)
Provides:       tex(cidtgr1-v.vf)
Provides:       tex(cidtgr2-h.tfm)
Provides:       tex(cidtgr2-h.vf)
Provides:       tex(cidtgr2-v.tfm)
Provides:       tex(cidtgr2-v.vf)
Provides:       tex(cidtgr3-h.tfm)
Provides:       tex(cidtgr3-h.vf)
Provides:       tex(cidtgr3-v.tfm)
Provides:       tex(cidtgr3-v.vf)
Provides:       tex(cidtgr4-h.tfm)
Provides:       tex(cidtgr4-h.vf)
Provides:       tex(cidtgr4-v.tfm)
Provides:       tex(cidtgr4-v.vf)
Provides:       tex(cidtmr0-h.tfm)
Provides:       tex(cidtmr0-h.vf)
Provides:       tex(cidtmr0-v.tfm)
Provides:       tex(cidtmr0-v.vf)
Provides:       tex(cidtmr1-h.tfm)
Provides:       tex(cidtmr1-h.vf)
Provides:       tex(cidtmr1-v.tfm)
Provides:       tex(cidtmr1-v.vf)
Provides:       tex(cidtmr2-h.tfm)
Provides:       tex(cidtmr2-h.vf)
Provides:       tex(cidtmr2-v.tfm)
Provides:       tex(cidtmr2-v.vf)
Provides:       tex(cidtmr3-h.tfm)
Provides:       tex(cidtmr3-h.vf)
Provides:       tex(cidtmr3-v.tfm)
Provides:       tex(cidtmr3-v.vf)
Provides:       tex(cidtmr4-h.tfm)
Provides:       tex(cidtmr4-h.vf)
Provides:       tex(cidtmr4-v.tfm)
Provides:       tex(cidtmr4-v.vf)
Provides:       tex(expgothb-h.tfm)
Provides:       tex(expgothb-h.vf)
Provides:       tex(expgothb-v.tfm)
Provides:       tex(expgothb-v.vf)
Provides:       tex(expgothbn-h.tfm)
Provides:       tex(expgothbn-h.vf)
Provides:       tex(expgothbn-v.tfm)
Provides:       tex(expgothbn-v.vf)
Provides:       tex(expgotheb-h.tfm)
Provides:       tex(expgotheb-h.vf)
Provides:       tex(expgotheb-v.tfm)
Provides:       tex(expgotheb-v.vf)
Provides:       tex(expgothebn-h.tfm)
Provides:       tex(expgothebn-h.vf)
Provides:       tex(expgothebn-v.tfm)
Provides:       tex(expgothebn-v.vf)
Provides:       tex(expgothr-h.tfm)
Provides:       tex(expgothr-h.vf)
Provides:       tex(expgothr-v.tfm)
Provides:       tex(expgothr-v.vf)
Provides:       tex(expgothrn-h.tfm)
Provides:       tex(expgothrn-h.vf)
Provides:       tex(expgothrn-v.tfm)
Provides:       tex(expgothrn-v.vf)
Provides:       tex(expmgothr-h.tfm)
Provides:       tex(expmgothr-h.vf)
Provides:       tex(expmgothr-v.tfm)
Provides:       tex(expmgothr-v.vf)
Provides:       tex(expmgothrn-h.tfm)
Provides:       tex(expmgothrn-h.vf)
Provides:       tex(expmgothrn-v.tfm)
Provides:       tex(expmgothrn-v.vf)
Provides:       tex(expminb-h.tfm)
Provides:       tex(expminb-h.vf)
Provides:       tex(expminb-v.tfm)
Provides:       tex(expminb-v.vf)
Provides:       tex(expminbn-h.tfm)
Provides:       tex(expminbn-h.vf)
Provides:       tex(expminbn-v.tfm)
Provides:       tex(expminbn-v.vf)
Provides:       tex(expminl-h.tfm)
Provides:       tex(expminl-h.vf)
Provides:       tex(expminl-v.tfm)
Provides:       tex(expminl-v.vf)
Provides:       tex(expminln-h.tfm)
Provides:       tex(expminln-h.vf)
Provides:       tex(expminln-v.tfm)
Provides:       tex(expminln-v.vf)
Provides:       tex(expminr-h.tfm)
Provides:       tex(expminr-h.vf)
Provides:       tex(expminr-v.tfm)
Provides:       tex(expminr-v.vf)
Provides:       tex(expminrn-h.tfm)
Provides:       tex(expminrn-h.vf)
Provides:       tex(expminrn-v.tfm)
Provides:       tex(expminrn-v.vf)
Provides:       tex(hgothb-h.tfm)
Provides:       tex(hgothb-v.tfm)
Provides:       tex(hgothbn-h.tfm)
Provides:       tex(hgothbn-v.tfm)
Provides:       tex(hgotheb-h.tfm)
Provides:       tex(hgotheb-v.tfm)
Provides:       tex(hgothebn-h.tfm)
Provides:       tex(hgothebn-v.tfm)
Provides:       tex(hgothr-h.tfm)
Provides:       tex(hgothr-v.tfm)
Provides:       tex(hgothrn-h.tfm)
Provides:       tex(hgothrn-v.tfm)
Provides:       tex(hmgothr-h.tfm)
Provides:       tex(hmgothr-v.tfm)
Provides:       tex(hmgothrn-h.tfm)
Provides:       tex(hmgothrn-v.tfm)
Provides:       tex(hminb-h.tfm)
Provides:       tex(hminb-v.tfm)
Provides:       tex(hminbn-h.tfm)
Provides:       tex(hminbn-v.tfm)
Provides:       tex(hminl-h.tfm)
Provides:       tex(hminl-v.tfm)
Provides:       tex(hminln-h.tfm)
Provides:       tex(hminln-v.tfm)
Provides:       tex(hminr-h.tfm)
Provides:       tex(hminr-v.tfm)
Provides:       tex(hminrn-h.tfm)
Provides:       tex(hminrn-v.tfm)
Provides:       tex(mlcid.sty)
Provides:       tex(mlutf.sty)
Provides:       tex(nmlgothb-h.tfm)
Provides:       tex(nmlgothb-h.vf)
Provides:       tex(nmlgothb-v.tfm)
Provides:       tex(nmlgothb-v.vf)
Provides:       tex(nmlgothbn-h.tfm)
Provides:       tex(nmlgothbn-h.vf)
Provides:       tex(nmlgothbn-v.tfm)
Provides:       tex(nmlgothbn-v.vf)
Provides:       tex(nmlgotheb-h.tfm)
Provides:       tex(nmlgotheb-h.vf)
Provides:       tex(nmlgotheb-v.tfm)
Provides:       tex(nmlgotheb-v.vf)
Provides:       tex(nmlgothebn-h.tfm)
Provides:       tex(nmlgothebn-h.vf)
Provides:       tex(nmlgothebn-v.tfm)
Provides:       tex(nmlgothebn-v.vf)
Provides:       tex(nmlgothr-h.tfm)
Provides:       tex(nmlgothr-h.vf)
Provides:       tex(nmlgothr-v.tfm)
Provides:       tex(nmlgothr-v.vf)
Provides:       tex(nmlgothrn-h.tfm)
Provides:       tex(nmlgothrn-h.vf)
Provides:       tex(nmlgothrn-v.tfm)
Provides:       tex(nmlgothrn-v.vf)
Provides:       tex(nmlmgothr-h.tfm)
Provides:       tex(nmlmgothr-h.vf)
Provides:       tex(nmlmgothr-v.tfm)
Provides:       tex(nmlmgothr-v.vf)
Provides:       tex(nmlmgothrn-h.tfm)
Provides:       tex(nmlmgothrn-h.vf)
Provides:       tex(nmlmgothrn-v.tfm)
Provides:       tex(nmlmgothrn-v.vf)
Provides:       tex(nmlminb-h.tfm)
Provides:       tex(nmlminb-h.vf)
Provides:       tex(nmlminb-v.tfm)
Provides:       tex(nmlminb-v.vf)
Provides:       tex(nmlminbn-h.tfm)
Provides:       tex(nmlminbn-h.vf)
Provides:       tex(nmlminbn-v.tfm)
Provides:       tex(nmlminbn-v.vf)
Provides:       tex(nmlminl-h.tfm)
Provides:       tex(nmlminl-h.vf)
Provides:       tex(nmlminl-v.tfm)
Provides:       tex(nmlminl-v.vf)
Provides:       tex(nmlminln-h.tfm)
Provides:       tex(nmlminln-h.vf)
Provides:       tex(nmlminln-v.tfm)
Provides:       tex(nmlminln-v.vf)
Provides:       tex(nmlminr-h.tfm)
Provides:       tex(nmlminr-h.vf)
Provides:       tex(nmlminr-v.tfm)
Provides:       tex(nmlminr-v.vf)
Provides:       tex(nmlminrn-h.tfm)
Provides:       tex(nmlminrn-h.vf)
Provides:       tex(nmlminrn-v.tfm)
Provides:       tex(nmlminrn-v.vf)
Provides:       tex(otf-ccgr-h.tfm)
Provides:       tex(otf-ccgr-v.tfm)
Provides:       tex(otf-ccmr-h.tfm)
Provides:       tex(otf-ccmr-v.tfm)
Provides:       tex(otf-cjgb-h.tfm)
Provides:       tex(otf-cjgb-v.tfm)
Provides:       tex(otf-cjge-h.tfm)
Provides:       tex(otf-cjge-v.tfm)
Provides:       tex(otf-cjgr-h.tfm)
Provides:       tex(otf-cjgr-v.tfm)
Provides:       tex(otf-cjmb-h.tfm)
Provides:       tex(otf-cjmb-v.tfm)
Provides:       tex(otf-cjmgr-h.tfm)
Provides:       tex(otf-cjmgr-v.tfm)
Provides:       tex(otf-cjml-h.tfm)
Provides:       tex(otf-cjml-v.tfm)
Provides:       tex(otf-cjmr-h.tfm)
Provides:       tex(otf-cjmr-v.tfm)
Provides:       tex(otf-ckgr-h.tfm)
Provides:       tex(otf-ckgr-v.tfm)
Provides:       tex(otf-ckmr-h.tfm)
Provides:       tex(otf-ckmr-v.tfm)
Provides:       tex(otf-ctgr-h.tfm)
Provides:       tex(otf-ctgr-v.tfm)
Provides:       tex(otf-ctmr-h.tfm)
Provides:       tex(otf-ctmr-v.tfm)
Provides:       tex(otf-ucgb-h.tfm)
Provides:       tex(otf-ucgb-v.tfm)
Provides:       tex(otf-ucge-h.tfm)
Provides:       tex(otf-ucge-v.tfm)
Provides:       tex(otf-ucgr-h.tfm)
Provides:       tex(otf-ucgr-v.tfm)
Provides:       tex(otf-ucmb-h.tfm)
Provides:       tex(otf-ucmb-v.tfm)
Provides:       tex(otf-ucmgr-h.tfm)
Provides:       tex(otf-ucmgr-v.tfm)
Provides:       tex(otf-ucml-h.tfm)
Provides:       tex(otf-ucml-v.tfm)
Provides:       tex(otf-ucmr-h.tfm)
Provides:       tex(otf-ucmr-v.tfm)
Provides:       tex(otf-ujgb-h.tfm)
Provides:       tex(otf-ujgb-v.tfm)
Provides:       tex(otf-ujgbn-h.tfm)
Provides:       tex(otf-ujgbn-v.tfm)
Provides:       tex(otf-ujge-h.tfm)
Provides:       tex(otf-ujge-v.tfm)
Provides:       tex(otf-ujgen-h.tfm)
Provides:       tex(otf-ujgen-v.tfm)
Provides:       tex(otf-ujgr-h.tfm)
Provides:       tex(otf-ujgr-v.tfm)
Provides:       tex(otf-ujgrn-h.tfm)
Provides:       tex(otf-ujgrn-v.tfm)
Provides:       tex(otf-ujmb-h.tfm)
Provides:       tex(otf-ujmb-v.tfm)
Provides:       tex(otf-ujmbn-h.tfm)
Provides:       tex(otf-ujmbn-v.tfm)
Provides:       tex(otf-ujmgr-h.tfm)
Provides:       tex(otf-ujmgr-v.tfm)
Provides:       tex(otf-ujmgrn-h.tfm)
Provides:       tex(otf-ujmgrn-v.tfm)
Provides:       tex(otf-ujml-h.tfm)
Provides:       tex(otf-ujml-v.tfm)
Provides:       tex(otf-ujmln-h.tfm)
Provides:       tex(otf-ujmln-v.tfm)
Provides:       tex(otf-ujmr-h.tfm)
Provides:       tex(otf-ujmr-v.tfm)
Provides:       tex(otf-ujmrn-h.tfm)
Provides:       tex(otf-ujmrn-v.tfm)
Provides:       tex(otf-ukgb-h.tfm)
Provides:       tex(otf-ukgb-v.tfm)
Provides:       tex(otf-ukge-h.tfm)
Provides:       tex(otf-ukge-v.tfm)
Provides:       tex(otf-ukgr-h.tfm)
Provides:       tex(otf-ukgr-v.tfm)
Provides:       tex(otf-ukmb-h.tfm)
Provides:       tex(otf-ukmb-v.tfm)
Provides:       tex(otf-ukmgr-h.tfm)
Provides:       tex(otf-ukmgr-v.tfm)
Provides:       tex(otf-ukml-h.tfm)
Provides:       tex(otf-ukml-v.tfm)
Provides:       tex(otf-ukmr-h.tfm)
Provides:       tex(otf-ukmr-v.tfm)
Provides:       tex(otf-utgb-h.tfm)
Provides:       tex(otf-utgb-v.tfm)
Provides:       tex(otf-utge-h.tfm)
Provides:       tex(otf-utge-v.tfm)
Provides:       tex(otf-utgr-h.tfm)
Provides:       tex(otf-utgr-v.tfm)
Provides:       tex(otf-utmb-h.tfm)
Provides:       tex(otf-utmb-v.tfm)
Provides:       tex(otf-utmgr-h.tfm)
Provides:       tex(otf-utmgr-v.tfm)
Provides:       tex(otf-utml-h.tfm)
Provides:       tex(otf-utml-v.tfm)
Provides:       tex(otf-utmr-h.tfm)
Provides:       tex(otf-utmr-v.tfm)
Provides:       tex(otf.sty)
Provides:       tex(redeffont.sty)
Provides:       tex(rubygothb-h.tfm)
Provides:       tex(rubygothb-h.vf)
Provides:       tex(rubygothb-v.tfm)
Provides:       tex(rubygothb-v.vf)
Provides:       tex(rubygotheb-h.tfm)
Provides:       tex(rubygotheb-h.vf)
Provides:       tex(rubygotheb-v.tfm)
Provides:       tex(rubygotheb-v.vf)
Provides:       tex(rubygothr-h.tfm)
Provides:       tex(rubygothr-h.vf)
Provides:       tex(rubygothr-v.tfm)
Provides:       tex(rubygothr-v.vf)
Provides:       tex(rubymgothr-h.tfm)
Provides:       tex(rubymgothr-h.vf)
Provides:       tex(rubymgothr-v.tfm)
Provides:       tex(rubymgothr-v.vf)
Provides:       tex(rubyminb-h.tfm)
Provides:       tex(rubyminb-h.vf)
Provides:       tex(rubyminb-v.tfm)
Provides:       tex(rubyminb-v.vf)
Provides:       tex(rubyminl-h.tfm)
Provides:       tex(rubyminl-h.vf)
Provides:       tex(rubyminl-v.tfm)
Provides:       tex(rubyminl-v.vf)
Provides:       tex(rubyminr-h.tfm)
Provides:       tex(rubyminr-h.vf)
Provides:       tex(rubyminr-v.tfm)
Provides:       tex(rubyminr-v.vf)
Provides:       tex(upakorgothb-h.tfm)
Provides:       tex(upakorgothb-v.tfm)
Provides:       tex(upakorgotheb-h.tfm)
Provides:       tex(upakorgotheb-v.tfm)
Provides:       tex(upakorgothr-h.tfm)
Provides:       tex(upakorgothr-v.tfm)
Provides:       tex(upakormgothr-h.tfm)
Provides:       tex(upakormgothr-v.tfm)
Provides:       tex(upakorminb-h.tfm)
Provides:       tex(upakorminb-v.tfm)
Provides:       tex(upakorminl-h.tfm)
Provides:       tex(upakorminl-v.tfm)
Provides:       tex(upakorminr-h.tfm)
Provides:       tex(upakorminr-v.tfm)
Provides:       tex(upaschgothb-h.tfm)
Provides:       tex(upaschgothb-v.tfm)
Provides:       tex(upaschgotheb-h.tfm)
Provides:       tex(upaschgotheb-v.tfm)
Provides:       tex(upaschgothr-h.tfm)
Provides:       tex(upaschgothr-v.tfm)
Provides:       tex(upaschmgothr-h.tfm)
Provides:       tex(upaschmgothr-v.tfm)
Provides:       tex(upaschminb-h.tfm)
Provides:       tex(upaschminb-v.tfm)
Provides:       tex(upaschminl-h.tfm)
Provides:       tex(upaschminl-v.tfm)
Provides:       tex(upaschminr-h.tfm)
Provides:       tex(upaschminr-v.tfm)
Provides:       tex(upatchgothb-h.tfm)
Provides:       tex(upatchgothb-v.tfm)
Provides:       tex(upatchgotheb-h.tfm)
Provides:       tex(upatchgotheb-v.tfm)
Provides:       tex(upatchgothr-h.tfm)
Provides:       tex(upatchgothr-v.tfm)
Provides:       tex(upatchmgothr-h.tfm)
Provides:       tex(upatchmgothr-v.tfm)
Provides:       tex(upatchminb-h.tfm)
Provides:       tex(upatchminb-v.tfm)
Provides:       tex(upatchminl-h.tfm)
Provides:       tex(upatchminl-v.tfm)
Provides:       tex(upatchminr-h.tfm)
Provides:       tex(upatchminr-v.tfm)
Provides:       tex(upbrsgexpgothb-h.tfm)
Provides:       tex(upbrsgexpgothb-h.vf)
Provides:       tex(upbrsgexpgothb-v.tfm)
Provides:       tex(upbrsgexpgothb-v.vf)
Provides:       tex(upbrsgexpgothbn-h.tfm)
Provides:       tex(upbrsgexpgothbn-h.vf)
Provides:       tex(upbrsgexpgothbn-v.tfm)
Provides:       tex(upbrsgexpgothbn-v.vf)
Provides:       tex(upbrsgexpgotheb-h.tfm)
Provides:       tex(upbrsgexpgotheb-h.vf)
Provides:       tex(upbrsgexpgotheb-v.tfm)
Provides:       tex(upbrsgexpgotheb-v.vf)
Provides:       tex(upbrsgexpgothebn-h.tfm)
Provides:       tex(upbrsgexpgothebn-h.vf)
Provides:       tex(upbrsgexpgothebn-v.tfm)
Provides:       tex(upbrsgexpgothebn-v.vf)
Provides:       tex(upbrsgexpgothr-h.tfm)
Provides:       tex(upbrsgexpgothr-h.vf)
Provides:       tex(upbrsgexpgothr-v.tfm)
Provides:       tex(upbrsgexpgothr-v.vf)
Provides:       tex(upbrsgexpgothrn-h.tfm)
Provides:       tex(upbrsgexpgothrn-h.vf)
Provides:       tex(upbrsgexpgothrn-v.tfm)
Provides:       tex(upbrsgexpgothrn-v.vf)
Provides:       tex(upbrsgexpmgothr-h.tfm)
Provides:       tex(upbrsgexpmgothr-h.vf)
Provides:       tex(upbrsgexpmgothr-v.tfm)
Provides:       tex(upbrsgexpmgothr-v.vf)
Provides:       tex(upbrsgexpmgothrn-h.tfm)
Provides:       tex(upbrsgexpmgothrn-h.vf)
Provides:       tex(upbrsgexpmgothrn-v.tfm)
Provides:       tex(upbrsgexpmgothrn-v.vf)
Provides:       tex(upbrsgexpminb-h.tfm)
Provides:       tex(upbrsgexpminb-h.vf)
Provides:       tex(upbrsgexpminb-v.tfm)
Provides:       tex(upbrsgexpminb-v.vf)
Provides:       tex(upbrsgexpminbn-h.tfm)
Provides:       tex(upbrsgexpminbn-h.vf)
Provides:       tex(upbrsgexpminbn-v.tfm)
Provides:       tex(upbrsgexpminbn-v.vf)
Provides:       tex(upbrsgexpminl-h.tfm)
Provides:       tex(upbrsgexpminl-h.vf)
Provides:       tex(upbrsgexpminl-v.tfm)
Provides:       tex(upbrsgexpminl-v.vf)
Provides:       tex(upbrsgexpminln-h.tfm)
Provides:       tex(upbrsgexpminln-h.vf)
Provides:       tex(upbrsgexpminln-v.tfm)
Provides:       tex(upbrsgexpminln-v.vf)
Provides:       tex(upbrsgexpminr-h.tfm)
Provides:       tex(upbrsgexpminr-h.vf)
Provides:       tex(upbrsgexpminr-v.tfm)
Provides:       tex(upbrsgexpminr-v.vf)
Provides:       tex(upbrsgexpminrn-h.tfm)
Provides:       tex(upbrsgexpminrn-h.vf)
Provides:       tex(upbrsgexpminrn-v.tfm)
Provides:       tex(upbrsgexpminrn-v.vf)
Provides:       tex(upbrsgnmlgothb-h.tfm)
Provides:       tex(upbrsgnmlgothb-h.vf)
Provides:       tex(upbrsgnmlgothb-v.tfm)
Provides:       tex(upbrsgnmlgothb-v.vf)
Provides:       tex(upbrsgnmlgothbn-h.tfm)
Provides:       tex(upbrsgnmlgothbn-h.vf)
Provides:       tex(upbrsgnmlgothbn-v.tfm)
Provides:       tex(upbrsgnmlgothbn-v.vf)
Provides:       tex(upbrsgnmlgotheb-h.tfm)
Provides:       tex(upbrsgnmlgotheb-h.vf)
Provides:       tex(upbrsgnmlgotheb-v.tfm)
Provides:       tex(upbrsgnmlgotheb-v.vf)
Provides:       tex(upbrsgnmlgothebn-h.tfm)
Provides:       tex(upbrsgnmlgothebn-h.vf)
Provides:       tex(upbrsgnmlgothebn-v.tfm)
Provides:       tex(upbrsgnmlgothebn-v.vf)
Provides:       tex(upbrsgnmlgothr-h.tfm)
Provides:       tex(upbrsgnmlgothr-h.vf)
Provides:       tex(upbrsgnmlgothr-v.tfm)
Provides:       tex(upbrsgnmlgothr-v.vf)
Provides:       tex(upbrsgnmlgothrn-h.tfm)
Provides:       tex(upbrsgnmlgothrn-h.vf)
Provides:       tex(upbrsgnmlgothrn-v.tfm)
Provides:       tex(upbrsgnmlgothrn-v.vf)
Provides:       tex(upbrsgnmlmgothr-h.tfm)
Provides:       tex(upbrsgnmlmgothr-h.vf)
Provides:       tex(upbrsgnmlmgothr-v.tfm)
Provides:       tex(upbrsgnmlmgothr-v.vf)
Provides:       tex(upbrsgnmlmgothrn-h.tfm)
Provides:       tex(upbrsgnmlmgothrn-h.vf)
Provides:       tex(upbrsgnmlmgothrn-v.tfm)
Provides:       tex(upbrsgnmlmgothrn-v.vf)
Provides:       tex(upbrsgnmlminb-h.tfm)
Provides:       tex(upbrsgnmlminb-h.vf)
Provides:       tex(upbrsgnmlminb-v.tfm)
Provides:       tex(upbrsgnmlminb-v.vf)
Provides:       tex(upbrsgnmlminbn-h.tfm)
Provides:       tex(upbrsgnmlminbn-h.vf)
Provides:       tex(upbrsgnmlminbn-v.tfm)
Provides:       tex(upbrsgnmlminbn-v.vf)
Provides:       tex(upbrsgnmlminl-h.tfm)
Provides:       tex(upbrsgnmlminl-h.vf)
Provides:       tex(upbrsgnmlminl-v.tfm)
Provides:       tex(upbrsgnmlminl-v.vf)
Provides:       tex(upbrsgnmlminln-h.tfm)
Provides:       tex(upbrsgnmlminln-h.vf)
Provides:       tex(upbrsgnmlminln-v.tfm)
Provides:       tex(upbrsgnmlminln-v.vf)
Provides:       tex(upbrsgnmlminr-h.tfm)
Provides:       tex(upbrsgnmlminr-h.vf)
Provides:       tex(upbrsgnmlminr-v.tfm)
Provides:       tex(upbrsgnmlminr-v.vf)
Provides:       tex(upbrsgnmlminrn-h.tfm)
Provides:       tex(upbrsgnmlminrn-h.vf)
Provides:       tex(upbrsgnmlminrn-v.tfm)
Provides:       tex(upbrsgnmlminrn-v.vf)
Provides:       tex(upexpgothb-h.tfm)
Provides:       tex(upexpgothb-h.vf)
Provides:       tex(upexpgothb-v.tfm)
Provides:       tex(upexpgothb-v.vf)
Provides:       tex(upexpgothbn-h.tfm)
Provides:       tex(upexpgothbn-h.vf)
Provides:       tex(upexpgothbn-v.tfm)
Provides:       tex(upexpgothbn-v.vf)
Provides:       tex(upexpgotheb-h.tfm)
Provides:       tex(upexpgotheb-h.vf)
Provides:       tex(upexpgotheb-v.tfm)
Provides:       tex(upexpgotheb-v.vf)
Provides:       tex(upexpgothebn-h.tfm)
Provides:       tex(upexpgothebn-h.vf)
Provides:       tex(upexpgothebn-v.tfm)
Provides:       tex(upexpgothebn-v.vf)
Provides:       tex(upexpgothr-h.tfm)
Provides:       tex(upexpgothr-h.vf)
Provides:       tex(upexpgothr-v.tfm)
Provides:       tex(upexpgothr-v.vf)
Provides:       tex(upexpgothrn-h.tfm)
Provides:       tex(upexpgothrn-h.vf)
Provides:       tex(upexpgothrn-v.tfm)
Provides:       tex(upexpgothrn-v.vf)
Provides:       tex(upexpmgothr-h.tfm)
Provides:       tex(upexpmgothr-h.vf)
Provides:       tex(upexpmgothr-v.tfm)
Provides:       tex(upexpmgothr-v.vf)
Provides:       tex(upexpmgothrn-h.tfm)
Provides:       tex(upexpmgothrn-h.vf)
Provides:       tex(upexpmgothrn-v.tfm)
Provides:       tex(upexpmgothrn-v.vf)
Provides:       tex(upexpminb-h.tfm)
Provides:       tex(upexpminb-h.vf)
Provides:       tex(upexpminb-v.tfm)
Provides:       tex(upexpminb-v.vf)
Provides:       tex(upexpminbn-h.tfm)
Provides:       tex(upexpminbn-h.vf)
Provides:       tex(upexpminbn-v.tfm)
Provides:       tex(upexpminbn-v.vf)
Provides:       tex(upexpminl-h.tfm)
Provides:       tex(upexpminl-h.vf)
Provides:       tex(upexpminl-v.tfm)
Provides:       tex(upexpminl-v.vf)
Provides:       tex(upexpminln-h.tfm)
Provides:       tex(upexpminln-h.vf)
Provides:       tex(upexpminln-v.tfm)
Provides:       tex(upexpminln-v.vf)
Provides:       tex(upexpminr-h.tfm)
Provides:       tex(upexpminr-h.vf)
Provides:       tex(upexpminr-v.tfm)
Provides:       tex(upexpminr-v.vf)
Provides:       tex(upexpminrn-h.tfm)
Provides:       tex(upexpminrn-h.vf)
Provides:       tex(upexpminrn-v.tfm)
Provides:       tex(upexpminrn-v.vf)
Provides:       tex(uphgothb-h.tfm)
Provides:       tex(uphgothb-v.tfm)
Provides:       tex(uphgothbn-h.tfm)
Provides:       tex(uphgothbn-v.tfm)
Provides:       tex(uphgotheb-h.tfm)
Provides:       tex(uphgotheb-v.tfm)
Provides:       tex(uphgothebn-h.tfm)
Provides:       tex(uphgothebn-v.tfm)
Provides:       tex(uphgothr-h.tfm)
Provides:       tex(uphgothr-v.tfm)
Provides:       tex(uphgothrn-h.tfm)
Provides:       tex(uphgothrn-v.tfm)
Provides:       tex(uphmgothr-h.tfm)
Provides:       tex(uphmgothr-v.tfm)
Provides:       tex(uphmgothrn-h.tfm)
Provides:       tex(uphmgothrn-v.tfm)
Provides:       tex(uphminb-h.tfm)
Provides:       tex(uphminb-v.tfm)
Provides:       tex(uphminbn-h.tfm)
Provides:       tex(uphminbn-v.tfm)
Provides:       tex(uphminl-h.tfm)
Provides:       tex(uphminl-v.tfm)
Provides:       tex(uphminln-h.tfm)
Provides:       tex(uphminln-v.tfm)
Provides:       tex(uphminr-h.tfm)
Provides:       tex(uphminr-v.tfm)
Provides:       tex(uphminrn-h.tfm)
Provides:       tex(uphminrn-v.tfm)
Provides:       tex(upnmkorgothb-h.tfm)
Provides:       tex(upnmkorgothb-h.vf)
Provides:       tex(upnmkorgothb-v.tfm)
Provides:       tex(upnmkorgothb-v.vf)
Provides:       tex(upnmkorgotheb-h.tfm)
Provides:       tex(upnmkorgotheb-h.vf)
Provides:       tex(upnmkorgotheb-v.tfm)
Provides:       tex(upnmkorgotheb-v.vf)
Provides:       tex(upnmkorgothr-h.tfm)
Provides:       tex(upnmkorgothr-h.vf)
Provides:       tex(upnmkorgothr-v.tfm)
Provides:       tex(upnmkorgothr-v.vf)
Provides:       tex(upnmkormgothr-h.tfm)
Provides:       tex(upnmkormgothr-h.vf)
Provides:       tex(upnmkormgothr-v.tfm)
Provides:       tex(upnmkormgothr-v.vf)
Provides:       tex(upnmkorminb-h.tfm)
Provides:       tex(upnmkorminb-h.vf)
Provides:       tex(upnmkorminb-v.tfm)
Provides:       tex(upnmkorminb-v.vf)
Provides:       tex(upnmkorminl-h.tfm)
Provides:       tex(upnmkorminl-h.vf)
Provides:       tex(upnmkorminl-v.tfm)
Provides:       tex(upnmkorminl-v.vf)
Provides:       tex(upnmkorminr-h.tfm)
Provides:       tex(upnmkorminr-h.vf)
Provides:       tex(upnmkorminr-v.tfm)
Provides:       tex(upnmkorminr-v.vf)
Provides:       tex(upnmlgothb-h.tfm)
Provides:       tex(upnmlgothb-h.vf)
Provides:       tex(upnmlgothb-v.tfm)
Provides:       tex(upnmlgothb-v.vf)
Provides:       tex(upnmlgothbn-h.tfm)
Provides:       tex(upnmlgothbn-h.vf)
Provides:       tex(upnmlgothbn-v.tfm)
Provides:       tex(upnmlgothbn-v.vf)
Provides:       tex(upnmlgotheb-h.tfm)
Provides:       tex(upnmlgotheb-h.vf)
Provides:       tex(upnmlgotheb-v.tfm)
Provides:       tex(upnmlgotheb-v.vf)
Provides:       tex(upnmlgothebn-h.tfm)
Provides:       tex(upnmlgothebn-h.vf)
Provides:       tex(upnmlgothebn-v.tfm)
Provides:       tex(upnmlgothebn-v.vf)
Provides:       tex(upnmlgothr-h.tfm)
Provides:       tex(upnmlgothr-h.vf)
Provides:       tex(upnmlgothr-v.tfm)
Provides:       tex(upnmlgothr-v.vf)
Provides:       tex(upnmlgothrn-h.tfm)
Provides:       tex(upnmlgothrn-h.vf)
Provides:       tex(upnmlgothrn-v.tfm)
Provides:       tex(upnmlgothrn-v.vf)
Provides:       tex(upnmlmgothr-h.tfm)
Provides:       tex(upnmlmgothr-h.vf)
Provides:       tex(upnmlmgothr-v.tfm)
Provides:       tex(upnmlmgothr-v.vf)
Provides:       tex(upnmlmgothrn-h.tfm)
Provides:       tex(upnmlmgothrn-h.vf)
Provides:       tex(upnmlmgothrn-v.tfm)
Provides:       tex(upnmlmgothrn-v.vf)
Provides:       tex(upnmlminb-h.tfm)
Provides:       tex(upnmlminb-h.vf)
Provides:       tex(upnmlminb-v.tfm)
Provides:       tex(upnmlminb-v.vf)
Provides:       tex(upnmlminbn-h.tfm)
Provides:       tex(upnmlminbn-h.vf)
Provides:       tex(upnmlminbn-v.tfm)
Provides:       tex(upnmlminbn-v.vf)
Provides:       tex(upnmlminl-h.tfm)
Provides:       tex(upnmlminl-h.vf)
Provides:       tex(upnmlminl-v.tfm)
Provides:       tex(upnmlminl-v.vf)
Provides:       tex(upnmlminln-h.tfm)
Provides:       tex(upnmlminln-h.vf)
Provides:       tex(upnmlminln-v.tfm)
Provides:       tex(upnmlminln-v.vf)
Provides:       tex(upnmlminr-h.tfm)
Provides:       tex(upnmlminr-h.vf)
Provides:       tex(upnmlminr-v.tfm)
Provides:       tex(upnmlminr-v.vf)
Provides:       tex(upnmlminrn-h.tfm)
Provides:       tex(upnmlminrn-h.vf)
Provides:       tex(upnmlminrn-v.tfm)
Provides:       tex(upnmlminrn-v.vf)
Provides:       tex(upnmschgothb-h.tfm)
Provides:       tex(upnmschgothb-h.vf)
Provides:       tex(upnmschgothb-v.tfm)
Provides:       tex(upnmschgothb-v.vf)
Provides:       tex(upnmschgotheb-h.tfm)
Provides:       tex(upnmschgotheb-h.vf)
Provides:       tex(upnmschgotheb-v.tfm)
Provides:       tex(upnmschgotheb-v.vf)
Provides:       tex(upnmschgothr-h.tfm)
Provides:       tex(upnmschgothr-h.vf)
Provides:       tex(upnmschgothr-v.tfm)
Provides:       tex(upnmschgothr-v.vf)
Provides:       tex(upnmschmgothr-h.tfm)
Provides:       tex(upnmschmgothr-h.vf)
Provides:       tex(upnmschmgothr-v.tfm)
Provides:       tex(upnmschmgothr-v.vf)
Provides:       tex(upnmschminb-h.tfm)
Provides:       tex(upnmschminb-h.vf)
Provides:       tex(upnmschminb-v.tfm)
Provides:       tex(upnmschminb-v.vf)
Provides:       tex(upnmschminl-h.tfm)
Provides:       tex(upnmschminl-h.vf)
Provides:       tex(upnmschminl-v.tfm)
Provides:       tex(upnmschminl-v.vf)
Provides:       tex(upnmschminr-h.tfm)
Provides:       tex(upnmschminr-h.vf)
Provides:       tex(upnmschminr-v.tfm)
Provides:       tex(upnmschminr-v.vf)
Provides:       tex(upnmtchgothb-h.tfm)
Provides:       tex(upnmtchgothb-h.vf)
Provides:       tex(upnmtchgothb-v.tfm)
Provides:       tex(upnmtchgothb-v.vf)
Provides:       tex(upnmtchgotheb-h.tfm)
Provides:       tex(upnmtchgotheb-h.vf)
Provides:       tex(upnmtchgotheb-v.tfm)
Provides:       tex(upnmtchgotheb-v.vf)
Provides:       tex(upnmtchgothr-h.tfm)
Provides:       tex(upnmtchgothr-h.vf)
Provides:       tex(upnmtchgothr-v.tfm)
Provides:       tex(upnmtchgothr-v.vf)
Provides:       tex(upnmtchmgothr-h.tfm)
Provides:       tex(upnmtchmgothr-h.vf)
Provides:       tex(upnmtchmgothr-v.tfm)
Provides:       tex(upnmtchmgothr-v.vf)
Provides:       tex(upnmtchminb-h.tfm)
Provides:       tex(upnmtchminb-h.vf)
Provides:       tex(upnmtchminb-v.tfm)
Provides:       tex(upnmtchminb-v.vf)
Provides:       tex(upnmtchminl-h.tfm)
Provides:       tex(upnmtchminl-h.vf)
Provides:       tex(upnmtchminl-v.tfm)
Provides:       tex(upnmtchminl-v.vf)
Provides:       tex(upnmtchminr-h.tfm)
Provides:       tex(upnmtchminr-h.vf)
Provides:       tex(upnmtchminr-v.tfm)
Provides:       tex(upnmtchminr-v.vf)
Provides:       tex(uprubygothb-h.tfm)
Provides:       tex(uprubygothb-h.vf)
Provides:       tex(uprubygothb-v.tfm)
Provides:       tex(uprubygothb-v.vf)
Provides:       tex(uprubygotheb-h.tfm)
Provides:       tex(uprubygotheb-h.vf)
Provides:       tex(uprubygotheb-v.tfm)
Provides:       tex(uprubygotheb-v.vf)
Provides:       tex(uprubygothr-h.tfm)
Provides:       tex(uprubygothr-h.vf)
Provides:       tex(uprubygothr-v.tfm)
Provides:       tex(uprubygothr-v.vf)
Provides:       tex(uprubymgothr-h.tfm)
Provides:       tex(uprubymgothr-h.vf)
Provides:       tex(uprubymgothr-v.tfm)
Provides:       tex(uprubymgothr-v.vf)
Provides:       tex(uprubyminb-h.tfm)
Provides:       tex(uprubyminb-h.vf)
Provides:       tex(uprubyminb-v.tfm)
Provides:       tex(uprubyminb-v.vf)
Provides:       tex(uprubyminl-h.tfm)
Provides:       tex(uprubyminl-h.vf)
Provides:       tex(uprubyminl-v.tfm)
Provides:       tex(uprubyminl-v.vf)
Provides:       tex(uprubyminr-h.tfm)
Provides:       tex(uprubyminr-h.vf)
Provides:       tex(uprubyminr-v.tfm)
Provides:       tex(uprubyminr-v.vf)
Provides:       tex(utfcgb--h.tfm)
Provides:       tex(utfcgb--h.vf)
Provides:       tex(utfcgb--v.tfm)
Provides:       tex(utfcgb--v.vf)
Provides:       tex(utfcge--h.tfm)
Provides:       tex(utfcge--h.vf)
Provides:       tex(utfcge--v.tfm)
Provides:       tex(utfcge--v.vf)
Provides:       tex(utfcgr--h.tfm)
Provides:       tex(utfcgr--h.vf)
Provides:       tex(utfcgr--v.tfm)
Provides:       tex(utfcgr--v.vf)
Provides:       tex(utfcgr0-h.tfm)
Provides:       tex(utfcgr0-h.vf)
Provides:       tex(utfcgr0-v.tfm)
Provides:       tex(utfcgr0-v.vf)
Provides:       tex(utfcgr1-h.tfm)
Provides:       tex(utfcgr1-h.vf)
Provides:       tex(utfcgr1-v.tfm)
Provides:       tex(utfcgr1-v.vf)
Provides:       tex(utfcgr2-h.tfm)
Provides:       tex(utfcgr2-h.vf)
Provides:       tex(utfcgr2-v.tfm)
Provides:       tex(utfcgr2-v.vf)
Provides:       tex(utfcgr3-h.tfm)
Provides:       tex(utfcgr3-h.vf)
Provides:       tex(utfcgr3-v.tfm)
Provides:       tex(utfcgr3-v.vf)
Provides:       tex(utfcgr4-h.tfm)
Provides:       tex(utfcgr4-h.vf)
Provides:       tex(utfcgr4-v.tfm)
Provides:       tex(utfcgr4-v.vf)
Provides:       tex(utfcgr5-h.tfm)
Provides:       tex(utfcgr5-h.vf)
Provides:       tex(utfcgr5-v.tfm)
Provides:       tex(utfcgr5-v.vf)
Provides:       tex(utfcgr6-h.tfm)
Provides:       tex(utfcgr6-h.vf)
Provides:       tex(utfcgr6-v.tfm)
Provides:       tex(utfcgr6-v.vf)
Provides:       tex(utfcgr7-h.tfm)
Provides:       tex(utfcgr7-h.vf)
Provides:       tex(utfcgr7-v.tfm)
Provides:       tex(utfcgr7-v.vf)
Provides:       tex(utfcgr8-h.tfm)
Provides:       tex(utfcgr8-h.vf)
Provides:       tex(utfcgr8-v.tfm)
Provides:       tex(utfcgr8-v.vf)
Provides:       tex(utfcgr9-h.tfm)
Provides:       tex(utfcgr9-h.vf)
Provides:       tex(utfcgr9-v.tfm)
Provides:       tex(utfcgr9-v.vf)
Provides:       tex(utfcgra-h.tfm)
Provides:       tex(utfcgra-h.vf)
Provides:       tex(utfcgra-v.tfm)
Provides:       tex(utfcgra-v.vf)
Provides:       tex(utfcgrb-h.tfm)
Provides:       tex(utfcgrb-h.vf)
Provides:       tex(utfcgrb-v.tfm)
Provides:       tex(utfcgrb-v.vf)
Provides:       tex(utfcgrc-h.tfm)
Provides:       tex(utfcgrc-h.vf)
Provides:       tex(utfcgrc-v.tfm)
Provides:       tex(utfcgrc-v.vf)
Provides:       tex(utfcgrd-h.tfm)
Provides:       tex(utfcgrd-h.vf)
Provides:       tex(utfcgrd-v.tfm)
Provides:       tex(utfcgrd-v.vf)
Provides:       tex(utfcgre-h.tfm)
Provides:       tex(utfcgre-h.vf)
Provides:       tex(utfcgre-v.tfm)
Provides:       tex(utfcgre-v.vf)
Provides:       tex(utfcgrf-h.tfm)
Provides:       tex(utfcgrf-h.vf)
Provides:       tex(utfcgrf-v.tfm)
Provides:       tex(utfcgrf-v.vf)
Provides:       tex(utfcgrk-h.tfm)
Provides:       tex(utfcgrk-h.vf)
Provides:       tex(utfcgrk-v.tfm)
Provides:       tex(utfcgrk-v.vf)
Provides:       tex(utfcgrl-h.tfm)
Provides:       tex(utfcgrl-h.vf)
Provides:       tex(utfcgrl-v.tfm)
Provides:       tex(utfcgrl-v.vf)
Provides:       tex(utfcgrm-h.tfm)
Provides:       tex(utfcgrm-h.vf)
Provides:       tex(utfcgrm-v.tfm)
Provides:       tex(utfcgrm-v.vf)
Provides:       tex(utfcgro-h.tfm)
Provides:       tex(utfcgro-h.vf)
Provides:       tex(utfcgro-v.tfm)
Provides:       tex(utfcgro-v.vf)
Provides:       tex(utfcmb--h.tfm)
Provides:       tex(utfcmb--h.vf)
Provides:       tex(utfcmb--v.tfm)
Provides:       tex(utfcmb--v.vf)
Provides:       tex(utfcmgr--h.tfm)
Provides:       tex(utfcmgr--h.vf)
Provides:       tex(utfcmgr--v.tfm)
Provides:       tex(utfcmgr--v.vf)
Provides:       tex(utfcml--h.tfm)
Provides:       tex(utfcml--h.vf)
Provides:       tex(utfcml--v.tfm)
Provides:       tex(utfcml--v.vf)
Provides:       tex(utfcmr--h.tfm)
Provides:       tex(utfcmr--h.vf)
Provides:       tex(utfcmr--v.tfm)
Provides:       tex(utfcmr--v.vf)
Provides:       tex(utfcmr0-h.tfm)
Provides:       tex(utfcmr0-h.vf)
Provides:       tex(utfcmr0-v.tfm)
Provides:       tex(utfcmr0-v.vf)
Provides:       tex(utfcmr1-h.tfm)
Provides:       tex(utfcmr1-h.vf)
Provides:       tex(utfcmr1-v.tfm)
Provides:       tex(utfcmr1-v.vf)
Provides:       tex(utfcmr2-h.tfm)
Provides:       tex(utfcmr2-h.vf)
Provides:       tex(utfcmr2-v.tfm)
Provides:       tex(utfcmr2-v.vf)
Provides:       tex(utfcmr3-h.tfm)
Provides:       tex(utfcmr3-h.vf)
Provides:       tex(utfcmr3-v.tfm)
Provides:       tex(utfcmr3-v.vf)
Provides:       tex(utfcmr4-h.tfm)
Provides:       tex(utfcmr4-h.vf)
Provides:       tex(utfcmr4-v.tfm)
Provides:       tex(utfcmr4-v.vf)
Provides:       tex(utfcmr5-h.tfm)
Provides:       tex(utfcmr5-h.vf)
Provides:       tex(utfcmr5-v.tfm)
Provides:       tex(utfcmr5-v.vf)
Provides:       tex(utfcmr6-h.tfm)
Provides:       tex(utfcmr6-h.vf)
Provides:       tex(utfcmr6-v.tfm)
Provides:       tex(utfcmr6-v.vf)
Provides:       tex(utfcmr7-h.tfm)
Provides:       tex(utfcmr7-h.vf)
Provides:       tex(utfcmr7-v.tfm)
Provides:       tex(utfcmr7-v.vf)
Provides:       tex(utfcmr8-h.tfm)
Provides:       tex(utfcmr8-h.vf)
Provides:       tex(utfcmr8-v.tfm)
Provides:       tex(utfcmr8-v.vf)
Provides:       tex(utfcmr9-h.tfm)
Provides:       tex(utfcmr9-h.vf)
Provides:       tex(utfcmr9-v.tfm)
Provides:       tex(utfcmr9-v.vf)
Provides:       tex(utfcmra-h.tfm)
Provides:       tex(utfcmra-h.vf)
Provides:       tex(utfcmra-v.tfm)
Provides:       tex(utfcmra-v.vf)
Provides:       tex(utfcmrb-h.tfm)
Provides:       tex(utfcmrb-h.vf)
Provides:       tex(utfcmrb-v.tfm)
Provides:       tex(utfcmrb-v.vf)
Provides:       tex(utfcmrc-h.tfm)
Provides:       tex(utfcmrc-h.vf)
Provides:       tex(utfcmrc-v.tfm)
Provides:       tex(utfcmrc-v.vf)
Provides:       tex(utfcmrd-h.tfm)
Provides:       tex(utfcmrd-h.vf)
Provides:       tex(utfcmrd-v.tfm)
Provides:       tex(utfcmrd-v.vf)
Provides:       tex(utfcmre-h.tfm)
Provides:       tex(utfcmre-h.vf)
Provides:       tex(utfcmre-v.tfm)
Provides:       tex(utfcmre-v.vf)
Provides:       tex(utfcmrf-h.tfm)
Provides:       tex(utfcmrf-h.vf)
Provides:       tex(utfcmrf-v.tfm)
Provides:       tex(utfcmrf-v.vf)
Provides:       tex(utfcmrk-h.tfm)
Provides:       tex(utfcmrk-h.vf)
Provides:       tex(utfcmrk-v.tfm)
Provides:       tex(utfcmrk-v.vf)
Provides:       tex(utfcmrl-h.tfm)
Provides:       tex(utfcmrl-h.vf)
Provides:       tex(utfcmrl-v.tfm)
Provides:       tex(utfcmrl-v.vf)
Provides:       tex(utfcmrm-h.tfm)
Provides:       tex(utfcmrm-h.vf)
Provides:       tex(utfcmrm-v.tfm)
Provides:       tex(utfcmrm-v.vf)
Provides:       tex(utfcmro-h.tfm)
Provides:       tex(utfcmro-h.vf)
Provides:       tex(utfcmro-v.tfm)
Provides:       tex(utfcmro-v.vf)
Provides:       tex(utfgr0-h.tfm)
Provides:       tex(utfgr0-h.vf)
Provides:       tex(utfgr0-v.tfm)
Provides:       tex(utfgr0-v.vf)
Provides:       tex(utfgr1-h.tfm)
Provides:       tex(utfgr1-h.vf)
Provides:       tex(utfgr1-v.tfm)
Provides:       tex(utfgr1-v.vf)
Provides:       tex(utfgr2-h.tfm)
Provides:       tex(utfgr2-h.vf)
Provides:       tex(utfgr2-v.tfm)
Provides:       tex(utfgr2-v.vf)
Provides:       tex(utfgr3-h.tfm)
Provides:       tex(utfgr3-h.vf)
Provides:       tex(utfgr3-v.tfm)
Provides:       tex(utfgr3-v.vf)
Provides:       tex(utfgr4-h.tfm)
Provides:       tex(utfgr4-h.vf)
Provides:       tex(utfgr4-v.tfm)
Provides:       tex(utfgr4-v.vf)
Provides:       tex(utfgr5-h.tfm)
Provides:       tex(utfgr5-h.vf)
Provides:       tex(utfgr5-v.tfm)
Provides:       tex(utfgr5-v.vf)
Provides:       tex(utfgr6-h.tfm)
Provides:       tex(utfgr6-h.vf)
Provides:       tex(utfgr6-v.tfm)
Provides:       tex(utfgr6-v.vf)
Provides:       tex(utfgr7-h.tfm)
Provides:       tex(utfgr7-h.vf)
Provides:       tex(utfgr7-v.tfm)
Provides:       tex(utfgr7-v.vf)
Provides:       tex(utfgr8-h.tfm)
Provides:       tex(utfgr8-h.vf)
Provides:       tex(utfgr8-v.tfm)
Provides:       tex(utfgr8-v.vf)
Provides:       tex(utfgr9-h.tfm)
Provides:       tex(utfgr9-h.vf)
Provides:       tex(utfgr9-v.tfm)
Provides:       tex(utfgr9-v.vf)
Provides:       tex(utfgra-h.tfm)
Provides:       tex(utfgra-h.vf)
Provides:       tex(utfgra-v.tfm)
Provides:       tex(utfgra-v.vf)
Provides:       tex(utfgrb-h.tfm)
Provides:       tex(utfgrb-h.vf)
Provides:       tex(utfgrb-v.tfm)
Provides:       tex(utfgrb-v.vf)
Provides:       tex(utfgrc-h.tfm)
Provides:       tex(utfgrc-h.vf)
Provides:       tex(utfgrc-v.tfm)
Provides:       tex(utfgrc-v.vf)
Provides:       tex(utfgrd-h.tfm)
Provides:       tex(utfgrd-h.vf)
Provides:       tex(utfgrd-v.tfm)
Provides:       tex(utfgrd-v.vf)
Provides:       tex(utfgre-h.tfm)
Provides:       tex(utfgre-h.vf)
Provides:       tex(utfgre-v.tfm)
Provides:       tex(utfgre-v.vf)
Provides:       tex(utfgrf-h.tfm)
Provides:       tex(utfgrf-h.vf)
Provides:       tex(utfgrf-v.tfm)
Provides:       tex(utfgrf-v.vf)
Provides:       tex(utfgrg-h.tfm)
Provides:       tex(utfgrg-h.vf)
Provides:       tex(utfgrg-v.tfm)
Provides:       tex(utfgrg-v.vf)
Provides:       tex(utfgrj-h.tfm)
Provides:       tex(utfgrj-h.vf)
Provides:       tex(utfgrj-v.tfm)
Provides:       tex(utfgrj-v.vf)
Provides:       tex(utfgrk-h.tfm)
Provides:       tex(utfgrk-h.vf)
Provides:       tex(utfgrk-v.tfm)
Provides:       tex(utfgrk-v.vf)
Provides:       tex(utfgrl-h.tfm)
Provides:       tex(utfgrl-h.vf)
Provides:       tex(utfgrl-v.tfm)
Provides:       tex(utfgrl-v.vf)
Provides:       tex(utfgrm-h.tfm)
Provides:       tex(utfgrm-h.vf)
Provides:       tex(utfgrm-v.tfm)
Provides:       tex(utfgrm-v.vf)
Provides:       tex(utfgrn-h.tfm)
Provides:       tex(utfgrn-h.vf)
Provides:       tex(utfgrn-v.tfm)
Provides:       tex(utfgrn-v.vf)
Provides:       tex(utfgro-h.tfm)
Provides:       tex(utfgro-h.vf)
Provides:       tex(utfgro-v.tfm)
Provides:       tex(utfgro-v.vf)
Provides:       tex(utfgrp-h.tfm)
Provides:       tex(utfgrp-h.vf)
Provides:       tex(utfgrp-v.tfm)
Provides:       tex(utfgrp-v.vf)
Provides:       tex(utfgrq-h.tfm)
Provides:       tex(utfgrq-h.vf)
Provides:       tex(utfgrq-v.tfm)
Provides:       tex(utfgrq-v.vf)
Provides:       tex(utfgrr-h.tfm)
Provides:       tex(utfgrr-h.vf)
Provides:       tex(utfgrr-v.tfm)
Provides:       tex(utfgrr-v.vf)
Provides:       tex(utfgrs-h.tfm)
Provides:       tex(utfgrs-h.vf)
Provides:       tex(utfgrs-v.tfm)
Provides:       tex(utfgrs-v.vf)
Provides:       tex(utfgrt-h.tfm)
Provides:       tex(utfgrt-h.vf)
Provides:       tex(utfgrt-v.tfm)
Provides:       tex(utfgrt-v.vf)
Provides:       tex(utfgru-h.tfm)
Provides:       tex(utfgru-h.vf)
Provides:       tex(utfgru-v.tfm)
Provides:       tex(utfgru-v.vf)
Provides:       tex(utfgrv-h.tfm)
Provides:       tex(utfgrv-h.vf)
Provides:       tex(utfgrv-v.tfm)
Provides:       tex(utfgrv-v.vf)
Provides:       tex(utfgrw-h.tfm)
Provides:       tex(utfgrw-h.vf)
Provides:       tex(utfgrw-v.tfm)
Provides:       tex(utfgrw-v.vf)
Provides:       tex(utfgrx-h.tfm)
Provides:       tex(utfgrx-h.vf)
Provides:       tex(utfgrx-v.tfm)
Provides:       tex(utfgrx-v.vf)
Provides:       tex(utfgry-h.tfm)
Provides:       tex(utfgry-h.vf)
Provides:       tex(utfgry-v.tfm)
Provides:       tex(utfgry-v.vf)
Provides:       tex(utfgrz-h.tfm)
Provides:       tex(utfgrz-h.vf)
Provides:       tex(utfgrz-v.tfm)
Provides:       tex(utfgrz-v.vf)
Provides:       tex(utfjgb--h.tfm)
Provides:       tex(utfjgb--h.vf)
Provides:       tex(utfjgb--v.tfm)
Provides:       tex(utfjgb--v.vf)
Provides:       tex(utfjgb0-h.tfm)
Provides:       tex(utfjgb0-h.vf)
Provides:       tex(utfjgb0-v.tfm)
Provides:       tex(utfjgb0-v.vf)
Provides:       tex(utfjgb1-h.tfm)
Provides:       tex(utfjgb1-h.vf)
Provides:       tex(utfjgb1-v.tfm)
Provides:       tex(utfjgb1-v.vf)
Provides:       tex(utfjgb2-h.tfm)
Provides:       tex(utfjgb2-h.vf)
Provides:       tex(utfjgb2-v.tfm)
Provides:       tex(utfjgb2-v.vf)
Provides:       tex(utfjgb3-h.tfm)
Provides:       tex(utfjgb3-h.vf)
Provides:       tex(utfjgb3-v.tfm)
Provides:       tex(utfjgb3-v.vf)
Provides:       tex(utfjgb4-h.tfm)
Provides:       tex(utfjgb4-h.vf)
Provides:       tex(utfjgb4-v.tfm)
Provides:       tex(utfjgb4-v.vf)
Provides:       tex(utfjgb5-h.tfm)
Provides:       tex(utfjgb5-h.vf)
Provides:       tex(utfjgb5-v.tfm)
Provides:       tex(utfjgb5-v.vf)
Provides:       tex(utfjgb6-h.tfm)
Provides:       tex(utfjgb6-h.vf)
Provides:       tex(utfjgb6-v.tfm)
Provides:       tex(utfjgb6-v.vf)
Provides:       tex(utfjgb7-h.tfm)
Provides:       tex(utfjgb7-h.vf)
Provides:       tex(utfjgb7-v.tfm)
Provides:       tex(utfjgb7-v.vf)
Provides:       tex(utfjgb8-h.tfm)
Provides:       tex(utfjgb8-h.vf)
Provides:       tex(utfjgb8-v.tfm)
Provides:       tex(utfjgb8-v.vf)
Provides:       tex(utfjgb9-h.tfm)
Provides:       tex(utfjgb9-h.vf)
Provides:       tex(utfjgb9-v.tfm)
Provides:       tex(utfjgb9-v.vf)
Provides:       tex(utfjgba-h.tfm)
Provides:       tex(utfjgba-h.vf)
Provides:       tex(utfjgba-v.tfm)
Provides:       tex(utfjgba-v.vf)
Provides:       tex(utfjgbb-h.tfm)
Provides:       tex(utfjgbb-h.vf)
Provides:       tex(utfjgbb-v.tfm)
Provides:       tex(utfjgbb-v.vf)
Provides:       tex(utfjgbc-h.tfm)
Provides:       tex(utfjgbc-h.vf)
Provides:       tex(utfjgbc-v.tfm)
Provides:       tex(utfjgbc-v.vf)
Provides:       tex(utfjgbd-h.tfm)
Provides:       tex(utfjgbd-h.vf)
Provides:       tex(utfjgbd-v.tfm)
Provides:       tex(utfjgbd-v.vf)
Provides:       tex(utfjgbe-h.tfm)
Provides:       tex(utfjgbe-h.vf)
Provides:       tex(utfjgbe-v.tfm)
Provides:       tex(utfjgbe-v.vf)
Provides:       tex(utfjgbf-h.tfm)
Provides:       tex(utfjgbf-h.vf)
Provides:       tex(utfjgbf-v.tfm)
Provides:       tex(utfjgbf-v.vf)
Provides:       tex(utfjgbg-h.tfm)
Provides:       tex(utfjgbg-h.vf)
Provides:       tex(utfjgbg-v.tfm)
Provides:       tex(utfjgbg-v.vf)
Provides:       tex(utfjgbj-h.tfm)
Provides:       tex(utfjgbj-h.vf)
Provides:       tex(utfjgbj-v.tfm)
Provides:       tex(utfjgbj-v.vf)
Provides:       tex(utfjgbk-h.tfm)
Provides:       tex(utfjgbk-h.vf)
Provides:       tex(utfjgbk-v.tfm)
Provides:       tex(utfjgbk-v.vf)
Provides:       tex(utfjgbl-h.tfm)
Provides:       tex(utfjgbl-h.vf)
Provides:       tex(utfjgbl-v.tfm)
Provides:       tex(utfjgbl-v.vf)
Provides:       tex(utfjgbm-h.tfm)
Provides:       tex(utfjgbm-h.vf)
Provides:       tex(utfjgbm-v.tfm)
Provides:       tex(utfjgbm-v.vf)
Provides:       tex(utfjgbn--h.tfm)
Provides:       tex(utfjgbn--h.vf)
Provides:       tex(utfjgbn--v.tfm)
Provides:       tex(utfjgbn--v.vf)
Provides:       tex(utfjgbn-h.tfm)
Provides:       tex(utfjgbn-h.vf)
Provides:       tex(utfjgbn-v.tfm)
Provides:       tex(utfjgbn-v.vf)
Provides:       tex(utfjgbn0-h.tfm)
Provides:       tex(utfjgbn0-h.vf)
Provides:       tex(utfjgbn0-v.tfm)
Provides:       tex(utfjgbn0-v.vf)
Provides:       tex(utfjgbn1-h.tfm)
Provides:       tex(utfjgbn1-h.vf)
Provides:       tex(utfjgbn1-v.tfm)
Provides:       tex(utfjgbn1-v.vf)
Provides:       tex(utfjgbn2-h.tfm)
Provides:       tex(utfjgbn2-h.vf)
Provides:       tex(utfjgbn2-v.tfm)
Provides:       tex(utfjgbn2-v.vf)
Provides:       tex(utfjgbn3-h.tfm)
Provides:       tex(utfjgbn3-h.vf)
Provides:       tex(utfjgbn3-v.tfm)
Provides:       tex(utfjgbn3-v.vf)
Provides:       tex(utfjgbn4-h.tfm)
Provides:       tex(utfjgbn4-h.vf)
Provides:       tex(utfjgbn4-v.tfm)
Provides:       tex(utfjgbn4-v.vf)
Provides:       tex(utfjgbn5-h.tfm)
Provides:       tex(utfjgbn5-h.vf)
Provides:       tex(utfjgbn5-v.tfm)
Provides:       tex(utfjgbn5-v.vf)
Provides:       tex(utfjgbn6-h.tfm)
Provides:       tex(utfjgbn6-h.vf)
Provides:       tex(utfjgbn6-v.tfm)
Provides:       tex(utfjgbn6-v.vf)
Provides:       tex(utfjgbn7-h.tfm)
Provides:       tex(utfjgbn7-h.vf)
Provides:       tex(utfjgbn7-v.tfm)
Provides:       tex(utfjgbn7-v.vf)
Provides:       tex(utfjgbn8-h.tfm)
Provides:       tex(utfjgbn8-h.vf)
Provides:       tex(utfjgbn8-v.tfm)
Provides:       tex(utfjgbn8-v.vf)
Provides:       tex(utfjgbn9-h.tfm)
Provides:       tex(utfjgbn9-h.vf)
Provides:       tex(utfjgbn9-v.tfm)
Provides:       tex(utfjgbn9-v.vf)
Provides:       tex(utfjgbna-h.tfm)
Provides:       tex(utfjgbna-h.vf)
Provides:       tex(utfjgbna-v.tfm)
Provides:       tex(utfjgbna-v.vf)
Provides:       tex(utfjgbnb-h.tfm)
Provides:       tex(utfjgbnb-h.vf)
Provides:       tex(utfjgbnb-v.tfm)
Provides:       tex(utfjgbnb-v.vf)
Provides:       tex(utfjgbnc-h.tfm)
Provides:       tex(utfjgbnc-h.vf)
Provides:       tex(utfjgbnc-v.tfm)
Provides:       tex(utfjgbnc-v.vf)
Provides:       tex(utfjgbnd-h.tfm)
Provides:       tex(utfjgbnd-h.vf)
Provides:       tex(utfjgbnd-v.tfm)
Provides:       tex(utfjgbnd-v.vf)
Provides:       tex(utfjgbne-h.tfm)
Provides:       tex(utfjgbne-h.vf)
Provides:       tex(utfjgbne-v.tfm)
Provides:       tex(utfjgbne-v.vf)
Provides:       tex(utfjgbnf-h.tfm)
Provides:       tex(utfjgbnf-h.vf)
Provides:       tex(utfjgbnf-v.tfm)
Provides:       tex(utfjgbnf-v.vf)
Provides:       tex(utfjgbo-h.tfm)
Provides:       tex(utfjgbo-h.vf)
Provides:       tex(utfjgbo-v.tfm)
Provides:       tex(utfjgbo-v.vf)
Provides:       tex(utfjgbp-h.tfm)
Provides:       tex(utfjgbp-h.vf)
Provides:       tex(utfjgbp-v.tfm)
Provides:       tex(utfjgbp-v.vf)
Provides:       tex(utfjgbq-h.tfm)
Provides:       tex(utfjgbq-h.vf)
Provides:       tex(utfjgbq-v.tfm)
Provides:       tex(utfjgbq-v.vf)
Provides:       tex(utfjgbr-h.tfm)
Provides:       tex(utfjgbr-h.vf)
Provides:       tex(utfjgbr-v.tfm)
Provides:       tex(utfjgbr-v.vf)
Provides:       tex(utfjgbs-h.tfm)
Provides:       tex(utfjgbs-h.vf)
Provides:       tex(utfjgbs-v.tfm)
Provides:       tex(utfjgbs-v.vf)
Provides:       tex(utfjgbt-h.tfm)
Provides:       tex(utfjgbt-h.vf)
Provides:       tex(utfjgbt-v.tfm)
Provides:       tex(utfjgbt-v.vf)
Provides:       tex(utfjgbu-h.tfm)
Provides:       tex(utfjgbu-h.vf)
Provides:       tex(utfjgbu-v.tfm)
Provides:       tex(utfjgbu-v.vf)
Provides:       tex(utfjgbv-h.tfm)
Provides:       tex(utfjgbv-h.vf)
Provides:       tex(utfjgbv-v.tfm)
Provides:       tex(utfjgbv-v.vf)
Provides:       tex(utfjgbx-h.tfm)
Provides:       tex(utfjgbx-h.vf)
Provides:       tex(utfjgbx-v.tfm)
Provides:       tex(utfjgbx-v.vf)
Provides:       tex(utfjgby-h.tfm)
Provides:       tex(utfjgby-h.vf)
Provides:       tex(utfjgby-v.tfm)
Provides:       tex(utfjgby-v.vf)
Provides:       tex(utfjgbz-h.tfm)
Provides:       tex(utfjgbz-h.vf)
Provides:       tex(utfjgbz-v.tfm)
Provides:       tex(utfjgbz-v.vf)
Provides:       tex(utfjge--h.tfm)
Provides:       tex(utfjge--h.vf)
Provides:       tex(utfjge--v.tfm)
Provides:       tex(utfjge--v.vf)
Provides:       tex(utfjge0-h.tfm)
Provides:       tex(utfjge0-h.vf)
Provides:       tex(utfjge0-v.tfm)
Provides:       tex(utfjge0-v.vf)
Provides:       tex(utfjge1-h.tfm)
Provides:       tex(utfjge1-h.vf)
Provides:       tex(utfjge1-v.tfm)
Provides:       tex(utfjge1-v.vf)
Provides:       tex(utfjge2-h.tfm)
Provides:       tex(utfjge2-h.vf)
Provides:       tex(utfjge2-v.tfm)
Provides:       tex(utfjge2-v.vf)
Provides:       tex(utfjge3-h.tfm)
Provides:       tex(utfjge3-h.vf)
Provides:       tex(utfjge3-v.tfm)
Provides:       tex(utfjge3-v.vf)
Provides:       tex(utfjge4-h.tfm)
Provides:       tex(utfjge4-h.vf)
Provides:       tex(utfjge4-v.tfm)
Provides:       tex(utfjge4-v.vf)
Provides:       tex(utfjge5-h.tfm)
Provides:       tex(utfjge5-h.vf)
Provides:       tex(utfjge5-v.tfm)
Provides:       tex(utfjge5-v.vf)
Provides:       tex(utfjge6-h.tfm)
Provides:       tex(utfjge6-h.vf)
Provides:       tex(utfjge6-v.tfm)
Provides:       tex(utfjge6-v.vf)
Provides:       tex(utfjge7-h.tfm)
Provides:       tex(utfjge7-h.vf)
Provides:       tex(utfjge7-v.tfm)
Provides:       tex(utfjge7-v.vf)
Provides:       tex(utfjge8-h.tfm)
Provides:       tex(utfjge8-h.vf)
Provides:       tex(utfjge8-v.tfm)
Provides:       tex(utfjge8-v.vf)
Provides:       tex(utfjge9-h.tfm)
Provides:       tex(utfjge9-h.vf)
Provides:       tex(utfjge9-v.tfm)
Provides:       tex(utfjge9-v.vf)
Provides:       tex(utfjgea-h.tfm)
Provides:       tex(utfjgea-h.vf)
Provides:       tex(utfjgea-v.tfm)
Provides:       tex(utfjgea-v.vf)
Provides:       tex(utfjgeb-h.tfm)
Provides:       tex(utfjgeb-h.vf)
Provides:       tex(utfjgeb-v.tfm)
Provides:       tex(utfjgeb-v.vf)
Provides:       tex(utfjgec-h.tfm)
Provides:       tex(utfjgec-h.vf)
Provides:       tex(utfjgec-v.tfm)
Provides:       tex(utfjgec-v.vf)
Provides:       tex(utfjged-h.tfm)
Provides:       tex(utfjged-h.vf)
Provides:       tex(utfjged-v.tfm)
Provides:       tex(utfjged-v.vf)
Provides:       tex(utfjgee-h.tfm)
Provides:       tex(utfjgee-h.vf)
Provides:       tex(utfjgee-v.tfm)
Provides:       tex(utfjgee-v.vf)
Provides:       tex(utfjgef-h.tfm)
Provides:       tex(utfjgef-h.vf)
Provides:       tex(utfjgef-v.tfm)
Provides:       tex(utfjgef-v.vf)
Provides:       tex(utfjgeg-h.tfm)
Provides:       tex(utfjgeg-h.vf)
Provides:       tex(utfjgeg-v.tfm)
Provides:       tex(utfjgeg-v.vf)
Provides:       tex(utfjgej-h.tfm)
Provides:       tex(utfjgej-h.vf)
Provides:       tex(utfjgej-v.tfm)
Provides:       tex(utfjgej-v.vf)
Provides:       tex(utfjgek-h.tfm)
Provides:       tex(utfjgek-h.vf)
Provides:       tex(utfjgek-v.tfm)
Provides:       tex(utfjgek-v.vf)
Provides:       tex(utfjgel-h.tfm)
Provides:       tex(utfjgel-h.vf)
Provides:       tex(utfjgel-v.tfm)
Provides:       tex(utfjgel-v.vf)
Provides:       tex(utfjgem-h.tfm)
Provides:       tex(utfjgem-h.vf)
Provides:       tex(utfjgem-v.tfm)
Provides:       tex(utfjgem-v.vf)
Provides:       tex(utfjgen--h.tfm)
Provides:       tex(utfjgen--h.vf)
Provides:       tex(utfjgen--v.tfm)
Provides:       tex(utfjgen--v.vf)
Provides:       tex(utfjgen-h.tfm)
Provides:       tex(utfjgen-h.vf)
Provides:       tex(utfjgen-v.tfm)
Provides:       tex(utfjgen-v.vf)
Provides:       tex(utfjgen0-h.tfm)
Provides:       tex(utfjgen0-h.vf)
Provides:       tex(utfjgen0-v.tfm)
Provides:       tex(utfjgen0-v.vf)
Provides:       tex(utfjgen1-h.tfm)
Provides:       tex(utfjgen1-h.vf)
Provides:       tex(utfjgen1-v.tfm)
Provides:       tex(utfjgen1-v.vf)
Provides:       tex(utfjgen2-h.tfm)
Provides:       tex(utfjgen2-h.vf)
Provides:       tex(utfjgen2-v.tfm)
Provides:       tex(utfjgen2-v.vf)
Provides:       tex(utfjgen3-h.tfm)
Provides:       tex(utfjgen3-h.vf)
Provides:       tex(utfjgen3-v.tfm)
Provides:       tex(utfjgen3-v.vf)
Provides:       tex(utfjgen4-h.tfm)
Provides:       tex(utfjgen4-h.vf)
Provides:       tex(utfjgen4-v.tfm)
Provides:       tex(utfjgen4-v.vf)
Provides:       tex(utfjgen5-h.tfm)
Provides:       tex(utfjgen5-h.vf)
Provides:       tex(utfjgen5-v.tfm)
Provides:       tex(utfjgen5-v.vf)
Provides:       tex(utfjgen6-h.tfm)
Provides:       tex(utfjgen6-h.vf)
Provides:       tex(utfjgen6-v.tfm)
Provides:       tex(utfjgen6-v.vf)
Provides:       tex(utfjgen7-h.tfm)
Provides:       tex(utfjgen7-h.vf)
Provides:       tex(utfjgen7-v.tfm)
Provides:       tex(utfjgen7-v.vf)
Provides:       tex(utfjgen8-h.tfm)
Provides:       tex(utfjgen8-h.vf)
Provides:       tex(utfjgen8-v.tfm)
Provides:       tex(utfjgen8-v.vf)
Provides:       tex(utfjgen9-h.tfm)
Provides:       tex(utfjgen9-h.vf)
Provides:       tex(utfjgen9-v.tfm)
Provides:       tex(utfjgen9-v.vf)
Provides:       tex(utfjgena-h.tfm)
Provides:       tex(utfjgena-h.vf)
Provides:       tex(utfjgena-v.tfm)
Provides:       tex(utfjgena-v.vf)
Provides:       tex(utfjgenb-h.tfm)
Provides:       tex(utfjgenb-h.vf)
Provides:       tex(utfjgenb-v.tfm)
Provides:       tex(utfjgenb-v.vf)
Provides:       tex(utfjgenc-h.tfm)
Provides:       tex(utfjgenc-h.vf)
Provides:       tex(utfjgenc-v.tfm)
Provides:       tex(utfjgenc-v.vf)
Provides:       tex(utfjgend-h.tfm)
Provides:       tex(utfjgend-h.vf)
Provides:       tex(utfjgend-v.tfm)
Provides:       tex(utfjgend-v.vf)
Provides:       tex(utfjgene-h.tfm)
Provides:       tex(utfjgene-h.vf)
Provides:       tex(utfjgene-v.tfm)
Provides:       tex(utfjgene-v.vf)
Provides:       tex(utfjgenf-h.tfm)
Provides:       tex(utfjgenf-h.vf)
Provides:       tex(utfjgenf-v.tfm)
Provides:       tex(utfjgenf-v.vf)
Provides:       tex(utfjgeo-h.tfm)
Provides:       tex(utfjgeo-h.vf)
Provides:       tex(utfjgeo-v.tfm)
Provides:       tex(utfjgeo-v.vf)
Provides:       tex(utfjgep-h.tfm)
Provides:       tex(utfjgep-h.vf)
Provides:       tex(utfjgep-v.tfm)
Provides:       tex(utfjgep-v.vf)
Provides:       tex(utfjgeq-h.tfm)
Provides:       tex(utfjgeq-h.vf)
Provides:       tex(utfjgeq-v.tfm)
Provides:       tex(utfjgeq-v.vf)
Provides:       tex(utfjger-h.tfm)
Provides:       tex(utfjger-h.vf)
Provides:       tex(utfjger-v.tfm)
Provides:       tex(utfjger-v.vf)
Provides:       tex(utfjges-h.tfm)
Provides:       tex(utfjges-h.vf)
Provides:       tex(utfjges-v.tfm)
Provides:       tex(utfjges-v.vf)
Provides:       tex(utfjget-h.tfm)
Provides:       tex(utfjget-h.vf)
Provides:       tex(utfjget-v.tfm)
Provides:       tex(utfjget-v.vf)
Provides:       tex(utfjgeu-h.tfm)
Provides:       tex(utfjgeu-h.vf)
Provides:       tex(utfjgeu-v.tfm)
Provides:       tex(utfjgeu-v.vf)
Provides:       tex(utfjgev-h.tfm)
Provides:       tex(utfjgev-h.vf)
Provides:       tex(utfjgev-v.tfm)
Provides:       tex(utfjgev-v.vf)
Provides:       tex(utfjgex-h.tfm)
Provides:       tex(utfjgex-h.vf)
Provides:       tex(utfjgex-v.tfm)
Provides:       tex(utfjgex-v.vf)
Provides:       tex(utfjgey-h.tfm)
Provides:       tex(utfjgey-h.vf)
Provides:       tex(utfjgey-v.tfm)
Provides:       tex(utfjgey-v.vf)
Provides:       tex(utfjgez-h.tfm)
Provides:       tex(utfjgez-h.vf)
Provides:       tex(utfjgez-v.tfm)
Provides:       tex(utfjgez-v.vf)
Provides:       tex(utfjgr--h.tfm)
Provides:       tex(utfjgr--h.vf)
Provides:       tex(utfjgr--v.tfm)
Provides:       tex(utfjgr--v.vf)
Provides:       tex(utfjgr0-h.tfm)
Provides:       tex(utfjgr0-h.vf)
Provides:       tex(utfjgr0-v.tfm)
Provides:       tex(utfjgr0-v.vf)
Provides:       tex(utfjgr1-h.tfm)
Provides:       tex(utfjgr1-h.vf)
Provides:       tex(utfjgr1-v.tfm)
Provides:       tex(utfjgr1-v.vf)
Provides:       tex(utfjgr2-h.tfm)
Provides:       tex(utfjgr2-h.vf)
Provides:       tex(utfjgr2-v.tfm)
Provides:       tex(utfjgr2-v.vf)
Provides:       tex(utfjgr3-h.tfm)
Provides:       tex(utfjgr3-h.vf)
Provides:       tex(utfjgr3-v.tfm)
Provides:       tex(utfjgr3-v.vf)
Provides:       tex(utfjgr4-h.tfm)
Provides:       tex(utfjgr4-h.vf)
Provides:       tex(utfjgr4-v.tfm)
Provides:       tex(utfjgr4-v.vf)
Provides:       tex(utfjgr5-h.tfm)
Provides:       tex(utfjgr5-h.vf)
Provides:       tex(utfjgr5-v.tfm)
Provides:       tex(utfjgr5-v.vf)
Provides:       tex(utfjgr6-h.tfm)
Provides:       tex(utfjgr6-h.vf)
Provides:       tex(utfjgr6-v.tfm)
Provides:       tex(utfjgr6-v.vf)
Provides:       tex(utfjgr7-h.tfm)
Provides:       tex(utfjgr7-h.vf)
Provides:       tex(utfjgr7-v.tfm)
Provides:       tex(utfjgr7-v.vf)
Provides:       tex(utfjgr8-h.tfm)
Provides:       tex(utfjgr8-h.vf)
Provides:       tex(utfjgr8-v.tfm)
Provides:       tex(utfjgr8-v.vf)
Provides:       tex(utfjgr9-h.tfm)
Provides:       tex(utfjgr9-h.vf)
Provides:       tex(utfjgr9-v.tfm)
Provides:       tex(utfjgr9-v.vf)
Provides:       tex(utfjgra-h.tfm)
Provides:       tex(utfjgra-h.vf)
Provides:       tex(utfjgra-v.tfm)
Provides:       tex(utfjgra-v.vf)
Provides:       tex(utfjgrb-h.tfm)
Provides:       tex(utfjgrb-h.vf)
Provides:       tex(utfjgrb-v.tfm)
Provides:       tex(utfjgrb-v.vf)
Provides:       tex(utfjgrc-h.tfm)
Provides:       tex(utfjgrc-h.vf)
Provides:       tex(utfjgrc-v.tfm)
Provides:       tex(utfjgrc-v.vf)
Provides:       tex(utfjgrd-h.tfm)
Provides:       tex(utfjgrd-h.vf)
Provides:       tex(utfjgrd-v.tfm)
Provides:       tex(utfjgrd-v.vf)
Provides:       tex(utfjgre-h.tfm)
Provides:       tex(utfjgre-h.vf)
Provides:       tex(utfjgre-v.tfm)
Provides:       tex(utfjgre-v.vf)
Provides:       tex(utfjgrf-h.tfm)
Provides:       tex(utfjgrf-h.vf)
Provides:       tex(utfjgrf-v.tfm)
Provides:       tex(utfjgrf-v.vf)
Provides:       tex(utfjgrg-h.tfm)
Provides:       tex(utfjgrg-h.vf)
Provides:       tex(utfjgrg-v.tfm)
Provides:       tex(utfjgrg-v.vf)
Provides:       tex(utfjgrj-h.tfm)
Provides:       tex(utfjgrj-h.vf)
Provides:       tex(utfjgrj-v.tfm)
Provides:       tex(utfjgrj-v.vf)
Provides:       tex(utfjgrk-h.tfm)
Provides:       tex(utfjgrk-h.vf)
Provides:       tex(utfjgrk-v.tfm)
Provides:       tex(utfjgrk-v.vf)
Provides:       tex(utfjgrl-h.tfm)
Provides:       tex(utfjgrl-h.vf)
Provides:       tex(utfjgrl-v.tfm)
Provides:       tex(utfjgrl-v.vf)
Provides:       tex(utfjgrm-h.tfm)
Provides:       tex(utfjgrm-h.vf)
Provides:       tex(utfjgrm-v.tfm)
Provides:       tex(utfjgrm-v.vf)
Provides:       tex(utfjgrn--h.tfm)
Provides:       tex(utfjgrn--h.vf)
Provides:       tex(utfjgrn--v.tfm)
Provides:       tex(utfjgrn--v.vf)
Provides:       tex(utfjgrn-h.tfm)
Provides:       tex(utfjgrn-h.vf)
Provides:       tex(utfjgrn-v.tfm)
Provides:       tex(utfjgrn-v.vf)
Provides:       tex(utfjgrn0-h.tfm)
Provides:       tex(utfjgrn0-h.vf)
Provides:       tex(utfjgrn0-v.tfm)
Provides:       tex(utfjgrn0-v.vf)
Provides:       tex(utfjgrn1-h.tfm)
Provides:       tex(utfjgrn1-h.vf)
Provides:       tex(utfjgrn1-v.tfm)
Provides:       tex(utfjgrn1-v.vf)
Provides:       tex(utfjgrn2-h.tfm)
Provides:       tex(utfjgrn2-h.vf)
Provides:       tex(utfjgrn2-v.tfm)
Provides:       tex(utfjgrn2-v.vf)
Provides:       tex(utfjgrn3-h.tfm)
Provides:       tex(utfjgrn3-h.vf)
Provides:       tex(utfjgrn3-v.tfm)
Provides:       tex(utfjgrn3-v.vf)
Provides:       tex(utfjgrn4-h.tfm)
Provides:       tex(utfjgrn4-h.vf)
Provides:       tex(utfjgrn4-v.tfm)
Provides:       tex(utfjgrn4-v.vf)
Provides:       tex(utfjgrn5-h.tfm)
Provides:       tex(utfjgrn5-h.vf)
Provides:       tex(utfjgrn5-v.tfm)
Provides:       tex(utfjgrn5-v.vf)
Provides:       tex(utfjgrn6-h.tfm)
Provides:       tex(utfjgrn6-h.vf)
Provides:       tex(utfjgrn6-v.tfm)
Provides:       tex(utfjgrn6-v.vf)
Provides:       tex(utfjgrn7-h.tfm)
Provides:       tex(utfjgrn7-h.vf)
Provides:       tex(utfjgrn7-v.tfm)
Provides:       tex(utfjgrn7-v.vf)
Provides:       tex(utfjgrn8-h.tfm)
Provides:       tex(utfjgrn8-h.vf)
Provides:       tex(utfjgrn8-v.tfm)
Provides:       tex(utfjgrn8-v.vf)
Provides:       tex(utfjgrn9-h.tfm)
Provides:       tex(utfjgrn9-h.vf)
Provides:       tex(utfjgrn9-v.tfm)
Provides:       tex(utfjgrn9-v.vf)
Provides:       tex(utfjgrna-h.tfm)
Provides:       tex(utfjgrna-h.vf)
Provides:       tex(utfjgrna-v.tfm)
Provides:       tex(utfjgrna-v.vf)
Provides:       tex(utfjgrnb-h.tfm)
Provides:       tex(utfjgrnb-h.vf)
Provides:       tex(utfjgrnb-v.tfm)
Provides:       tex(utfjgrnb-v.vf)
Provides:       tex(utfjgrnc-h.tfm)
Provides:       tex(utfjgrnc-h.vf)
Provides:       tex(utfjgrnc-v.tfm)
Provides:       tex(utfjgrnc-v.vf)
Provides:       tex(utfjgrnd-h.tfm)
Provides:       tex(utfjgrnd-h.vf)
Provides:       tex(utfjgrnd-v.tfm)
Provides:       tex(utfjgrnd-v.vf)
Provides:       tex(utfjgrne-h.tfm)
Provides:       tex(utfjgrne-h.vf)
Provides:       tex(utfjgrne-v.tfm)
Provides:       tex(utfjgrne-v.vf)
Provides:       tex(utfjgrnf-h.tfm)
Provides:       tex(utfjgrnf-h.vf)
Provides:       tex(utfjgrnf-v.tfm)
Provides:       tex(utfjgrnf-v.vf)
Provides:       tex(utfjgro-h.tfm)
Provides:       tex(utfjgro-h.vf)
Provides:       tex(utfjgro-v.tfm)
Provides:       tex(utfjgro-v.vf)
Provides:       tex(utfjgrp-h.tfm)
Provides:       tex(utfjgrp-h.vf)
Provides:       tex(utfjgrp-v.tfm)
Provides:       tex(utfjgrp-v.vf)
Provides:       tex(utfjgrq-h.tfm)
Provides:       tex(utfjgrq-h.vf)
Provides:       tex(utfjgrq-v.tfm)
Provides:       tex(utfjgrq-v.vf)
Provides:       tex(utfjgrr-h.tfm)
Provides:       tex(utfjgrr-h.vf)
Provides:       tex(utfjgrr-v.tfm)
Provides:       tex(utfjgrr-v.vf)
Provides:       tex(utfjgrs-h.tfm)
Provides:       tex(utfjgrs-h.vf)
Provides:       tex(utfjgrs-v.tfm)
Provides:       tex(utfjgrs-v.vf)
Provides:       tex(utfjgrt-h.tfm)
Provides:       tex(utfjgrt-h.vf)
Provides:       tex(utfjgrt-v.tfm)
Provides:       tex(utfjgrt-v.vf)
Provides:       tex(utfjgru-h.tfm)
Provides:       tex(utfjgru-h.vf)
Provides:       tex(utfjgru-v.tfm)
Provides:       tex(utfjgru-v.vf)
Provides:       tex(utfjgrv-h.tfm)
Provides:       tex(utfjgrv-h.vf)
Provides:       tex(utfjgrv-v.tfm)
Provides:       tex(utfjgrv-v.vf)
Provides:       tex(utfjgrx-h.tfm)
Provides:       tex(utfjgrx-h.vf)
Provides:       tex(utfjgrx-v.tfm)
Provides:       tex(utfjgrx-v.vf)
Provides:       tex(utfjgry-h.tfm)
Provides:       tex(utfjgry-h.vf)
Provides:       tex(utfjgry-v.tfm)
Provides:       tex(utfjgry-v.vf)
Provides:       tex(utfjgrz-h.tfm)
Provides:       tex(utfjgrz-h.vf)
Provides:       tex(utfjgrz-v.tfm)
Provides:       tex(utfjgrz-v.vf)
Provides:       tex(utfjmb--h.tfm)
Provides:       tex(utfjmb--h.vf)
Provides:       tex(utfjmb--v.tfm)
Provides:       tex(utfjmb--v.vf)
Provides:       tex(utfjmb0-h.tfm)
Provides:       tex(utfjmb0-h.vf)
Provides:       tex(utfjmb0-v.tfm)
Provides:       tex(utfjmb0-v.vf)
Provides:       tex(utfjmb1-h.tfm)
Provides:       tex(utfjmb1-h.vf)
Provides:       tex(utfjmb1-v.tfm)
Provides:       tex(utfjmb1-v.vf)
Provides:       tex(utfjmb2-h.tfm)
Provides:       tex(utfjmb2-h.vf)
Provides:       tex(utfjmb2-v.tfm)
Provides:       tex(utfjmb2-v.vf)
Provides:       tex(utfjmb3-h.tfm)
Provides:       tex(utfjmb3-h.vf)
Provides:       tex(utfjmb3-v.tfm)
Provides:       tex(utfjmb3-v.vf)
Provides:       tex(utfjmb4-h.tfm)
Provides:       tex(utfjmb4-h.vf)
Provides:       tex(utfjmb4-v.tfm)
Provides:       tex(utfjmb4-v.vf)
Provides:       tex(utfjmb5-h.tfm)
Provides:       tex(utfjmb5-h.vf)
Provides:       tex(utfjmb5-v.tfm)
Provides:       tex(utfjmb5-v.vf)
Provides:       tex(utfjmb6-h.tfm)
Provides:       tex(utfjmb6-h.vf)
Provides:       tex(utfjmb6-v.tfm)
Provides:       tex(utfjmb6-v.vf)
Provides:       tex(utfjmb7-h.tfm)
Provides:       tex(utfjmb7-h.vf)
Provides:       tex(utfjmb7-v.tfm)
Provides:       tex(utfjmb7-v.vf)
Provides:       tex(utfjmb8-h.tfm)
Provides:       tex(utfjmb8-h.vf)
Provides:       tex(utfjmb8-v.tfm)
Provides:       tex(utfjmb8-v.vf)
Provides:       tex(utfjmb9-h.tfm)
Provides:       tex(utfjmb9-h.vf)
Provides:       tex(utfjmb9-v.tfm)
Provides:       tex(utfjmb9-v.vf)
Provides:       tex(utfjmba-h.tfm)
Provides:       tex(utfjmba-h.vf)
Provides:       tex(utfjmba-v.tfm)
Provides:       tex(utfjmba-v.vf)
Provides:       tex(utfjmbb-h.tfm)
Provides:       tex(utfjmbb-h.vf)
Provides:       tex(utfjmbb-v.tfm)
Provides:       tex(utfjmbb-v.vf)
Provides:       tex(utfjmbc-h.tfm)
Provides:       tex(utfjmbc-h.vf)
Provides:       tex(utfjmbc-v.tfm)
Provides:       tex(utfjmbc-v.vf)
Provides:       tex(utfjmbd-h.tfm)
Provides:       tex(utfjmbd-h.vf)
Provides:       tex(utfjmbd-v.tfm)
Provides:       tex(utfjmbd-v.vf)
Provides:       tex(utfjmbe-h.tfm)
Provides:       tex(utfjmbe-h.vf)
Provides:       tex(utfjmbe-v.tfm)
Provides:       tex(utfjmbe-v.vf)
Provides:       tex(utfjmbf-h.tfm)
Provides:       tex(utfjmbf-h.vf)
Provides:       tex(utfjmbf-v.tfm)
Provides:       tex(utfjmbf-v.vf)
Provides:       tex(utfjmbg-h.tfm)
Provides:       tex(utfjmbg-h.vf)
Provides:       tex(utfjmbg-v.tfm)
Provides:       tex(utfjmbg-v.vf)
Provides:       tex(utfjmbj-h.tfm)
Provides:       tex(utfjmbj-h.vf)
Provides:       tex(utfjmbj-v.tfm)
Provides:       tex(utfjmbj-v.vf)
Provides:       tex(utfjmbk-h.tfm)
Provides:       tex(utfjmbk-h.vf)
Provides:       tex(utfjmbk-v.tfm)
Provides:       tex(utfjmbk-v.vf)
Provides:       tex(utfjmbl-h.tfm)
Provides:       tex(utfjmbl-h.vf)
Provides:       tex(utfjmbl-v.tfm)
Provides:       tex(utfjmbl-v.vf)
Provides:       tex(utfjmbm-h.tfm)
Provides:       tex(utfjmbm-h.vf)
Provides:       tex(utfjmbm-v.tfm)
Provides:       tex(utfjmbm-v.vf)
Provides:       tex(utfjmbn--h.tfm)
Provides:       tex(utfjmbn--h.vf)
Provides:       tex(utfjmbn--v.tfm)
Provides:       tex(utfjmbn--v.vf)
Provides:       tex(utfjmbn-h.tfm)
Provides:       tex(utfjmbn-h.vf)
Provides:       tex(utfjmbn-v.tfm)
Provides:       tex(utfjmbn-v.vf)
Provides:       tex(utfjmbn0-h.tfm)
Provides:       tex(utfjmbn0-h.vf)
Provides:       tex(utfjmbn0-v.tfm)
Provides:       tex(utfjmbn0-v.vf)
Provides:       tex(utfjmbn1-h.tfm)
Provides:       tex(utfjmbn1-h.vf)
Provides:       tex(utfjmbn1-v.tfm)
Provides:       tex(utfjmbn1-v.vf)
Provides:       tex(utfjmbn2-h.tfm)
Provides:       tex(utfjmbn2-h.vf)
Provides:       tex(utfjmbn2-v.tfm)
Provides:       tex(utfjmbn2-v.vf)
Provides:       tex(utfjmbn3-h.tfm)
Provides:       tex(utfjmbn3-h.vf)
Provides:       tex(utfjmbn3-v.tfm)
Provides:       tex(utfjmbn3-v.vf)
Provides:       tex(utfjmbn4-h.tfm)
Provides:       tex(utfjmbn4-h.vf)
Provides:       tex(utfjmbn4-v.tfm)
Provides:       tex(utfjmbn4-v.vf)
Provides:       tex(utfjmbn5-h.tfm)
Provides:       tex(utfjmbn5-h.vf)
Provides:       tex(utfjmbn5-v.tfm)
Provides:       tex(utfjmbn5-v.vf)
Provides:       tex(utfjmbn6-h.tfm)
Provides:       tex(utfjmbn6-h.vf)
Provides:       tex(utfjmbn6-v.tfm)
Provides:       tex(utfjmbn6-v.vf)
Provides:       tex(utfjmbn7-h.tfm)
Provides:       tex(utfjmbn7-h.vf)
Provides:       tex(utfjmbn7-v.tfm)
Provides:       tex(utfjmbn7-v.vf)
Provides:       tex(utfjmbn8-h.tfm)
Provides:       tex(utfjmbn8-h.vf)
Provides:       tex(utfjmbn8-v.tfm)
Provides:       tex(utfjmbn8-v.vf)
Provides:       tex(utfjmbn9-h.tfm)
Provides:       tex(utfjmbn9-h.vf)
Provides:       tex(utfjmbn9-v.tfm)
Provides:       tex(utfjmbn9-v.vf)
Provides:       tex(utfjmbna-h.tfm)
Provides:       tex(utfjmbna-h.vf)
Provides:       tex(utfjmbna-v.tfm)
Provides:       tex(utfjmbna-v.vf)
Provides:       tex(utfjmbnb-h.tfm)
Provides:       tex(utfjmbnb-h.vf)
Provides:       tex(utfjmbnb-v.tfm)
Provides:       tex(utfjmbnb-v.vf)
Provides:       tex(utfjmbnc-h.tfm)
Provides:       tex(utfjmbnc-h.vf)
Provides:       tex(utfjmbnc-v.tfm)
Provides:       tex(utfjmbnc-v.vf)
Provides:       tex(utfjmbnd-h.tfm)
Provides:       tex(utfjmbnd-h.vf)
Provides:       tex(utfjmbnd-v.tfm)
Provides:       tex(utfjmbnd-v.vf)
Provides:       tex(utfjmbne-h.tfm)
Provides:       tex(utfjmbne-h.vf)
Provides:       tex(utfjmbne-v.tfm)
Provides:       tex(utfjmbne-v.vf)
Provides:       tex(utfjmbnf-h.tfm)
Provides:       tex(utfjmbnf-h.vf)
Provides:       tex(utfjmbnf-v.tfm)
Provides:       tex(utfjmbnf-v.vf)
Provides:       tex(utfjmbo-h.tfm)
Provides:       tex(utfjmbo-h.vf)
Provides:       tex(utfjmbo-v.tfm)
Provides:       tex(utfjmbo-v.vf)
Provides:       tex(utfjmbp-h.tfm)
Provides:       tex(utfjmbp-h.vf)
Provides:       tex(utfjmbp-v.tfm)
Provides:       tex(utfjmbp-v.vf)
Provides:       tex(utfjmbq-h.tfm)
Provides:       tex(utfjmbq-h.vf)
Provides:       tex(utfjmbq-v.tfm)
Provides:       tex(utfjmbq-v.vf)
Provides:       tex(utfjmbr-h.tfm)
Provides:       tex(utfjmbr-h.vf)
Provides:       tex(utfjmbr-v.tfm)
Provides:       tex(utfjmbr-v.vf)
Provides:       tex(utfjmbs-h.tfm)
Provides:       tex(utfjmbs-h.vf)
Provides:       tex(utfjmbs-v.tfm)
Provides:       tex(utfjmbs-v.vf)
Provides:       tex(utfjmbt-h.tfm)
Provides:       tex(utfjmbt-h.vf)
Provides:       tex(utfjmbt-v.tfm)
Provides:       tex(utfjmbt-v.vf)
Provides:       tex(utfjmbu-h.tfm)
Provides:       tex(utfjmbu-h.vf)
Provides:       tex(utfjmbu-v.tfm)
Provides:       tex(utfjmbu-v.vf)
Provides:       tex(utfjmbv-h.tfm)
Provides:       tex(utfjmbv-h.vf)
Provides:       tex(utfjmbv-v.tfm)
Provides:       tex(utfjmbv-v.vf)
Provides:       tex(utfjmbx-h.tfm)
Provides:       tex(utfjmbx-h.vf)
Provides:       tex(utfjmbx-v.tfm)
Provides:       tex(utfjmbx-v.vf)
Provides:       tex(utfjmby-h.tfm)
Provides:       tex(utfjmby-h.vf)
Provides:       tex(utfjmby-v.tfm)
Provides:       tex(utfjmby-v.vf)
Provides:       tex(utfjmbz-h.tfm)
Provides:       tex(utfjmbz-h.vf)
Provides:       tex(utfjmbz-v.tfm)
Provides:       tex(utfjmbz-v.vf)
Provides:       tex(utfjmgr--h.tfm)
Provides:       tex(utfjmgr--h.vf)
Provides:       tex(utfjmgr--v.tfm)
Provides:       tex(utfjmgr--v.vf)
Provides:       tex(utfjmgr0-h.tfm)
Provides:       tex(utfjmgr0-h.vf)
Provides:       tex(utfjmgr0-v.tfm)
Provides:       tex(utfjmgr0-v.vf)
Provides:       tex(utfjmgr1-h.tfm)
Provides:       tex(utfjmgr1-h.vf)
Provides:       tex(utfjmgr1-v.tfm)
Provides:       tex(utfjmgr1-v.vf)
Provides:       tex(utfjmgr2-h.tfm)
Provides:       tex(utfjmgr2-h.vf)
Provides:       tex(utfjmgr2-v.tfm)
Provides:       tex(utfjmgr2-v.vf)
Provides:       tex(utfjmgr3-h.tfm)
Provides:       tex(utfjmgr3-h.vf)
Provides:       tex(utfjmgr3-v.tfm)
Provides:       tex(utfjmgr3-v.vf)
Provides:       tex(utfjmgr4-h.tfm)
Provides:       tex(utfjmgr4-h.vf)
Provides:       tex(utfjmgr4-v.tfm)
Provides:       tex(utfjmgr4-v.vf)
Provides:       tex(utfjmgr5-h.tfm)
Provides:       tex(utfjmgr5-h.vf)
Provides:       tex(utfjmgr5-v.tfm)
Provides:       tex(utfjmgr5-v.vf)
Provides:       tex(utfjmgr6-h.tfm)
Provides:       tex(utfjmgr6-h.vf)
Provides:       tex(utfjmgr6-v.tfm)
Provides:       tex(utfjmgr6-v.vf)
Provides:       tex(utfjmgr7-h.tfm)
Provides:       tex(utfjmgr7-h.vf)
Provides:       tex(utfjmgr7-v.tfm)
Provides:       tex(utfjmgr7-v.vf)
Provides:       tex(utfjmgr8-h.tfm)
Provides:       tex(utfjmgr8-h.vf)
Provides:       tex(utfjmgr8-v.tfm)
Provides:       tex(utfjmgr8-v.vf)
Provides:       tex(utfjmgr9-h.tfm)
Provides:       tex(utfjmgr9-h.vf)
Provides:       tex(utfjmgr9-v.tfm)
Provides:       tex(utfjmgr9-v.vf)
Provides:       tex(utfjmgra-h.tfm)
Provides:       tex(utfjmgra-h.vf)
Provides:       tex(utfjmgra-v.tfm)
Provides:       tex(utfjmgra-v.vf)
Provides:       tex(utfjmgrb-h.tfm)
Provides:       tex(utfjmgrb-h.vf)
Provides:       tex(utfjmgrb-v.tfm)
Provides:       tex(utfjmgrb-v.vf)
Provides:       tex(utfjmgrc-h.tfm)
Provides:       tex(utfjmgrc-h.vf)
Provides:       tex(utfjmgrc-v.tfm)
Provides:       tex(utfjmgrc-v.vf)
Provides:       tex(utfjmgrd-h.tfm)
Provides:       tex(utfjmgrd-h.vf)
Provides:       tex(utfjmgrd-v.tfm)
Provides:       tex(utfjmgrd-v.vf)
Provides:       tex(utfjmgre-h.tfm)
Provides:       tex(utfjmgre-h.vf)
Provides:       tex(utfjmgre-v.tfm)
Provides:       tex(utfjmgre-v.vf)
Provides:       tex(utfjmgrf-h.tfm)
Provides:       tex(utfjmgrf-h.vf)
Provides:       tex(utfjmgrf-v.tfm)
Provides:       tex(utfjmgrf-v.vf)
Provides:       tex(utfjmgrg-h.tfm)
Provides:       tex(utfjmgrg-h.vf)
Provides:       tex(utfjmgrg-v.tfm)
Provides:       tex(utfjmgrg-v.vf)
Provides:       tex(utfjmgrj-h.tfm)
Provides:       tex(utfjmgrj-h.vf)
Provides:       tex(utfjmgrj-v.tfm)
Provides:       tex(utfjmgrj-v.vf)
Provides:       tex(utfjmgrk-h.tfm)
Provides:       tex(utfjmgrk-h.vf)
Provides:       tex(utfjmgrk-v.tfm)
Provides:       tex(utfjmgrk-v.vf)
Provides:       tex(utfjmgrl-h.tfm)
Provides:       tex(utfjmgrl-h.vf)
Provides:       tex(utfjmgrl-v.tfm)
Provides:       tex(utfjmgrl-v.vf)
Provides:       tex(utfjmgrm-h.tfm)
Provides:       tex(utfjmgrm-h.vf)
Provides:       tex(utfjmgrm-v.tfm)
Provides:       tex(utfjmgrm-v.vf)
Provides:       tex(utfjmgrn--h.tfm)
Provides:       tex(utfjmgrn--h.vf)
Provides:       tex(utfjmgrn--v.tfm)
Provides:       tex(utfjmgrn--v.vf)
Provides:       tex(utfjmgrn-h.tfm)
Provides:       tex(utfjmgrn-h.vf)
Provides:       tex(utfjmgrn-v.tfm)
Provides:       tex(utfjmgrn-v.vf)
Provides:       tex(utfjmgrn0-h.tfm)
Provides:       tex(utfjmgrn0-h.vf)
Provides:       tex(utfjmgrn0-v.tfm)
Provides:       tex(utfjmgrn0-v.vf)
Provides:       tex(utfjmgrn1-h.tfm)
Provides:       tex(utfjmgrn1-h.vf)
Provides:       tex(utfjmgrn1-v.tfm)
Provides:       tex(utfjmgrn1-v.vf)
Provides:       tex(utfjmgrn2-h.tfm)
Provides:       tex(utfjmgrn2-h.vf)
Provides:       tex(utfjmgrn2-v.tfm)
Provides:       tex(utfjmgrn2-v.vf)
Provides:       tex(utfjmgrn3-h.tfm)
Provides:       tex(utfjmgrn3-h.vf)
Provides:       tex(utfjmgrn3-v.tfm)
Provides:       tex(utfjmgrn3-v.vf)
Provides:       tex(utfjmgrn4-h.tfm)
Provides:       tex(utfjmgrn4-h.vf)
Provides:       tex(utfjmgrn4-v.tfm)
Provides:       tex(utfjmgrn4-v.vf)
Provides:       tex(utfjmgrn5-h.tfm)
Provides:       tex(utfjmgrn5-h.vf)
Provides:       tex(utfjmgrn5-v.tfm)
Provides:       tex(utfjmgrn5-v.vf)
Provides:       tex(utfjmgrn6-h.tfm)
Provides:       tex(utfjmgrn6-h.vf)
Provides:       tex(utfjmgrn6-v.tfm)
Provides:       tex(utfjmgrn6-v.vf)
Provides:       tex(utfjmgrn7-h.tfm)
Provides:       tex(utfjmgrn7-h.vf)
Provides:       tex(utfjmgrn7-v.tfm)
Provides:       tex(utfjmgrn7-v.vf)
Provides:       tex(utfjmgrn8-h.tfm)
Provides:       tex(utfjmgrn8-h.vf)
Provides:       tex(utfjmgrn8-v.tfm)
Provides:       tex(utfjmgrn8-v.vf)
Provides:       tex(utfjmgrn9-h.tfm)
Provides:       tex(utfjmgrn9-h.vf)
Provides:       tex(utfjmgrn9-v.tfm)
Provides:       tex(utfjmgrn9-v.vf)
Provides:       tex(utfjmgrna-h.tfm)
Provides:       tex(utfjmgrna-h.vf)
Provides:       tex(utfjmgrna-v.tfm)
Provides:       tex(utfjmgrna-v.vf)
Provides:       tex(utfjmgrnb-h.tfm)
Provides:       tex(utfjmgrnb-h.vf)
Provides:       tex(utfjmgrnb-v.tfm)
Provides:       tex(utfjmgrnb-v.vf)
Provides:       tex(utfjmgrnc-h.tfm)
Provides:       tex(utfjmgrnc-h.vf)
Provides:       tex(utfjmgrnc-v.tfm)
Provides:       tex(utfjmgrnc-v.vf)
Provides:       tex(utfjmgrnd-h.tfm)
Provides:       tex(utfjmgrnd-h.vf)
Provides:       tex(utfjmgrnd-v.tfm)
Provides:       tex(utfjmgrnd-v.vf)
Provides:       tex(utfjmgrne-h.tfm)
Provides:       tex(utfjmgrne-h.vf)
Provides:       tex(utfjmgrne-v.tfm)
Provides:       tex(utfjmgrne-v.vf)
Provides:       tex(utfjmgrnf-h.tfm)
Provides:       tex(utfjmgrnf-h.vf)
Provides:       tex(utfjmgrnf-v.tfm)
Provides:       tex(utfjmgrnf-v.vf)
Provides:       tex(utfjmgro-h.tfm)
Provides:       tex(utfjmgro-h.vf)
Provides:       tex(utfjmgro-v.tfm)
Provides:       tex(utfjmgro-v.vf)
Provides:       tex(utfjmgrp-h.tfm)
Provides:       tex(utfjmgrp-h.vf)
Provides:       tex(utfjmgrp-v.tfm)
Provides:       tex(utfjmgrp-v.vf)
Provides:       tex(utfjmgrq-h.tfm)
Provides:       tex(utfjmgrq-h.vf)
Provides:       tex(utfjmgrq-v.tfm)
Provides:       tex(utfjmgrq-v.vf)
Provides:       tex(utfjmgrr-h.tfm)
Provides:       tex(utfjmgrr-h.vf)
Provides:       tex(utfjmgrr-v.tfm)
Provides:       tex(utfjmgrr-v.vf)
Provides:       tex(utfjmgrs-h.tfm)
Provides:       tex(utfjmgrs-h.vf)
Provides:       tex(utfjmgrs-v.tfm)
Provides:       tex(utfjmgrs-v.vf)
Provides:       tex(utfjmgrt-h.tfm)
Provides:       tex(utfjmgrt-h.vf)
Provides:       tex(utfjmgrt-v.tfm)
Provides:       tex(utfjmgrt-v.vf)
Provides:       tex(utfjmgru-h.tfm)
Provides:       tex(utfjmgru-h.vf)
Provides:       tex(utfjmgru-v.tfm)
Provides:       tex(utfjmgru-v.vf)
Provides:       tex(utfjmgrv-h.tfm)
Provides:       tex(utfjmgrv-h.vf)
Provides:       tex(utfjmgrv-v.tfm)
Provides:       tex(utfjmgrv-v.vf)
Provides:       tex(utfjmgrx-h.tfm)
Provides:       tex(utfjmgrx-h.vf)
Provides:       tex(utfjmgrx-v.tfm)
Provides:       tex(utfjmgrx-v.vf)
Provides:       tex(utfjmgry-h.tfm)
Provides:       tex(utfjmgry-h.vf)
Provides:       tex(utfjmgry-v.tfm)
Provides:       tex(utfjmgry-v.vf)
Provides:       tex(utfjmgrz-h.tfm)
Provides:       tex(utfjmgrz-h.vf)
Provides:       tex(utfjmgrz-v.tfm)
Provides:       tex(utfjmgrz-v.vf)
Provides:       tex(utfjml--h.tfm)
Provides:       tex(utfjml--h.vf)
Provides:       tex(utfjml--v.tfm)
Provides:       tex(utfjml--v.vf)
Provides:       tex(utfjml0-h.tfm)
Provides:       tex(utfjml0-h.vf)
Provides:       tex(utfjml0-v.tfm)
Provides:       tex(utfjml0-v.vf)
Provides:       tex(utfjml1-h.tfm)
Provides:       tex(utfjml1-h.vf)
Provides:       tex(utfjml1-v.tfm)
Provides:       tex(utfjml1-v.vf)
Provides:       tex(utfjml2-h.tfm)
Provides:       tex(utfjml2-h.vf)
Provides:       tex(utfjml2-v.tfm)
Provides:       tex(utfjml2-v.vf)
Provides:       tex(utfjml3-h.tfm)
Provides:       tex(utfjml3-h.vf)
Provides:       tex(utfjml3-v.tfm)
Provides:       tex(utfjml3-v.vf)
Provides:       tex(utfjml4-h.tfm)
Provides:       tex(utfjml4-h.vf)
Provides:       tex(utfjml4-v.tfm)
Provides:       tex(utfjml4-v.vf)
Provides:       tex(utfjml5-h.tfm)
Provides:       tex(utfjml5-h.vf)
Provides:       tex(utfjml5-v.tfm)
Provides:       tex(utfjml5-v.vf)
Provides:       tex(utfjml6-h.tfm)
Provides:       tex(utfjml6-h.vf)
Provides:       tex(utfjml6-v.tfm)
Provides:       tex(utfjml6-v.vf)
Provides:       tex(utfjml7-h.tfm)
Provides:       tex(utfjml7-h.vf)
Provides:       tex(utfjml7-v.tfm)
Provides:       tex(utfjml7-v.vf)
Provides:       tex(utfjml8-h.tfm)
Provides:       tex(utfjml8-h.vf)
Provides:       tex(utfjml8-v.tfm)
Provides:       tex(utfjml8-v.vf)
Provides:       tex(utfjml9-h.tfm)
Provides:       tex(utfjml9-h.vf)
Provides:       tex(utfjml9-v.tfm)
Provides:       tex(utfjml9-v.vf)
Provides:       tex(utfjmla-h.tfm)
Provides:       tex(utfjmla-h.vf)
Provides:       tex(utfjmla-v.tfm)
Provides:       tex(utfjmla-v.vf)
Provides:       tex(utfjmlb-h.tfm)
Provides:       tex(utfjmlb-h.vf)
Provides:       tex(utfjmlb-v.tfm)
Provides:       tex(utfjmlb-v.vf)
Provides:       tex(utfjmlc-h.tfm)
Provides:       tex(utfjmlc-h.vf)
Provides:       tex(utfjmlc-v.tfm)
Provides:       tex(utfjmlc-v.vf)
Provides:       tex(utfjmld-h.tfm)
Provides:       tex(utfjmld-h.vf)
Provides:       tex(utfjmld-v.tfm)
Provides:       tex(utfjmld-v.vf)
Provides:       tex(utfjmle-h.tfm)
Provides:       tex(utfjmle-h.vf)
Provides:       tex(utfjmle-v.tfm)
Provides:       tex(utfjmle-v.vf)
Provides:       tex(utfjmlf-h.tfm)
Provides:       tex(utfjmlf-h.vf)
Provides:       tex(utfjmlf-v.tfm)
Provides:       tex(utfjmlf-v.vf)
Provides:       tex(utfjmlg-h.tfm)
Provides:       tex(utfjmlg-h.vf)
Provides:       tex(utfjmlg-v.tfm)
Provides:       tex(utfjmlg-v.vf)
Provides:       tex(utfjmlj-h.tfm)
Provides:       tex(utfjmlj-h.vf)
Provides:       tex(utfjmlj-v.tfm)
Provides:       tex(utfjmlj-v.vf)
Provides:       tex(utfjmlk-h.tfm)
Provides:       tex(utfjmlk-h.vf)
Provides:       tex(utfjmlk-v.tfm)
Provides:       tex(utfjmlk-v.vf)
Provides:       tex(utfjmll-h.tfm)
Provides:       tex(utfjmll-h.vf)
Provides:       tex(utfjmll-v.tfm)
Provides:       tex(utfjmll-v.vf)
Provides:       tex(utfjmlm-h.tfm)
Provides:       tex(utfjmlm-h.vf)
Provides:       tex(utfjmlm-v.tfm)
Provides:       tex(utfjmlm-v.vf)
Provides:       tex(utfjmln--h.tfm)
Provides:       tex(utfjmln--h.vf)
Provides:       tex(utfjmln--v.tfm)
Provides:       tex(utfjmln--v.vf)
Provides:       tex(utfjmln-h.tfm)
Provides:       tex(utfjmln-h.vf)
Provides:       tex(utfjmln-v.tfm)
Provides:       tex(utfjmln-v.vf)
Provides:       tex(utfjmln0-h.tfm)
Provides:       tex(utfjmln0-h.vf)
Provides:       tex(utfjmln0-v.tfm)
Provides:       tex(utfjmln0-v.vf)
Provides:       tex(utfjmln1-h.tfm)
Provides:       tex(utfjmln1-h.vf)
Provides:       tex(utfjmln1-v.tfm)
Provides:       tex(utfjmln1-v.vf)
Provides:       tex(utfjmln2-h.tfm)
Provides:       tex(utfjmln2-h.vf)
Provides:       tex(utfjmln2-v.tfm)
Provides:       tex(utfjmln2-v.vf)
Provides:       tex(utfjmln3-h.tfm)
Provides:       tex(utfjmln3-h.vf)
Provides:       tex(utfjmln3-v.tfm)
Provides:       tex(utfjmln3-v.vf)
Provides:       tex(utfjmln4-h.tfm)
Provides:       tex(utfjmln4-h.vf)
Provides:       tex(utfjmln4-v.tfm)
Provides:       tex(utfjmln4-v.vf)
Provides:       tex(utfjmln5-h.tfm)
Provides:       tex(utfjmln5-h.vf)
Provides:       tex(utfjmln5-v.tfm)
Provides:       tex(utfjmln5-v.vf)
Provides:       tex(utfjmln6-h.tfm)
Provides:       tex(utfjmln6-h.vf)
Provides:       tex(utfjmln6-v.tfm)
Provides:       tex(utfjmln6-v.vf)
Provides:       tex(utfjmln7-h.tfm)
Provides:       tex(utfjmln7-h.vf)
Provides:       tex(utfjmln7-v.tfm)
Provides:       tex(utfjmln7-v.vf)
Provides:       tex(utfjmln8-h.tfm)
Provides:       tex(utfjmln8-h.vf)
Provides:       tex(utfjmln8-v.tfm)
Provides:       tex(utfjmln8-v.vf)
Provides:       tex(utfjmln9-h.tfm)
Provides:       tex(utfjmln9-h.vf)
Provides:       tex(utfjmln9-v.tfm)
Provides:       tex(utfjmln9-v.vf)
Provides:       tex(utfjmlna-h.tfm)
Provides:       tex(utfjmlna-h.vf)
Provides:       tex(utfjmlna-v.tfm)
Provides:       tex(utfjmlna-v.vf)
Provides:       tex(utfjmlnb-h.tfm)
Provides:       tex(utfjmlnb-h.vf)
Provides:       tex(utfjmlnb-v.tfm)
Provides:       tex(utfjmlnb-v.vf)
Provides:       tex(utfjmlnc-h.tfm)
Provides:       tex(utfjmlnc-h.vf)
Provides:       tex(utfjmlnc-v.tfm)
Provides:       tex(utfjmlnc-v.vf)
Provides:       tex(utfjmlnd-h.tfm)
Provides:       tex(utfjmlnd-h.vf)
Provides:       tex(utfjmlnd-v.tfm)
Provides:       tex(utfjmlnd-v.vf)
Provides:       tex(utfjmlne-h.tfm)
Provides:       tex(utfjmlne-h.vf)
Provides:       tex(utfjmlne-v.tfm)
Provides:       tex(utfjmlne-v.vf)
Provides:       tex(utfjmlnf-h.tfm)
Provides:       tex(utfjmlnf-h.vf)
Provides:       tex(utfjmlnf-v.tfm)
Provides:       tex(utfjmlnf-v.vf)
Provides:       tex(utfjmlo-h.tfm)
Provides:       tex(utfjmlo-h.vf)
Provides:       tex(utfjmlo-v.tfm)
Provides:       tex(utfjmlo-v.vf)
Provides:       tex(utfjmlp-h.tfm)
Provides:       tex(utfjmlp-h.vf)
Provides:       tex(utfjmlp-v.tfm)
Provides:       tex(utfjmlp-v.vf)
Provides:       tex(utfjmlq-h.tfm)
Provides:       tex(utfjmlq-h.vf)
Provides:       tex(utfjmlq-v.tfm)
Provides:       tex(utfjmlq-v.vf)
Provides:       tex(utfjmlr-h.tfm)
Provides:       tex(utfjmlr-h.vf)
Provides:       tex(utfjmlr-v.tfm)
Provides:       tex(utfjmlr-v.vf)
Provides:       tex(utfjmls-h.tfm)
Provides:       tex(utfjmls-h.vf)
Provides:       tex(utfjmls-v.tfm)
Provides:       tex(utfjmls-v.vf)
Provides:       tex(utfjmlt-h.tfm)
Provides:       tex(utfjmlt-h.vf)
Provides:       tex(utfjmlt-v.tfm)
Provides:       tex(utfjmlt-v.vf)
Provides:       tex(utfjmlu-h.tfm)
Provides:       tex(utfjmlu-h.vf)
Provides:       tex(utfjmlu-v.tfm)
Provides:       tex(utfjmlu-v.vf)
Provides:       tex(utfjmlv-h.tfm)
Provides:       tex(utfjmlv-h.vf)
Provides:       tex(utfjmlv-v.tfm)
Provides:       tex(utfjmlv-v.vf)
Provides:       tex(utfjmlx-h.tfm)
Provides:       tex(utfjmlx-h.vf)
Provides:       tex(utfjmlx-v.tfm)
Provides:       tex(utfjmlx-v.vf)
Provides:       tex(utfjmly-h.tfm)
Provides:       tex(utfjmly-h.vf)
Provides:       tex(utfjmly-v.tfm)
Provides:       tex(utfjmly-v.vf)
Provides:       tex(utfjmlz-h.tfm)
Provides:       tex(utfjmlz-h.vf)
Provides:       tex(utfjmlz-v.tfm)
Provides:       tex(utfjmlz-v.vf)
Provides:       tex(utfjmr--h.tfm)
Provides:       tex(utfjmr--h.vf)
Provides:       tex(utfjmr--v.tfm)
Provides:       tex(utfjmr--v.vf)
Provides:       tex(utfjmr0-h.tfm)
Provides:       tex(utfjmr0-h.vf)
Provides:       tex(utfjmr0-v.tfm)
Provides:       tex(utfjmr0-v.vf)
Provides:       tex(utfjmr1-h.tfm)
Provides:       tex(utfjmr1-h.vf)
Provides:       tex(utfjmr1-v.tfm)
Provides:       tex(utfjmr1-v.vf)
Provides:       tex(utfjmr2-h.tfm)
Provides:       tex(utfjmr2-h.vf)
Provides:       tex(utfjmr2-v.tfm)
Provides:       tex(utfjmr2-v.vf)
Provides:       tex(utfjmr3-h.tfm)
Provides:       tex(utfjmr3-h.vf)
Provides:       tex(utfjmr3-v.tfm)
Provides:       tex(utfjmr3-v.vf)
Provides:       tex(utfjmr4-h.tfm)
Provides:       tex(utfjmr4-h.vf)
Provides:       tex(utfjmr4-v.tfm)
Provides:       tex(utfjmr4-v.vf)
Provides:       tex(utfjmr5-h.tfm)
Provides:       tex(utfjmr5-h.vf)
Provides:       tex(utfjmr5-v.tfm)
Provides:       tex(utfjmr5-v.vf)
Provides:       tex(utfjmr6-h.tfm)
Provides:       tex(utfjmr6-h.vf)
Provides:       tex(utfjmr6-v.tfm)
Provides:       tex(utfjmr6-v.vf)
Provides:       tex(utfjmr7-h.tfm)
Provides:       tex(utfjmr7-h.vf)
Provides:       tex(utfjmr7-v.tfm)
Provides:       tex(utfjmr7-v.vf)
Provides:       tex(utfjmr8-h.tfm)
Provides:       tex(utfjmr8-h.vf)
Provides:       tex(utfjmr8-v.tfm)
Provides:       tex(utfjmr8-v.vf)
Provides:       tex(utfjmr9-h.tfm)
Provides:       tex(utfjmr9-h.vf)
Provides:       tex(utfjmr9-v.tfm)
Provides:       tex(utfjmr9-v.vf)
Provides:       tex(utfjmra-h.tfm)
Provides:       tex(utfjmra-h.vf)
Provides:       tex(utfjmra-v.tfm)
Provides:       tex(utfjmra-v.vf)
Provides:       tex(utfjmrb-h.tfm)
Provides:       tex(utfjmrb-h.vf)
Provides:       tex(utfjmrb-v.tfm)
Provides:       tex(utfjmrb-v.vf)
Provides:       tex(utfjmrc-h.tfm)
Provides:       tex(utfjmrc-h.vf)
Provides:       tex(utfjmrc-v.tfm)
Provides:       tex(utfjmrc-v.vf)
Provides:       tex(utfjmrd-h.tfm)
Provides:       tex(utfjmrd-h.vf)
Provides:       tex(utfjmrd-v.tfm)
Provides:       tex(utfjmrd-v.vf)
Provides:       tex(utfjmre-h.tfm)
Provides:       tex(utfjmre-h.vf)
Provides:       tex(utfjmre-v.tfm)
Provides:       tex(utfjmre-v.vf)
Provides:       tex(utfjmrf-h.tfm)
Provides:       tex(utfjmrf-h.vf)
Provides:       tex(utfjmrf-v.tfm)
Provides:       tex(utfjmrf-v.vf)
Provides:       tex(utfjmrg-h.tfm)
Provides:       tex(utfjmrg-h.vf)
Provides:       tex(utfjmrg-v.tfm)
Provides:       tex(utfjmrg-v.vf)
Provides:       tex(utfjmrj-h.tfm)
Provides:       tex(utfjmrj-h.vf)
Provides:       tex(utfjmrj-v.tfm)
Provides:       tex(utfjmrj-v.vf)
Provides:       tex(utfjmrk-h.tfm)
Provides:       tex(utfjmrk-h.vf)
Provides:       tex(utfjmrk-v.tfm)
Provides:       tex(utfjmrk-v.vf)
Provides:       tex(utfjmrl-h.tfm)
Provides:       tex(utfjmrl-h.vf)
Provides:       tex(utfjmrl-v.tfm)
Provides:       tex(utfjmrl-v.vf)
Provides:       tex(utfjmrm-h.tfm)
Provides:       tex(utfjmrm-h.vf)
Provides:       tex(utfjmrm-v.tfm)
Provides:       tex(utfjmrm-v.vf)
Provides:       tex(utfjmrn--h.tfm)
Provides:       tex(utfjmrn--h.vf)
Provides:       tex(utfjmrn--v.tfm)
Provides:       tex(utfjmrn--v.vf)
Provides:       tex(utfjmrn-h.tfm)
Provides:       tex(utfjmrn-h.vf)
Provides:       tex(utfjmrn-v.tfm)
Provides:       tex(utfjmrn-v.vf)
Provides:       tex(utfjmrn0-h.tfm)
Provides:       tex(utfjmrn0-h.vf)
Provides:       tex(utfjmrn0-v.tfm)
Provides:       tex(utfjmrn0-v.vf)
Provides:       tex(utfjmrn1-h.tfm)
Provides:       tex(utfjmrn1-h.vf)
Provides:       tex(utfjmrn1-v.tfm)
Provides:       tex(utfjmrn1-v.vf)
Provides:       tex(utfjmrn2-h.tfm)
Provides:       tex(utfjmrn2-h.vf)
Provides:       tex(utfjmrn2-v.tfm)
Provides:       tex(utfjmrn2-v.vf)
Provides:       tex(utfjmrn3-h.tfm)
Provides:       tex(utfjmrn3-h.vf)
Provides:       tex(utfjmrn3-v.tfm)
Provides:       tex(utfjmrn3-v.vf)
Provides:       tex(utfjmrn4-h.tfm)
Provides:       tex(utfjmrn4-h.vf)
Provides:       tex(utfjmrn4-v.tfm)
Provides:       tex(utfjmrn4-v.vf)
Provides:       tex(utfjmrn5-h.tfm)
Provides:       tex(utfjmrn5-h.vf)
Provides:       tex(utfjmrn5-v.tfm)
Provides:       tex(utfjmrn5-v.vf)
Provides:       tex(utfjmrn6-h.tfm)
Provides:       tex(utfjmrn6-h.vf)
Provides:       tex(utfjmrn6-v.tfm)
Provides:       tex(utfjmrn6-v.vf)
Provides:       tex(utfjmrn7-h.tfm)
Provides:       tex(utfjmrn7-h.vf)
Provides:       tex(utfjmrn7-v.tfm)
Provides:       tex(utfjmrn7-v.vf)
Provides:       tex(utfjmrn8-h.tfm)
Provides:       tex(utfjmrn8-h.vf)
Provides:       tex(utfjmrn8-v.tfm)
Provides:       tex(utfjmrn8-v.vf)
Provides:       tex(utfjmrn9-h.tfm)
Provides:       tex(utfjmrn9-h.vf)
Provides:       tex(utfjmrn9-v.tfm)
Provides:       tex(utfjmrn9-v.vf)
Provides:       tex(utfjmrna-h.tfm)
Provides:       tex(utfjmrna-h.vf)
Provides:       tex(utfjmrna-v.tfm)
Provides:       tex(utfjmrna-v.vf)
Provides:       tex(utfjmrnb-h.tfm)
Provides:       tex(utfjmrnb-h.vf)
Provides:       tex(utfjmrnb-v.tfm)
Provides:       tex(utfjmrnb-v.vf)
Provides:       tex(utfjmrnc-h.tfm)
Provides:       tex(utfjmrnc-h.vf)
Provides:       tex(utfjmrnc-v.tfm)
Provides:       tex(utfjmrnc-v.vf)
Provides:       tex(utfjmrnd-h.tfm)
Provides:       tex(utfjmrnd-h.vf)
Provides:       tex(utfjmrnd-v.tfm)
Provides:       tex(utfjmrnd-v.vf)
Provides:       tex(utfjmrne-h.tfm)
Provides:       tex(utfjmrne-h.vf)
Provides:       tex(utfjmrne-v.tfm)
Provides:       tex(utfjmrne-v.vf)
Provides:       tex(utfjmrnf-h.tfm)
Provides:       tex(utfjmrnf-h.vf)
Provides:       tex(utfjmrnf-v.tfm)
Provides:       tex(utfjmrnf-v.vf)
Provides:       tex(utfjmro-h.tfm)
Provides:       tex(utfjmro-h.vf)
Provides:       tex(utfjmro-v.tfm)
Provides:       tex(utfjmro-v.vf)
Provides:       tex(utfjmrp-h.tfm)
Provides:       tex(utfjmrp-h.vf)
Provides:       tex(utfjmrp-v.tfm)
Provides:       tex(utfjmrp-v.vf)
Provides:       tex(utfjmrq-h.tfm)
Provides:       tex(utfjmrq-h.vf)
Provides:       tex(utfjmrq-v.tfm)
Provides:       tex(utfjmrq-v.vf)
Provides:       tex(utfjmrr-h.tfm)
Provides:       tex(utfjmrr-h.vf)
Provides:       tex(utfjmrr-v.tfm)
Provides:       tex(utfjmrr-v.vf)
Provides:       tex(utfjmrs-h.tfm)
Provides:       tex(utfjmrs-h.vf)
Provides:       tex(utfjmrs-v.tfm)
Provides:       tex(utfjmrs-v.vf)
Provides:       tex(utfjmrt-h.tfm)
Provides:       tex(utfjmrt-h.vf)
Provides:       tex(utfjmrt-v.tfm)
Provides:       tex(utfjmrt-v.vf)
Provides:       tex(utfjmru-h.tfm)
Provides:       tex(utfjmru-h.vf)
Provides:       tex(utfjmru-v.tfm)
Provides:       tex(utfjmru-v.vf)
Provides:       tex(utfjmrv-h.tfm)
Provides:       tex(utfjmrv-h.vf)
Provides:       tex(utfjmrv-v.tfm)
Provides:       tex(utfjmrv-v.vf)
Provides:       tex(utfjmrx-h.tfm)
Provides:       tex(utfjmrx-h.vf)
Provides:       tex(utfjmrx-v.tfm)
Provides:       tex(utfjmrx-v.vf)
Provides:       tex(utfjmry-h.tfm)
Provides:       tex(utfjmry-h.vf)
Provides:       tex(utfjmry-v.tfm)
Provides:       tex(utfjmry-v.vf)
Provides:       tex(utfjmrz-h.tfm)
Provides:       tex(utfjmrz-h.vf)
Provides:       tex(utfjmrz-v.tfm)
Provides:       tex(utfjmrz-v.vf)
Provides:       tex(utfkgb--h.tfm)
Provides:       tex(utfkgb--h.vf)
Provides:       tex(utfkgb--v.tfm)
Provides:       tex(utfkgb--v.vf)
Provides:       tex(utfkge--h.tfm)
Provides:       tex(utfkge--h.vf)
Provides:       tex(utfkge--v.tfm)
Provides:       tex(utfkge--v.vf)
Provides:       tex(utfkgr--h.tfm)
Provides:       tex(utfkgr--h.vf)
Provides:       tex(utfkgr--v.tfm)
Provides:       tex(utfkgr--v.vf)
Provides:       tex(utfkgr0-h.tfm)
Provides:       tex(utfkgr0-h.vf)
Provides:       tex(utfkgr0-v.tfm)
Provides:       tex(utfkgr0-v.vf)
Provides:       tex(utfkgr1-h.tfm)
Provides:       tex(utfkgr1-h.vf)
Provides:       tex(utfkgr1-v.tfm)
Provides:       tex(utfkgr1-v.vf)
Provides:       tex(utfkgr2-h.tfm)
Provides:       tex(utfkgr2-h.vf)
Provides:       tex(utfkgr2-v.tfm)
Provides:       tex(utfkgr2-v.vf)
Provides:       tex(utfkgr3-h.tfm)
Provides:       tex(utfkgr3-h.vf)
Provides:       tex(utfkgr3-v.tfm)
Provides:       tex(utfkgr3-v.vf)
Provides:       tex(utfkgr4-h.tfm)
Provides:       tex(utfkgr4-h.vf)
Provides:       tex(utfkgr4-v.tfm)
Provides:       tex(utfkgr4-v.vf)
Provides:       tex(utfkgr5-h.tfm)
Provides:       tex(utfkgr5-h.vf)
Provides:       tex(utfkgr5-v.tfm)
Provides:       tex(utfkgr5-v.vf)
Provides:       tex(utfkgr6-h.tfm)
Provides:       tex(utfkgr6-h.vf)
Provides:       tex(utfkgr6-v.tfm)
Provides:       tex(utfkgr6-v.vf)
Provides:       tex(utfkgr7-h.tfm)
Provides:       tex(utfkgr7-h.vf)
Provides:       tex(utfkgr7-v.tfm)
Provides:       tex(utfkgr7-v.vf)
Provides:       tex(utfkgr8-h.tfm)
Provides:       tex(utfkgr8-h.vf)
Provides:       tex(utfkgr8-v.tfm)
Provides:       tex(utfkgr8-v.vf)
Provides:       tex(utfkgr9-h.tfm)
Provides:       tex(utfkgr9-h.vf)
Provides:       tex(utfkgr9-v.tfm)
Provides:       tex(utfkgr9-v.vf)
Provides:       tex(utfkgra-h.tfm)
Provides:       tex(utfkgra-h.vf)
Provides:       tex(utfkgra-v.tfm)
Provides:       tex(utfkgra-v.vf)
Provides:       tex(utfkgrb-h.tfm)
Provides:       tex(utfkgrb-h.vf)
Provides:       tex(utfkgrb-v.tfm)
Provides:       tex(utfkgrb-v.vf)
Provides:       tex(utfkgrc-h.tfm)
Provides:       tex(utfkgrc-h.vf)
Provides:       tex(utfkgrc-v.tfm)
Provides:       tex(utfkgrc-v.vf)
Provides:       tex(utfkgrd-h.tfm)
Provides:       tex(utfkgrd-h.vf)
Provides:       tex(utfkgrd-v.tfm)
Provides:       tex(utfkgrd-v.vf)
Provides:       tex(utfkgre-h.tfm)
Provides:       tex(utfkgre-h.vf)
Provides:       tex(utfkgre-v.tfm)
Provides:       tex(utfkgre-v.vf)
Provides:       tex(utfkgrf-h.tfm)
Provides:       tex(utfkgrf-h.vf)
Provides:       tex(utfkgrf-v.tfm)
Provides:       tex(utfkgrf-v.vf)
Provides:       tex(utfkmb--h.tfm)
Provides:       tex(utfkmb--h.vf)
Provides:       tex(utfkmb--v.tfm)
Provides:       tex(utfkmb--v.vf)
Provides:       tex(utfkmgr--h.tfm)
Provides:       tex(utfkmgr--h.vf)
Provides:       tex(utfkmgr--v.tfm)
Provides:       tex(utfkmgr--v.vf)
Provides:       tex(utfkml--h.tfm)
Provides:       tex(utfkml--h.vf)
Provides:       tex(utfkml--v.tfm)
Provides:       tex(utfkml--v.vf)
Provides:       tex(utfkmr--h.tfm)
Provides:       tex(utfkmr--h.vf)
Provides:       tex(utfkmr--v.tfm)
Provides:       tex(utfkmr--v.vf)
Provides:       tex(utfkmr0-h.tfm)
Provides:       tex(utfkmr0-h.vf)
Provides:       tex(utfkmr0-v.tfm)
Provides:       tex(utfkmr0-v.vf)
Provides:       tex(utfkmr1-h.tfm)
Provides:       tex(utfkmr1-h.vf)
Provides:       tex(utfkmr1-v.tfm)
Provides:       tex(utfkmr1-v.vf)
Provides:       tex(utfkmr2-h.tfm)
Provides:       tex(utfkmr2-h.vf)
Provides:       tex(utfkmr2-v.tfm)
Provides:       tex(utfkmr2-v.vf)
Provides:       tex(utfkmr3-h.tfm)
Provides:       tex(utfkmr3-h.vf)
Provides:       tex(utfkmr3-v.tfm)
Provides:       tex(utfkmr3-v.vf)
Provides:       tex(utfkmr4-h.tfm)
Provides:       tex(utfkmr4-h.vf)
Provides:       tex(utfkmr4-v.tfm)
Provides:       tex(utfkmr4-v.vf)
Provides:       tex(utfkmr5-h.tfm)
Provides:       tex(utfkmr5-h.vf)
Provides:       tex(utfkmr5-v.tfm)
Provides:       tex(utfkmr5-v.vf)
Provides:       tex(utfkmr6-h.tfm)
Provides:       tex(utfkmr6-h.vf)
Provides:       tex(utfkmr6-v.tfm)
Provides:       tex(utfkmr6-v.vf)
Provides:       tex(utfkmr7-h.tfm)
Provides:       tex(utfkmr7-h.vf)
Provides:       tex(utfkmr7-v.tfm)
Provides:       tex(utfkmr7-v.vf)
Provides:       tex(utfkmr8-h.tfm)
Provides:       tex(utfkmr8-h.vf)
Provides:       tex(utfkmr8-v.tfm)
Provides:       tex(utfkmr8-v.vf)
Provides:       tex(utfkmr9-h.tfm)
Provides:       tex(utfkmr9-h.vf)
Provides:       tex(utfkmr9-v.tfm)
Provides:       tex(utfkmr9-v.vf)
Provides:       tex(utfkmra-h.tfm)
Provides:       tex(utfkmra-h.vf)
Provides:       tex(utfkmra-v.tfm)
Provides:       tex(utfkmra-v.vf)
Provides:       tex(utfkmrb-h.tfm)
Provides:       tex(utfkmrb-h.vf)
Provides:       tex(utfkmrb-v.tfm)
Provides:       tex(utfkmrb-v.vf)
Provides:       tex(utfkmrc-h.tfm)
Provides:       tex(utfkmrc-h.vf)
Provides:       tex(utfkmrc-v.tfm)
Provides:       tex(utfkmrc-v.vf)
Provides:       tex(utfkmrd-h.tfm)
Provides:       tex(utfkmrd-h.vf)
Provides:       tex(utfkmrd-v.tfm)
Provides:       tex(utfkmrd-v.vf)
Provides:       tex(utfkmre-h.tfm)
Provides:       tex(utfkmre-h.vf)
Provides:       tex(utfkmre-v.tfm)
Provides:       tex(utfkmre-v.vf)
Provides:       tex(utfkmrf-h.tfm)
Provides:       tex(utfkmrf-h.vf)
Provides:       tex(utfkmrf-v.tfm)
Provides:       tex(utfkmrf-v.vf)
Provides:       tex(utfmr0-h.tfm)
Provides:       tex(utfmr0-h.vf)
Provides:       tex(utfmr0-v.tfm)
Provides:       tex(utfmr0-v.vf)
Provides:       tex(utfmr1-h.tfm)
Provides:       tex(utfmr1-h.vf)
Provides:       tex(utfmr1-v.tfm)
Provides:       tex(utfmr1-v.vf)
Provides:       tex(utfmr2-h.tfm)
Provides:       tex(utfmr2-h.vf)
Provides:       tex(utfmr2-v.tfm)
Provides:       tex(utfmr2-v.vf)
Provides:       tex(utfmr3-h.tfm)
Provides:       tex(utfmr3-h.vf)
Provides:       tex(utfmr3-v.tfm)
Provides:       tex(utfmr3-v.vf)
Provides:       tex(utfmr4-h.tfm)
Provides:       tex(utfmr4-h.vf)
Provides:       tex(utfmr4-v.tfm)
Provides:       tex(utfmr4-v.vf)
Provides:       tex(utfmr5-h.tfm)
Provides:       tex(utfmr5-h.vf)
Provides:       tex(utfmr5-v.tfm)
Provides:       tex(utfmr5-v.vf)
Provides:       tex(utfmr6-h.tfm)
Provides:       tex(utfmr6-h.vf)
Provides:       tex(utfmr6-v.tfm)
Provides:       tex(utfmr6-v.vf)
Provides:       tex(utfmr7-h.tfm)
Provides:       tex(utfmr7-h.vf)
Provides:       tex(utfmr7-v.tfm)
Provides:       tex(utfmr7-v.vf)
Provides:       tex(utfmr8-h.tfm)
Provides:       tex(utfmr8-h.vf)
Provides:       tex(utfmr8-v.tfm)
Provides:       tex(utfmr8-v.vf)
Provides:       tex(utfmr9-h.tfm)
Provides:       tex(utfmr9-h.vf)
Provides:       tex(utfmr9-v.tfm)
Provides:       tex(utfmr9-v.vf)
Provides:       tex(utfmra-h.tfm)
Provides:       tex(utfmra-h.vf)
Provides:       tex(utfmra-v.tfm)
Provides:       tex(utfmra-v.vf)
Provides:       tex(utfmrb-h.tfm)
Provides:       tex(utfmrb-h.vf)
Provides:       tex(utfmrb-v.tfm)
Provides:       tex(utfmrb-v.vf)
Provides:       tex(utfmrc-h.tfm)
Provides:       tex(utfmrc-h.vf)
Provides:       tex(utfmrc-v.tfm)
Provides:       tex(utfmrc-v.vf)
Provides:       tex(utfmrd-h.tfm)
Provides:       tex(utfmrd-h.vf)
Provides:       tex(utfmrd-v.tfm)
Provides:       tex(utfmrd-v.vf)
Provides:       tex(utfmre-h.tfm)
Provides:       tex(utfmre-h.vf)
Provides:       tex(utfmre-v.tfm)
Provides:       tex(utfmre-v.vf)
Provides:       tex(utfmrf-h.tfm)
Provides:       tex(utfmrf-h.vf)
Provides:       tex(utfmrf-v.tfm)
Provides:       tex(utfmrf-v.vf)
Provides:       tex(utfmrg-h.tfm)
Provides:       tex(utfmrg-h.vf)
Provides:       tex(utfmrg-v.tfm)
Provides:       tex(utfmrg-v.vf)
Provides:       tex(utfmrj-h.tfm)
Provides:       tex(utfmrj-h.vf)
Provides:       tex(utfmrj-v.tfm)
Provides:       tex(utfmrj-v.vf)
Provides:       tex(utfmrk-h.tfm)
Provides:       tex(utfmrk-h.vf)
Provides:       tex(utfmrk-v.tfm)
Provides:       tex(utfmrk-v.vf)
Provides:       tex(utfmrl-h.tfm)
Provides:       tex(utfmrl-h.vf)
Provides:       tex(utfmrl-v.tfm)
Provides:       tex(utfmrl-v.vf)
Provides:       tex(utfmrm-h.tfm)
Provides:       tex(utfmrm-h.vf)
Provides:       tex(utfmrm-v.tfm)
Provides:       tex(utfmrm-v.vf)
Provides:       tex(utfmrn-h.tfm)
Provides:       tex(utfmrn-h.vf)
Provides:       tex(utfmrn-v.tfm)
Provides:       tex(utfmrn-v.vf)
Provides:       tex(utfmro-h.tfm)
Provides:       tex(utfmro-h.vf)
Provides:       tex(utfmro-v.tfm)
Provides:       tex(utfmro-v.vf)
Provides:       tex(utfmrp-h.tfm)
Provides:       tex(utfmrp-h.vf)
Provides:       tex(utfmrp-v.tfm)
Provides:       tex(utfmrp-v.vf)
Provides:       tex(utfmrq-h.tfm)
Provides:       tex(utfmrq-h.vf)
Provides:       tex(utfmrq-v.tfm)
Provides:       tex(utfmrq-v.vf)
Provides:       tex(utfmrr-h.tfm)
Provides:       tex(utfmrr-h.vf)
Provides:       tex(utfmrr-v.tfm)
Provides:       tex(utfmrr-v.vf)
Provides:       tex(utfmrs-h.tfm)
Provides:       tex(utfmrs-h.vf)
Provides:       tex(utfmrs-v.tfm)
Provides:       tex(utfmrs-v.vf)
Provides:       tex(utfmrt-h.tfm)
Provides:       tex(utfmrt-h.vf)
Provides:       tex(utfmrt-v.tfm)
Provides:       tex(utfmrt-v.vf)
Provides:       tex(utfmru-h.tfm)
Provides:       tex(utfmru-h.vf)
Provides:       tex(utfmru-v.tfm)
Provides:       tex(utfmru-v.vf)
Provides:       tex(utfmrv-h.tfm)
Provides:       tex(utfmrv-h.vf)
Provides:       tex(utfmrv-v.tfm)
Provides:       tex(utfmrv-v.vf)
Provides:       tex(utfmrw-h.tfm)
Provides:       tex(utfmrw-h.vf)
Provides:       tex(utfmrw-v.tfm)
Provides:       tex(utfmrw-v.vf)
Provides:       tex(utfmrx-h.tfm)
Provides:       tex(utfmrx-h.vf)
Provides:       tex(utfmrx-v.tfm)
Provides:       tex(utfmrx-v.vf)
Provides:       tex(utfmry-h.tfm)
Provides:       tex(utfmry-h.vf)
Provides:       tex(utfmry-v.tfm)
Provides:       tex(utfmry-v.vf)
Provides:       tex(utfmrz-h.tfm)
Provides:       tex(utfmrz-h.vf)
Provides:       tex(utfmrz-v.tfm)
Provides:       tex(utfmrz-v.vf)
Provides:       tex(utftgb--h.tfm)
Provides:       tex(utftgb--h.vf)
Provides:       tex(utftgb--v.tfm)
Provides:       tex(utftgb--v.vf)
Provides:       tex(utftge--h.tfm)
Provides:       tex(utftge--h.vf)
Provides:       tex(utftge--v.tfm)
Provides:       tex(utftge--v.vf)
Provides:       tex(utftgr--h.tfm)
Provides:       tex(utftgr--h.vf)
Provides:       tex(utftgr--v.tfm)
Provides:       tex(utftgr--v.vf)
Provides:       tex(utftgr0-h.tfm)
Provides:       tex(utftgr0-h.vf)
Provides:       tex(utftgr0-v.tfm)
Provides:       tex(utftgr0-v.vf)
Provides:       tex(utftgr1-h.tfm)
Provides:       tex(utftgr1-h.vf)
Provides:       tex(utftgr1-v.tfm)
Provides:       tex(utftgr1-v.vf)
Provides:       tex(utftgr2-h.tfm)
Provides:       tex(utftgr2-h.vf)
Provides:       tex(utftgr2-v.tfm)
Provides:       tex(utftgr2-v.vf)
Provides:       tex(utftgr3-h.tfm)
Provides:       tex(utftgr3-h.vf)
Provides:       tex(utftgr3-v.tfm)
Provides:       tex(utftgr3-v.vf)
Provides:       tex(utftgr4-h.tfm)
Provides:       tex(utftgr4-h.vf)
Provides:       tex(utftgr4-v.tfm)
Provides:       tex(utftgr4-v.vf)
Provides:       tex(utftgr5-h.tfm)
Provides:       tex(utftgr5-h.vf)
Provides:       tex(utftgr5-v.tfm)
Provides:       tex(utftgr5-v.vf)
Provides:       tex(utftgr6-h.tfm)
Provides:       tex(utftgr6-h.vf)
Provides:       tex(utftgr6-v.tfm)
Provides:       tex(utftgr6-v.vf)
Provides:       tex(utftgr7-h.tfm)
Provides:       tex(utftgr7-h.vf)
Provides:       tex(utftgr7-v.tfm)
Provides:       tex(utftgr7-v.vf)
Provides:       tex(utftgr8-h.tfm)
Provides:       tex(utftgr8-h.vf)
Provides:       tex(utftgr8-v.tfm)
Provides:       tex(utftgr8-v.vf)
Provides:       tex(utftgr9-h.tfm)
Provides:       tex(utftgr9-h.vf)
Provides:       tex(utftgr9-v.tfm)
Provides:       tex(utftgr9-v.vf)
Provides:       tex(utftgra-h.tfm)
Provides:       tex(utftgra-h.vf)
Provides:       tex(utftgra-v.tfm)
Provides:       tex(utftgra-v.vf)
Provides:       tex(utftgrb-h.tfm)
Provides:       tex(utftgrb-h.vf)
Provides:       tex(utftgrb-v.tfm)
Provides:       tex(utftgrb-v.vf)
Provides:       tex(utftgrc-h.tfm)
Provides:       tex(utftgrc-h.vf)
Provides:       tex(utftgrc-v.tfm)
Provides:       tex(utftgrc-v.vf)
Provides:       tex(utftgrd-h.tfm)
Provides:       tex(utftgrd-h.vf)
Provides:       tex(utftgrd-v.tfm)
Provides:       tex(utftgrd-v.vf)
Provides:       tex(utftgre-h.tfm)
Provides:       tex(utftgre-h.vf)
Provides:       tex(utftgre-v.tfm)
Provides:       tex(utftgre-v.vf)
Provides:       tex(utftgrf-h.tfm)
Provides:       tex(utftgrf-h.vf)
Provides:       tex(utftgrf-v.tfm)
Provides:       tex(utftgrf-v.vf)
Provides:       tex(utftgrk-h.tfm)
Provides:       tex(utftgrk-h.vf)
Provides:       tex(utftgrk-v.tfm)
Provides:       tex(utftgrk-v.vf)
Provides:       tex(utftgrl-h.tfm)
Provides:       tex(utftgrl-h.vf)
Provides:       tex(utftgrl-v.tfm)
Provides:       tex(utftgrl-v.vf)
Provides:       tex(utftgrm-h.tfm)
Provides:       tex(utftgrm-h.vf)
Provides:       tex(utftgrm-v.tfm)
Provides:       tex(utftgrm-v.vf)
Provides:       tex(utftgrn-h.tfm)
Provides:       tex(utftgrn-h.vf)
Provides:       tex(utftgrn-v.tfm)
Provides:       tex(utftgrn-v.vf)
Provides:       tex(utftgro-h.tfm)
Provides:       tex(utftgro-h.vf)
Provides:       tex(utftgro-v.tfm)
Provides:       tex(utftgro-v.vf)
Provides:       tex(utftgrp-h.tfm)
Provides:       tex(utftgrp-h.vf)
Provides:       tex(utftgrp-v.tfm)
Provides:       tex(utftgrp-v.vf)
Provides:       tex(utftgrq-h.tfm)
Provides:       tex(utftgrq-h.vf)
Provides:       tex(utftgrq-v.tfm)
Provides:       tex(utftgrq-v.vf)
Provides:       tex(utftgrr-h.tfm)
Provides:       tex(utftgrr-h.vf)
Provides:       tex(utftgrr-v.tfm)
Provides:       tex(utftgrr-v.vf)
Provides:       tex(utftgrs-h.tfm)
Provides:       tex(utftgrs-h.vf)
Provides:       tex(utftgrs-v.tfm)
Provides:       tex(utftgrs-v.vf)
Provides:       tex(utftgrt-h.tfm)
Provides:       tex(utftgrt-h.vf)
Provides:       tex(utftgrt-v.tfm)
Provides:       tex(utftgrt-v.vf)
Provides:       tex(utftgru-h.tfm)
Provides:       tex(utftgru-h.vf)
Provides:       tex(utftgru-v.tfm)
Provides:       tex(utftgru-v.vf)
Provides:       tex(utftgrv-h.tfm)
Provides:       tex(utftgrv-h.vf)
Provides:       tex(utftgrv-v.tfm)
Provides:       tex(utftgrv-v.vf)
Provides:       tex(utftgrw-h.tfm)
Provides:       tex(utftgrw-h.vf)
Provides:       tex(utftgrw-v.tfm)
Provides:       tex(utftgrw-v.vf)
Provides:       tex(utftgrx-h.tfm)
Provides:       tex(utftgrx-h.vf)
Provides:       tex(utftgrx-v.tfm)
Provides:       tex(utftgrx-v.vf)
Provides:       tex(utftgrz-h.tfm)
Provides:       tex(utftgrz-h.vf)
Provides:       tex(utftgrz-v.tfm)
Provides:       tex(utftgrz-v.vf)
Provides:       tex(utftmb--h.tfm)
Provides:       tex(utftmb--h.vf)
Provides:       tex(utftmb--v.tfm)
Provides:       tex(utftmb--v.vf)
Provides:       tex(utftmgr--h.tfm)
Provides:       tex(utftmgr--h.vf)
Provides:       tex(utftmgr--v.tfm)
Provides:       tex(utftmgr--v.vf)
Provides:       tex(utftml--h.tfm)
Provides:       tex(utftml--h.vf)
Provides:       tex(utftml--v.tfm)
Provides:       tex(utftml--v.vf)
Provides:       tex(utftmr--h.tfm)
Provides:       tex(utftmr--h.vf)
Provides:       tex(utftmr--v.tfm)
Provides:       tex(utftmr--v.vf)
Provides:       tex(utftmr0-h.tfm)
Provides:       tex(utftmr0-h.vf)
Provides:       tex(utftmr0-v.tfm)
Provides:       tex(utftmr0-v.vf)
Provides:       tex(utftmr1-h.tfm)
Provides:       tex(utftmr1-h.vf)
Provides:       tex(utftmr1-v.tfm)
Provides:       tex(utftmr1-v.vf)
Provides:       tex(utftmr2-h.tfm)
Provides:       tex(utftmr2-h.vf)
Provides:       tex(utftmr2-v.tfm)
Provides:       tex(utftmr2-v.vf)
Provides:       tex(utftmr3-h.tfm)
Provides:       tex(utftmr3-h.vf)
Provides:       tex(utftmr3-v.tfm)
Provides:       tex(utftmr3-v.vf)
Provides:       tex(utftmr4-h.tfm)
Provides:       tex(utftmr4-h.vf)
Provides:       tex(utftmr4-v.tfm)
Provides:       tex(utftmr4-v.vf)
Provides:       tex(utftmr5-h.tfm)
Provides:       tex(utftmr5-h.vf)
Provides:       tex(utftmr5-v.tfm)
Provides:       tex(utftmr5-v.vf)
Provides:       tex(utftmr6-h.tfm)
Provides:       tex(utftmr6-h.vf)
Provides:       tex(utftmr6-v.tfm)
Provides:       tex(utftmr6-v.vf)
Provides:       tex(utftmr7-h.tfm)
Provides:       tex(utftmr7-h.vf)
Provides:       tex(utftmr7-v.tfm)
Provides:       tex(utftmr7-v.vf)
Provides:       tex(utftmr8-h.tfm)
Provides:       tex(utftmr8-h.vf)
Provides:       tex(utftmr8-v.tfm)
Provides:       tex(utftmr8-v.vf)
Provides:       tex(utftmr9-h.tfm)
Provides:       tex(utftmr9-h.vf)
Provides:       tex(utftmr9-v.tfm)
Provides:       tex(utftmr9-v.vf)
Provides:       tex(utftmra-h.tfm)
Provides:       tex(utftmra-h.vf)
Provides:       tex(utftmra-v.tfm)
Provides:       tex(utftmra-v.vf)
Provides:       tex(utftmrb-h.tfm)
Provides:       tex(utftmrb-h.vf)
Provides:       tex(utftmrb-v.tfm)
Provides:       tex(utftmrb-v.vf)
Provides:       tex(utftmrc-h.tfm)
Provides:       tex(utftmrc-h.vf)
Provides:       tex(utftmrc-v.tfm)
Provides:       tex(utftmrc-v.vf)
Provides:       tex(utftmrd-h.tfm)
Provides:       tex(utftmrd-h.vf)
Provides:       tex(utftmrd-v.tfm)
Provides:       tex(utftmrd-v.vf)
Provides:       tex(utftmre-h.tfm)
Provides:       tex(utftmre-h.vf)
Provides:       tex(utftmre-v.tfm)
Provides:       tex(utftmre-v.vf)
Provides:       tex(utftmrf-h.tfm)
Provides:       tex(utftmrf-h.vf)
Provides:       tex(utftmrf-v.tfm)
Provides:       tex(utftmrf-v.vf)
Provides:       tex(utftmrk-h.tfm)
Provides:       tex(utftmrk-h.vf)
Provides:       tex(utftmrk-v.tfm)
Provides:       tex(utftmrk-v.vf)
Provides:       tex(utftmrl-h.tfm)
Provides:       tex(utftmrl-h.vf)
Provides:       tex(utftmrl-v.tfm)
Provides:       tex(utftmrl-v.vf)
Provides:       tex(utftmrm-h.tfm)
Provides:       tex(utftmrm-h.vf)
Provides:       tex(utftmrm-v.tfm)
Provides:       tex(utftmrm-v.vf)
Provides:       tex(utftmrn-h.tfm)
Provides:       tex(utftmrn-h.vf)
Provides:       tex(utftmrn-v.tfm)
Provides:       tex(utftmrn-v.vf)
Provides:       tex(utftmro-h.tfm)
Provides:       tex(utftmro-h.vf)
Provides:       tex(utftmro-v.tfm)
Provides:       tex(utftmro-v.vf)
Provides:       tex(utftmrp-h.tfm)
Provides:       tex(utftmrp-h.vf)
Provides:       tex(utftmrp-v.tfm)
Provides:       tex(utftmrp-v.vf)
Provides:       tex(utftmrq-h.tfm)
Provides:       tex(utftmrq-h.vf)
Provides:       tex(utftmrq-v.tfm)
Provides:       tex(utftmrq-v.vf)
Provides:       tex(utftmrr-h.tfm)
Provides:       tex(utftmrr-h.vf)
Provides:       tex(utftmrr-v.tfm)
Provides:       tex(utftmrr-v.vf)
Provides:       tex(utftmrs-h.tfm)
Provides:       tex(utftmrs-h.vf)
Provides:       tex(utftmrs-v.tfm)
Provides:       tex(utftmrs-v.vf)
Provides:       tex(utftmrt-h.tfm)
Provides:       tex(utftmrt-h.vf)
Provides:       tex(utftmrt-v.tfm)
Provides:       tex(utftmrt-v.vf)
Provides:       tex(utftmru-h.tfm)
Provides:       tex(utftmru-h.vf)
Provides:       tex(utftmru-v.tfm)
Provides:       tex(utftmru-v.vf)
Provides:       tex(utftmrv-h.tfm)
Provides:       tex(utftmrv-h.vf)
Provides:       tex(utftmrv-v.tfm)
Provides:       tex(utftmrv-v.vf)
Provides:       tex(utftmrw-h.tfm)
Provides:       tex(utftmrw-h.vf)
Provides:       tex(utftmrw-v.tfm)
Provides:       tex(utftmrw-v.vf)
Provides:       tex(utftmrx-h.tfm)
Provides:       tex(utftmrx-h.vf)
Provides:       tex(utftmrx-v.tfm)
Provides:       tex(utftmrx-v.vf)
Provides:       tex(utftmrz-h.tfm)
Provides:       tex(utftmrz-h.vf)
Provides:       tex(utftmrz-v.tfm)
Provides:       tex(utftmrz-v.vf)
Requires:       tex(keyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source52:       japanese-otf.tar.xz
Source53:       japanese-otf.doc.tar.xz

%description -n texlive-japanese-otf
The package contains pLaTeX support files and virtual fonts for
supporting a wide variety of fonts in LaTeX using the pTeX
engine.

%package -n texlive-japanese-otf-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66091
Release:        0
Summary:        Documentation for texlive-japanese-otf
License:        BSD-3-Clause
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-japanese-otf and texlive-alldocumentation)
Provides:       locale(texlive-japanese-otf-doc:en;ja)

%description -n texlive-japanese-otf-doc
This package includes the documentation for texlive-japanese-otf

%post -n texlive-japanese-otf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addKanjiMap otf-@jaEmbed@.map' >> /var/run/texlive/run-updmap
echo 'addKanjiMap otf-ko-@koEmbed@.map' >> /var/run/texlive/run-updmap
echo 'addKanjiMap otf-sc-@scEmbed@.map' >> /var/run/texlive/run-updmap
echo 'addKanjiMap otf-tc-@tcEmbed@.map' >> /var/run/texlive/run-updmap
echo 'addKanjiMap otf-up-@jaEmbed@.map' >> /var/run/texlive/run-updmap

%postun -n texlive-japanese-otf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteKanjiMap otf-@jaEmbed@.map' >> /var/run/texlive/run-updmap
    echo 'deleteKanjiMap otf-ko-@koEmbed@.map' >> /var/run/texlive/run-updmap
    echo 'deleteKanjiMap otf-sc-@scEmbed@.map' >> /var/run/texlive/run-updmap
    echo 'deleteKanjiMap otf-tc-@tcEmbed@.map' >> /var/run/texlive/run-updmap
    echo 'deleteKanjiMap otf-up-@jaEmbed@.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-japanese-otf
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-japanese-otf-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/japanese-otf/COPYRIGHT
%{_texmfdistdir}/doc/fonts/japanese-otf/ChangeLog.md
%{_texmfdistdir}/doc/fonts/japanese-otf/README
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/00otf-uptex.txt
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/TeXLive-maps/otf-cktx.map
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/otf-script-gteb.diff
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/readme-ja.txt
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/brsgtest.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/hankana_test.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/jis2004.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/koreanexample.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/otftest.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/pkanatest.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/pkanatest2.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/Makefile
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/cjk-mltwght-h.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/cjk-mltwght-v.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/cjk-pxbabel-h.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/cjk-pxbabel-v.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/direction-utf8.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/era.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/exclam.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/jotf-psfonts.map
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/otfscale.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/paren0.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/punct0.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/punctuation.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/sp_cns_utf.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/sp_gb_utf.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/sp_jp_text.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/sp_jp_utf.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/sp_kr_utf.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/uotf-sp-utf8.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/uotftest-utf8.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/uotftest.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/upbrsgtest.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/upjis2004.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/upkanatest1.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/upkanatest2.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/utfmacro-cjk.tex
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/utfmacro-haranoaji.map
%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex/utfmacro-kozuka.map

%files -n texlive-japanese-otf
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjgb-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjgb-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjge-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjge-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjgr-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjgr-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmb-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmb-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmgr-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmgr-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjml-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjml-v.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmr-h.ofm
%{_texmfdistdir}/fonts/ofm/public/japanese-otf/otf-cjmr-v.ofm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/brsgnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidcmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgb5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjge5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmb5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjml5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidjmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidkmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/cidtmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/expminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/hminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/nmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ccgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ccgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ccmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ccmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjgb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjgb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjge-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjge-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjml-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjml-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-cjmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ckgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ckgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ckmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ckmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ctgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ctgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ctmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ctmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucgb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucgb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucge-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucge-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucml-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucml-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ucmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujge-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujge-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgen-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgen-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujml-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujml-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ujmrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukgb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukgb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukge-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukge-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukml-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukml-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-ukmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utgb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utgb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utge-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utge-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmgr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmgr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utml-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utml-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/otf-utmr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/rubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakormgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakormgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upakorminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upaschminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upatchminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upbrsgnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uphminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkormgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkormgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmkorminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmschminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/upnmtchminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/uprubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcge--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcge--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcgro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcml--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcml--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfcmro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrw-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrw-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgry-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgry-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfgrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgb9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgba-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgba-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbe-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbe-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbn9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbo-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbo-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbu-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbu-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgby-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgby-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgbz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjge9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgea-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgea-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgec-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgec-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjged-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjged-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgee-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgee-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgef-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgef-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgej-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgej-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgek-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgek-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgel-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgel-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgem-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgem-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgen9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgena-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgena-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgend-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgend-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgene-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgene-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgenf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeo-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeo-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgep-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgep-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjger-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjger-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjges-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjges-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjget-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjget-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeu-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgeu-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgev-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgev-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgex-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgex-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgey-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgey-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgez-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgez-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrn9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgry-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgry-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjgrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmb9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmba-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmba-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbe-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbe-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbn9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbo-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbo-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbu-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbu-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmby-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmby-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmbz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrn9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgry-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgry-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmgrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjml9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmla-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmla-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmld-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmld-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmle-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmle-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmll-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmll-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmln9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlo-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlo-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmls-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmls-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlu-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlu-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmly-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmly-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmlz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrn9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrna-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrna-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrne-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrne-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrnf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmry-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmry-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfjmrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkge--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkge--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkml--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkml--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfkmrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrg-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrj-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrj-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrw-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrw-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmry-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmry-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utfmrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftge--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftge--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrw-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrw-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftgrz-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmb--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmb--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmgr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmgr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftml--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftml--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr--h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr--v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr0-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr0-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr1-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr1-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr2-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr2-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr3-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr3-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr4-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr4-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr5-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr5-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr6-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr6-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr7-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr7-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr8-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr8-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr9-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmr9-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmra-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmra-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrc-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrc-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrd-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrd-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmre-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmre-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrf-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrf-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrk-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrk-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrm-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrm-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmro-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmro-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrp-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrp-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrq-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrs-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrs-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrt-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrt-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmru-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmru-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrv-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrv-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrw-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrw-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrx-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrx-v.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrz-h.tfm
%{_texmfdistdir}/fonts/tfm/public/japanese-otf/utftmrz-v.tfm
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/brsgnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidcmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgb5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjge5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmb5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjml5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidjmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidkmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/cidtmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/expminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/nmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/rubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upbrsgnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkormgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkormgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmkorminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmschminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/upnmtchminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/uprubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcge--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcge--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcgro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcml--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcml--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfcmro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrw-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrw-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgry-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgry-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfgrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgb9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgba-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgba-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbe-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbe-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbn9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbo-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbo-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbu-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbu-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgby-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgby-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgbz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjge9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgea-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgea-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgec-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgec-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjged-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjged-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgee-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgee-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgef-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgef-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgej-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgej-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgek-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgek-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgel-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgel-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgem-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgem-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgen9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgena-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgena-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgend-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgend-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgene-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgene-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgenf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeo-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeo-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgep-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgep-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjger-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjger-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjges-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjges-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjget-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjget-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeu-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgeu-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgev-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgev-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgex-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgex-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgey-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgey-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgez-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgez-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrn9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgry-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgry-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjgrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmb9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmba-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmba-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbe-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbe-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbn9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbo-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbo-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbu-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbu-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmby-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmby-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmbz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrn9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgry-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgry-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmgrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjml9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmla-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmla-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmld-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmld-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmle-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmle-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmll-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmll-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmln9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlo-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlo-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmls-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmls-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlu-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlu-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmly-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmly-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmlz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrn9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrna-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrna-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrne-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrne-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrnf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmry-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmry-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfjmrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkge--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkge--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkml--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkml--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfkmrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrg-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrg-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrj-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrj-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrw-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrw-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmry-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmry-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utfmrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftge--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftge--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrw-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrw-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftgrz-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmb--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmb--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmgr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmgr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftml--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftml--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr--h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr--v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr0-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr0-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr1-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr1-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr2-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr2-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr3-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr3-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr4-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr4-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr5-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr5-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr6-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr6-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr7-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr7-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr8-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr8-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr9-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmr9-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmra-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmra-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrb-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrb-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrc-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrc-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrd-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrd-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmre-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmre-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrf-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrf-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrk-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrk-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrl-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrl-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrm-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrm-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrn-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrn-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmro-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmro-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrp-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrp-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrq-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrq-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrr-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrr-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrs-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrs-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrt-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrt-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmru-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmru-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrv-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrv-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrw-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrw-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrx-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrx-v.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrz-h.vf
%{_texmfdistdir}/fonts/vf/public/japanese-otf/utftmrz-v.vf
%{_texmfdistdir}/tex/platex/japanese-otf/ajmacros.sty
%{_texmfdistdir}/tex/platex/japanese-otf/mlcid.sty
%{_texmfdistdir}/tex/platex/japanese-otf/mlutf.sty
%{_texmfdistdir}/tex/platex/japanese-otf/otf-hangul.dfu
%{_texmfdistdir}/tex/platex/japanese-otf/otf.sty
%{_texmfdistdir}/tex/platex/japanese-otf/redeffont.sty

%package -n texlive-jbact
Version:        %{texlive_version}.%{texlive_noarch}.1.30svn52717
Release:        0
License:        LPPL-1.0
Summary:        BibTeX style for biology journals
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source54:       jbact.tar.xz

%description -n texlive-jbact
The style is a development of apalike.bst in the BibTeX bundle.
The style serves two journals -- if the user executes
"\nocite{TitlesOn}", the style serves for the Journal of
Theoretical Biology; otherwise it serves for the Journal of
Molecular Biology.

%post -n texlive-jbact
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jbact
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jbact
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jbact
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/jbact/jbact.bst

%package -n texlive-jeuxcartes
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2.3svn66190
Release:        0
License:        LPPL-1.0
Summary:        Macros to insert playing cards
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jeuxcartes-doc >= %{texlive_version}
Provides:       tex(JeuxCartes.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(listofitems.sty)
Requires:       tex(pgffor.sty)
Requires:       tex(pifont.sty)
Requires:       tex(randomlist.sty)
Requires:       tex(simplekv.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xfp.sty)
Requires:       tex(xinttools.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source55:       jeuxcartes.tar.xz
Source56:       jeuxcartes.doc.tar.xz

%description -n texlive-jeuxcartes
This package provides macros to insert playing cards, single,
or hand, or random-hand, Poker or French Tarot or Uno, from png
files.

%package -n texlive-jeuxcartes-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2.3svn66190
Release:        0
Summary:        Documentation for texlive-jeuxcartes
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jeuxcartes and texlive-alldocumentation)
Provides:       locale(texlive-jeuxcartes-doc:fr)

%description -n texlive-jeuxcartes-doc
This package includes the documentation for texlive-jeuxcartes

%post -n texlive-jeuxcartes
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jeuxcartes
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jeuxcartes
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jeuxcartes-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jeuxcartes/JeuxCartes-doc.pdf
%{_texmfdistdir}/doc/latex/jeuxcartes/JeuxCartes-doc.tex
%{_texmfdistdir}/doc/latex/jeuxcartes/README.md

%files -n texlive-jeuxcartes
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-10C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-10K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-10P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-10T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-2C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-2K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-2P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-2T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-3C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-3K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-3P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-3T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-4C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-4K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-4P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-4T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-5C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-5K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-5P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-5T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-6C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-6K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-6P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-6T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-7C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-7K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-7P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-7T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-8C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-8K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-8P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-8T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-9C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-9K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-9P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-9T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-AC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-AK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-AP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-AT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-DC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-DK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-DP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-DT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-Dos.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-JN.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-JR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-RC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-RK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-RP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-RT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-VC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-VK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-VP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv1-VT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-10C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-10K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-10P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-10T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-2C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-2K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-2P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-2T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-3C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-3K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-3P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-3T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-4C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-4K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-4P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-4T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-5C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-5K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-5P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-5T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-6C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-6K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-6P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-6T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-7C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-7K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-7P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-7T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-8C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-8K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-8P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-8T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-9C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-9K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-9P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-9T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-AC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-AK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-AP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-AT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DosBleu.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DosBleu2.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DosRouge.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-DosRouge2.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-JN.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-JR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-RC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-RK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-RP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-RT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-VC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-VK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-VP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv2-VT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-10C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-10K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-10P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-10T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-2C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-2K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-2P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-2T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-3C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-3K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-3P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-3T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-4C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-4K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-4P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-4T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-5C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-5K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-5P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-5T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-6C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-6K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-6P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-6T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-7C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-7K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-7P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-7T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-8C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-8K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-8P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-8T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-9C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-9K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-9P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-9T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-AC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-AK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-AP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-APv2.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-AT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DosNoir.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-DosRouge.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-JN.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-JR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-JS.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-RC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-RK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-RP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-RT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-VC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-VK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-VP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv3-VT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-10C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-10K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-10P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-10T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-2C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-2K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-2P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-2T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-3C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-3K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-3P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-3T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-4C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-4K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-4P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-4T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-5C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-5K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-5P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-5T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-6C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-6K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-6P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-6T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-7C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-7K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-7P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-7T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-8C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-8K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-8P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-8T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-9C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-9K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-9P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-9T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-AC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-AK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-AP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-AT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DosBleu.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-DosRouge.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-JN.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-JR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-RC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-RK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-RP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-RT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-VC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-VK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-VP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv4-VT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-10C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-10K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-10P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-10T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-2C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-2K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-2P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-2T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-3C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-3K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-3P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-3T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-4C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-4K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-4P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-4T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-5C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-5K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-5P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-5T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-6C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-6K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-6P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-6T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-7C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-7K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-7P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-7T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-8C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-8K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-8P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-8T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-9C.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-9K.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-9P.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-9T.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-AC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-AK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-AP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-AT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DosNoir.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-DosRouge.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-JN.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-JR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-RC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-RK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-RP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-RT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-VC.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-VK.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-VP.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-PokeRv5-VT.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-10AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-10C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-10K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-10P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-10T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-11AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-12AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-13AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-14AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-15AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-16AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-17AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-18AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-19AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-1AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-20AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-21AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-2AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-2C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-2K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-2P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-2T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-3AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-3C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-3K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-3P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-3T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-4AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-4C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-4K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-4P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-4T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-5AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-5C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-5K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-5P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-5T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-6AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-6C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-6K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-6P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-6T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-7AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-7C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-7K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-7P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-7T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-8AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-8C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-8K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-8P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-8T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-9AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-9C.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-9K.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-9P.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-9T.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-AC.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-AK.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-AP.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-AT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-CC.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-CK.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-CP.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-CT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-DC.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-DK.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-DP.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-DT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-Dos.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-Exc.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-RC.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-RK.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-RP.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-RT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-VC.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-VK.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-VP.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-TaroTv1-VT.png
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-0B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-0J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-0R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-0V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-1B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-1J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-1R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-1V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-2B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-2J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-2R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-2V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-3B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-3J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-3R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-3V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-4B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-4J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-4R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-4V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-5B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-5J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-5R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-5V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-6B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-6J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-6R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-6V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-7B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-7J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-7R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-7V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-8B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-8J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-8R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-8V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-9B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-9J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-9R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-9V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-CSB.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-CSJ.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-CSR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-CSV.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-Coul.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-Dos.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-P2B.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-P2J.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-P2R.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-P2V.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-P4.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-PTB.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-PTJ.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-PTR.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/CaJ-UnOv1-PTV.pdf
%{_texmfdistdir}/tex/latex/jeuxcartes/JeuxCartes.sty

%package -n texlive-jfmutil
Version:        %{texlive_version}.%{texlive_noarch}.1.3.3svn60987
Release:        0
License:        LPPL-1.0
Summary:        Utility to process pTeX-extended TFM and VF
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-jfmutil-bin >= %{texlive_version}
#!BuildIgnore: texlive-jfmutil-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jfmutil-doc >= %{texlive_version}
Requires:       perl(Encode)
#!BuildIgnore:  perl(Encode)
Requires:       perl(IPC::Open3)
#!BuildIgnore:  perl(IPC::Open3)
Requires:       perl(constant)
#!BuildIgnore:  perl(constant)
Requires:       perl(strict)
#!BuildIgnore:  perl(strict)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source57:       jfmutil.tar.xz
Source58:       jfmutil.doc.tar.xz

%description -n texlive-jfmutil
This program provides functionality to process data files (JFM
and VF) that form logical fonts used in (u)pTeX. The functions
currently available include: The mutual conversion between
Japanese virtual fonts (pairs of VF and JFM) and files in the
"ZVP format", which is an original text format representing
data in virtual fonts. This function can be seen as a
counterpart to the vftovp/vptovf programs. The mutual
conversion between VF files alone and files in the "ZVP0
format", which is a subset of the ZVP format.

%package -n texlive-jfmutil-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.3.3svn60987
Release:        0
Summary:        Documentation for texlive-jfmutil
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jfmutil and texlive-alldocumentation)
Provides:       locale(texlive-jfmutil-doc:ja)

%description -n texlive-jfmutil-doc
This package includes the documentation for texlive-jfmutil

%post -n texlive-jfmutil
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jfmutil
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jfmutil
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jfmutil-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/jfmutil/LICENSE
%{_texmfdistdir}/doc/fonts/jfmutil/README-ja.md
%{_texmfdistdir}/doc/fonts/jfmutil/README.md

%files -n texlive-jfmutil
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/jfmutil/jfmutil.pl

%package -n texlive-jieeetran
Version:        %{texlive_version}.%{texlive_noarch}.0.0.19svn65642
Release:        0
License:        LPPL-1.0
Summary:        UnofficiaL BibTeX style for citing Japanese articles in IEEE format
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jieeetran-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source59:       jieeetran.tar.xz
Source60:       jieeetran.doc.tar.xz

%description -n texlive-jieeetran
This package provides an unofficial BibTeX style for authors
trying to cite Japanese articles in the Institute of Electrical
and Electronics Engineers (IEEE) format.

%package -n texlive-jieeetran-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.19svn65642
Release:        0
Summary:        Documentation for texlive-jieeetran
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jieeetran and texlive-alldocumentation)
Provides:       locale(texlive-jieeetran-doc:ja)

%description -n texlive-jieeetran-doc
This package includes the documentation for texlive-jieeetran

%post -n texlive-jieeetran
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jieeetran
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jieeetran
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jieeetran-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/bibtex/jieeetran/README
%{_texmfdistdir}/doc/bibtex/jieeetran/jieeetran-en.pdf
%{_texmfdistdir}/doc/bibtex/jieeetran/jieeetran-en.tex
%{_texmfdistdir}/doc/bibtex/jieeetran/jieeetran.pdf
%{_texmfdistdir}/doc/bibtex/jieeetran/jieeetran.tex
%{_texmfdistdir}/doc/bibtex/jieeetran/mixej.py

%files -n texlive-jieeetran
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/jieeetran/jIEEEtran.bst

%package -n texlive-jigsaw
Version:        %{texlive_version}.%{texlive_noarch}.0.0.4svn66009
Release:        0
License:        LPPL-1.0
Summary:        Draw jigsaw pieces with TikZ
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jigsaw-doc >= %{texlive_version}
Provides:       tex(jigsaw.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(tikz.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source61:       jigsaw.tar.xz
Source62:       jigsaw.doc.tar.xz

%description -n texlive-jigsaw
This is a small LaTeX package to draw jigsaw pieces with TikZ.
It is possible to draw individual pieces and adjust their
shape, create tile patterns or automatically generate complete
jigsaws.

%package -n texlive-jigsaw-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.4svn66009
Release:        0
Summary:        Documentation for texlive-jigsaw
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jigsaw and texlive-alldocumentation)

%description -n texlive-jigsaw-doc
This package includes the documentation for texlive-jigsaw

%post -n texlive-jigsaw
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jigsaw
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jigsaw
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jigsaw-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jigsaw/README.md
%{_texmfdistdir}/doc/latex/jigsaw/jigsaw-doc.pdf
%{_texmfdistdir}/doc/latex/jigsaw/jigsaw-doc.tex

%files -n texlive-jigsaw
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jigsaw/jigsaw.sty

%package -n texlive-jkmath
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn47109
Release:        0
License:        LPPL-1.0
Summary:        Macros for mathematics that make the code more readable
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jkmath-doc >= %{texlive_version}
Provides:       tex(jkmath.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(array.sty)
Requires:       tex(physics.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source63:       jkmath.tar.xz
Source64:       jkmath.doc.tar.xz

%description -n texlive-jkmath
Inspired by the physicspackage on CTAN, the package defines
some simple macros for mathematical notation which make the
code more readable and/or allow flexibility in typesetting
material.

%package -n texlive-jkmath-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn47109
Release:        0
Summary:        Documentation for texlive-jkmath
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jkmath and texlive-alldocumentation)

%description -n texlive-jkmath-doc
This package includes the documentation for texlive-jkmath

%post -n texlive-jkmath
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jkmath
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jkmath
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jkmath-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jkmath/README.md
%{_texmfdistdir}/doc/latex/jkmath/jkmath.pdf
%{_texmfdistdir}/doc/latex/jkmath/jkmath.tex

%files -n texlive-jkmath
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jkmath/jkmath.sty

%package -n texlive-jknapltx
Version:        %{texlive_version}.%{texlive_noarch}.svn19440
Release:        0
License:        GPL-2.0-or-later
Summary:        Miscellaneous packages by Joerg Knappen
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jknapltx-doc >= %{texlive_version}
Provides:       tex(greekctr.sty)
Provides:       tex(holtpolt.sty)
Provides:       tex(latin1jk.def)
Provides:       tex(latin2jk.def)
Provides:       tex(latin3jk.def)
Provides:       tex(mathbbol.sty)
Provides:       tex(mathrsfs.sty)
Provides:       tex(parboxx.sty)
Provides:       tex(sans.sty)
Provides:       tex(semtrans.sty)
Provides:       tex(sgmlcmpt.sty)
Provides:       tex(smartmn.sty)
Provides:       tex(tccompat.sty)
Provides:       tex(ursfs.fd)
Provides:       tex(ustmary.fd)
Provides:       tex(young.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(textcomp.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source65:       jknapltx.tar.xz
Source66:       jknapltx.doc.tar.xz

%description -n texlive-jknapltx
Miscellaneous macros by Jorg Knappen, including: represent
counters in greek; Maxwell's non-commutative division;
latin1jk, latin2jk and latin3jk, which are their inputenc
definition files that allow verbatim input in the respective
ISO Latin codes; blackboard bold fonts in maths; use of RSFS
fonts in maths; extra alignments for \parboxes; swap Roman and
Sans fonts; transliterate semitic languages; patches to make
(La)TeX formulae embeddable in SGML; use maths "minus" in text
as appropriate; simple Young tableaux.

%package -n texlive-jknapltx-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn19440
Release:        0
Summary:        Documentation for texlive-jknapltx
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jknapltx and texlive-alldocumentation)

%description -n texlive-jknapltx-doc
This package includes the documentation for texlive-jknapltx

%post -n texlive-jknapltx
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jknapltx
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jknapltx
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jknapltx-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jknapltx/00readme.txt
%{_texmfdistdir}/doc/latex/jknapltx/README.TEXLIVE
%{_texmfdistdir}/doc/latex/jknapltx/mathbbol.rme
%{_texmfdistdir}/doc/latex/jknapltx/mathrsfs.rme

%files -n texlive-jknapltx
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jknapltx/greekctr.sty
%{_texmfdistdir}/tex/latex/jknapltx/holtpolt.sty
%{_texmfdistdir}/tex/latex/jknapltx/latin1jk.def
%{_texmfdistdir}/tex/latex/jknapltx/latin2jk.def
%{_texmfdistdir}/tex/latex/jknapltx/latin3jk.def
%{_texmfdistdir}/tex/latex/jknapltx/mathbbol.sty
%{_texmfdistdir}/tex/latex/jknapltx/mathrsfs.sty
%{_texmfdistdir}/tex/latex/jknapltx/parboxx.sty
%{_texmfdistdir}/tex/latex/jknapltx/sans.sty
%{_texmfdistdir}/tex/latex/jknapltx/semtrans.sty
%{_texmfdistdir}/tex/latex/jknapltx/sgmlcmpt.sty
%{_texmfdistdir}/tex/latex/jknapltx/smartmn.sty
%{_texmfdistdir}/tex/latex/jknapltx/tccompat.sty
%{_texmfdistdir}/tex/latex/jknapltx/ursfs.fd
%{_texmfdistdir}/tex/latex/jknapltx/ustmary.fd
%{_texmfdistdir}/tex/latex/jknapltx/young.sty

%package -n texlive-jlabels
Version:        %{texlive_version}.%{texlive_noarch}.svn24858
Release:        0
License:        LPPL-1.0
Summary:        Make letter-sized pages of labels
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jlabels-doc >= %{texlive_version}
Provides:       tex(jlabels.sty)
Requires:       tex(calc.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(pstricks.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source67:       jlabels.tar.xz
Source68:       jlabels.doc.tar.xz

%description -n texlive-jlabels
The package provides controls for the numbers of rows and
columns.

%package -n texlive-jlabels-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn24858
Release:        0
Summary:        Documentation for texlive-jlabels
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jlabels and texlive-alldocumentation)

%description -n texlive-jlabels-doc
This package includes the documentation for texlive-jlabels

%post -n texlive-jlabels
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jlabels
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jlabels
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jlabels-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jlabels/README
%{_texmfdistdir}/doc/latex/jlabels/jlabels.pdf
%{_texmfdistdir}/doc/latex/jlabels/jlabels.tex

%files -n texlive-jlabels
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jlabels/jlabels.sty

%package -n texlive-jlreq
Version:        %{texlive_version}.%{texlive_noarch}.svn66362
Release:        0
License:        BSD-3-Clause
Summary:        Japanese document class based on requirements for Japanese text layout
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jlreq-doc >= %{texlive_version}
Provides:       tex(bjlreq-v.tfm)
Provides:       tex(bjlreq-v.vf)
Provides:       tex(bjlreq.tfm)
Provides:       tex(bjlreq.vf)
Provides:       tex(bjlreqg-v.tfm)
Provides:       tex(bjlreqg-v.vf)
Provides:       tex(bjlreqg.tfm)
Provides:       tex(bjlreqg.vf)
Provides:       tex(bzjlreq-v.tfm)
Provides:       tex(bzjlreq-v.vf)
Provides:       tex(bzjlreq.tfm)
Provides:       tex(bzjlreq.vf)
Provides:       tex(bzjlreqg-v.tfm)
Provides:       tex(bzjlreqg-v.vf)
Provides:       tex(bzjlreqg.tfm)
Provides:       tex(bzjlreqg.vf)
Provides:       tex(jlreq-complements.sty)
Provides:       tex(jlreq-helpers.sty)
Provides:       tex(jlreq-jidori.tfm)
Provides:       tex(jlreq-jidori.vf)
Provides:       tex(jlreq-trimmarks.sty)
Provides:       tex(jlreq-v-jidori.tfm)
Provides:       tex(jlreq-v-jidori.vf)
Provides:       tex(jlreq-v.tfm)
Provides:       tex(jlreq-v.vf)
Provides:       tex(jlreq.cls)
Provides:       tex(jlreq.tfm)
Provides:       tex(jlreq.vf)
Provides:       tex(jlreqg-jidori.tfm)
Provides:       tex(jlreqg-jidori.vf)
Provides:       tex(jlreqg-v-jidori.tfm)
Provides:       tex(jlreqg-v-jidori.vf)
Provides:       tex(jlreqg-v.tfm)
Provides:       tex(jlreqg-v.vf)
Provides:       tex(jlreqg.tfm)
Provides:       tex(jlreqg.vf)
Provides:       tex(ubjlreq-q.tfm)
Provides:       tex(ubjlreq-q.vf)
Provides:       tex(ubjlreq-v.tfm)
Provides:       tex(ubjlreq-v.vf)
Provides:       tex(ubjlreq.tfm)
Provides:       tex(ubjlreq.vf)
Provides:       tex(ubjlreqg-q.tfm)
Provides:       tex(ubjlreqg-q.vf)
Provides:       tex(ubjlreqg-v.tfm)
Provides:       tex(ubjlreqg-v.vf)
Provides:       tex(ubjlreqg.tfm)
Provides:       tex(ubjlreqg.vf)
Provides:       tex(ubzjlreq-q.tfm)
Provides:       tex(ubzjlreq-q.vf)
Provides:       tex(ubzjlreq-v.tfm)
Provides:       tex(ubzjlreq-v.vf)
Provides:       tex(ubzjlreq.tfm)
Provides:       tex(ubzjlreq.vf)
Provides:       tex(ubzjlreqg-q.tfm)
Provides:       tex(ubzjlreqg-q.vf)
Provides:       tex(ubzjlreqg-v.tfm)
Provides:       tex(ubzjlreqg-v.vf)
Provides:       tex(ubzjlreqg.tfm)
Provides:       tex(ubzjlreqg.vf)
Provides:       tex(ujlreq-jidori-q.tfm)
Provides:       tex(ujlreq-jidori-q.vf)
Provides:       tex(ujlreq-jidori.tfm)
Provides:       tex(ujlreq-jidori.vf)
Provides:       tex(ujlreq-q.tfm)
Provides:       tex(ujlreq-q.vf)
Provides:       tex(ujlreq-v-jidori.tfm)
Provides:       tex(ujlreq-v-jidori.vf)
Provides:       tex(ujlreq-v.tfm)
Provides:       tex(ujlreq-v.vf)
Provides:       tex(ujlreq.tfm)
Provides:       tex(ujlreq.vf)
Provides:       tex(ujlreqg-jidori-q.tfm)
Provides:       tex(ujlreqg-jidori-q.vf)
Provides:       tex(ujlreqg-jidori.tfm)
Provides:       tex(ujlreqg-jidori.vf)
Provides:       tex(ujlreqg-q.tfm)
Provides:       tex(ujlreqg-q.vf)
Provides:       tex(ujlreqg-v-jidori.tfm)
Provides:       tex(ujlreqg-v-jidori.vf)
Provides:       tex(ujlreqg-v.tfm)
Provides:       tex(ujlreqg-v.vf)
Provides:       tex(ujlreqg.tfm)
Provides:       tex(ujlreqg.vf)
Provides:       tex(uzjlreq-q.tfm)
Provides:       tex(uzjlreq-q.vf)
Provides:       tex(uzjlreq-v.tfm)
Provides:       tex(uzjlreq-v.vf)
Provides:       tex(uzjlreq.tfm)
Provides:       tex(uzjlreq.vf)
Provides:       tex(uzjlreqg-q.tfm)
Provides:       tex(uzjlreqg-q.vf)
Provides:       tex(uzjlreqg-v.tfm)
Provides:       tex(uzjlreqg-v.vf)
Provides:       tex(uzjlreqg.tfm)
Provides:       tex(uzjlreqg.vf)
Provides:       tex(zjlreq-v.tfm)
Provides:       tex(zjlreq-v.vf)
Provides:       tex(zjlreq.tfm)
Provides:       tex(zjlreq.vf)
Provides:       tex(zjlreqg-v.tfm)
Provides:       tex(zjlreqg-v.vf)
Provides:       tex(zjlreqg.tfm)
Provides:       tex(zjlreqg.vf)
Requires:       tex(etoolbox.sty)
Requires:       tex(everyhook.sty)
Requires:       tex(filehook.sty)
Requires:       tex(gbm.tfm)
Requires:       tex(gbmv.tfm)
Requires:       tex(l3keys2e.sty)
Requires:       tex(lmodern.sty)
Requires:       tex(luatexja-adjust.sty)
Requires:       tex(luatexja.sty)
Requires:       tex(rml.tfm)
Requires:       tex(rmlv.tfm)
Requires:       tex(upgbm-h.tfm)
Requires:       tex(upgbm-hq.tfm)
Requires:       tex(upgbm-v.tfm)
Requires:       tex(uprml-h.tfm)
Requires:       tex(uprml-hq.tfm)
Requires:       tex(uprml-v.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source69:       jlreq.tar.xz
Source70:       jlreq.doc.tar.xz

%description -n texlive-jlreq
This package provides a Japanese document class based on
requirements for Japanese text layout. The class file and the
JFM (Japanese font metric) files for LuaTeX-ja / pLaTeX /
upLaTeX are provided.

%package -n texlive-jlreq-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66362
Release:        0
Summary:        Documentation for texlive-jlreq
License:        BSD-3-Clause
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jlreq and texlive-alldocumentation)
Provides:       locale(texlive-jlreq-doc:ja)

%description -n texlive-jlreq-doc
This package includes the documentation for texlive-jlreq

%post -n texlive-jlreq
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jlreq
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jlreq
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jlreq-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jlreq/LICENSE
%{_texmfdistdir}/doc/latex/jlreq/README-ja.md
%{_texmfdistdir}/doc/latex/jlreq/README.md
%{_texmfdistdir}/doc/latex/jlreq/jlreq-ja.html
%{_texmfdistdir}/doc/latex/jlreq/jlreq-ja.pdf
%{_texmfdistdir}/doc/latex/jlreq/jlreq-trimmarks-ja.html
%{_texmfdistdir}/doc/latex/jlreq/jlreq-trimmarks-ja.md
%{_texmfdistdir}/doc/latex/jlreq/jlreq-trimmarks.html
%{_texmfdistdir}/doc/latex/jlreq/jlreq-trimmarks.md
%{_texmfdistdir}/doc/latex/jlreq/jlreq.html
%{_texmfdistdir}/doc/latex/jlreq/jlreq.pdf

%files -n texlive-jlreq
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/tfm/public/jlreq/bjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bjlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bzjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bzjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bzjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/bzjlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreq-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreq-v-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreqg-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreqg-v-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/jlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreq-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreqg-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubjlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreq-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreqg-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ubzjlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq-jidori-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq-v-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg-jidori-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg-v-jidori.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/ujlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreq-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreqg-q.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/uzjlreqg.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/zjlreq-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/zjlreq.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/zjlreqg-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq/zjlreqg.tfm
%{_texmfdistdir}/fonts/vf/public/jlreq/bjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bjlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bzjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bzjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bzjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/bzjlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreq-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreq-v-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreqg-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreqg-v-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/jlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreq-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreqg-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubjlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreq-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreqg-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ubzjlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq-jidori-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq-v-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg-jidori-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg-v-jidori.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/ujlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreq-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreqg-q.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/uzjlreqg.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/zjlreq-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/zjlreq.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/zjlreqg-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq/zjlreqg.vf
%{_texmfdistdir}/tex/latex/jlreq/jlreq-complements.sty
%{_texmfdistdir}/tex/latex/jlreq/jlreq-helpers.sty
%{_texmfdistdir}/tex/latex/jlreq/jlreq-trimmarks.sty
%{_texmfdistdir}/tex/latex/jlreq/jlreq.cls
%{_texmfdistdir}/tex/luatex/jlreq/jfm-jlreq-jidori.lua
%{_texmfdistdir}/tex/luatex/jlreq/jfm-jlreq.lua
%{_texmfdistdir}/tex/luatex/jlreq/jfm-jlreqv-jidori.lua
%{_texmfdistdir}/tex/luatex/jlreq/jfm-jlreqv.lua

%package -n texlive-jlreq-deluxe
Version:        %{texlive_version}.%{texlive_noarch}.0.0.4.1svn66115
Release:        0
License:        LPPL-1.0
Summary:        Multi-weight Japanese font support for the jlreq class
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jlreq-deluxe-doc >= %{texlive_version}
Provides:       tex(bjlreq--expgothb-h.tfm)
Provides:       tex(bjlreq--expgothb-h.vf)
Provides:       tex(bjlreq--expgothb-v.tfm)
Provides:       tex(bjlreq--expgothb-v.vf)
Provides:       tex(bjlreq--expgothbn-h.tfm)
Provides:       tex(bjlreq--expgothbn-h.vf)
Provides:       tex(bjlreq--expgothbn-v.tfm)
Provides:       tex(bjlreq--expgothbn-v.vf)
Provides:       tex(bjlreq--expgotheb-h.tfm)
Provides:       tex(bjlreq--expgotheb-h.vf)
Provides:       tex(bjlreq--expgotheb-v.tfm)
Provides:       tex(bjlreq--expgotheb-v.vf)
Provides:       tex(bjlreq--expgothebn-h.tfm)
Provides:       tex(bjlreq--expgothebn-h.vf)
Provides:       tex(bjlreq--expgothebn-v.tfm)
Provides:       tex(bjlreq--expgothebn-v.vf)
Provides:       tex(bjlreq--expgothr-h.tfm)
Provides:       tex(bjlreq--expgothr-h.vf)
Provides:       tex(bjlreq--expgothr-v.tfm)
Provides:       tex(bjlreq--expgothr-v.vf)
Provides:       tex(bjlreq--expgothrn-h.tfm)
Provides:       tex(bjlreq--expgothrn-h.vf)
Provides:       tex(bjlreq--expgothrn-v.tfm)
Provides:       tex(bjlreq--expgothrn-v.vf)
Provides:       tex(bjlreq--expmgothr-h.tfm)
Provides:       tex(bjlreq--expmgothr-h.vf)
Provides:       tex(bjlreq--expmgothr-v.tfm)
Provides:       tex(bjlreq--expmgothr-v.vf)
Provides:       tex(bjlreq--expmgothrn-h.tfm)
Provides:       tex(bjlreq--expmgothrn-h.vf)
Provides:       tex(bjlreq--expmgothrn-v.tfm)
Provides:       tex(bjlreq--expmgothrn-v.vf)
Provides:       tex(bjlreq--expminb-h.tfm)
Provides:       tex(bjlreq--expminb-h.vf)
Provides:       tex(bjlreq--expminb-v.tfm)
Provides:       tex(bjlreq--expminb-v.vf)
Provides:       tex(bjlreq--expminbn-h.tfm)
Provides:       tex(bjlreq--expminbn-h.vf)
Provides:       tex(bjlreq--expminbn-v.tfm)
Provides:       tex(bjlreq--expminbn-v.vf)
Provides:       tex(bjlreq--expminl-h.tfm)
Provides:       tex(bjlreq--expminl-h.vf)
Provides:       tex(bjlreq--expminl-v.tfm)
Provides:       tex(bjlreq--expminl-v.vf)
Provides:       tex(bjlreq--expminln-h.tfm)
Provides:       tex(bjlreq--expminln-h.vf)
Provides:       tex(bjlreq--expminln-v.tfm)
Provides:       tex(bjlreq--expminln-v.vf)
Provides:       tex(bjlreq--expminr-h.tfm)
Provides:       tex(bjlreq--expminr-h.vf)
Provides:       tex(bjlreq--expminr-v.tfm)
Provides:       tex(bjlreq--expminr-v.vf)
Provides:       tex(bjlreq--expminrn-h.tfm)
Provides:       tex(bjlreq--expminrn-h.vf)
Provides:       tex(bjlreq--expminrn-v.tfm)
Provides:       tex(bjlreq--expminrn-v.vf)
Provides:       tex(bjlreq--nmlgothb-h.tfm)
Provides:       tex(bjlreq--nmlgothb-h.vf)
Provides:       tex(bjlreq--nmlgothb-v.tfm)
Provides:       tex(bjlreq--nmlgothb-v.vf)
Provides:       tex(bjlreq--nmlgothbn-h.tfm)
Provides:       tex(bjlreq--nmlgothbn-h.vf)
Provides:       tex(bjlreq--nmlgothbn-v.tfm)
Provides:       tex(bjlreq--nmlgothbn-v.vf)
Provides:       tex(bjlreq--nmlgotheb-h.tfm)
Provides:       tex(bjlreq--nmlgotheb-h.vf)
Provides:       tex(bjlreq--nmlgotheb-v.tfm)
Provides:       tex(bjlreq--nmlgotheb-v.vf)
Provides:       tex(bjlreq--nmlgothebn-h.tfm)
Provides:       tex(bjlreq--nmlgothebn-h.vf)
Provides:       tex(bjlreq--nmlgothebn-v.tfm)
Provides:       tex(bjlreq--nmlgothebn-v.vf)
Provides:       tex(bjlreq--nmlgothr-h.tfm)
Provides:       tex(bjlreq--nmlgothr-h.vf)
Provides:       tex(bjlreq--nmlgothr-v.tfm)
Provides:       tex(bjlreq--nmlgothr-v.vf)
Provides:       tex(bjlreq--nmlgothrn-h.tfm)
Provides:       tex(bjlreq--nmlgothrn-h.vf)
Provides:       tex(bjlreq--nmlgothrn-v.tfm)
Provides:       tex(bjlreq--nmlgothrn-v.vf)
Provides:       tex(bjlreq--nmlmgothr-h.tfm)
Provides:       tex(bjlreq--nmlmgothr-h.vf)
Provides:       tex(bjlreq--nmlmgothr-v.tfm)
Provides:       tex(bjlreq--nmlmgothr-v.vf)
Provides:       tex(bjlreq--nmlmgothrn-h.tfm)
Provides:       tex(bjlreq--nmlmgothrn-h.vf)
Provides:       tex(bjlreq--nmlmgothrn-v.tfm)
Provides:       tex(bjlreq--nmlmgothrn-v.vf)
Provides:       tex(bjlreq--nmlminb-h.tfm)
Provides:       tex(bjlreq--nmlminb-h.vf)
Provides:       tex(bjlreq--nmlminb-v.tfm)
Provides:       tex(bjlreq--nmlminb-v.vf)
Provides:       tex(bjlreq--nmlminbn-h.tfm)
Provides:       tex(bjlreq--nmlminbn-h.vf)
Provides:       tex(bjlreq--nmlminbn-v.tfm)
Provides:       tex(bjlreq--nmlminbn-v.vf)
Provides:       tex(bjlreq--nmlminl-h.tfm)
Provides:       tex(bjlreq--nmlminl-h.vf)
Provides:       tex(bjlreq--nmlminl-v.tfm)
Provides:       tex(bjlreq--nmlminl-v.vf)
Provides:       tex(bjlreq--nmlminln-h.tfm)
Provides:       tex(bjlreq--nmlminln-h.vf)
Provides:       tex(bjlreq--nmlminln-v.tfm)
Provides:       tex(bjlreq--nmlminln-v.vf)
Provides:       tex(bjlreq--nmlminr-h.tfm)
Provides:       tex(bjlreq--nmlminr-h.vf)
Provides:       tex(bjlreq--nmlminr-v.tfm)
Provides:       tex(bjlreq--nmlminr-v.vf)
Provides:       tex(bjlreq--nmlminrn-h.tfm)
Provides:       tex(bjlreq--nmlminrn-h.vf)
Provides:       tex(bjlreq--nmlminrn-v.tfm)
Provides:       tex(bjlreq--nmlminrn-v.vf)
Provides:       tex(bjlreq--rubygothb-h.tfm)
Provides:       tex(bjlreq--rubygothb-h.vf)
Provides:       tex(bjlreq--rubygothb-v.tfm)
Provides:       tex(bjlreq--rubygothb-v.vf)
Provides:       tex(bjlreq--rubygotheb-h.tfm)
Provides:       tex(bjlreq--rubygotheb-h.vf)
Provides:       tex(bjlreq--rubygotheb-v.tfm)
Provides:       tex(bjlreq--rubygotheb-v.vf)
Provides:       tex(bjlreq--rubygothr-h.tfm)
Provides:       tex(bjlreq--rubygothr-h.vf)
Provides:       tex(bjlreq--rubygothr-v.tfm)
Provides:       tex(bjlreq--rubygothr-v.vf)
Provides:       tex(bjlreq--rubymgothr-h.tfm)
Provides:       tex(bjlreq--rubymgothr-h.vf)
Provides:       tex(bjlreq--rubymgothr-v.tfm)
Provides:       tex(bjlreq--rubymgothr-v.vf)
Provides:       tex(bjlreq--rubyminb-h.tfm)
Provides:       tex(bjlreq--rubyminb-h.vf)
Provides:       tex(bjlreq--rubyminb-v.tfm)
Provides:       tex(bjlreq--rubyminb-v.vf)
Provides:       tex(bjlreq--rubyminl-h.tfm)
Provides:       tex(bjlreq--rubyminl-h.vf)
Provides:       tex(bjlreq--rubyminl-v.tfm)
Provides:       tex(bjlreq--rubyminl-v.vf)
Provides:       tex(bjlreq--rubyminr-h.tfm)
Provides:       tex(bjlreq--rubyminr-h.vf)
Provides:       tex(bjlreq--rubyminr-v.tfm)
Provides:       tex(bjlreq--rubyminr-v.vf)
Provides:       tex(bjlreq--upexpgothb-h.tfm)
Provides:       tex(bjlreq--upexpgothb-h.vf)
Provides:       tex(bjlreq--upexpgothb-v.tfm)
Provides:       tex(bjlreq--upexpgothb-v.vf)
Provides:       tex(bjlreq--upexpgothbn-h.tfm)
Provides:       tex(bjlreq--upexpgothbn-h.vf)
Provides:       tex(bjlreq--upexpgothbn-v.tfm)
Provides:       tex(bjlreq--upexpgothbn-v.vf)
Provides:       tex(bjlreq--upexpgotheb-h.tfm)
Provides:       tex(bjlreq--upexpgotheb-h.vf)
Provides:       tex(bjlreq--upexpgotheb-v.tfm)
Provides:       tex(bjlreq--upexpgotheb-v.vf)
Provides:       tex(bjlreq--upexpgothebn-h.tfm)
Provides:       tex(bjlreq--upexpgothebn-h.vf)
Provides:       tex(bjlreq--upexpgothebn-v.tfm)
Provides:       tex(bjlreq--upexpgothebn-v.vf)
Provides:       tex(bjlreq--upexpgothr-h.tfm)
Provides:       tex(bjlreq--upexpgothr-h.vf)
Provides:       tex(bjlreq--upexpgothr-v.tfm)
Provides:       tex(bjlreq--upexpgothr-v.vf)
Provides:       tex(bjlreq--upexpgothrn-h.tfm)
Provides:       tex(bjlreq--upexpgothrn-h.vf)
Provides:       tex(bjlreq--upexpgothrn-v.tfm)
Provides:       tex(bjlreq--upexpgothrn-v.vf)
Provides:       tex(bjlreq--upexpmgothr-h.tfm)
Provides:       tex(bjlreq--upexpmgothr-h.vf)
Provides:       tex(bjlreq--upexpmgothr-v.tfm)
Provides:       tex(bjlreq--upexpmgothr-v.vf)
Provides:       tex(bjlreq--upexpmgothrn-h.tfm)
Provides:       tex(bjlreq--upexpmgothrn-h.vf)
Provides:       tex(bjlreq--upexpmgothrn-v.tfm)
Provides:       tex(bjlreq--upexpmgothrn-v.vf)
Provides:       tex(bjlreq--upexpminb-h.tfm)
Provides:       tex(bjlreq--upexpminb-h.vf)
Provides:       tex(bjlreq--upexpminb-v.tfm)
Provides:       tex(bjlreq--upexpminb-v.vf)
Provides:       tex(bjlreq--upexpminbn-h.tfm)
Provides:       tex(bjlreq--upexpminbn-h.vf)
Provides:       tex(bjlreq--upexpminbn-v.tfm)
Provides:       tex(bjlreq--upexpminbn-v.vf)
Provides:       tex(bjlreq--upexpminl-h.tfm)
Provides:       tex(bjlreq--upexpminl-h.vf)
Provides:       tex(bjlreq--upexpminl-v.tfm)
Provides:       tex(bjlreq--upexpminl-v.vf)
Provides:       tex(bjlreq--upexpminln-h.tfm)
Provides:       tex(bjlreq--upexpminln-h.vf)
Provides:       tex(bjlreq--upexpminln-v.tfm)
Provides:       tex(bjlreq--upexpminln-v.vf)
Provides:       tex(bjlreq--upexpminr-h.tfm)
Provides:       tex(bjlreq--upexpminr-h.vf)
Provides:       tex(bjlreq--upexpminr-v.tfm)
Provides:       tex(bjlreq--upexpminr-v.vf)
Provides:       tex(bjlreq--upexpminrn-h.tfm)
Provides:       tex(bjlreq--upexpminrn-h.vf)
Provides:       tex(bjlreq--upexpminrn-v.tfm)
Provides:       tex(bjlreq--upexpminrn-v.vf)
Provides:       tex(bjlreq--upnmlgothb-h.tfm)
Provides:       tex(bjlreq--upnmlgothb-h.vf)
Provides:       tex(bjlreq--upnmlgothb-v.tfm)
Provides:       tex(bjlreq--upnmlgothb-v.vf)
Provides:       tex(bjlreq--upnmlgothbn-h.tfm)
Provides:       tex(bjlreq--upnmlgothbn-h.vf)
Provides:       tex(bjlreq--upnmlgothbn-v.tfm)
Provides:       tex(bjlreq--upnmlgothbn-v.vf)
Provides:       tex(bjlreq--upnmlgotheb-h.tfm)
Provides:       tex(bjlreq--upnmlgotheb-h.vf)
Provides:       tex(bjlreq--upnmlgotheb-v.tfm)
Provides:       tex(bjlreq--upnmlgotheb-v.vf)
Provides:       tex(bjlreq--upnmlgothebn-h.tfm)
Provides:       tex(bjlreq--upnmlgothebn-h.vf)
Provides:       tex(bjlreq--upnmlgothebn-v.tfm)
Provides:       tex(bjlreq--upnmlgothebn-v.vf)
Provides:       tex(bjlreq--upnmlgothr-h.tfm)
Provides:       tex(bjlreq--upnmlgothr-h.vf)
Provides:       tex(bjlreq--upnmlgothr-v.tfm)
Provides:       tex(bjlreq--upnmlgothr-v.vf)
Provides:       tex(bjlreq--upnmlgothrn-h.tfm)
Provides:       tex(bjlreq--upnmlgothrn-h.vf)
Provides:       tex(bjlreq--upnmlgothrn-v.tfm)
Provides:       tex(bjlreq--upnmlgothrn-v.vf)
Provides:       tex(bjlreq--upnmlmgothr-h.tfm)
Provides:       tex(bjlreq--upnmlmgothr-h.vf)
Provides:       tex(bjlreq--upnmlmgothr-v.tfm)
Provides:       tex(bjlreq--upnmlmgothr-v.vf)
Provides:       tex(bjlreq--upnmlmgothrn-h.tfm)
Provides:       tex(bjlreq--upnmlmgothrn-h.vf)
Provides:       tex(bjlreq--upnmlmgothrn-v.tfm)
Provides:       tex(bjlreq--upnmlmgothrn-v.vf)
Provides:       tex(bjlreq--upnmlminb-h.tfm)
Provides:       tex(bjlreq--upnmlminb-h.vf)
Provides:       tex(bjlreq--upnmlminb-v.tfm)
Provides:       tex(bjlreq--upnmlminb-v.vf)
Provides:       tex(bjlreq--upnmlminbn-h.tfm)
Provides:       tex(bjlreq--upnmlminbn-h.vf)
Provides:       tex(bjlreq--upnmlminbn-v.tfm)
Provides:       tex(bjlreq--upnmlminbn-v.vf)
Provides:       tex(bjlreq--upnmlminl-h.tfm)
Provides:       tex(bjlreq--upnmlminl-h.vf)
Provides:       tex(bjlreq--upnmlminl-v.tfm)
Provides:       tex(bjlreq--upnmlminl-v.vf)
Provides:       tex(bjlreq--upnmlminln-h.tfm)
Provides:       tex(bjlreq--upnmlminln-h.vf)
Provides:       tex(bjlreq--upnmlminln-v.tfm)
Provides:       tex(bjlreq--upnmlminln-v.vf)
Provides:       tex(bjlreq--upnmlminr-h.tfm)
Provides:       tex(bjlreq--upnmlminr-h.vf)
Provides:       tex(bjlreq--upnmlminr-v.tfm)
Provides:       tex(bjlreq--upnmlminr-v.vf)
Provides:       tex(bjlreq--upnmlminrn-h.tfm)
Provides:       tex(bjlreq--upnmlminrn-h.vf)
Provides:       tex(bjlreq--upnmlminrn-v.tfm)
Provides:       tex(bjlreq--upnmlminrn-v.vf)
Provides:       tex(bjlreq--uprubygothb-h.tfm)
Provides:       tex(bjlreq--uprubygothb-h.vf)
Provides:       tex(bjlreq--uprubygothb-v.tfm)
Provides:       tex(bjlreq--uprubygothb-v.vf)
Provides:       tex(bjlreq--uprubygotheb-h.tfm)
Provides:       tex(bjlreq--uprubygotheb-h.vf)
Provides:       tex(bjlreq--uprubygotheb-v.tfm)
Provides:       tex(bjlreq--uprubygotheb-v.vf)
Provides:       tex(bjlreq--uprubygothr-h.tfm)
Provides:       tex(bjlreq--uprubygothr-h.vf)
Provides:       tex(bjlreq--uprubygothr-v.tfm)
Provides:       tex(bjlreq--uprubygothr-v.vf)
Provides:       tex(bjlreq--uprubymgothr-h.tfm)
Provides:       tex(bjlreq--uprubymgothr-h.vf)
Provides:       tex(bjlreq--uprubymgothr-v.tfm)
Provides:       tex(bjlreq--uprubymgothr-v.vf)
Provides:       tex(bjlreq--uprubyminb-h.tfm)
Provides:       tex(bjlreq--uprubyminb-h.vf)
Provides:       tex(bjlreq--uprubyminb-v.tfm)
Provides:       tex(bjlreq--uprubyminb-v.vf)
Provides:       tex(bjlreq--uprubyminl-h.tfm)
Provides:       tex(bjlreq--uprubyminl-h.vf)
Provides:       tex(bjlreq--uprubyminl-v.tfm)
Provides:       tex(bjlreq--uprubyminl-v.vf)
Provides:       tex(bjlreq--uprubyminr-h.tfm)
Provides:       tex(bjlreq--uprubyminr-h.vf)
Provides:       tex(bjlreq--uprubyminr-v.tfm)
Provides:       tex(bjlreq--uprubyminr-v.vf)
Provides:       tex(bzjlreq--expgothb-h.tfm)
Provides:       tex(bzjlreq--expgothb-h.vf)
Provides:       tex(bzjlreq--expgothb-v.tfm)
Provides:       tex(bzjlreq--expgothb-v.vf)
Provides:       tex(bzjlreq--expgothbn-h.tfm)
Provides:       tex(bzjlreq--expgothbn-h.vf)
Provides:       tex(bzjlreq--expgothbn-v.tfm)
Provides:       tex(bzjlreq--expgothbn-v.vf)
Provides:       tex(bzjlreq--expgotheb-h.tfm)
Provides:       tex(bzjlreq--expgotheb-h.vf)
Provides:       tex(bzjlreq--expgotheb-v.tfm)
Provides:       tex(bzjlreq--expgotheb-v.vf)
Provides:       tex(bzjlreq--expgothebn-h.tfm)
Provides:       tex(bzjlreq--expgothebn-h.vf)
Provides:       tex(bzjlreq--expgothebn-v.tfm)
Provides:       tex(bzjlreq--expgothebn-v.vf)
Provides:       tex(bzjlreq--expgothr-h.tfm)
Provides:       tex(bzjlreq--expgothr-h.vf)
Provides:       tex(bzjlreq--expgothr-v.tfm)
Provides:       tex(bzjlreq--expgothr-v.vf)
Provides:       tex(bzjlreq--expgothrn-h.tfm)
Provides:       tex(bzjlreq--expgothrn-h.vf)
Provides:       tex(bzjlreq--expgothrn-v.tfm)
Provides:       tex(bzjlreq--expgothrn-v.vf)
Provides:       tex(bzjlreq--expmgothr-h.tfm)
Provides:       tex(bzjlreq--expmgothr-h.vf)
Provides:       tex(bzjlreq--expmgothr-v.tfm)
Provides:       tex(bzjlreq--expmgothr-v.vf)
Provides:       tex(bzjlreq--expmgothrn-h.tfm)
Provides:       tex(bzjlreq--expmgothrn-h.vf)
Provides:       tex(bzjlreq--expmgothrn-v.tfm)
Provides:       tex(bzjlreq--expmgothrn-v.vf)
Provides:       tex(bzjlreq--expminb-h.tfm)
Provides:       tex(bzjlreq--expminb-h.vf)
Provides:       tex(bzjlreq--expminb-v.tfm)
Provides:       tex(bzjlreq--expminb-v.vf)
Provides:       tex(bzjlreq--expminbn-h.tfm)
Provides:       tex(bzjlreq--expminbn-h.vf)
Provides:       tex(bzjlreq--expminbn-v.tfm)
Provides:       tex(bzjlreq--expminbn-v.vf)
Provides:       tex(bzjlreq--expminl-h.tfm)
Provides:       tex(bzjlreq--expminl-h.vf)
Provides:       tex(bzjlreq--expminl-v.tfm)
Provides:       tex(bzjlreq--expminl-v.vf)
Provides:       tex(bzjlreq--expminln-h.tfm)
Provides:       tex(bzjlreq--expminln-h.vf)
Provides:       tex(bzjlreq--expminln-v.tfm)
Provides:       tex(bzjlreq--expminln-v.vf)
Provides:       tex(bzjlreq--expminr-h.tfm)
Provides:       tex(bzjlreq--expminr-h.vf)
Provides:       tex(bzjlreq--expminr-v.tfm)
Provides:       tex(bzjlreq--expminr-v.vf)
Provides:       tex(bzjlreq--expminrn-h.tfm)
Provides:       tex(bzjlreq--expminrn-h.vf)
Provides:       tex(bzjlreq--expminrn-v.tfm)
Provides:       tex(bzjlreq--expminrn-v.vf)
Provides:       tex(bzjlreq--nmlgothb-h.tfm)
Provides:       tex(bzjlreq--nmlgothb-h.vf)
Provides:       tex(bzjlreq--nmlgothb-v.tfm)
Provides:       tex(bzjlreq--nmlgothb-v.vf)
Provides:       tex(bzjlreq--nmlgothbn-h.tfm)
Provides:       tex(bzjlreq--nmlgothbn-h.vf)
Provides:       tex(bzjlreq--nmlgothbn-v.tfm)
Provides:       tex(bzjlreq--nmlgothbn-v.vf)
Provides:       tex(bzjlreq--nmlgotheb-h.tfm)
Provides:       tex(bzjlreq--nmlgotheb-h.vf)
Provides:       tex(bzjlreq--nmlgotheb-v.tfm)
Provides:       tex(bzjlreq--nmlgotheb-v.vf)
Provides:       tex(bzjlreq--nmlgothebn-h.tfm)
Provides:       tex(bzjlreq--nmlgothebn-h.vf)
Provides:       tex(bzjlreq--nmlgothebn-v.tfm)
Provides:       tex(bzjlreq--nmlgothebn-v.vf)
Provides:       tex(bzjlreq--nmlgothr-h.tfm)
Provides:       tex(bzjlreq--nmlgothr-h.vf)
Provides:       tex(bzjlreq--nmlgothr-v.tfm)
Provides:       tex(bzjlreq--nmlgothr-v.vf)
Provides:       tex(bzjlreq--nmlgothrn-h.tfm)
Provides:       tex(bzjlreq--nmlgothrn-h.vf)
Provides:       tex(bzjlreq--nmlgothrn-v.tfm)
Provides:       tex(bzjlreq--nmlgothrn-v.vf)
Provides:       tex(bzjlreq--nmlmgothr-h.tfm)
Provides:       tex(bzjlreq--nmlmgothr-h.vf)
Provides:       tex(bzjlreq--nmlmgothr-v.tfm)
Provides:       tex(bzjlreq--nmlmgothr-v.vf)
Provides:       tex(bzjlreq--nmlmgothrn-h.tfm)
Provides:       tex(bzjlreq--nmlmgothrn-h.vf)
Provides:       tex(bzjlreq--nmlmgothrn-v.tfm)
Provides:       tex(bzjlreq--nmlmgothrn-v.vf)
Provides:       tex(bzjlreq--nmlminb-h.tfm)
Provides:       tex(bzjlreq--nmlminb-h.vf)
Provides:       tex(bzjlreq--nmlminb-v.tfm)
Provides:       tex(bzjlreq--nmlminb-v.vf)
Provides:       tex(bzjlreq--nmlminbn-h.tfm)
Provides:       tex(bzjlreq--nmlminbn-h.vf)
Provides:       tex(bzjlreq--nmlminbn-v.tfm)
Provides:       tex(bzjlreq--nmlminbn-v.vf)
Provides:       tex(bzjlreq--nmlminl-h.tfm)
Provides:       tex(bzjlreq--nmlminl-h.vf)
Provides:       tex(bzjlreq--nmlminl-v.tfm)
Provides:       tex(bzjlreq--nmlminl-v.vf)
Provides:       tex(bzjlreq--nmlminln-h.tfm)
Provides:       tex(bzjlreq--nmlminln-h.vf)
Provides:       tex(bzjlreq--nmlminln-v.tfm)
Provides:       tex(bzjlreq--nmlminln-v.vf)
Provides:       tex(bzjlreq--nmlminr-h.tfm)
Provides:       tex(bzjlreq--nmlminr-h.vf)
Provides:       tex(bzjlreq--nmlminr-v.tfm)
Provides:       tex(bzjlreq--nmlminr-v.vf)
Provides:       tex(bzjlreq--nmlminrn-h.tfm)
Provides:       tex(bzjlreq--nmlminrn-h.vf)
Provides:       tex(bzjlreq--nmlminrn-v.tfm)
Provides:       tex(bzjlreq--nmlminrn-v.vf)
Provides:       tex(bzjlreq--rubygothb-h.tfm)
Provides:       tex(bzjlreq--rubygothb-h.vf)
Provides:       tex(bzjlreq--rubygothb-v.tfm)
Provides:       tex(bzjlreq--rubygothb-v.vf)
Provides:       tex(bzjlreq--rubygotheb-h.tfm)
Provides:       tex(bzjlreq--rubygotheb-h.vf)
Provides:       tex(bzjlreq--rubygotheb-v.tfm)
Provides:       tex(bzjlreq--rubygotheb-v.vf)
Provides:       tex(bzjlreq--rubygothr-h.tfm)
Provides:       tex(bzjlreq--rubygothr-h.vf)
Provides:       tex(bzjlreq--rubygothr-v.tfm)
Provides:       tex(bzjlreq--rubygothr-v.vf)
Provides:       tex(bzjlreq--rubymgothr-h.tfm)
Provides:       tex(bzjlreq--rubymgothr-h.vf)
Provides:       tex(bzjlreq--rubymgothr-v.tfm)
Provides:       tex(bzjlreq--rubymgothr-v.vf)
Provides:       tex(bzjlreq--rubyminb-h.tfm)
Provides:       tex(bzjlreq--rubyminb-h.vf)
Provides:       tex(bzjlreq--rubyminb-v.tfm)
Provides:       tex(bzjlreq--rubyminb-v.vf)
Provides:       tex(bzjlreq--rubyminl-h.tfm)
Provides:       tex(bzjlreq--rubyminl-h.vf)
Provides:       tex(bzjlreq--rubyminl-v.tfm)
Provides:       tex(bzjlreq--rubyminl-v.vf)
Provides:       tex(bzjlreq--rubyminr-h.tfm)
Provides:       tex(bzjlreq--rubyminr-h.vf)
Provides:       tex(bzjlreq--rubyminr-v.tfm)
Provides:       tex(bzjlreq--rubyminr-v.vf)
Provides:       tex(bzjlreq--upexpgothb-h.tfm)
Provides:       tex(bzjlreq--upexpgothb-h.vf)
Provides:       tex(bzjlreq--upexpgothb-v.tfm)
Provides:       tex(bzjlreq--upexpgothb-v.vf)
Provides:       tex(bzjlreq--upexpgothbn-h.tfm)
Provides:       tex(bzjlreq--upexpgothbn-h.vf)
Provides:       tex(bzjlreq--upexpgothbn-v.tfm)
Provides:       tex(bzjlreq--upexpgothbn-v.vf)
Provides:       tex(bzjlreq--upexpgotheb-h.tfm)
Provides:       tex(bzjlreq--upexpgotheb-h.vf)
Provides:       tex(bzjlreq--upexpgotheb-v.tfm)
Provides:       tex(bzjlreq--upexpgotheb-v.vf)
Provides:       tex(bzjlreq--upexpgothebn-h.tfm)
Provides:       tex(bzjlreq--upexpgothebn-h.vf)
Provides:       tex(bzjlreq--upexpgothebn-v.tfm)
Provides:       tex(bzjlreq--upexpgothebn-v.vf)
Provides:       tex(bzjlreq--upexpgothr-h.tfm)
Provides:       tex(bzjlreq--upexpgothr-h.vf)
Provides:       tex(bzjlreq--upexpgothr-v.tfm)
Provides:       tex(bzjlreq--upexpgothr-v.vf)
Provides:       tex(bzjlreq--upexpgothrn-h.tfm)
Provides:       tex(bzjlreq--upexpgothrn-h.vf)
Provides:       tex(bzjlreq--upexpgothrn-v.tfm)
Provides:       tex(bzjlreq--upexpgothrn-v.vf)
Provides:       tex(bzjlreq--upexpmgothr-h.tfm)
Provides:       tex(bzjlreq--upexpmgothr-h.vf)
Provides:       tex(bzjlreq--upexpmgothr-v.tfm)
Provides:       tex(bzjlreq--upexpmgothr-v.vf)
Provides:       tex(bzjlreq--upexpmgothrn-h.tfm)
Provides:       tex(bzjlreq--upexpmgothrn-h.vf)
Provides:       tex(bzjlreq--upexpmgothrn-v.tfm)
Provides:       tex(bzjlreq--upexpmgothrn-v.vf)
Provides:       tex(bzjlreq--upexpminb-h.tfm)
Provides:       tex(bzjlreq--upexpminb-h.vf)
Provides:       tex(bzjlreq--upexpminb-v.tfm)
Provides:       tex(bzjlreq--upexpminb-v.vf)
Provides:       tex(bzjlreq--upexpminbn-h.tfm)
Provides:       tex(bzjlreq--upexpminbn-h.vf)
Provides:       tex(bzjlreq--upexpminbn-v.tfm)
Provides:       tex(bzjlreq--upexpminbn-v.vf)
Provides:       tex(bzjlreq--upexpminl-h.tfm)
Provides:       tex(bzjlreq--upexpminl-h.vf)
Provides:       tex(bzjlreq--upexpminl-v.tfm)
Provides:       tex(bzjlreq--upexpminl-v.vf)
Provides:       tex(bzjlreq--upexpminln-h.tfm)
Provides:       tex(bzjlreq--upexpminln-h.vf)
Provides:       tex(bzjlreq--upexpminln-v.tfm)
Provides:       tex(bzjlreq--upexpminln-v.vf)
Provides:       tex(bzjlreq--upexpminr-h.tfm)
Provides:       tex(bzjlreq--upexpminr-h.vf)
Provides:       tex(bzjlreq--upexpminr-v.tfm)
Provides:       tex(bzjlreq--upexpminr-v.vf)
Provides:       tex(bzjlreq--upexpminrn-h.tfm)
Provides:       tex(bzjlreq--upexpminrn-h.vf)
Provides:       tex(bzjlreq--upexpminrn-v.tfm)
Provides:       tex(bzjlreq--upexpminrn-v.vf)
Provides:       tex(bzjlreq--upnmlgothb-h.tfm)
Provides:       tex(bzjlreq--upnmlgothb-h.vf)
Provides:       tex(bzjlreq--upnmlgothb-v.tfm)
Provides:       tex(bzjlreq--upnmlgothb-v.vf)
Provides:       tex(bzjlreq--upnmlgothbn-h.tfm)
Provides:       tex(bzjlreq--upnmlgothbn-h.vf)
Provides:       tex(bzjlreq--upnmlgothbn-v.tfm)
Provides:       tex(bzjlreq--upnmlgothbn-v.vf)
Provides:       tex(bzjlreq--upnmlgotheb-h.tfm)
Provides:       tex(bzjlreq--upnmlgotheb-h.vf)
Provides:       tex(bzjlreq--upnmlgotheb-v.tfm)
Provides:       tex(bzjlreq--upnmlgotheb-v.vf)
Provides:       tex(bzjlreq--upnmlgothebn-h.tfm)
Provides:       tex(bzjlreq--upnmlgothebn-h.vf)
Provides:       tex(bzjlreq--upnmlgothebn-v.tfm)
Provides:       tex(bzjlreq--upnmlgothebn-v.vf)
Provides:       tex(bzjlreq--upnmlgothr-h.tfm)
Provides:       tex(bzjlreq--upnmlgothr-h.vf)
Provides:       tex(bzjlreq--upnmlgothr-v.tfm)
Provides:       tex(bzjlreq--upnmlgothr-v.vf)
Provides:       tex(bzjlreq--upnmlgothrn-h.tfm)
Provides:       tex(bzjlreq--upnmlgothrn-h.vf)
Provides:       tex(bzjlreq--upnmlgothrn-v.tfm)
Provides:       tex(bzjlreq--upnmlgothrn-v.vf)
Provides:       tex(bzjlreq--upnmlmgothr-h.tfm)
Provides:       tex(bzjlreq--upnmlmgothr-h.vf)
Provides:       tex(bzjlreq--upnmlmgothr-v.tfm)
Provides:       tex(bzjlreq--upnmlmgothr-v.vf)
Provides:       tex(bzjlreq--upnmlmgothrn-h.tfm)
Provides:       tex(bzjlreq--upnmlmgothrn-h.vf)
Provides:       tex(bzjlreq--upnmlmgothrn-v.tfm)
Provides:       tex(bzjlreq--upnmlmgothrn-v.vf)
Provides:       tex(bzjlreq--upnmlminb-h.tfm)
Provides:       tex(bzjlreq--upnmlminb-h.vf)
Provides:       tex(bzjlreq--upnmlminb-v.tfm)
Provides:       tex(bzjlreq--upnmlminb-v.vf)
Provides:       tex(bzjlreq--upnmlminbn-h.tfm)
Provides:       tex(bzjlreq--upnmlminbn-h.vf)
Provides:       tex(bzjlreq--upnmlminbn-v.tfm)
Provides:       tex(bzjlreq--upnmlminbn-v.vf)
Provides:       tex(bzjlreq--upnmlminl-h.tfm)
Provides:       tex(bzjlreq--upnmlminl-h.vf)
Provides:       tex(bzjlreq--upnmlminl-v.tfm)
Provides:       tex(bzjlreq--upnmlminl-v.vf)
Provides:       tex(bzjlreq--upnmlminln-h.tfm)
Provides:       tex(bzjlreq--upnmlminln-h.vf)
Provides:       tex(bzjlreq--upnmlminln-v.tfm)
Provides:       tex(bzjlreq--upnmlminln-v.vf)
Provides:       tex(bzjlreq--upnmlminr-h.tfm)
Provides:       tex(bzjlreq--upnmlminr-h.vf)
Provides:       tex(bzjlreq--upnmlminr-v.tfm)
Provides:       tex(bzjlreq--upnmlminr-v.vf)
Provides:       tex(bzjlreq--upnmlminrn-h.tfm)
Provides:       tex(bzjlreq--upnmlminrn-h.vf)
Provides:       tex(bzjlreq--upnmlminrn-v.tfm)
Provides:       tex(bzjlreq--upnmlminrn-v.vf)
Provides:       tex(bzjlreq--uprubygothb-h.tfm)
Provides:       tex(bzjlreq--uprubygothb-h.vf)
Provides:       tex(bzjlreq--uprubygothb-v.tfm)
Provides:       tex(bzjlreq--uprubygothb-v.vf)
Provides:       tex(bzjlreq--uprubygotheb-h.tfm)
Provides:       tex(bzjlreq--uprubygotheb-h.vf)
Provides:       tex(bzjlreq--uprubygotheb-v.tfm)
Provides:       tex(bzjlreq--uprubygotheb-v.vf)
Provides:       tex(bzjlreq--uprubygothr-h.tfm)
Provides:       tex(bzjlreq--uprubygothr-h.vf)
Provides:       tex(bzjlreq--uprubygothr-v.tfm)
Provides:       tex(bzjlreq--uprubygothr-v.vf)
Provides:       tex(bzjlreq--uprubymgothr-h.tfm)
Provides:       tex(bzjlreq--uprubymgothr-h.vf)
Provides:       tex(bzjlreq--uprubymgothr-v.tfm)
Provides:       tex(bzjlreq--uprubymgothr-v.vf)
Provides:       tex(bzjlreq--uprubyminb-h.tfm)
Provides:       tex(bzjlreq--uprubyminb-h.vf)
Provides:       tex(bzjlreq--uprubyminb-v.tfm)
Provides:       tex(bzjlreq--uprubyminb-v.vf)
Provides:       tex(bzjlreq--uprubyminl-h.tfm)
Provides:       tex(bzjlreq--uprubyminl-h.vf)
Provides:       tex(bzjlreq--uprubyminl-v.tfm)
Provides:       tex(bzjlreq--uprubyminl-v.vf)
Provides:       tex(bzjlreq--uprubyminr-h.tfm)
Provides:       tex(bzjlreq--uprubyminr-h.vf)
Provides:       tex(bzjlreq--uprubyminr-v.tfm)
Provides:       tex(bzjlreq--uprubyminr-v.vf)
Provides:       tex(jlreq--expgothb-h.tfm)
Provides:       tex(jlreq--expgothb-h.vf)
Provides:       tex(jlreq--expgothb-v.tfm)
Provides:       tex(jlreq--expgothb-v.vf)
Provides:       tex(jlreq--expgothbn-h.tfm)
Provides:       tex(jlreq--expgothbn-h.vf)
Provides:       tex(jlreq--expgothbn-v.tfm)
Provides:       tex(jlreq--expgothbn-v.vf)
Provides:       tex(jlreq--expgotheb-h.tfm)
Provides:       tex(jlreq--expgotheb-h.vf)
Provides:       tex(jlreq--expgotheb-v.tfm)
Provides:       tex(jlreq--expgotheb-v.vf)
Provides:       tex(jlreq--expgothebn-h.tfm)
Provides:       tex(jlreq--expgothebn-h.vf)
Provides:       tex(jlreq--expgothebn-v.tfm)
Provides:       tex(jlreq--expgothebn-v.vf)
Provides:       tex(jlreq--expgothr-h.tfm)
Provides:       tex(jlreq--expgothr-h.vf)
Provides:       tex(jlreq--expgothr-v.tfm)
Provides:       tex(jlreq--expgothr-v.vf)
Provides:       tex(jlreq--expgothrn-h.tfm)
Provides:       tex(jlreq--expgothrn-h.vf)
Provides:       tex(jlreq--expgothrn-v.tfm)
Provides:       tex(jlreq--expgothrn-v.vf)
Provides:       tex(jlreq--expmgothr-h.tfm)
Provides:       tex(jlreq--expmgothr-h.vf)
Provides:       tex(jlreq--expmgothr-v.tfm)
Provides:       tex(jlreq--expmgothr-v.vf)
Provides:       tex(jlreq--expmgothrn-h.tfm)
Provides:       tex(jlreq--expmgothrn-h.vf)
Provides:       tex(jlreq--expmgothrn-v.tfm)
Provides:       tex(jlreq--expmgothrn-v.vf)
Provides:       tex(jlreq--expminb-h.tfm)
Provides:       tex(jlreq--expminb-h.vf)
Provides:       tex(jlreq--expminb-v.tfm)
Provides:       tex(jlreq--expminb-v.vf)
Provides:       tex(jlreq--expminbn-h.tfm)
Provides:       tex(jlreq--expminbn-h.vf)
Provides:       tex(jlreq--expminbn-v.tfm)
Provides:       tex(jlreq--expminbn-v.vf)
Provides:       tex(jlreq--expminl-h.tfm)
Provides:       tex(jlreq--expminl-h.vf)
Provides:       tex(jlreq--expminl-v.tfm)
Provides:       tex(jlreq--expminl-v.vf)
Provides:       tex(jlreq--expminln-h.tfm)
Provides:       tex(jlreq--expminln-h.vf)
Provides:       tex(jlreq--expminln-v.tfm)
Provides:       tex(jlreq--expminln-v.vf)
Provides:       tex(jlreq--expminr-h.tfm)
Provides:       tex(jlreq--expminr-h.vf)
Provides:       tex(jlreq--expminr-v.tfm)
Provides:       tex(jlreq--expminr-v.vf)
Provides:       tex(jlreq--expminrn-h.tfm)
Provides:       tex(jlreq--expminrn-h.vf)
Provides:       tex(jlreq--expminrn-v.tfm)
Provides:       tex(jlreq--expminrn-v.vf)
Provides:       tex(jlreq--nmlgothb-h.tfm)
Provides:       tex(jlreq--nmlgothb-h.vf)
Provides:       tex(jlreq--nmlgothb-v.tfm)
Provides:       tex(jlreq--nmlgothb-v.vf)
Provides:       tex(jlreq--nmlgothbn-h.tfm)
Provides:       tex(jlreq--nmlgothbn-h.vf)
Provides:       tex(jlreq--nmlgothbn-v.tfm)
Provides:       tex(jlreq--nmlgothbn-v.vf)
Provides:       tex(jlreq--nmlgotheb-h.tfm)
Provides:       tex(jlreq--nmlgotheb-h.vf)
Provides:       tex(jlreq--nmlgotheb-v.tfm)
Provides:       tex(jlreq--nmlgotheb-v.vf)
Provides:       tex(jlreq--nmlgothebn-h.tfm)
Provides:       tex(jlreq--nmlgothebn-h.vf)
Provides:       tex(jlreq--nmlgothebn-v.tfm)
Provides:       tex(jlreq--nmlgothebn-v.vf)
Provides:       tex(jlreq--nmlgothr-h.tfm)
Provides:       tex(jlreq--nmlgothr-h.vf)
Provides:       tex(jlreq--nmlgothr-v.tfm)
Provides:       tex(jlreq--nmlgothr-v.vf)
Provides:       tex(jlreq--nmlgothrn-h.tfm)
Provides:       tex(jlreq--nmlgothrn-h.vf)
Provides:       tex(jlreq--nmlgothrn-v.tfm)
Provides:       tex(jlreq--nmlgothrn-v.vf)
Provides:       tex(jlreq--nmlmgothr-h.tfm)
Provides:       tex(jlreq--nmlmgothr-h.vf)
Provides:       tex(jlreq--nmlmgothr-v.tfm)
Provides:       tex(jlreq--nmlmgothr-v.vf)
Provides:       tex(jlreq--nmlmgothrn-h.tfm)
Provides:       tex(jlreq--nmlmgothrn-h.vf)
Provides:       tex(jlreq--nmlmgothrn-v.tfm)
Provides:       tex(jlreq--nmlmgothrn-v.vf)
Provides:       tex(jlreq--nmlminb-h.tfm)
Provides:       tex(jlreq--nmlminb-h.vf)
Provides:       tex(jlreq--nmlminb-v.tfm)
Provides:       tex(jlreq--nmlminb-v.vf)
Provides:       tex(jlreq--nmlminbn-h.tfm)
Provides:       tex(jlreq--nmlminbn-h.vf)
Provides:       tex(jlreq--nmlminbn-v.tfm)
Provides:       tex(jlreq--nmlminbn-v.vf)
Provides:       tex(jlreq--nmlminl-h.tfm)
Provides:       tex(jlreq--nmlminl-h.vf)
Provides:       tex(jlreq--nmlminl-v.tfm)
Provides:       tex(jlreq--nmlminl-v.vf)
Provides:       tex(jlreq--nmlminln-h.tfm)
Provides:       tex(jlreq--nmlminln-h.vf)
Provides:       tex(jlreq--nmlminln-v.tfm)
Provides:       tex(jlreq--nmlminln-v.vf)
Provides:       tex(jlreq--nmlminr-h.tfm)
Provides:       tex(jlreq--nmlminr-h.vf)
Provides:       tex(jlreq--nmlminr-v.tfm)
Provides:       tex(jlreq--nmlminr-v.vf)
Provides:       tex(jlreq--nmlminrn-h.tfm)
Provides:       tex(jlreq--nmlminrn-h.vf)
Provides:       tex(jlreq--nmlminrn-v.tfm)
Provides:       tex(jlreq--nmlminrn-v.vf)
Provides:       tex(jlreq--rubygothb-h.tfm)
Provides:       tex(jlreq--rubygothb-h.vf)
Provides:       tex(jlreq--rubygothb-v.tfm)
Provides:       tex(jlreq--rubygothb-v.vf)
Provides:       tex(jlreq--rubygotheb-h.tfm)
Provides:       tex(jlreq--rubygotheb-h.vf)
Provides:       tex(jlreq--rubygotheb-v.tfm)
Provides:       tex(jlreq--rubygotheb-v.vf)
Provides:       tex(jlreq--rubygothr-h.tfm)
Provides:       tex(jlreq--rubygothr-h.vf)
Provides:       tex(jlreq--rubygothr-v.tfm)
Provides:       tex(jlreq--rubygothr-v.vf)
Provides:       tex(jlreq--rubymgothr-h.tfm)
Provides:       tex(jlreq--rubymgothr-h.vf)
Provides:       tex(jlreq--rubymgothr-v.tfm)
Provides:       tex(jlreq--rubymgothr-v.vf)
Provides:       tex(jlreq--rubyminb-h.tfm)
Provides:       tex(jlreq--rubyminb-h.vf)
Provides:       tex(jlreq--rubyminb-v.tfm)
Provides:       tex(jlreq--rubyminb-v.vf)
Provides:       tex(jlreq--rubyminl-h.tfm)
Provides:       tex(jlreq--rubyminl-h.vf)
Provides:       tex(jlreq--rubyminl-v.tfm)
Provides:       tex(jlreq--rubyminl-v.vf)
Provides:       tex(jlreq--rubyminr-h.tfm)
Provides:       tex(jlreq--rubyminr-h.vf)
Provides:       tex(jlreq--rubyminr-v.tfm)
Provides:       tex(jlreq--rubyminr-v.vf)
Provides:       tex(jlreq--upexpgothb-h.tfm)
Provides:       tex(jlreq--upexpgothb-h.vf)
Provides:       tex(jlreq--upexpgothb-v.tfm)
Provides:       tex(jlreq--upexpgothb-v.vf)
Provides:       tex(jlreq--upexpgothbn-h.tfm)
Provides:       tex(jlreq--upexpgothbn-h.vf)
Provides:       tex(jlreq--upexpgothbn-v.tfm)
Provides:       tex(jlreq--upexpgothbn-v.vf)
Provides:       tex(jlreq--upexpgotheb-h.tfm)
Provides:       tex(jlreq--upexpgotheb-h.vf)
Provides:       tex(jlreq--upexpgotheb-v.tfm)
Provides:       tex(jlreq--upexpgotheb-v.vf)
Provides:       tex(jlreq--upexpgothebn-h.tfm)
Provides:       tex(jlreq--upexpgothebn-h.vf)
Provides:       tex(jlreq--upexpgothebn-v.tfm)
Provides:       tex(jlreq--upexpgothebn-v.vf)
Provides:       tex(jlreq--upexpgothr-h.tfm)
Provides:       tex(jlreq--upexpgothr-h.vf)
Provides:       tex(jlreq--upexpgothr-v.tfm)
Provides:       tex(jlreq--upexpgothr-v.vf)
Provides:       tex(jlreq--upexpgothrn-h.tfm)
Provides:       tex(jlreq--upexpgothrn-h.vf)
Provides:       tex(jlreq--upexpgothrn-v.tfm)
Provides:       tex(jlreq--upexpgothrn-v.vf)
Provides:       tex(jlreq--upexpmgothr-h.tfm)
Provides:       tex(jlreq--upexpmgothr-h.vf)
Provides:       tex(jlreq--upexpmgothr-v.tfm)
Provides:       tex(jlreq--upexpmgothr-v.vf)
Provides:       tex(jlreq--upexpmgothrn-h.tfm)
Provides:       tex(jlreq--upexpmgothrn-h.vf)
Provides:       tex(jlreq--upexpmgothrn-v.tfm)
Provides:       tex(jlreq--upexpmgothrn-v.vf)
Provides:       tex(jlreq--upexpminb-h.tfm)
Provides:       tex(jlreq--upexpminb-h.vf)
Provides:       tex(jlreq--upexpminb-v.tfm)
Provides:       tex(jlreq--upexpminb-v.vf)
Provides:       tex(jlreq--upexpminbn-h.tfm)
Provides:       tex(jlreq--upexpminbn-h.vf)
Provides:       tex(jlreq--upexpminbn-v.tfm)
Provides:       tex(jlreq--upexpminbn-v.vf)
Provides:       tex(jlreq--upexpminl-h.tfm)
Provides:       tex(jlreq--upexpminl-h.vf)
Provides:       tex(jlreq--upexpminl-v.tfm)
Provides:       tex(jlreq--upexpminl-v.vf)
Provides:       tex(jlreq--upexpminln-h.tfm)
Provides:       tex(jlreq--upexpminln-h.vf)
Provides:       tex(jlreq--upexpminln-v.tfm)
Provides:       tex(jlreq--upexpminln-v.vf)
Provides:       tex(jlreq--upexpminr-h.tfm)
Provides:       tex(jlreq--upexpminr-h.vf)
Provides:       tex(jlreq--upexpminr-v.tfm)
Provides:       tex(jlreq--upexpminr-v.vf)
Provides:       tex(jlreq--upexpminrn-h.tfm)
Provides:       tex(jlreq--upexpminrn-h.vf)
Provides:       tex(jlreq--upexpminrn-v.tfm)
Provides:       tex(jlreq--upexpminrn-v.vf)
Provides:       tex(jlreq--upnmlgothb-h.tfm)
Provides:       tex(jlreq--upnmlgothb-h.vf)
Provides:       tex(jlreq--upnmlgothb-v.tfm)
Provides:       tex(jlreq--upnmlgothb-v.vf)
Provides:       tex(jlreq--upnmlgothbn-h.tfm)
Provides:       tex(jlreq--upnmlgothbn-h.vf)
Provides:       tex(jlreq--upnmlgothbn-v.tfm)
Provides:       tex(jlreq--upnmlgothbn-v.vf)
Provides:       tex(jlreq--upnmlgotheb-h.tfm)
Provides:       tex(jlreq--upnmlgotheb-h.vf)
Provides:       tex(jlreq--upnmlgotheb-v.tfm)
Provides:       tex(jlreq--upnmlgotheb-v.vf)
Provides:       tex(jlreq--upnmlgothebn-h.tfm)
Provides:       tex(jlreq--upnmlgothebn-h.vf)
Provides:       tex(jlreq--upnmlgothebn-v.tfm)
Provides:       tex(jlreq--upnmlgothebn-v.vf)
Provides:       tex(jlreq--upnmlgothr-h.tfm)
Provides:       tex(jlreq--upnmlgothr-h.vf)
Provides:       tex(jlreq--upnmlgothr-v.tfm)
Provides:       tex(jlreq--upnmlgothr-v.vf)
Provides:       tex(jlreq--upnmlgothrn-h.tfm)
Provides:       tex(jlreq--upnmlgothrn-h.vf)
Provides:       tex(jlreq--upnmlgothrn-v.tfm)
Provides:       tex(jlreq--upnmlgothrn-v.vf)
Provides:       tex(jlreq--upnmlmgothr-h.tfm)
Provides:       tex(jlreq--upnmlmgothr-h.vf)
Provides:       tex(jlreq--upnmlmgothr-v.tfm)
Provides:       tex(jlreq--upnmlmgothr-v.vf)
Provides:       tex(jlreq--upnmlmgothrn-h.tfm)
Provides:       tex(jlreq--upnmlmgothrn-h.vf)
Provides:       tex(jlreq--upnmlmgothrn-v.tfm)
Provides:       tex(jlreq--upnmlmgothrn-v.vf)
Provides:       tex(jlreq--upnmlminb-h.tfm)
Provides:       tex(jlreq--upnmlminb-h.vf)
Provides:       tex(jlreq--upnmlminb-v.tfm)
Provides:       tex(jlreq--upnmlminb-v.vf)
Provides:       tex(jlreq--upnmlminbn-h.tfm)
Provides:       tex(jlreq--upnmlminbn-h.vf)
Provides:       tex(jlreq--upnmlminbn-v.tfm)
Provides:       tex(jlreq--upnmlminbn-v.vf)
Provides:       tex(jlreq--upnmlminl-h.tfm)
Provides:       tex(jlreq--upnmlminl-h.vf)
Provides:       tex(jlreq--upnmlminl-v.tfm)
Provides:       tex(jlreq--upnmlminl-v.vf)
Provides:       tex(jlreq--upnmlminln-h.tfm)
Provides:       tex(jlreq--upnmlminln-h.vf)
Provides:       tex(jlreq--upnmlminln-v.tfm)
Provides:       tex(jlreq--upnmlminln-v.vf)
Provides:       tex(jlreq--upnmlminr-h.tfm)
Provides:       tex(jlreq--upnmlminr-h.vf)
Provides:       tex(jlreq--upnmlminr-v.tfm)
Provides:       tex(jlreq--upnmlminr-v.vf)
Provides:       tex(jlreq--upnmlminrn-h.tfm)
Provides:       tex(jlreq--upnmlminrn-h.vf)
Provides:       tex(jlreq--upnmlminrn-v.tfm)
Provides:       tex(jlreq--upnmlminrn-v.vf)
Provides:       tex(jlreq--uprubygothb-h.tfm)
Provides:       tex(jlreq--uprubygothb-h.vf)
Provides:       tex(jlreq--uprubygothb-v.tfm)
Provides:       tex(jlreq--uprubygothb-v.vf)
Provides:       tex(jlreq--uprubygotheb-h.tfm)
Provides:       tex(jlreq--uprubygotheb-h.vf)
Provides:       tex(jlreq--uprubygotheb-v.tfm)
Provides:       tex(jlreq--uprubygotheb-v.vf)
Provides:       tex(jlreq--uprubygothr-h.tfm)
Provides:       tex(jlreq--uprubygothr-h.vf)
Provides:       tex(jlreq--uprubygothr-v.tfm)
Provides:       tex(jlreq--uprubygothr-v.vf)
Provides:       tex(jlreq--uprubymgothr-h.tfm)
Provides:       tex(jlreq--uprubymgothr-h.vf)
Provides:       tex(jlreq--uprubymgothr-v.tfm)
Provides:       tex(jlreq--uprubymgothr-v.vf)
Provides:       tex(jlreq--uprubyminb-h.tfm)
Provides:       tex(jlreq--uprubyminb-h.vf)
Provides:       tex(jlreq--uprubyminb-v.tfm)
Provides:       tex(jlreq--uprubyminb-v.vf)
Provides:       tex(jlreq--uprubyminl-h.tfm)
Provides:       tex(jlreq--uprubyminl-h.vf)
Provides:       tex(jlreq--uprubyminl-v.tfm)
Provides:       tex(jlreq--uprubyminl-v.vf)
Provides:       tex(jlreq--uprubyminr-h.tfm)
Provides:       tex(jlreq--uprubyminr-h.vf)
Provides:       tex(jlreq--uprubyminr-v.tfm)
Provides:       tex(jlreq--uprubyminr-v.vf)
Provides:       tex(jlreq-deluxe.sty)
Provides:       tex(zjlreq--expgothb-h.tfm)
Provides:       tex(zjlreq--expgothb-h.vf)
Provides:       tex(zjlreq--expgothb-v.tfm)
Provides:       tex(zjlreq--expgothb-v.vf)
Provides:       tex(zjlreq--expgothbn-h.tfm)
Provides:       tex(zjlreq--expgothbn-h.vf)
Provides:       tex(zjlreq--expgothbn-v.tfm)
Provides:       tex(zjlreq--expgothbn-v.vf)
Provides:       tex(zjlreq--expgotheb-h.tfm)
Provides:       tex(zjlreq--expgotheb-h.vf)
Provides:       tex(zjlreq--expgotheb-v.tfm)
Provides:       tex(zjlreq--expgotheb-v.vf)
Provides:       tex(zjlreq--expgothebn-h.tfm)
Provides:       tex(zjlreq--expgothebn-h.vf)
Provides:       tex(zjlreq--expgothebn-v.tfm)
Provides:       tex(zjlreq--expgothebn-v.vf)
Provides:       tex(zjlreq--expgothr-h.tfm)
Provides:       tex(zjlreq--expgothr-h.vf)
Provides:       tex(zjlreq--expgothr-v.tfm)
Provides:       tex(zjlreq--expgothr-v.vf)
Provides:       tex(zjlreq--expgothrn-h.tfm)
Provides:       tex(zjlreq--expgothrn-h.vf)
Provides:       tex(zjlreq--expgothrn-v.tfm)
Provides:       tex(zjlreq--expgothrn-v.vf)
Provides:       tex(zjlreq--expmgothr-h.tfm)
Provides:       tex(zjlreq--expmgothr-h.vf)
Provides:       tex(zjlreq--expmgothr-v.tfm)
Provides:       tex(zjlreq--expmgothr-v.vf)
Provides:       tex(zjlreq--expmgothrn-h.tfm)
Provides:       tex(zjlreq--expmgothrn-h.vf)
Provides:       tex(zjlreq--expmgothrn-v.tfm)
Provides:       tex(zjlreq--expmgothrn-v.vf)
Provides:       tex(zjlreq--expminb-h.tfm)
Provides:       tex(zjlreq--expminb-h.vf)
Provides:       tex(zjlreq--expminb-v.tfm)
Provides:       tex(zjlreq--expminb-v.vf)
Provides:       tex(zjlreq--expminbn-h.tfm)
Provides:       tex(zjlreq--expminbn-h.vf)
Provides:       tex(zjlreq--expminbn-v.tfm)
Provides:       tex(zjlreq--expminbn-v.vf)
Provides:       tex(zjlreq--expminl-h.tfm)
Provides:       tex(zjlreq--expminl-h.vf)
Provides:       tex(zjlreq--expminl-v.tfm)
Provides:       tex(zjlreq--expminl-v.vf)
Provides:       tex(zjlreq--expminln-h.tfm)
Provides:       tex(zjlreq--expminln-h.vf)
Provides:       tex(zjlreq--expminln-v.tfm)
Provides:       tex(zjlreq--expminln-v.vf)
Provides:       tex(zjlreq--expminr-h.tfm)
Provides:       tex(zjlreq--expminr-h.vf)
Provides:       tex(zjlreq--expminr-v.tfm)
Provides:       tex(zjlreq--expminr-v.vf)
Provides:       tex(zjlreq--expminrn-h.tfm)
Provides:       tex(zjlreq--expminrn-h.vf)
Provides:       tex(zjlreq--expminrn-v.tfm)
Provides:       tex(zjlreq--expminrn-v.vf)
Provides:       tex(zjlreq--nmlgothb-h.tfm)
Provides:       tex(zjlreq--nmlgothb-h.vf)
Provides:       tex(zjlreq--nmlgothb-v.tfm)
Provides:       tex(zjlreq--nmlgothb-v.vf)
Provides:       tex(zjlreq--nmlgothbn-h.tfm)
Provides:       tex(zjlreq--nmlgothbn-h.vf)
Provides:       tex(zjlreq--nmlgothbn-v.tfm)
Provides:       tex(zjlreq--nmlgothbn-v.vf)
Provides:       tex(zjlreq--nmlgotheb-h.tfm)
Provides:       tex(zjlreq--nmlgotheb-h.vf)
Provides:       tex(zjlreq--nmlgotheb-v.tfm)
Provides:       tex(zjlreq--nmlgotheb-v.vf)
Provides:       tex(zjlreq--nmlgothebn-h.tfm)
Provides:       tex(zjlreq--nmlgothebn-h.vf)
Provides:       tex(zjlreq--nmlgothebn-v.tfm)
Provides:       tex(zjlreq--nmlgothebn-v.vf)
Provides:       tex(zjlreq--nmlgothr-h.tfm)
Provides:       tex(zjlreq--nmlgothr-h.vf)
Provides:       tex(zjlreq--nmlgothr-v.tfm)
Provides:       tex(zjlreq--nmlgothr-v.vf)
Provides:       tex(zjlreq--nmlgothrn-h.tfm)
Provides:       tex(zjlreq--nmlgothrn-h.vf)
Provides:       tex(zjlreq--nmlgothrn-v.tfm)
Provides:       tex(zjlreq--nmlgothrn-v.vf)
Provides:       tex(zjlreq--nmlmgothr-h.tfm)
Provides:       tex(zjlreq--nmlmgothr-h.vf)
Provides:       tex(zjlreq--nmlmgothr-v.tfm)
Provides:       tex(zjlreq--nmlmgothr-v.vf)
Provides:       tex(zjlreq--nmlmgothrn-h.tfm)
Provides:       tex(zjlreq--nmlmgothrn-h.vf)
Provides:       tex(zjlreq--nmlmgothrn-v.tfm)
Provides:       tex(zjlreq--nmlmgothrn-v.vf)
Provides:       tex(zjlreq--nmlminb-h.tfm)
Provides:       tex(zjlreq--nmlminb-h.vf)
Provides:       tex(zjlreq--nmlminb-v.tfm)
Provides:       tex(zjlreq--nmlminb-v.vf)
Provides:       tex(zjlreq--nmlminbn-h.tfm)
Provides:       tex(zjlreq--nmlminbn-h.vf)
Provides:       tex(zjlreq--nmlminbn-v.tfm)
Provides:       tex(zjlreq--nmlminbn-v.vf)
Provides:       tex(zjlreq--nmlminl-h.tfm)
Provides:       tex(zjlreq--nmlminl-h.vf)
Provides:       tex(zjlreq--nmlminl-v.tfm)
Provides:       tex(zjlreq--nmlminl-v.vf)
Provides:       tex(zjlreq--nmlminln-h.tfm)
Provides:       tex(zjlreq--nmlminln-h.vf)
Provides:       tex(zjlreq--nmlminln-v.tfm)
Provides:       tex(zjlreq--nmlminln-v.vf)
Provides:       tex(zjlreq--nmlminr-h.tfm)
Provides:       tex(zjlreq--nmlminr-h.vf)
Provides:       tex(zjlreq--nmlminr-v.tfm)
Provides:       tex(zjlreq--nmlminr-v.vf)
Provides:       tex(zjlreq--nmlminrn-h.tfm)
Provides:       tex(zjlreq--nmlminrn-h.vf)
Provides:       tex(zjlreq--nmlminrn-v.tfm)
Provides:       tex(zjlreq--nmlminrn-v.vf)
Provides:       tex(zjlreq--rubygothb-h.tfm)
Provides:       tex(zjlreq--rubygothb-h.vf)
Provides:       tex(zjlreq--rubygothb-v.tfm)
Provides:       tex(zjlreq--rubygothb-v.vf)
Provides:       tex(zjlreq--rubygotheb-h.tfm)
Provides:       tex(zjlreq--rubygotheb-h.vf)
Provides:       tex(zjlreq--rubygotheb-v.tfm)
Provides:       tex(zjlreq--rubygotheb-v.vf)
Provides:       tex(zjlreq--rubygothr-h.tfm)
Provides:       tex(zjlreq--rubygothr-h.vf)
Provides:       tex(zjlreq--rubygothr-v.tfm)
Provides:       tex(zjlreq--rubygothr-v.vf)
Provides:       tex(zjlreq--rubymgothr-h.tfm)
Provides:       tex(zjlreq--rubymgothr-h.vf)
Provides:       tex(zjlreq--rubymgothr-v.tfm)
Provides:       tex(zjlreq--rubymgothr-v.vf)
Provides:       tex(zjlreq--rubyminb-h.tfm)
Provides:       tex(zjlreq--rubyminb-h.vf)
Provides:       tex(zjlreq--rubyminb-v.tfm)
Provides:       tex(zjlreq--rubyminb-v.vf)
Provides:       tex(zjlreq--rubyminl-h.tfm)
Provides:       tex(zjlreq--rubyminl-h.vf)
Provides:       tex(zjlreq--rubyminl-v.tfm)
Provides:       tex(zjlreq--rubyminl-v.vf)
Provides:       tex(zjlreq--rubyminr-h.tfm)
Provides:       tex(zjlreq--rubyminr-h.vf)
Provides:       tex(zjlreq--rubyminr-v.tfm)
Provides:       tex(zjlreq--rubyminr-v.vf)
Provides:       tex(zjlreq--upexpgothb-h.tfm)
Provides:       tex(zjlreq--upexpgothb-h.vf)
Provides:       tex(zjlreq--upexpgothb-v.tfm)
Provides:       tex(zjlreq--upexpgothb-v.vf)
Provides:       tex(zjlreq--upexpgothbn-h.tfm)
Provides:       tex(zjlreq--upexpgothbn-h.vf)
Provides:       tex(zjlreq--upexpgothbn-v.tfm)
Provides:       tex(zjlreq--upexpgothbn-v.vf)
Provides:       tex(zjlreq--upexpgotheb-h.tfm)
Provides:       tex(zjlreq--upexpgotheb-h.vf)
Provides:       tex(zjlreq--upexpgotheb-v.tfm)
Provides:       tex(zjlreq--upexpgotheb-v.vf)
Provides:       tex(zjlreq--upexpgothebn-h.tfm)
Provides:       tex(zjlreq--upexpgothebn-h.vf)
Provides:       tex(zjlreq--upexpgothebn-v.tfm)
Provides:       tex(zjlreq--upexpgothebn-v.vf)
Provides:       tex(zjlreq--upexpgothr-h.tfm)
Provides:       tex(zjlreq--upexpgothr-h.vf)
Provides:       tex(zjlreq--upexpgothr-v.tfm)
Provides:       tex(zjlreq--upexpgothr-v.vf)
Provides:       tex(zjlreq--upexpgothrn-h.tfm)
Provides:       tex(zjlreq--upexpgothrn-h.vf)
Provides:       tex(zjlreq--upexpgothrn-v.tfm)
Provides:       tex(zjlreq--upexpgothrn-v.vf)
Provides:       tex(zjlreq--upexpmgothr-h.tfm)
Provides:       tex(zjlreq--upexpmgothr-h.vf)
Provides:       tex(zjlreq--upexpmgothr-v.tfm)
Provides:       tex(zjlreq--upexpmgothr-v.vf)
Provides:       tex(zjlreq--upexpmgothrn-h.tfm)
Provides:       tex(zjlreq--upexpmgothrn-h.vf)
Provides:       tex(zjlreq--upexpmgothrn-v.tfm)
Provides:       tex(zjlreq--upexpmgothrn-v.vf)
Provides:       tex(zjlreq--upexpminb-h.tfm)
Provides:       tex(zjlreq--upexpminb-h.vf)
Provides:       tex(zjlreq--upexpminb-v.tfm)
Provides:       tex(zjlreq--upexpminb-v.vf)
Provides:       tex(zjlreq--upexpminbn-h.tfm)
Provides:       tex(zjlreq--upexpminbn-h.vf)
Provides:       tex(zjlreq--upexpminbn-v.tfm)
Provides:       tex(zjlreq--upexpminbn-v.vf)
Provides:       tex(zjlreq--upexpminl-h.tfm)
Provides:       tex(zjlreq--upexpminl-h.vf)
Provides:       tex(zjlreq--upexpminl-v.tfm)
Provides:       tex(zjlreq--upexpminl-v.vf)
Provides:       tex(zjlreq--upexpminln-h.tfm)
Provides:       tex(zjlreq--upexpminln-h.vf)
Provides:       tex(zjlreq--upexpminln-v.tfm)
Provides:       tex(zjlreq--upexpminln-v.vf)
Provides:       tex(zjlreq--upexpminr-h.tfm)
Provides:       tex(zjlreq--upexpminr-h.vf)
Provides:       tex(zjlreq--upexpminr-v.tfm)
Provides:       tex(zjlreq--upexpminr-v.vf)
Provides:       tex(zjlreq--upexpminrn-h.tfm)
Provides:       tex(zjlreq--upexpminrn-h.vf)
Provides:       tex(zjlreq--upexpminrn-v.tfm)
Provides:       tex(zjlreq--upexpminrn-v.vf)
Provides:       tex(zjlreq--upnmlgothb-h.tfm)
Provides:       tex(zjlreq--upnmlgothb-h.vf)
Provides:       tex(zjlreq--upnmlgothb-v.tfm)
Provides:       tex(zjlreq--upnmlgothb-v.vf)
Provides:       tex(zjlreq--upnmlgothbn-h.tfm)
Provides:       tex(zjlreq--upnmlgothbn-h.vf)
Provides:       tex(zjlreq--upnmlgothbn-v.tfm)
Provides:       tex(zjlreq--upnmlgothbn-v.vf)
Provides:       tex(zjlreq--upnmlgotheb-h.tfm)
Provides:       tex(zjlreq--upnmlgotheb-h.vf)
Provides:       tex(zjlreq--upnmlgotheb-v.tfm)
Provides:       tex(zjlreq--upnmlgotheb-v.vf)
Provides:       tex(zjlreq--upnmlgothebn-h.tfm)
Provides:       tex(zjlreq--upnmlgothebn-h.vf)
Provides:       tex(zjlreq--upnmlgothebn-v.tfm)
Provides:       tex(zjlreq--upnmlgothebn-v.vf)
Provides:       tex(zjlreq--upnmlgothr-h.tfm)
Provides:       tex(zjlreq--upnmlgothr-h.vf)
Provides:       tex(zjlreq--upnmlgothr-v.tfm)
Provides:       tex(zjlreq--upnmlgothr-v.vf)
Provides:       tex(zjlreq--upnmlgothrn-h.tfm)
Provides:       tex(zjlreq--upnmlgothrn-h.vf)
Provides:       tex(zjlreq--upnmlgothrn-v.tfm)
Provides:       tex(zjlreq--upnmlgothrn-v.vf)
Provides:       tex(zjlreq--upnmlmgothr-h.tfm)
Provides:       tex(zjlreq--upnmlmgothr-h.vf)
Provides:       tex(zjlreq--upnmlmgothr-v.tfm)
Provides:       tex(zjlreq--upnmlmgothr-v.vf)
Provides:       tex(zjlreq--upnmlmgothrn-h.tfm)
Provides:       tex(zjlreq--upnmlmgothrn-h.vf)
Provides:       tex(zjlreq--upnmlmgothrn-v.tfm)
Provides:       tex(zjlreq--upnmlmgothrn-v.vf)
Provides:       tex(zjlreq--upnmlminb-h.tfm)
Provides:       tex(zjlreq--upnmlminb-h.vf)
Provides:       tex(zjlreq--upnmlminb-v.tfm)
Provides:       tex(zjlreq--upnmlminb-v.vf)
Provides:       tex(zjlreq--upnmlminbn-h.tfm)
Provides:       tex(zjlreq--upnmlminbn-h.vf)
Provides:       tex(zjlreq--upnmlminbn-v.tfm)
Provides:       tex(zjlreq--upnmlminbn-v.vf)
Provides:       tex(zjlreq--upnmlminl-h.tfm)
Provides:       tex(zjlreq--upnmlminl-h.vf)
Provides:       tex(zjlreq--upnmlminl-v.tfm)
Provides:       tex(zjlreq--upnmlminl-v.vf)
Provides:       tex(zjlreq--upnmlminln-h.tfm)
Provides:       tex(zjlreq--upnmlminln-h.vf)
Provides:       tex(zjlreq--upnmlminln-v.tfm)
Provides:       tex(zjlreq--upnmlminln-v.vf)
Provides:       tex(zjlreq--upnmlminr-h.tfm)
Provides:       tex(zjlreq--upnmlminr-h.vf)
Provides:       tex(zjlreq--upnmlminr-v.tfm)
Provides:       tex(zjlreq--upnmlminr-v.vf)
Provides:       tex(zjlreq--upnmlminrn-h.tfm)
Provides:       tex(zjlreq--upnmlminrn-h.vf)
Provides:       tex(zjlreq--upnmlminrn-v.tfm)
Provides:       tex(zjlreq--upnmlminrn-v.vf)
Provides:       tex(zjlreq--uprubygothb-h.tfm)
Provides:       tex(zjlreq--uprubygothb-h.vf)
Provides:       tex(zjlreq--uprubygothb-v.tfm)
Provides:       tex(zjlreq--uprubygothb-v.vf)
Provides:       tex(zjlreq--uprubygotheb-h.tfm)
Provides:       tex(zjlreq--uprubygotheb-h.vf)
Provides:       tex(zjlreq--uprubygotheb-v.tfm)
Provides:       tex(zjlreq--uprubygotheb-v.vf)
Provides:       tex(zjlreq--uprubygothr-h.tfm)
Provides:       tex(zjlreq--uprubygothr-h.vf)
Provides:       tex(zjlreq--uprubygothr-v.tfm)
Provides:       tex(zjlreq--uprubygothr-v.vf)
Provides:       tex(zjlreq--uprubymgothr-h.tfm)
Provides:       tex(zjlreq--uprubymgothr-h.vf)
Provides:       tex(zjlreq--uprubymgothr-v.tfm)
Provides:       tex(zjlreq--uprubymgothr-v.vf)
Provides:       tex(zjlreq--uprubyminb-h.tfm)
Provides:       tex(zjlreq--uprubyminb-h.vf)
Provides:       tex(zjlreq--uprubyminb-v.tfm)
Provides:       tex(zjlreq--uprubyminb-v.vf)
Provides:       tex(zjlreq--uprubyminl-h.tfm)
Provides:       tex(zjlreq--uprubyminl-h.vf)
Provides:       tex(zjlreq--uprubyminl-v.tfm)
Provides:       tex(zjlreq--uprubyminl-v.vf)
Provides:       tex(zjlreq--uprubyminr-h.tfm)
Provides:       tex(zjlreq--uprubyminr-h.vf)
Provides:       tex(zjlreq--uprubyminr-v.tfm)
Provides:       tex(zjlreq--uprubyminr-v.vf)
Requires:       tex(expl3.sty)
Requires:       tex(hgothb-h.tfm)
Requires:       tex(hgothb-v.tfm)
Requires:       tex(hgothbn-h.tfm)
Requires:       tex(hgothbn-v.tfm)
Requires:       tex(hgotheb-h.tfm)
Requires:       tex(hgotheb-v.tfm)
Requires:       tex(hgothebn-h.tfm)
Requires:       tex(hgothebn-v.tfm)
Requires:       tex(hgothr-h.tfm)
Requires:       tex(hgothr-v.tfm)
Requires:       tex(hgothrn-h.tfm)
Requires:       tex(hgothrn-v.tfm)
Requires:       tex(hmgothr-h.tfm)
Requires:       tex(hmgothr-v.tfm)
Requires:       tex(hmgothrn-h.tfm)
Requires:       tex(hmgothrn-v.tfm)
Requires:       tex(hminb-h.tfm)
Requires:       tex(hminb-v.tfm)
Requires:       tex(hminbn-h.tfm)
Requires:       tex(hminbn-v.tfm)
Requires:       tex(hminl-h.tfm)
Requires:       tex(hminl-v.tfm)
Requires:       tex(hminln-h.tfm)
Requires:       tex(hminln-v.tfm)
Requires:       tex(hminr-h.tfm)
Requires:       tex(hminr-v.tfm)
Requires:       tex(hminrn-h.tfm)
Requires:       tex(hminrn-v.tfm)
Requires:       tex(l3keys2e.sty)
Requires:       tex(otf-cjgb-h.tfm)
Requires:       tex(otf-cjgb-v.tfm)
Requires:       tex(otf-cjge-h.tfm)
Requires:       tex(otf-cjge-v.tfm)
Requires:       tex(otf-cjgr-h.tfm)
Requires:       tex(otf-cjgr-v.tfm)
Requires:       tex(otf-cjmb-h.tfm)
Requires:       tex(otf-cjmb-v.tfm)
Requires:       tex(otf-cjmgr-h.tfm)
Requires:       tex(otf-cjmgr-v.tfm)
Requires:       tex(otf-cjml-h.tfm)
Requires:       tex(otf-cjml-v.tfm)
Requires:       tex(otf-cjmr-h.tfm)
Requires:       tex(otf-cjmr-v.tfm)
Requires:       tex(pxjodel.sty)
Requires:       tex(uphgothb-h.tfm)
Requires:       tex(uphgothb-v.tfm)
Requires:       tex(uphgothbn-h.tfm)
Requires:       tex(uphgothbn-v.tfm)
Requires:       tex(uphgotheb-h.tfm)
Requires:       tex(uphgotheb-v.tfm)
Requires:       tex(uphgothebn-h.tfm)
Requires:       tex(uphgothebn-v.tfm)
Requires:       tex(uphgothr-h.tfm)
Requires:       tex(uphgothr-v.tfm)
Requires:       tex(uphgothrn-h.tfm)
Requires:       tex(uphgothrn-v.tfm)
Requires:       tex(uphmgothr-h.tfm)
Requires:       tex(uphmgothr-v.tfm)
Requires:       tex(uphmgothrn-h.tfm)
Requires:       tex(uphmgothrn-v.tfm)
Requires:       tex(uphminb-h.tfm)
Requires:       tex(uphminb-v.tfm)
Requires:       tex(uphminbn-h.tfm)
Requires:       tex(uphminbn-v.tfm)
Requires:       tex(uphminl-h.tfm)
Requires:       tex(uphminl-v.tfm)
Requires:       tex(uphminln-h.tfm)
Requires:       tex(uphminln-v.tfm)
Requires:       tex(uphminr-h.tfm)
Requires:       tex(uphminr-v.tfm)
Requires:       tex(uphminrn-h.tfm)
Requires:       tex(uphminrn-v.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source71:       jlreq-deluxe.tar.xz
Source72:       jlreq-deluxe.doc.tar.xz

%description -n texlive-jlreq-deluxe
This package provides multi-weight Japanese font support for
the jlreq class.

%package -n texlive-jlreq-deluxe-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.4.1svn66115
Release:        0
Summary:        Documentation for texlive-jlreq-deluxe
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jlreq-deluxe and texlive-alldocumentation)
Provides:       locale(texlive-jlreq-deluxe-doc:ja)

%description -n texlive-jlreq-deluxe-doc
This package includes the documentation for texlive-jlreq-deluxe

%post -n texlive-jlreq-deluxe
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jlreq-deluxe
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jlreq-deluxe
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jlreq-deluxe-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/platex/jlreq-deluxe/LICENSE
%{_texmfdistdir}/doc/platex/jlreq-deluxe/README-ja.md
%{_texmfdistdir}/doc/platex/jlreq-deluxe/README.md
%{_texmfdistdir}/doc/platex/jlreq-deluxe/jlreq-deluxe.pdf
%{_texmfdistdir}/doc/platex/jlreq-deluxe/jlreq-deluxe.tex

%files -n texlive-jlreq-deluxe
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--expminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--nmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--rubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--upnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bjlreq--uprubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--expminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--nmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--rubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--upnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/bzjlreq--uprubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--expminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--nmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--rubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--upnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/jlreq--uprubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--expminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--nmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--rubyminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upexpminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothebn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothebn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlmgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlmgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlmgothrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlmgothrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminbn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminbn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminln-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminln-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminrn-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--upnmlminrn-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygothb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygothb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygotheb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygotheb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubygothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubymgothr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubymgothr-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminb-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminb-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminl-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminl-v.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminr-h.tfm
%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe/zjlreq--uprubyminr-v.tfm
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--expminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--nmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--rubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--upnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bjlreq--uprubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--expminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--nmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--rubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--upnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/bzjlreq--uprubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--expminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--nmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--rubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--upnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/jlreq--uprubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--expminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--nmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--rubyminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upexpminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothebn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothebn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlmgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlmgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlmgothrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlmgothrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminbn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminbn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminln-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminln-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminrn-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--upnmlminrn-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygothb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygothb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygotheb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygotheb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubygothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubymgothr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubymgothr-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminb-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminb-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminl-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminl-v.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminr-h.vf
%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe/zjlreq--uprubyminr-v.vf
%{_texmfdistdir}/tex/platex/jlreq-deluxe/jlreq-deluxe.sty

%package -n texlive-jmb
Version:        %{texlive_version}.%{texlive_noarch}.1.21svn52718
Release:        0
License:        LPPL-1.0
Summary:        BibTeX style for the Journal of Theoretical Biology
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       tex(jmb.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source73:       jmb.tar.xz

%description -n texlive-jmb
This BibTeX bibliography style is for the Journal of Molecular
Biology and Journal of Theoretical Biology; the accompanying
LaTeX (2.09) package is a close relative of apalike.sty in the
BibTeX distribution; it features author-date references. The
bibliography style has control over whether to print reference
titles; if your database contains an article with the cite key
"TitlesOn", and you invoke it by \nocite{TitlesOn}, titles will
be printed; otherwise titles will not be printed.

%post -n texlive-jmb
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jmb
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jmb
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jmb
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/jmb/jmb.bst
%{_texmfdistdir}/tex/latex/jmb/jmb.sty

%package -n texlive-jmlr
Version:        %{texlive_version}.%{texlive_noarch}.1.30svn61957
Release:        0
License:        LPPL-1.0
Summary:        Class files for the Journal of Machine Learning Research
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jmlr-doc >= %{texlive_version}
Provides:       tex(jmlr.cls)
Provides:       tex(jmlrbook.cls)
Provides:       tex(jmlrutils.sty)
Requires:       tex(algorithm2e.sty)
Requires:       tex(aliascnt.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(article.cls)
Requires:       tex(calc.sty)
Requires:       tex(cleveref.sty)
Requires:       tex(combnat.sty)
Requires:       tex(currfile.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(fink.sty)
Requires:       tex(glyphtounicode-cmr.tex)
Requires:       tex(glyphtounicode.tex)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(nameref.sty)
Requires:       tex(natbib.sty)
Requires:       tex(placeins.sty)
Requires:       tex(setspace.sty)
Requires:       tex(url.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xmpincl.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source74:       jmlr.tar.xz
Source75:       jmlr.doc.tar.xz

%description -n texlive-jmlr
The jmlr bundle provides a class for authors (jmlr) and a class
for production editors (jmlrbook). The jmlrbook class can be
used to combine articles written using the jmlr class into a
book. The class uses the combine class and the hyperref package
to produce either a colour hyperlinked book for on-line viewing
or a greyscale nonhyperlinked book for printing. Production
editors can use makejmlrbookgui to help build the proceedings
from the articles.

%package -n texlive-jmlr-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.30svn61957
Release:        0
Summary:        Documentation for texlive-jmlr
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jmlr and texlive-alldocumentation)

%description -n texlive-jmlr-doc
This package includes the documentation for texlive-jmlr

%post -n texlive-jmlr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jmlr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jmlr
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jmlr-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jmlr/CHANGES
%{_texmfdistdir}/doc/latex/jmlr/README
%{_texmfdistdir}/doc/latex/jmlr/example-teximage.tex
%{_texmfdistdir}/doc/latex/jmlr/jmlr.pdf
%{_texmfdistdir}/doc/latex/jmlr/pmlr-sample.bib
%{_texmfdistdir}/doc/latex/jmlr/pmlr-sample.pdf
%{_texmfdistdir}/doc/latex/jmlr/pmlr-sample.tex

%files -n texlive-jmlr
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jmlr/jmlr.cls
%{_texmfdistdir}/tex/latex/jmlr/jmlrbook.cls
%{_texmfdistdir}/tex/latex/jmlr/jmlrutils.sty

%package -n texlive-jmn
Version:        %{texlive_version}.%{texlive_noarch}.svn45751
Release:        0
License:        LPPL-1.0
Summary:        Special fonts for ConTeXt
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-jmn-fonts >= %{texlive_version}
Provides:       tex(hans-sh.tfm)
Provides:       tex(hans.enc)
Provides:       tex(hans.map)
Provides:       tex(hans.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source76:       jmn.tar.xz

%description -n texlive-jmn
The jmn package

%package -n texlive-jmn-fonts
Version:        %{texlive_version}.%{texlive_noarch}.svn45751
Release:        0
Summary:        Severed fonts for texlive-jmn
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-jmn-fonts
The  separated fonts package for texlive-jmn

%post -n texlive-jmn
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jmn
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jmn
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-jmn-fonts

%files -n texlive-jmn
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/jmn/hans/hans-sh.afm
%{_texmfdistdir}/fonts/afm/jmn/hans/hans.afm
%{_texmfdistdir}/fonts/enc/dvips/jmn/hans.enc
%{_texmfdistdir}/fonts/map/dvips/jmn/hans.map
%{_texmfdistdir}/fonts/tfm/jmn/hans/hans-sh.tfm
%{_texmfdistdir}/fonts/tfm/jmn/hans/hans.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/jmn/hans/hans-sh.pfb
%{_texmfdistdir}/fonts/type1/jmn/hans/hans-sh.pfm
%verify(link) %{_texmfdistdir}/fonts/type1/jmn/hans/hans.pfb
%{_texmfdistdir}/fonts/type1/jmn/hans/hans.pfm

%files -n texlive-jmn-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-jmn
%{_datadir}/fontconfig/conf.avail/58-texlive-jmn.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-jmn/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-jmn/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-jmn/fonts.scale
%{_datadir}/fonts/texlive-jmn/hans-sh.pfb
%{_datadir}/fonts/texlive-jmn/hans.pfb

%package -n texlive-jmsdelim
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2.0svn62630
Release:        0
License:        LPPL-1.0
Summary:        A package for compositional delimiter sizing
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jmsdelim-doc >= %{texlive_version}
Provides:       tex(jmsdelim.sty)
Requires:       tex(expl3.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(scalerel.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source77:       jmsdelim.tar.xz
Source78:       jmsdelim.doc.tar.xz

%description -n texlive-jmsdelim
Correctly sizing delimiters is very difficult, particularly in
well-architected documents: a correctly engineered mathematical
document will include macros for all operations, and these
macros necessarily will include delimiters (such as
parentheses). However, the correct size for the delimiter
cannot be chosen ahead of time, because it will depend on the
arguments; two options are available: Provide optional
arguments to each notation macro for choosing delimiter sizes.
This is nearly intractable to do in practice. Ignore delimiter
sizes. With jmsdelim we offer an alternative: the correct
delimiter sizes can be set at the leaf nodes of a mathematical
expression, and magically bubble upward through the delimiters.

%package -n texlive-jmsdelim-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2.0svn62630
Release:        0
Summary:        Documentation for texlive-jmsdelim
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jmsdelim and texlive-alldocumentation)

%description -n texlive-jmsdelim-doc
This package includes the documentation for texlive-jmsdelim

%post -n texlive-jmsdelim
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jmsdelim
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jmsdelim
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jmsdelim-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jmsdelim/README.md
%{_texmfdistdir}/doc/latex/jmsdelim/jmsdelim.pdf
%{_texmfdistdir}/doc/latex/jmsdelim/refs.bib

%files -n texlive-jmsdelim
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jmsdelim/jmsdelim.sty

%package -n texlive-jneurosci
Version:        %{texlive_version}.%{texlive_noarch}.1.00svn17346
Release:        0
License:        LPPL-1.0
Summary:        BibTeX style for the Journal of Neuroscience
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jneurosci-doc >= %{texlive_version}
Provides:       tex(jneurosci.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source79:       jneurosci.tar.xz
Source80:       jneurosci.doc.tar.xz

%description -n texlive-jneurosci
This is a slightly modified version of the namedplus style,
which fully conforms with the Journal of Neuroscience citation
style. It should be characterised as an author-date citation
style; a BibTeX style and a LaTeX package are provided.

%package -n texlive-jneurosci-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.00svn17346
Release:        0
Summary:        Documentation for texlive-jneurosci
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jneurosci and texlive-alldocumentation)

%description -n texlive-jneurosci-doc
This package includes the documentation for texlive-jneurosci

%post -n texlive-jneurosci
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jneurosci
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jneurosci
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jneurosci-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jneurosci/README
%{_texmfdistdir}/doc/latex/jneurosci/jneurosci.pdf
%{_texmfdistdir}/doc/latex/jneurosci/jneurosci.tex

%files -n texlive-jneurosci
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/jneurosci/jneurosci.bst
%{_texmfdistdir}/tex/latex/jneurosci/jneurosci.sty

%package -n texlive-jnuexam
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn56867
Release:        0
License:        LPPL-1.0
Summary:        Exam class for Jinan University
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jnuexam-doc >= %{texlive_version}
Provides:       tex(jnuexam.cls)
Requires:       tex(CJKfntef.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(calc.sty)
Requires:       tex(cellspace.sty)
Requires:       tex(comment.sty)
Requires:       tex(ctexart.cls)
Requires:       tex(diagbox.sty)
Requires:       tex(environ.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(everypage.sty)
Requires:       tex(extarrows.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(geometry.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(iftex.sty)
Requires:       tex(lastpage.sty)
Requires:       tex(mathdesign.sty)
Requires:       tex(multirow.sty)
Requires:       tex(pdfpages.sty)
Requires:       tex(relsize.sty)
Requires:       tex(tabu.sty)
Requires:       tex(tabularx.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(zref-savepos.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source81:       jnuexam.tar.xz
Source82:       jnuexam.doc.tar.xz

%description -n texlive-jnuexam
The package provides an exam class for Jinan University
(China).

%package -n texlive-jnuexam-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn56867
Release:        0
Summary:        Documentation for texlive-jnuexam
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jnuexam and texlive-alldocumentation)
Provides:       locale(texlive-jnuexam-doc:zh)

%description -n texlive-jnuexam-doc
This package includes the documentation for texlive-jnuexam

%post -n texlive-jnuexam
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jnuexam
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jnuexam
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jnuexam-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jnuexam/README
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-a3input.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-a3input.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-a3split.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-a3split.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-empty.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-a-empty.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-a.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-a.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-a3input.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-a3input.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-a3split.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-a3split.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-empty.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-b-empty.tex
%{_texmfdistdir}/doc/latex/jnuexam/exam-b.pdf
%{_texmfdistdir}/doc/latex/jnuexam/exam-b.tex
%{_texmfdistdir}/doc/latex/jnuexam/jnuexam.pdf
%{_texmfdistdir}/doc/latex/jnuexam/jnuexam.tex

%files -n texlive-jnuexam
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jnuexam/jnuexam.cls

%package -n texlive-jobname-suffix
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn64797
Release:        0
License:        LPPL-1.0
Summary:        Compile differently based on the filename
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jobname-suffix-doc >= %{texlive_version}
Provides:       tex(jobname-suffix.sty)
Requires:       tex(expl3.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source83:       jobname-suffix.tar.xz
Source84:       jobname-suffix.doc.tar.xz

%description -n texlive-jobname-suffix
This package allows to compile a document differently depending
on the portion of the document's file name (internally, the
\jobname) that comes after the first "-" character. This allows
one to have one source file and multiple links to this source
file that each compile differently.

%package -n texlive-jobname-suffix-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn64797
Release:        0
Summary:        Documentation for texlive-jobname-suffix
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jobname-suffix and texlive-alldocumentation)

%description -n texlive-jobname-suffix-doc
This package includes the documentation for texlive-jobname-suffix

%post -n texlive-jobname-suffix
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jobname-suffix
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jobname-suffix
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jobname-suffix-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jobname-suffix/README.md
%{_texmfdistdir}/doc/latex/jobname-suffix/jobname-suffix.pdf
%{_texmfdistdir}/doc/latex/jobname-suffix/jobname-suffix.tex

%files -n texlive-jobname-suffix
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jobname-suffix/jobname-suffix.sty

%package -n texlive-josefin
Version:        %{texlive_version}.%{texlive_noarch}.svn64569
Release:        0
License:        OFL-1.1
Summary:        Josefin fonts with LaTeX support
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-josefin-fonts >= %{texlive_version}
Suggests:       texlive-josefin-doc >= %{texlive_version}
Provides:       tex(JosefinSans-Bold-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Bold-lf-ly1.tfm)
Provides:       tex(JosefinSans-Bold-lf-ly1.vf)
Provides:       tex(JosefinSans-Bold-lf-ot1.tfm)
Provides:       tex(JosefinSans-Bold-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Bold-lf-t1.tfm)
Provides:       tex(JosefinSans-Bold-lf-t1.vf)
Provides:       tex(JosefinSans-Bold-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Bold-lf-ts1.tfm)
Provides:       tex(JosefinSans-Bold-lf-ts1.vf)
Provides:       tex(JosefinSans-BoldItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-BoldItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-t1.vf)
Provides:       tex(JosefinSans-BoldItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-BoldItalic-lf-ts1.vf)
Provides:       tex(JosefinSans-ExtraLight-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-ly1.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-ly1.vf)
Provides:       tex(JosefinSans-ExtraLight-lf-ot1.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-t1--base.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-t1.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-t1.vf)
Provides:       tex(JosefinSans-ExtraLight-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-ts1.tfm)
Provides:       tex(JosefinSans-ExtraLight-lf-ts1.vf)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-t1.vf)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-ExtraLightItalic-lf-ts1.vf)
Provides:       tex(JosefinSans-Italic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Italic-lf-ly1.tfm)
Provides:       tex(JosefinSans-Italic-lf-ly1.vf)
Provides:       tex(JosefinSans-Italic-lf-ot1.tfm)
Provides:       tex(JosefinSans-Italic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Italic-lf-t1.tfm)
Provides:       tex(JosefinSans-Italic-lf-t1.vf)
Provides:       tex(JosefinSans-Italic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Italic-lf-ts1.tfm)
Provides:       tex(JosefinSans-Italic-lf-ts1.vf)
Provides:       tex(JosefinSans-Light-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Light-lf-ly1.tfm)
Provides:       tex(JosefinSans-Light-lf-ly1.vf)
Provides:       tex(JosefinSans-Light-lf-ot1.tfm)
Provides:       tex(JosefinSans-Light-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Light-lf-t1.tfm)
Provides:       tex(JosefinSans-Light-lf-t1.vf)
Provides:       tex(JosefinSans-Light-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Light-lf-ts1.tfm)
Provides:       tex(JosefinSans-Light-lf-ts1.vf)
Provides:       tex(JosefinSans-LightItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-LightItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-t1.vf)
Provides:       tex(JosefinSans-LightItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-LightItalic-lf-ts1.vf)
Provides:       tex(JosefinSans-Medium-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Medium-lf-ly1.tfm)
Provides:       tex(JosefinSans-Medium-lf-ly1.vf)
Provides:       tex(JosefinSans-Medium-lf-ot1.tfm)
Provides:       tex(JosefinSans-Medium-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Medium-lf-t1.tfm)
Provides:       tex(JosefinSans-Medium-lf-t1.vf)
Provides:       tex(JosefinSans-Medium-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Medium-lf-ts1.tfm)
Provides:       tex(JosefinSans-Medium-lf-ts1.vf)
Provides:       tex(JosefinSans-MediumItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-MediumItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-t1.vf)
Provides:       tex(JosefinSans-MediumItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-MediumItalic-lf-ts1.vf)
Provides:       tex(JosefinSans-Regular-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Regular-lf-ly1.tfm)
Provides:       tex(JosefinSans-Regular-lf-ly1.vf)
Provides:       tex(JosefinSans-Regular-lf-ot1.tfm)
Provides:       tex(JosefinSans-Regular-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Regular-lf-t1.tfm)
Provides:       tex(JosefinSans-Regular-lf-t1.vf)
Provides:       tex(JosefinSans-Regular-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Regular-lf-ts1.tfm)
Provides:       tex(JosefinSans-Regular-lf-ts1.vf)
Provides:       tex(JosefinSans-SemiBold-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-ly1.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-ly1.vf)
Provides:       tex(JosefinSans-SemiBold-lf-ot1.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-t1--base.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-t1.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-t1.vf)
Provides:       tex(JosefinSans-SemiBold-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-ts1.tfm)
Provides:       tex(JosefinSans-SemiBold-lf-ts1.vf)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-t1.vf)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-SemiBoldItalic-lf-ts1.vf)
Provides:       tex(JosefinSans-Thin-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-Thin-lf-ly1.tfm)
Provides:       tex(JosefinSans-Thin-lf-ly1.vf)
Provides:       tex(JosefinSans-Thin-lf-ot1.tfm)
Provides:       tex(JosefinSans-Thin-lf-t1--base.tfm)
Provides:       tex(JosefinSans-Thin-lf-t1.tfm)
Provides:       tex(JosefinSans-Thin-lf-t1.vf)
Provides:       tex(JosefinSans-Thin-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-Thin-lf-ts1.tfm)
Provides:       tex(JosefinSans-Thin-lf-ts1.vf)
Provides:       tex(JosefinSans-ThinItalic-lf-ly1--base.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-ly1.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-ly1.vf)
Provides:       tex(JosefinSans-ThinItalic-lf-ot1.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-t1--base.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-t1.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-t1.vf)
Provides:       tex(JosefinSans-ThinItalic-lf-ts1--base.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-ts1.tfm)
Provides:       tex(JosefinSans-ThinItalic-lf-ts1.vf)
Provides:       tex(LY1JosefinSans-LF.fd)
Provides:       tex(OT1JosefinSans-LF.fd)
Provides:       tex(T1JosefinSans-LF.fd)
Provides:       tex(TS1JosefinSans-LF.fd)
Provides:       tex(jfn_2p3jiy.enc)
Provides:       tex(jfn_adz5lu.enc)
Provides:       tex(jfn_d2anrk.enc)
Provides:       tex(jfn_ehgfhq.enc)
Provides:       tex(jfn_hf4msv.enc)
Provides:       tex(jfn_ti63qo.enc)
Provides:       tex(jfn_umrhwx.enc)
Provides:       tex(jfn_w4rwtq.enc)
Provides:       tex(josefin.map)
Provides:       tex(josefin.sty)
Requires:       tex(fontaxes.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source85:       josefin.tar.xz
Source86:       josefin.doc.tar.xz

%description -n texlive-josefin
This package provides LaTeX, pdfLaTeX, XeLaTeX and LuaLaTeX
support for the Josefin Sans family of fonts, designed by
Santiago Orozco of the Typemade foundry in Monterey, Mexico.
Josefin Sans is available in seven weights, with corresponding
italics.

%package -n texlive-josefin-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn64569
Release:        0
Summary:        Documentation for texlive-josefin
License:        OFL-1.1
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-josefin and texlive-alldocumentation)

%description -n texlive-josefin-doc
This package includes the documentation for texlive-josefin

%package -n texlive-josefin-fonts
Version:        %{texlive_version}.%{texlive_noarch}.svn64569
Release:        0
Summary:        Severed fonts for texlive-josefin
License:        OFL-1.1
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-josefin-fonts
The  separated fonts package for texlive-josefin

%post -n texlive-josefin
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap josefin.map' >> /var/run/texlive/run-updmap

%postun -n texlive-josefin
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap josefin.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-josefin
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-josefin-fonts

%files -n texlive-josefin-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/josefin/OFL.txt
%{_texmfdistdir}/doc/fonts/josefin/README
%{_texmfdistdir}/doc/fonts/josefin/josefin-samples.pdf
%{_texmfdistdir}/doc/fonts/josefin/josefin-samples.tex

%files -n texlive-josefin
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_2p3jiy.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_adz5lu.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_d2anrk.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_ehgfhq.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_hf4msv.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_ti63qo.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_umrhwx.enc
%{_texmfdistdir}/fonts/enc/dvips/josefin/jfn_w4rwtq.enc
%{_texmfdistdir}/fonts/map/dvips/josefin/josefin.map
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Bold-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-BoldItalic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLight-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ExtraLightItalic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Italic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Light-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-LightItalic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Medium-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-MediumItalic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Regular-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBold-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-SemiBoldItalic-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-Thin-lf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/josefin/JosefinSans-ThinItalic-lf-ts1.tfm
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Bold.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-BoldItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-ExtraLight.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-ExtraLightItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Italic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Light.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-LightItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Medium.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-MediumItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Regular.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-SemiBold.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-SemiBoldItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-Thin.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/josefin/JosefinSans-ThinItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Bold.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-BoldItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-ExtraLight.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-ExtraLightItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Italic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Light.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-LightItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Medium.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-MediumItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Regular.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-SemiBold.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-SemiBoldItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-Thin.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/josefin/JosefinSans-ThinItalic.pfb
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Bold-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Bold-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Bold-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-BoldItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-BoldItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-BoldItalic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLight-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLight-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLight-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLightItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLightItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ExtraLightItalic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Italic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Italic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Italic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Light-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Light-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Light-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-LightItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-LightItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-LightItalic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Medium-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Medium-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Medium-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-MediumItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-MediumItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-MediumItalic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Regular-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Regular-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Regular-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBold-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBold-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBold-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBoldItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBoldItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-SemiBoldItalic-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Thin-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Thin-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-Thin-lf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ThinItalic-lf-ly1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ThinItalic-lf-t1.vf
%{_texmfdistdir}/fonts/vf/public/josefin/JosefinSans-ThinItalic-lf-ts1.vf
%{_texmfdistdir}/tex/latex/josefin/LY1JosefinSans-LF.fd
%{_texmfdistdir}/tex/latex/josefin/OT1JosefinSans-LF.fd
%{_texmfdistdir}/tex/latex/josefin/T1JosefinSans-LF.fd
%{_texmfdistdir}/tex/latex/josefin/TS1JosefinSans-LF.fd
%{_texmfdistdir}/tex/latex/josefin/josefin.sty

%files -n texlive-josefin-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-josefin
%{_datadir}/fontconfig/conf.avail/58-texlive-josefin.conf
%{_datadir}/fontconfig/conf.avail/55-texlive-josefin.conf
%config %{_sysconfdir}/fonts/conf.d/55-texlive-josefin.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-josefin/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-josefin/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-josefin/fonts.scale
%{_datadir}/fonts/texlive-josefin/JosefinSans-Bold.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-BoldItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-ExtraLight.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-ExtraLightItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Italic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Light.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-LightItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Medium.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-MediumItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Regular.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-SemiBold.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-SemiBoldItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Thin.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-ThinItalic.ttf
%{_datadir}/fonts/texlive-josefin/JosefinSans-Bold.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-BoldItalic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-ExtraLight.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-ExtraLightItalic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-Italic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-Light.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-LightItalic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-Medium.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-MediumItalic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-Regular.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-SemiBold.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-SemiBoldItalic.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-Thin.pfb
%{_datadir}/fonts/texlive-josefin/JosefinSans-ThinItalic.pfb

%package -n texlive-jourcl
Version:        %{texlive_version}.%{texlive_noarch}.svn65290
Release:        0
License:        LPPL-1.0
Summary:        Cover letter for journal submissions
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jourcl-doc >= %{texlive_version}
Provides:       tex(jourcl.cls)
Requires:       tex(article.cls)
Requires:       tex(babel.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(fontawesome5.sty)
Requires:       tex(framed.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(isodate.sty)
Requires:       tex(lipsum.sty)
Requires:       tex(orcidlink.sty)
Requires:       tex(parskip.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source87:       jourcl.tar.xz
Source88:       jourcl.doc.tar.xz

%description -n texlive-jourcl
Paper submissions to journals are usually accompanied by a
cover letter. This package provides a LaTeX class and a
template for such a cover letter with the following main
features: Minimalistic design. Custom image. Pre-defined
commands for journal name, author, date, etc. Many macros
contained in this package speed up the process of preparing the
necessary ingredients for the cover letter. Macros for
recommending up to three reviewers and/or editors. ORCID logo
and link to the submitting author's ORCID page. Controls for
adding a "Conflict of interest" statement and declaration.
Custom greeting (e.g., "Dear Editor" for a regular submission,
"Dear Editor-in-Chief" for a submission to a journal's special
issue, etc.) Predefined valedictions for different types of
submissions (e.g., Yours sincerely, Yours faithfully, Best
regards, etc.)

%package -n texlive-jourcl-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65290
Release:        0
Summary:        Documentation for texlive-jourcl
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jourcl and texlive-alldocumentation)

%description -n texlive-jourcl-doc
This package includes the documentation for texlive-jourcl

%post -n texlive-jourcl
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jourcl
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jourcl
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jourcl-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jourcl/LICENSE
%{_texmfdistdir}/doc/latex/jourcl/README.md
%{_texmfdistdir}/doc/latex/jourcl/imgs/jourcl-logo.png
%{_texmfdistdir}/doc/latex/jourcl/imgs/jourcl-signature.png
%{_texmfdistdir}/doc/latex/jourcl/jourcl.pdf
%{_texmfdistdir}/doc/latex/jourcl/jourcl.tex

%files -n texlive-jourcl
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jourcl/jourcl.cls

%package -n texlive-jpneduenumerate
Version:        %{texlive_version}.%{texlive_noarch}.1.2svn63893
Release:        0
License:        LPPL-1.0
Summary:        Enumerative expressions in Japanese education
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jpneduenumerate-doc >= %{texlive_version}
Provides:       tex(jpneduenumerate.sty)
Requires:       tex(enumitem.sty)
Requires:       tex(luatexja-otf.sty)
Requires:       tex(otf.sty)
Requires:       tex(refcount.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source89:       jpneduenumerate.tar.xz
Source90:       jpneduenumerate.doc.tar.xz

%description -n texlive-jpneduenumerate
Mathematical equation representation in Japanese education
differs somewhat from the standard LaTeX writing style. This
package introduces enumerative expressions in Japanese
education.

%package -n texlive-jpneduenumerate-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.2svn63893
Release:        0
Summary:        Documentation for texlive-jpneduenumerate
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jpneduenumerate and texlive-alldocumentation)
Provides:       locale(texlive-jpneduenumerate-doc:en,ja)

%description -n texlive-jpneduenumerate-doc
This package includes the documentation for texlive-jpneduenumerate

%post -n texlive-jpneduenumerate
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jpneduenumerate
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jpneduenumerate
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jpneduenumerate-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jpneduenumerate/README.md
%{_texmfdistdir}/doc/latex/jpneduenumerate/jpneduenumerate.pdf
%{_texmfdistdir}/doc/latex/jpneduenumerate/jpneduenumerate.tex

%files -n texlive-jpneduenumerate
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jpneduenumerate/jpneduenumerate.sty

%package -n texlive-jpnedumathsymbols
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn63864
Release:        0
License:        LPPL-1.0
Summary:        Mathematical equation representation in Japanese education
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jpnedumathsymbols-doc >= %{texlive_version}
Provides:       tex(jpnedumathsymbols.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(empheq.sty)
Requires:       tex(luatexja-otf.sty)
Requires:       tex(otf.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source91:       jpnedumathsymbols.tar.xz
Source92:       jpnedumathsymbols.doc.tar.xz

%description -n texlive-jpnedumathsymbols
Mathematical equation representation in Japanese education
differs somewhat from the standard LaTeX writing style. This
package introduces mathematical equation representation in
Japanese education.

%package -n texlive-jpnedumathsymbols-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn63864
Release:        0
Summary:        Documentation for texlive-jpnedumathsymbols
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jpnedumathsymbols and texlive-alldocumentation)
Provides:       locale(texlive-jpnedumathsymbols-doc:en,ja)

%description -n texlive-jpnedumathsymbols-doc
This package includes the documentation for texlive-jpnedumathsymbols

%post -n texlive-jpnedumathsymbols
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jpnedumathsymbols
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jpnedumathsymbols
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jpnedumathsymbols-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jpnedumathsymbols/README.md
%{_texmfdistdir}/doc/latex/jpnedumathsymbols/jpnedumathsymbols.pdf
%{_texmfdistdir}/doc/latex/jpnedumathsymbols/jpnedumathsymbols.tex

%files -n texlive-jpnedumathsymbols
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jpnedumathsymbols/jpnedumathsymbols.sty

%package -n texlive-jpsj
Version:        %{texlive_version}.%{texlive_noarch}.1.2.2svn66115
Release:        0
License:        LPPL-1.0
Summary:        Document Class for Journal of the Physical Society of Japan
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jpsj-doc >= %{texlive_version}
Provides:       tex(jpsj2.cls)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(overcite.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source93:       jpsj.tar.xz
Source94:       jpsj.doc.tar.xz

%description -n texlive-jpsj
The jpsj package

%package -n texlive-jpsj-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.2.2svn66115
Release:        0
Summary:        Documentation for texlive-jpsj
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jpsj and texlive-alldocumentation)

%description -n texlive-jpsj-doc
This package includes the documentation for texlive-jpsj

%post -n texlive-jpsj
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jpsj
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jpsj
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jpsj-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jpsj/dummy.eps
%{_texmfdistdir}/doc/latex/jpsj/injpsj2.pdf
%{_texmfdistdir}/doc/latex/jpsj/injpsj2.tex
%{_texmfdistdir}/doc/latex/jpsj/template.tex

%files -n texlive-jpsj
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jpsj/jpsj2.cls

%package -n texlive-js-misc
Version:        %{texlive_version}.%{texlive_noarch}.svn16211
Release:        0
License:        SUSE-Public-Domain
Summary:        Miscellaneous macros from Joachim Schrod
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-js-misc-doc >= %{texlive_version}
Provides:       tex(cassette.tex)
Provides:       tex(idverb.tex)
Provides:       tex(js-misc.tex)
Provides:       tex(schild.tex)
Provides:       tex(sperr.tex)
Provides:       tex(xfig.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source95:       js-misc.tar.xz
Source96:       js-misc.doc.tar.xz

%description -n texlive-js-misc
A bunch of packages, including: idverb.tex, for 'short
verbatim'; xfig.tex, for including xfig/transfig output in a
TeX document; and cassette.tex for setting cassette labels.

%package -n texlive-js-misc-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn16211
Release:        0
Summary:        Documentation for texlive-js-misc
License:        SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-js-misc and texlive-alldocumentation)

%description -n texlive-js-misc-doc
This package includes the documentation for texlive-js-misc

%post -n texlive-js-misc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-js-misc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-js-misc
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-js-misc-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/plain/js-misc/History
%{_texmfdistdir}/doc/plain/js-misc/INSTALL
%{_texmfdistdir}/doc/plain/js-misc/Imakefile
%{_texmfdistdir}/doc/plain/js-misc/License
%{_texmfdistdir}/doc/plain/js-misc/Makefile
%{_texmfdistdir}/doc/plain/js-misc/README
%{_texmfdistdir}/doc/plain/js-misc/TODO
%{_texmfdistdir}/doc/plain/js-misc/deutsch.doc
%{_texmfdistdir}/doc/plain/js-misc/deutsch.tex
%{_texmfdistdir}/doc/plain/js-misc/idverb.doc
%{_texmfdistdir}/doc/plain/js-misc/names.sty
%{_texmfdistdir}/doc/plain/js-misc/xfig/text-2.1-doc.tex
%{_texmfdistdir}/doc/plain/js-misc/xfig/text-2.1.fig
%{_texmfdistdir}/doc/plain/js-misc/xfig/text-2.1.latex
%{_texmfdistdir}/doc/plain/js-misc/xfig/text-3.1-doc.tex
%{_texmfdistdir}/doc/plain/js-misc/xfig/text-3.1.latex

%files -n texlive-js-misc
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/plain/js-misc/cassette.tex
%{_texmfdistdir}/tex/plain/js-misc/idverb.tex
%{_texmfdistdir}/tex/plain/js-misc/js-misc.tex
%{_texmfdistdir}/tex/plain/js-misc/schild.tex
%{_texmfdistdir}/tex/plain/js-misc/sperr.tex
%{_texmfdistdir}/tex/plain/js-misc/xfig.tex

%package -n texlive-jsclasses
Version:        %{texlive_version}.%{texlive_noarch}.svn66093
Release:        0
License:        BSD-3-Clause
Summary:        Classes tailored for use with Japanese
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jsclasses-doc >= %{texlive_version}
Provides:       tex(jsarticle.cls)
Provides:       tex(jsbook.cls)
Provides:       tex(jslogo.sty)
Provides:       tex(jspf.cls)
Provides:       tex(jsreport.cls)
Provides:       tex(jsverb.sty)
Provides:       tex(kiyou.cls)
Provides:       tex(minijs.sty)
Provides:       tex(okumacro.sty)
Provides:       tex(okuverb.sty)
Requires:       tex(ts1enc.def)
Requires:       tex(type1cm.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source97:       jsclasses.tar.xz
Source98:       jsclasses.doc.tar.xz

%description -n texlive-jsclasses
Classes jsarticle and jsbook are provided, together with
packages okumacro and okuverb. These classes are designed to
work under ASCII Corporation's Japanese TeX system ptex.

%package -n texlive-jsclasses-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66093
Release:        0
Summary:        Documentation for texlive-jsclasses
License:        BSD-3-Clause
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jsclasses and texlive-alldocumentation)
Provides:       locale(texlive-jsclasses-doc:ja)

%description -n texlive-jsclasses-doc
This package includes the documentation for texlive-jsclasses

%post -n texlive-jsclasses
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jsclasses
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jsclasses
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jsclasses-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/platex/jsclasses/LICENSE
%{_texmfdistdir}/doc/platex/jsclasses/README.md
%{_texmfdistdir}/doc/platex/jsclasses/jsclasses.pdf
%{_texmfdistdir}/doc/platex/jsclasses/jslogo.pdf
%{_texmfdistdir}/doc/platex/jsclasses/jsverb.pdf
%{_texmfdistdir}/doc/platex/jsclasses/okumacro.pdf
%{_texmfdistdir}/doc/platex/jsclasses/okuverb.pdf

%files -n texlive-jsclasses
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/platex/jsclasses/jsarticle.cls
%{_texmfdistdir}/tex/platex/jsclasses/jsbook.cls
%{_texmfdistdir}/tex/platex/jsclasses/jslogo.sty
%{_texmfdistdir}/tex/platex/jsclasses/jspf.cls
%{_texmfdistdir}/tex/platex/jsclasses/jsreport.cls
%{_texmfdistdir}/tex/platex/jsclasses/jsverb.sty
%{_texmfdistdir}/tex/platex/jsclasses/kiyou.cls
%{_texmfdistdir}/tex/platex/jsclasses/minijs.sty
%{_texmfdistdir}/tex/platex/jsclasses/okumacro.sty
%{_texmfdistdir}/tex/platex/jsclasses/okuverb.sty

%package -n texlive-jslectureplanner
Version:        %{texlive_version}.%{texlive_noarch}.1.12svn57095
Release:        0
License:        LPPL-1.0
Summary:        Creation and management of university course material
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jslectureplanner-doc >= %{texlive_version}
Provides:       tex(jslectureplanner.sty)
Provides:       tex(jsmembertable.sty)
Requires:       tex(array.sty)
Requires:       tex(calc.sty)
Requires:       tex(datatool.sty)
Requires:       tex(datetime2.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(hhline.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(longtable.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source99:       jslectureplanner.tar.xz
Source100:      jslectureplanner.doc.tar.xz

%description -n texlive-jslectureplanner
The jslectureplanner package facilitates the generation and
management of university course material. It provides an
interface to set up and access centralized course data that can
be reused in all course documents. Furthermore, the package is
able to calculate the session dates of a whole semester and
generate course programs, if the course is held weekly and the
date of the first lecture is specified. Moreover, the package
can be used to generate a sectioned course bibliography via
BibLaTeX. The bundle also includes a package jsmembertable.sty
that helps in generating course member and presence lists.

%package -n texlive-jslectureplanner-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.12svn57095
Release:        0
Summary:        Documentation for texlive-jslectureplanner
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jslectureplanner and texlive-alldocumentation)

%description -n texlive-jslectureplanner-doc
This package includes the documentation for texlive-jslectureplanner

%post -n texlive-jslectureplanner
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jslectureplanner
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jslectureplanner
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jslectureplanner-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jslectureplanner/README
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecpresbody-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturebib-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturebib-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturehandout-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturehandout-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lectureplanner-examples.bib
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturepresentation-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturepresentation-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lectureprogram-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lectureprogram-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturescript-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/lecturescript-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/membertable-blank-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/membertable-blank-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/membertable-filled-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/membertable-filled-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/metadata.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presencetable-blank-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presencetable-blank-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presencetable-filled-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presencetable-filled-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presentation-list-english.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/presentation-list-english.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English/students.csv
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecpresbody.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturebib.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturebib.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturehandout.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturehandout.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lectureplanner-examples.bib
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturepresentation.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturepresentation.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lectureprogram.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lectureprogram.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturescript.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/lecturescript.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/membertable-blank.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/membertable-blank.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/membertable-filled.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/membertable-filled.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/metadata.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presencetable-blank.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presencetable-blank.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presencetable-filled.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presencetable-filled.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presentation-list.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/presentation-list.tex
%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German/students.csv
%{_texmfdistdir}/doc/latex/jslectureplanner/jslectureplanner.pdf
%{_texmfdistdir}/doc/latex/jslectureplanner/jslectureplanner.tex

%files -n texlive-jslectureplanner
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jslectureplanner/cologne.lps
%{_texmfdistdir}/tex/latex/jslectureplanner/english.lps
%{_texmfdistdir}/tex/latex/jslectureplanner/german-default.lps
%{_texmfdistdir}/tex/latex/jslectureplanner/jslectureplanner.sty
%{_texmfdistdir}/tex/latex/jslectureplanner/jsmembertable.sty

%package -n texlive-jumplines
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2svn37553
Release:        0
License:        LPPL-1.0
Summary:        Articles with teasers and continuation later on
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jumplines-doc >= %{texlive_version}
Provides:       tex(jumplines.sty)
Requires:       tex(babel.sty)
Requires:       tex(bookmark.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(luacolor.sty)
Requires:       tex(tcolorbox.sty)
Requires:       tex(tocloft.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source101:      jumplines.tar.xz
Source102:      jumplines.doc.tar.xz

%description -n texlive-jumplines
Jumplines is a package for typesetting (newspaper) articles
that show a teaser (some few lines of text/content) and are
continued at a later place, with optional hyperlinking and a
list of articles. It requires lualatex for colour support in
split boxes.

%package -n texlive-jumplines-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2svn37553
Release:        0
Summary:        Documentation for texlive-jumplines
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jumplines and texlive-alldocumentation)

%description -n texlive-jumplines-doc
This package includes the documentation for texlive-jumplines

%post -n texlive-jumplines
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jumplines
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jumplines
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jumplines-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jumplines/README
%{_texmfdistdir}/doc/latex/jumplines/jumplines_doc.pdf
%{_texmfdistdir}/doc/latex/jumplines/jumplines_doc.tex
%{_texmfdistdir}/doc/latex/jumplines/jumplines_example.pdf
%{_texmfdistdir}/doc/latex/jumplines/jumplines_example.tex

%files -n texlive-jumplines
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jumplines/jumplines.sty

%package -n texlive-junicode
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn61719
Release:        0
License:        OFL-1.1
Summary:        A TrueType font for mediaevalists
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-junicode-fonts >= %{texlive_version}
Suggests:       texlive-junicode-doc >= %{texlive_version}
Provides:       tex(Junicode-Bold-sup-ly1.tfm)
Provides:       tex(Junicode-Bold-sup-ot1.tfm)
Provides:       tex(Junicode-Bold-sup-t1--base.tfm)
Provides:       tex(Junicode-Bold-sup-t1.tfm)
Provides:       tex(Junicode-Bold-sup-t1.vf)
Provides:       tex(Junicode-Bold-sup-t3--base.tfm)
Provides:       tex(Junicode-Bold-sup-t3.tfm)
Provides:       tex(Junicode-Bold-sup-t3.vf)
Provides:       tex(Junicode-Bold-sup-ts3.tfm)
Provides:       tex(Junicode-Bold-tlf-ly1.tfm)
Provides:       tex(Junicode-Bold-tlf-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-ot1.tfm)
Provides:       tex(Junicode-Bold-tlf-ot1.vf)
Provides:       tex(Junicode-Bold-tlf-sc-ly1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-ly1.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-ly1.vf)
Provides:       tex(Junicode-Bold-tlf-sc-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-ot1.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-ot1.vf)
Provides:       tex(Junicode-Bold-tlf-sc-t1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-t1.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-t1.vf)
Provides:       tex(Junicode-Bold-tlf-sc-t3--base.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-t3.tfm)
Provides:       tex(Junicode-Bold-tlf-sc-t3.vf)
Provides:       tex(Junicode-Bold-tlf-sc-ts3.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-ly1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-ly1.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-ly1.vf)
Provides:       tex(Junicode-Bold-tlf-swash-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-ot1.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-ot1.vf)
Provides:       tex(Junicode-Bold-tlf-swash-t1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-t1.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-t1.vf)
Provides:       tex(Junicode-Bold-tlf-swash-t3--base.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-t3.tfm)
Provides:       tex(Junicode-Bold-tlf-swash-t3.vf)
Provides:       tex(Junicode-Bold-tlf-swash-ts3.tfm)
Provides:       tex(Junicode-Bold-tlf-t1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-t1.tfm)
Provides:       tex(Junicode-Bold-tlf-t1.vf)
Provides:       tex(Junicode-Bold-tlf-t3--base.tfm)
Provides:       tex(Junicode-Bold-tlf-t3.tfm)
Provides:       tex(Junicode-Bold-tlf-t3.vf)
Provides:       tex(Junicode-Bold-tlf-ts1--base.tfm)
Provides:       tex(Junicode-Bold-tlf-ts1.tfm)
Provides:       tex(Junicode-Bold-tlf-ts1.vf)
Provides:       tex(Junicode-Bold-tlf-ts3.tfm)
Provides:       tex(Junicode-Bold-tosf-ly1.tfm)
Provides:       tex(Junicode-Bold-tosf-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-ot1.tfm)
Provides:       tex(Junicode-Bold-tosf-ot1.vf)
Provides:       tex(Junicode-Bold-tosf-sc-ly1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-ly1.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-ly1.vf)
Provides:       tex(Junicode-Bold-tosf-sc-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-ot1.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-ot1.vf)
Provides:       tex(Junicode-Bold-tosf-sc-t1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-t1.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-t1.vf)
Provides:       tex(Junicode-Bold-tosf-sc-t3--base.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-t3.tfm)
Provides:       tex(Junicode-Bold-tosf-sc-t3.vf)
Provides:       tex(Junicode-Bold-tosf-sc-ts3.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-ly1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-ly1.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-ly1.vf)
Provides:       tex(Junicode-Bold-tosf-swash-ot1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-ot1.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-ot1.vf)
Provides:       tex(Junicode-Bold-tosf-swash-t1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-t1.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-t1.vf)
Provides:       tex(Junicode-Bold-tosf-swash-t3--base.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-t3.tfm)
Provides:       tex(Junicode-Bold-tosf-swash-t3.vf)
Provides:       tex(Junicode-Bold-tosf-swash-ts3.tfm)
Provides:       tex(Junicode-Bold-tosf-t1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-t1.tfm)
Provides:       tex(Junicode-Bold-tosf-t1.vf)
Provides:       tex(Junicode-Bold-tosf-t3--base.tfm)
Provides:       tex(Junicode-Bold-tosf-t3.tfm)
Provides:       tex(Junicode-Bold-tosf-t3.vf)
Provides:       tex(Junicode-Bold-tosf-ts1--base.tfm)
Provides:       tex(Junicode-Bold-tosf-ts1.tfm)
Provides:       tex(Junicode-Bold-tosf-ts1.vf)
Provides:       tex(Junicode-Bold-tosf-ts3.tfm)
Provides:       tex(Junicode-BoldItalic-sup-ly1.tfm)
Provides:       tex(Junicode-BoldItalic-sup-ot1.tfm)
Provides:       tex(Junicode-BoldItalic-sup-t1--base.tfm)
Provides:       tex(Junicode-BoldItalic-sup-t1.tfm)
Provides:       tex(Junicode-BoldItalic-sup-t1.vf)
Provides:       tex(Junicode-BoldItalic-sup-t3--base.tfm)
Provides:       tex(Junicode-BoldItalic-sup-t3.tfm)
Provides:       tex(Junicode-BoldItalic-sup-t3.vf)
Provides:       tex(Junicode-BoldItalic-sup-ts3.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ly1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ot1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ot1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ot1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ly1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ly1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ly1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ot1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ot1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ot1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t3--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t3.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-swash-t3.vf)
Provides:       tex(Junicode-BoldItalic-tlf-swash-ts3.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-t1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-t1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-t1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-t3--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-t3.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-t3.vf)
Provides:       tex(Junicode-BoldItalic-tlf-ts1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ts1.tfm)
Provides:       tex(Junicode-BoldItalic-tlf-ts1.vf)
Provides:       tex(Junicode-BoldItalic-tlf-ts3.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ly1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ot1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ot1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ot1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ly1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ly1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ly1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ot1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ot1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ot1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t3--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t3.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-swash-t3.vf)
Provides:       tex(Junicode-BoldItalic-tosf-swash-ts3.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-t1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-t1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-t1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-t3--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-t3.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-t3.vf)
Provides:       tex(Junicode-BoldItalic-tosf-ts1--base.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ts1.tfm)
Provides:       tex(Junicode-BoldItalic-tosf-ts1.vf)
Provides:       tex(Junicode-BoldItalic-tosf-ts3.tfm)
Provides:       tex(Junicode-Italic-inf-ly1.tfm)
Provides:       tex(Junicode-Italic-inf-ot1.tfm)
Provides:       tex(Junicode-Italic-inf-t1--base.tfm)
Provides:       tex(Junicode-Italic-inf-t1.tfm)
Provides:       tex(Junicode-Italic-inf-t1.vf)
Provides:       tex(Junicode-Italic-inf-t3--base.tfm)
Provides:       tex(Junicode-Italic-inf-t3.tfm)
Provides:       tex(Junicode-Italic-inf-t3.vf)
Provides:       tex(Junicode-Italic-inf-ts3--base.tfm)
Provides:       tex(Junicode-Italic-inf-ts3.tfm)
Provides:       tex(Junicode-Italic-inf-ts3.vf)
Provides:       tex(Junicode-Italic-sup-ly1.tfm)
Provides:       tex(Junicode-Italic-sup-ot1.tfm)
Provides:       tex(Junicode-Italic-sup-t1--base.tfm)
Provides:       tex(Junicode-Italic-sup-t1.tfm)
Provides:       tex(Junicode-Italic-sup-t1.vf)
Provides:       tex(Junicode-Italic-sup-t3--base.tfm)
Provides:       tex(Junicode-Italic-sup-t3.tfm)
Provides:       tex(Junicode-Italic-sup-t3.vf)
Provides:       tex(Junicode-Italic-sup-ts3--base.tfm)
Provides:       tex(Junicode-Italic-sup-ts3.tfm)
Provides:       tex(Junicode-Italic-sup-ts3.vf)
Provides:       tex(Junicode-Italic-tlf-ly1.tfm)
Provides:       tex(Junicode-Italic-tlf-ot1.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ly1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ly1.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ly1.vf)
Provides:       tex(Junicode-Italic-tlf-sc-ot1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ot1.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ot1.vf)
Provides:       tex(Junicode-Italic-tlf-sc-t1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-t1.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-t1.vf)
Provides:       tex(Junicode-Italic-tlf-sc-t3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-t3.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-t3.vf)
Provides:       tex(Junicode-Italic-tlf-sc-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ts3.tfm)
Provides:       tex(Junicode-Italic-tlf-sc-ts3.vf)
Provides:       tex(Junicode-Italic-tlf-swash-ly1.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-ot1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-ot1.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-ot1.vf)
Provides:       tex(Junicode-Italic-tlf-swash-t1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-t1.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-t1.vf)
Provides:       tex(Junicode-Italic-tlf-swash-t3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-t3.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-t3.vf)
Provides:       tex(Junicode-Italic-tlf-swash-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-ts3.tfm)
Provides:       tex(Junicode-Italic-tlf-swash-ts3.vf)
Provides:       tex(Junicode-Italic-tlf-t1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-t1.tfm)
Provides:       tex(Junicode-Italic-tlf-t1.vf)
Provides:       tex(Junicode-Italic-tlf-t3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-t3.tfm)
Provides:       tex(Junicode-Italic-tlf-t3.vf)
Provides:       tex(Junicode-Italic-tlf-ts1--base.tfm)
Provides:       tex(Junicode-Italic-tlf-ts1.tfm)
Provides:       tex(Junicode-Italic-tlf-ts1.vf)
Provides:       tex(Junicode-Italic-tlf-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tlf-ts3.tfm)
Provides:       tex(Junicode-Italic-tlf-ts3.vf)
Provides:       tex(Junicode-Italic-tosf-ly1.tfm)
Provides:       tex(Junicode-Italic-tosf-ot1.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ly1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ly1.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ly1.vf)
Provides:       tex(Junicode-Italic-tosf-sc-ot1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ot1.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ot1.vf)
Provides:       tex(Junicode-Italic-tosf-sc-t1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-t1.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-t1.vf)
Provides:       tex(Junicode-Italic-tosf-sc-t3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-t3.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-t3.vf)
Provides:       tex(Junicode-Italic-tosf-sc-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ts3.tfm)
Provides:       tex(Junicode-Italic-tosf-sc-ts3.vf)
Provides:       tex(Junicode-Italic-tosf-swash-ly1.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-ot1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-ot1.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-ot1.vf)
Provides:       tex(Junicode-Italic-tosf-swash-t1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-t1.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-t1.vf)
Provides:       tex(Junicode-Italic-tosf-swash-t3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-t3.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-t3.vf)
Provides:       tex(Junicode-Italic-tosf-swash-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-ts3.tfm)
Provides:       tex(Junicode-Italic-tosf-swash-ts3.vf)
Provides:       tex(Junicode-Italic-tosf-t1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-t1.tfm)
Provides:       tex(Junicode-Italic-tosf-t1.vf)
Provides:       tex(Junicode-Italic-tosf-t3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-t3.tfm)
Provides:       tex(Junicode-Italic-tosf-t3.vf)
Provides:       tex(Junicode-Italic-tosf-ts1--base.tfm)
Provides:       tex(Junicode-Italic-tosf-ts1.tfm)
Provides:       tex(Junicode-Italic-tosf-ts1.vf)
Provides:       tex(Junicode-Italic-tosf-ts3--base.tfm)
Provides:       tex(Junicode-Italic-tosf-ts3.tfm)
Provides:       tex(Junicode-Italic-tosf-ts3.vf)
Provides:       tex(Junicode-inf-ly1.tfm)
Provides:       tex(Junicode-inf-ot1.tfm)
Provides:       tex(Junicode-inf-t1--base.tfm)
Provides:       tex(Junicode-inf-t1.tfm)
Provides:       tex(Junicode-inf-t1.vf)
Provides:       tex(Junicode-inf-t3--base.tfm)
Provides:       tex(Junicode-inf-t3.tfm)
Provides:       tex(Junicode-inf-t3.vf)
Provides:       tex(Junicode-inf-ts3--base.tfm)
Provides:       tex(Junicode-inf-ts3.tfm)
Provides:       tex(Junicode-inf-ts3.vf)
Provides:       tex(Junicode-sup-ly1.tfm)
Provides:       tex(Junicode-sup-ot1.tfm)
Provides:       tex(Junicode-sup-t1--base.tfm)
Provides:       tex(Junicode-sup-t1.tfm)
Provides:       tex(Junicode-sup-t1.vf)
Provides:       tex(Junicode-sup-t3--base.tfm)
Provides:       tex(Junicode-sup-t3.tfm)
Provides:       tex(Junicode-sup-t3.vf)
Provides:       tex(Junicode-sup-ts3--base.tfm)
Provides:       tex(Junicode-sup-ts3.tfm)
Provides:       tex(Junicode-sup-ts3.vf)
Provides:       tex(Junicode-tlf-ly1.tfm)
Provides:       tex(Junicode-tlf-ot1.tfm)
Provides:       tex(Junicode-tlf-sc-ly1--base.tfm)
Provides:       tex(Junicode-tlf-sc-ly1.tfm)
Provides:       tex(Junicode-tlf-sc-ly1.vf)
Provides:       tex(Junicode-tlf-sc-ot1--base.tfm)
Provides:       tex(Junicode-tlf-sc-ot1.tfm)
Provides:       tex(Junicode-tlf-sc-ot1.vf)
Provides:       tex(Junicode-tlf-sc-t1--base.tfm)
Provides:       tex(Junicode-tlf-sc-t1.tfm)
Provides:       tex(Junicode-tlf-sc-t1.vf)
Provides:       tex(Junicode-tlf-sc-t3--base.tfm)
Provides:       tex(Junicode-tlf-sc-t3.tfm)
Provides:       tex(Junicode-tlf-sc-t3.vf)
Provides:       tex(Junicode-tlf-sc-ts3--base.tfm)
Provides:       tex(Junicode-tlf-sc-ts3.tfm)
Provides:       tex(Junicode-tlf-sc-ts3.vf)
Provides:       tex(Junicode-tlf-swash-ly1.tfm)
Provides:       tex(Junicode-tlf-swash-ot1--base.tfm)
Provides:       tex(Junicode-tlf-swash-ot1.tfm)
Provides:       tex(Junicode-tlf-swash-ot1.vf)
Provides:       tex(Junicode-tlf-swash-t1--base.tfm)
Provides:       tex(Junicode-tlf-swash-t1.tfm)
Provides:       tex(Junicode-tlf-swash-t1.vf)
Provides:       tex(Junicode-tlf-swash-t3--base.tfm)
Provides:       tex(Junicode-tlf-swash-t3.tfm)
Provides:       tex(Junicode-tlf-swash-t3.vf)
Provides:       tex(Junicode-tlf-swash-ts3--base.tfm)
Provides:       tex(Junicode-tlf-swash-ts3.tfm)
Provides:       tex(Junicode-tlf-swash-ts3.vf)
Provides:       tex(Junicode-tlf-t1--base.tfm)
Provides:       tex(Junicode-tlf-t1.tfm)
Provides:       tex(Junicode-tlf-t1.vf)
Provides:       tex(Junicode-tlf-t3--base.tfm)
Provides:       tex(Junicode-tlf-t3.tfm)
Provides:       tex(Junicode-tlf-t3.vf)
Provides:       tex(Junicode-tlf-ts1--base.tfm)
Provides:       tex(Junicode-tlf-ts1.tfm)
Provides:       tex(Junicode-tlf-ts1.vf)
Provides:       tex(Junicode-tlf-ts3--base.tfm)
Provides:       tex(Junicode-tlf-ts3.tfm)
Provides:       tex(Junicode-tlf-ts3.vf)
Provides:       tex(Junicode-tosf-ly1.tfm)
Provides:       tex(Junicode-tosf-ot1.tfm)
Provides:       tex(Junicode-tosf-sc-ly1--base.tfm)
Provides:       tex(Junicode-tosf-sc-ly1.tfm)
Provides:       tex(Junicode-tosf-sc-ly1.vf)
Provides:       tex(Junicode-tosf-sc-ot1--base.tfm)
Provides:       tex(Junicode-tosf-sc-ot1.tfm)
Provides:       tex(Junicode-tosf-sc-ot1.vf)
Provides:       tex(Junicode-tosf-sc-t1--base.tfm)
Provides:       tex(Junicode-tosf-sc-t1.tfm)
Provides:       tex(Junicode-tosf-sc-t1.vf)
Provides:       tex(Junicode-tosf-sc-t3--base.tfm)
Provides:       tex(Junicode-tosf-sc-t3.tfm)
Provides:       tex(Junicode-tosf-sc-t3.vf)
Provides:       tex(Junicode-tosf-sc-ts3--base.tfm)
Provides:       tex(Junicode-tosf-sc-ts3.tfm)
Provides:       tex(Junicode-tosf-sc-ts3.vf)
Provides:       tex(Junicode-tosf-swash-ly1.tfm)
Provides:       tex(Junicode-tosf-swash-ot1--base.tfm)
Provides:       tex(Junicode-tosf-swash-ot1.tfm)
Provides:       tex(Junicode-tosf-swash-ot1.vf)
Provides:       tex(Junicode-tosf-swash-t1--base.tfm)
Provides:       tex(Junicode-tosf-swash-t1.tfm)
Provides:       tex(Junicode-tosf-swash-t1.vf)
Provides:       tex(Junicode-tosf-swash-t3--base.tfm)
Provides:       tex(Junicode-tosf-swash-t3.tfm)
Provides:       tex(Junicode-tosf-swash-t3.vf)
Provides:       tex(Junicode-tosf-swash-ts3--base.tfm)
Provides:       tex(Junicode-tosf-swash-ts3.tfm)
Provides:       tex(Junicode-tosf-swash-ts3.vf)
Provides:       tex(Junicode-tosf-t1--base.tfm)
Provides:       tex(Junicode-tosf-t1.tfm)
Provides:       tex(Junicode-tosf-t1.vf)
Provides:       tex(Junicode-tosf-t3--base.tfm)
Provides:       tex(Junicode-tosf-t3.tfm)
Provides:       tex(Junicode-tosf-t3.vf)
Provides:       tex(Junicode-tosf-ts1--base.tfm)
Provides:       tex(Junicode-tosf-ts1.tfm)
Provides:       tex(Junicode-tosf-ts1.vf)
Provides:       tex(Junicode-tosf-ts3--base.tfm)
Provides:       tex(Junicode-tosf-ts3.tfm)
Provides:       tex(Junicode-tosf-ts3.vf)
Provides:       tex(Junicode.map)
Provides:       tex(LY1Junicode-Inf.fd)
Provides:       tex(LY1Junicode-Sup.fd)
Provides:       tex(LY1Junicode-TLF.fd)
Provides:       tex(LY1Junicode-TOsF.fd)
Provides:       tex(OT1Junicode-Inf.fd)
Provides:       tex(OT1Junicode-Sup.fd)
Provides:       tex(OT1Junicode-TLF.fd)
Provides:       tex(OT1Junicode-TOsF.fd)
Provides:       tex(T1Junicode-Inf.fd)
Provides:       tex(T1Junicode-Sup.fd)
Provides:       tex(T1Junicode-TLF.fd)
Provides:       tex(T1Junicode-TOsF.fd)
Provides:       tex(T3Junicode-Inf.fd)
Provides:       tex(T3Junicode-Sup.fd)
Provides:       tex(T3Junicode-TLF.fd)
Provides:       tex(T3Junicode-TOsF.fd)
Provides:       tex(TS1Junicode-TLF.fd)
Provides:       tex(TS1Junicode-TOsF.fd)
Provides:       tex(TS3Junicode-Inf.fd)
Provides:       tex(TS3Junicode-Sup.fd)
Provides:       tex(TS3Junicode-TLF.fd)
Provides:       tex(TS3Junicode-TOsF.fd)
Provides:       tex(a_2bpv3m.enc)
Provides:       tex(a_2mm3c2.enc)
Provides:       tex(a_2p6ois.enc)
Provides:       tex(a_2sfipb.enc)
Provides:       tex(a_3lniep.enc)
Provides:       tex(a_3oiwi3.enc)
Provides:       tex(a_3volwp.enc)
Provides:       tex(a_3xz3h2.enc)
Provides:       tex(a_4n6crv.enc)
Provides:       tex(a_4wispq.enc)
Provides:       tex(a_4ycye2.enc)
Provides:       tex(a_5swlfy.enc)
Provides:       tex(a_6u5uu4.enc)
Provides:       tex(a_7ds3wq.enc)
Provides:       tex(a_b5lvdl.enc)
Provides:       tex(a_b5zcir.enc)
Provides:       tex(a_bt27yq.enc)
Provides:       tex(a_buzzjq.enc)
Provides:       tex(a_bxn3t2.enc)
Provides:       tex(a_c3r5id.enc)
Provides:       tex(a_ciujvo.enc)
Provides:       tex(a_czanfn.enc)
Provides:       tex(a_daqx6o.enc)
Provides:       tex(a_ddgo45.enc)
Provides:       tex(a_dh7eks.enc)
Provides:       tex(a_dsxmxh.enc)
Provides:       tex(a_e224kq.enc)
Provides:       tex(a_e24h5d.enc)
Provides:       tex(a_eegkrc.enc)
Provides:       tex(a_egdeql.enc)
Provides:       tex(a_equvmx.enc)
Provides:       tex(a_ewwy5y.enc)
Provides:       tex(a_eyvcqg.enc)
Provides:       tex(a_fb4xbs.enc)
Provides:       tex(a_fsg22v.enc)
Provides:       tex(a_ghwqhd.enc)
Provides:       tex(a_gus7sm.enc)
Provides:       tex(a_h747e4.enc)
Provides:       tex(a_hlkg6v.enc)
Provides:       tex(a_hzunuz.enc)
Provides:       tex(a_iahbda.enc)
Provides:       tex(a_iapetj.enc)
Provides:       tex(a_iqg3f5.enc)
Provides:       tex(a_jddr6t.enc)
Provides:       tex(a_jg27fn.enc)
Provides:       tex(a_jjpsim.enc)
Provides:       tex(a_jtxgor.enc)
Provides:       tex(a_l3mb37.enc)
Provides:       tex(a_leirnf.enc)
Provides:       tex(a_lzmc63.enc)
Provides:       tex(a_m5vvpo.enc)
Provides:       tex(a_msm5ja.enc)
Provides:       tex(a_myi6mz.enc)
Provides:       tex(a_n574it.enc)
Provides:       tex(a_n5rwri.enc)
Provides:       tex(a_ncdqoi.enc)
Provides:       tex(a_nfgurc.enc)
Provides:       tex(a_ng574l.enc)
Provides:       tex(a_nxovao.enc)
Provides:       tex(a_ocfo6w.enc)
Provides:       tex(a_ofg65e.enc)
Provides:       tex(a_ovuqp7.enc)
Provides:       tex(a_oyqcvc.enc)
Provides:       tex(a_oz2voy.enc)
Provides:       tex(a_p42lhv.enc)
Provides:       tex(a_pjlm4h.enc)
Provides:       tex(a_pyi5bn.enc)
Provides:       tex(a_q5oomy.enc)
Provides:       tex(a_qojq43.enc)
Provides:       tex(a_qrnvns.enc)
Provides:       tex(a_r5vqsy.enc)
Provides:       tex(a_re7epd.enc)
Provides:       tex(a_reswd7.enc)
Provides:       tex(a_riy3vj.enc)
Provides:       tex(a_rld3th.enc)
Provides:       tex(a_rq7kaz.enc)
Provides:       tex(a_rufiuz.enc)
Provides:       tex(a_senygh.enc)
Provides:       tex(a_skkj5j.enc)
Provides:       tex(a_tgx5t5.enc)
Provides:       tex(a_ud6k5n.enc)
Provides:       tex(a_ue6kia.enc)
Provides:       tex(a_uqrabr.enc)
Provides:       tex(a_uteiqb.enc)
Provides:       tex(a_uui4bo.enc)
Provides:       tex(a_vd2fo2.enc)
Provides:       tex(a_w3oimd.enc)
Provides:       tex(a_wqhzsa.enc)
Provides:       tex(a_x5gcu6.enc)
Provides:       tex(a_xafpoq.enc)
Provides:       tex(a_xzdxuw.enc)
Provides:       tex(a_yabl64.enc)
Provides:       tex(a_yt7kgf.enc)
Provides:       tex(a_z2b6ll.enc)
Provides:       tex(a_zbjpie.enc)
Provides:       tex(a_zw22co.enc)
Provides:       tex(a_zyf2d6.enc)
Provides:       tex(junicode.sty)
Provides:       tex(mt-Junicode.cfg)
Requires:       tex(fontaxes.sty)
Requires:       tex(mweights.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source103:      junicode.tar.xz
Source104:      junicode.doc.tar.xz

%description -n texlive-junicode
Junicode is a TrueType font with many OpenType features for
antiquarians (especially medievalists) based on typefaces used
by the Oxford Press in the late 17th and early 18th centuries.
It works well with Xe(La)TeX.

%package -n texlive-junicode-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn61719
Release:        0
Summary:        Documentation for texlive-junicode
License:        OFL-1.1
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-junicode and texlive-alldocumentation)

%description -n texlive-junicode-doc
This package includes the documentation for texlive-junicode

%package -n texlive-junicode-fonts
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn61719
Release:        0
Summary:        Severed fonts for texlive-junicode
License:        OFL-1.1
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
Obsoletes:      ctan-junicode-fonts <= 0.7.8
Provides:       ctan-junicode-fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-junicode-fonts
The  separated fonts package for texlive-junicode

%post -n texlive-junicode
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap Junicode.map' >> /var/run/texlive/run-updmap

%postun -n texlive-junicode
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap Junicode.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-junicode
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-junicode-fonts

%files -n texlive-junicode-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/junicode/COPYING
%{_texmfdistdir}/doc/fonts/junicode/ChangeLog
%{_texmfdistdir}/doc/fonts/junicode/README
%{_texmfdistdir}/doc/fonts/junicode/README.TEXLIVE
%{_texmfdistdir}/doc/fonts/junicode/fleurons
%{_texmfdistdir}/doc/fonts/junicode/replacements

%files -n texlive-junicode
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_2bpv3m.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_2mm3c2.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_2p6ois.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_2sfipb.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_3lniep.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_3oiwi3.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_3volwp.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_3xz3h2.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_4n6crv.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_4wispq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_4ycye2.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_5swlfy.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_6u5uu4.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_7ds3wq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_b5lvdl.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_b5zcir.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_bt27yq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_buzzjq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_bxn3t2.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_c3r5id.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ciujvo.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_czanfn.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_daqx6o.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ddgo45.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_dh7eks.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_dsxmxh.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_e224kq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_e24h5d.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_eegkrc.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_egdeql.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_equvmx.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ewwy5y.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_eyvcqg.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_fb4xbs.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_fsg22v.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ghwqhd.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_gus7sm.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_h747e4.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_hlkg6v.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_hzunuz.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_iahbda.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_iapetj.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_iqg3f5.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_jddr6t.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_jg27fn.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_jjpsim.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_jtxgor.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_l3mb37.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_leirnf.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_lzmc63.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_m5vvpo.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_msm5ja.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_myi6mz.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_n574it.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_n5rwri.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ncdqoi.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_nfgurc.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ng574l.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_nxovao.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ocfo6w.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ofg65e.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ovuqp7.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_oyqcvc.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_oz2voy.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_p42lhv.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_pjlm4h.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_pyi5bn.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_q5oomy.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_qojq43.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_qrnvns.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_r5vqsy.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_re7epd.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_reswd7.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_riy3vj.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_rld3th.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_rq7kaz.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_rufiuz.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_senygh.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_skkj5j.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_tgx5t5.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ud6k5n.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_ue6kia.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_uqrabr.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_uteiqb.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_uui4bo.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_vd2fo2.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_w3oimd.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_wqhzsa.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_x5gcu6.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_xafpoq.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_xzdxuw.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_yabl64.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_yt7kgf.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_z2b6ll.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_zbjpie.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_zw22co.enc
%{_texmfdistdir}/fonts/enc/dvips/junicode/a_zyf2d6.enc
%{_texmfdistdir}/fonts/map/dvips/junicode/Junicode.map
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-sup-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tlf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Bold-tosf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-sup-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tlf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-BoldItalic-tosf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-inf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-sup-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tlf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-Italic-tosf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-inf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-sup-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tlf-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ly1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-sc-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-ly1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-ot1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-ot1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-swash-ts3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-t1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-t1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-t3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-t3.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ts1--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ts1.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ts3--base.tfm
%{_texmfdistdir}/fonts/tfm/public/junicode/Junicode-tosf-ts3.tfm
%verify(link) %{_texmfdistdir}/fonts/truetype/public/junicode/FoulisGreek.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/junicode/Junicode-Bold.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/junicode/Junicode-BoldItalic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/junicode/Junicode-Italic.ttf
%verify(link) %{_texmfdistdir}/fonts/truetype/public/junicode/Junicode.ttf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-sup-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-sup-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-swash-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tlf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-swash-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Bold-tosf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-sup-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-sup-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-swash-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tlf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-swash-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-BoldItalic-tosf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-inf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-inf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-inf-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-sup-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-sup-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-sup-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-sc-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-swash-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tlf-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-sc-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-swash-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-Italic-tosf-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-inf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-inf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-inf-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-sup-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-sup-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-sup-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-sc-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-swash-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tlf-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-sc-ly1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-sc-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-sc-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-sc-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-sc-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-swash-ot1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-swash-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-swash-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-swash-ts3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-t1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-t3.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-ts1.vf
%{_texmfdistdir}/fonts/vf/public/junicode/Junicode-tosf-ts3.vf
%{_texmfdistdir}/tex/latex/junicode/LY1Junicode-Inf.fd
%{_texmfdistdir}/tex/latex/junicode/LY1Junicode-Sup.fd
%{_texmfdistdir}/tex/latex/junicode/LY1Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/LY1Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/OT1Junicode-Inf.fd
%{_texmfdistdir}/tex/latex/junicode/OT1Junicode-Sup.fd
%{_texmfdistdir}/tex/latex/junicode/OT1Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/OT1Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/T1Junicode-Inf.fd
%{_texmfdistdir}/tex/latex/junicode/T1Junicode-Sup.fd
%{_texmfdistdir}/tex/latex/junicode/T1Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/T1Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/T3Junicode-Inf.fd
%{_texmfdistdir}/tex/latex/junicode/T3Junicode-Sup.fd
%{_texmfdistdir}/tex/latex/junicode/T3Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/T3Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/TS1Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/TS1Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/TS3Junicode-Inf.fd
%{_texmfdistdir}/tex/latex/junicode/TS3Junicode-Sup.fd
%{_texmfdistdir}/tex/latex/junicode/TS3Junicode-TLF.fd
%{_texmfdistdir}/tex/latex/junicode/TS3Junicode-TOsF.fd
%{_texmfdistdir}/tex/latex/junicode/junicode.sty
%{_texmfdistdir}/tex/latex/junicode/mt-Junicode.cfg

%files -n texlive-junicode-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-junicode
%{_datadir}/fontconfig/conf.avail/58-texlive-junicode.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-junicode/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-junicode/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-junicode/fonts.scale
%{_datadir}/fonts/texlive-junicode/FoulisGreek.ttf
%{_datadir}/fonts/texlive-junicode/Junicode-Bold.ttf
%{_datadir}/fonts/texlive-junicode/Junicode-BoldItalic.ttf
%{_datadir}/fonts/texlive-junicode/Junicode-Italic.ttf
%{_datadir}/fonts/texlive-junicode/Junicode.ttf

%package -n texlive-jupynotex
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn56715
Release:        0
License:        Apache-1.0
Summary:        Include whole or partial Jupyter notebooks in LaTeX documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jupynotex-doc >= %{texlive_version}
Provides:       tex(jupynotex.sty)
Requires:       tex(tcolorbox.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source105:      jupynotex.tar.xz
Source106:      jupynotex.doc.tar.xz

%description -n texlive-jupynotex
This package provides a python3 script and a LaTeX .sty file
which can be used together to include Jupyter Notebooks (all of
them, or some specific cells) as part of a LaTeX document. It
will convert the Jupyter Notebook format to proper LaTeX so it
gets included seamlessly, supporting text, LaTeX, images, etc.

%package -n texlive-jupynotex-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn56715
Release:        0
Summary:        Documentation for texlive-jupynotex
License:        Apache-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jupynotex and texlive-alldocumentation)

%description -n texlive-jupynotex-doc
This package includes the documentation for texlive-jupynotex

%post -n texlive-jupynotex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jupynotex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jupynotex
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jupynotex-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jupynotex/LICENSE
%{_texmfdistdir}/doc/latex/jupynotex/README.md
%{_texmfdistdir}/doc/latex/jupynotex/example/build
%{_texmfdistdir}/doc/latex/jupynotex/example/example.tex
%{_texmfdistdir}/doc/latex/jupynotex/example/notebook.ipynb
%{_texmfdistdir}/doc/latex/jupynotex/tests/run
%{_texmfdistdir}/doc/latex/jupynotex/tests/test_cellparser.py
%{_texmfdistdir}/doc/latex/jupynotex/tests/test_main.py
%{_texmfdistdir}/doc/latex/jupynotex/tests/test_notebook.py

%files -n texlive-jupynotex
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jupynotex/jupynotex.py
%{_texmfdistdir}/tex/latex/jupynotex/jupynotex.sty

%package -n texlive-jura
Version:        %{texlive_version}.%{texlive_noarch}.4.3svn15878
Release:        0
License:        GPL-2.0-or-later
Summary:        A document class for German legal texts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jura-doc >= %{texlive_version}
Provides:       tex(alphanum.sty)
Provides:       tex(jura.cls)
Requires:       tex(report.cls)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source107:      jura.tar.xz
Source108:      jura.doc.tar.xz

%description -n texlive-jura
Implements the standard layout for German term papers in law
(one-and-half linespacing, 7 cm margins, etc.). Includes
alphanum that permits alphanumeric section numbering (e.g., A.
Introduction; III. International Law).

%package -n texlive-jura-doc
Version:        %{texlive_version}.%{texlive_noarch}.4.3svn15878
Release:        0
Summary:        Documentation for texlive-jura
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jura and texlive-alldocumentation)
Provides:       locale(texlive-jura-doc:en;de)

%description -n texlive-jura-doc
This package includes the documentation for texlive-jura

%post -n texlive-jura
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jura
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jura
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jura-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jura/README
%{_texmfdistdir}/doc/latex/jura/jura.pdf
%{_texmfdistdir}/doc/latex/jura/jura2html
%{_texmfdistdir}/doc/latex/jura/juratest.ltx

%files -n texlive-jura
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jura/alphanum.sty
%{_texmfdistdir}/tex/latex/jura/jura.cls

%package -n texlive-juraabbrev
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
License:        GPL-2.0-or-later
Summary:        Abbreviations for typesetting (German) juridical documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-juraabbrev-doc >= %{texlive_version}
Provides:       tex(juraabbrev.sty)
Requires:       tex(ifthen.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source109:      juraabbrev.tar.xz
Source110:      juraabbrev.doc.tar.xz

%description -n texlive-juraabbrev
This package should be helpful for people working on (German)
law. It helps you to handle abbreviations and creates a list of
those (pre-defined) abbreviations that have actually been used
in the document

%package -n texlive-juraabbrev-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
Summary:        Documentation for texlive-juraabbrev
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-juraabbrev and texlive-alldocumentation)
Provides:       locale(texlive-juraabbrev-doc:de)

%description -n texlive-juraabbrev-doc
This package includes the documentation for texlive-juraabbrev

%post -n texlive-juraabbrev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-juraabbrev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-juraabbrev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-juraabbrev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/juraabbrev/README
%{_texmfdistdir}/doc/latex/juraabbrev/abbrevtest.tex
%{_texmfdistdir}/doc/latex/juraabbrev/juraabbrev.pdf

%files -n texlive-juraabbrev
%defattr(-,root,root,755)
%{_texmfdistdir}/makeindex/juraabbrev/laws.ist
%{_texmfdistdir}/tex/latex/juraabbrev/juraabbrev.4ht
%{_texmfdistdir}/tex/latex/juraabbrev/juraabbrev.sty

%package -n texlive-jurabib
Version:        %{texlive_version}.%{texlive_noarch}.0.0.6svn15878
Release:        0
License:        GPL-2.0-or-later
Summary:        Extended BibTeX citation support for the humanities and legal texts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jurabib-doc >= %{texlive_version}
Provides:       tex(dajbbib.ldf)
Provides:       tex(dejbbib.ldf)
Provides:       tex(dujbbib.ldf)
Provides:       tex(enjbbib.ldf)
Provides:       tex(fijbbib.ldf)
Provides:       tex(frjbbib.ldf)
Provides:       tex(itjbbib.ldf)
Provides:       tex(jblong.cfg)
Provides:       tex(jurabib.cfg)
Provides:       tex(jurabib.sty)
Provides:       tex(nojbbib.ldf)
Provides:       tex(ptjbbib.ldf)
Provides:       tex(spjbbib.ldf)
Requires:       tex(array.sty)
Requires:       tex(bibunits.sty)
Requires:       tex(calc.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(keyval.sty)
Requires:       tex(url.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source111:      jurabib.tar.xz
Source112:      jurabib.doc.tar.xz

%description -n texlive-jurabib
This package enables automated citation with BibTeX for legal
studies and the humanities. In addition, the package provides
commands for specifying editors in a commentary in a convenient
way. Simplified formatting of the citation as well as the
bibliography entry is also provided. It is possible to display
the (short) title of a work only if an authors is cited with
multiple works. Giving a full citation in the text, conforming
to the bibliography entry, is supported. Several options are
provided which might be of special interest for those outside
legal studies--for instance, displaying multiple full
citations. In addition, the format of last names and first
names of authors may be changed easily. Cross references to
other footnotes are possible. Language dependent handling of
bibliography entries is possible by the special language field.

%package -n texlive-jurabib-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.6svn15878
Release:        0
Summary:        Documentation for texlive-jurabib
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jurabib and texlive-alldocumentation)
Provides:       locale(texlive-jurabib-doc:en;de)

%description -n texlive-jurabib-doc
This package includes the documentation for texlive-jurabib

%post -n texlive-jurabib
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jurabib
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jurabib
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jurabib-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jurabib/changes.txt
%{_texmfdistdir}/doc/latex/jurabib/docs/english/jbendoc.pdf
%{_texmfdistdir}/doc/latex/jurabib/docs/english/jbendoc.tex
%{_texmfdistdir}/doc/latex/jurabib/docs/german/jbgerdoc.pdf
%{_texmfdistdir}/doc/latex/jurabib/docs/german/jbgerdoc.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtest.pdf
%{_texmfdistdir}/doc/latex/jurabib/jbtest.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtest.url
%{_texmfdistdir}/doc/latex/jurabib/jbtestbt.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtestbu.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtestcb.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtestcb1.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtestcb2.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtesthu.tex
%{_texmfdistdir}/doc/latex/jurabib/jbtestmb.tex

%files -n texlive-jurabib
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bib/jurabib/book.bib
%{_texmfdistdir}/bibtex/bib/jurabib/comment.bib
%{_texmfdistdir}/bibtex/bib/jurabib/jbtest.bib
%{_texmfdistdir}/bibtex/bib/jurabib/jbtesthu.bib
%{_texmfdistdir}/bibtex/bst/jurabib/jox.bst
%{_texmfdistdir}/bibtex/bst/jurabib/jurabib.bst
%{_texmfdistdir}/bibtex/bst/jurabib/jureco.bst
%{_texmfdistdir}/bibtex/bst/jurabib/jurunsrt.bst
%{_texmfdistdir}/tex/latex/jurabib/dajbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/dejbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/dujbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/enjbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/fijbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/frjbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/itjbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/jblong.cfg
%{_texmfdistdir}/tex/latex/jurabib/jurabib.cfg
%{_texmfdistdir}/tex/latex/jurabib/jurabib.sty
%{_texmfdistdir}/tex/latex/jurabib/nojbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/ptjbbib.ldf
%{_texmfdistdir}/tex/latex/jurabib/spjbbib.ldf

%package -n texlive-juramisc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.91svn15878
Release:        0
License:        LPPL-1.0
Summary:        Typesetting German juridical documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-juramisc-doc >= %{texlive_version}
Provides:       tex(jbgoe.clo)
Provides:       tex(jbstgallen.clo)
Provides:       tex(jbtrier.clo)
Provides:       tex(jurabase.sty)
Provides:       tex(jurabook.cls)
Provides:       tex(juraovw.cls)
Provides:       tex(juraurtl.cls)
Requires:       tex(array.sty)
Requires:       tex(book.cls)
Requires:       tex(calc.sty)
Requires:       tex(color.sty)
Requires:       tex(fancybox.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(ifpdf.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(multicol.sty)
Requires:       tex(pifont.sty)
Requires:       tex(ragged2e.sty)
Requires:       tex(remreset.sty)
Requires:       tex(scrartcl.cls)
Requires:       tex(xspace.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source113:      juramisc.tar.xz
Source114:      juramisc.doc.tar.xz

%description -n texlive-juramisc
A collection of classes for typesetting court sentences, legal
opinions, books and dissertations for German lawyers. A
jurabook class is also provided, which may not yet be complete.

%package -n texlive-juramisc-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.91svn15878
Release:        0
Summary:        Documentation for texlive-juramisc
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-juramisc and texlive-alldocumentation)
Provides:       locale(texlive-juramisc-doc:de)

%description -n texlive-juramisc-doc
This package includes the documentation for texlive-juramisc

%post -n texlive-juramisc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-juramisc
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-juramisc
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-juramisc-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/juramisc/README
%{_texmfdistdir}/doc/latex/juramisc/doc/jbook/jbook.dtx
%{_texmfdistdir}/doc/latex/juramisc/doc/jbook/jbook.ins
%{_texmfdistdir}/doc/latex/juramisc/doc/jmgerdoc.pdf
%{_texmfdistdir}/doc/latex/juramisc/doc/jmgerdoc.tex
%{_texmfdistdir}/doc/latex/juramisc/doc/jmgerdoc_scr.pdf

%files -n texlive-juramisc
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/juramisc/jbgoe.clo
%{_texmfdistdir}/tex/latex/juramisc/jbstgallen.clo
%{_texmfdistdir}/tex/latex/juramisc/jbtrier.clo
%{_texmfdistdir}/tex/latex/juramisc/jurabase.sty
%{_texmfdistdir}/tex/latex/juramisc/jurabook.cls
%{_texmfdistdir}/tex/latex/juramisc/juraovw.cls
%{_texmfdistdir}/tex/latex/juramisc/juraurtl.cls

%package -n texlive-jurarsp
Version:        %{texlive_version}.%{texlive_noarch}.0.0.52svn15878
Release:        0
License:        GPL-2.0-or-later
Summary:        Citations of judgements and official documents in (German) juridical documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jurarsp-doc >= %{texlive_version}
Provides:       tex(jurarsp.cfg)
Provides:       tex(jurarsp.sty)
Requires:       tex(calc.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(keyval.sty)
Requires:       tex(xspace.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source115:      jurarsp.tar.xz
Source116:      jurarsp.doc.tar.xz

%description -n texlive-jurarsp
This package should be helpful for people working on (German)
law. It (ab)uses BibTeX for citations of judgements and
official documents. For this purpose, a special BibTeX-style is
provided.

%package -n texlive-jurarsp-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.52svn15878
Release:        0
Summary:        Documentation for texlive-jurarsp
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jurarsp and texlive-alldocumentation)
Provides:       locale(texlive-jurarsp-doc:de)

%description -n texlive-jurarsp-doc
This package includes the documentation for texlive-jurarsp

%post -n texlive-jurarsp
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jurarsp
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jurarsp
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jurarsp-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jurarsp/README
%{_texmfdistdir}/doc/latex/jurarsp/jurarsp.pdf
%{_texmfdistdir}/doc/latex/jurarsp/rsptest.bib
%{_texmfdistdir}/doc/latex/jurarsp/rsptest.tex

%files -n texlive-jurarsp
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/jurarsp/jurarsp.bst
%{_texmfdistdir}/tex/latex/jurarsp/jurarsp.cfg
%{_texmfdistdir}/tex/latex/jurarsp/jurarsp.sty

%package -n texlive-jvlisting
Version:        %{texlive_version}.%{texlive_noarch}.0.0.7svn24638
Release:        0
License:        LPPL-1.0
Summary:        A replacement for LaTeX's verbatim package
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jvlisting-doc >= %{texlive_version}
Provides:       tex(jvlisting.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source117:      jvlisting.tar.xz
Source118:      jvlisting.doc.tar.xz

%description -n texlive-jvlisting
This package provides a LaTeX environment listing, an
alternative to the built-in verbatim environment. The listing
environment is tailored for including listings of computer
program source code into documents. The main advantages over
the original verbatim environment are: environments
automatically fixes leading whitespace so that the environment
and program listing can be indented with the rest of the
document source, and; listing environments may easily be
customised and extended.

%package -n texlive-jvlisting-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.7svn24638
Release:        0
Summary:        Documentation for texlive-jvlisting
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jvlisting and texlive-alldocumentation)

%description -n texlive-jvlisting-doc
This package includes the documentation for texlive-jvlisting

%post -n texlive-jvlisting
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jvlisting
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jvlisting
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jvlisting-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jvlisting/README
%{_texmfdistdir}/doc/latex/jvlisting/examples.tex
%{_texmfdistdir}/doc/latex/jvlisting/jvlisting.pdf
%{_texmfdistdir}/doc/latex/jvlisting/test.tex

%files -n texlive-jvlisting
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jvlisting/jvlisting.sty

%package -n texlive-jwjournal
Version:        %{texlive_version}.%{texlive_noarch}.svn65480
Release:        0
License:        LPPL-1.0
Summary:        A personal class for writing journals
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-einfart >= %{texlive_version}
#!BuildIgnore: texlive-einfart
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-jwjournal-doc >= %{texlive_version}
Provides:       tex(jwjournal.cls)
Requires:       tex(ProjLib.sty)
Requires:       tex(enumitem.sty)
Requires:       tex(needspace.sty)
Requires:       tex(tcolorbox.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source119:      jwjournal.tar.xz
Source120:      jwjournal.doc.tar.xz

%description -n texlive-jwjournal
This LaTeX document class enables the user to turn simple pure
text entries into a colorful and nicely formatted journal.

%package -n texlive-jwjournal-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65480
Release:        0
Summary:        Documentation for texlive-jwjournal
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-jwjournal and texlive-alldocumentation)

%description -n texlive-jwjournal-doc
This package includes the documentation for texlive-jwjournal

%post -n texlive-jwjournal
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-jwjournal
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-jwjournal
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-jwjournal-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/jwjournal/DEPENDS.txt
%{_texmfdistdir}/doc/latex/jwjournal/LICENSE
%{_texmfdistdir}/doc/latex/jwjournal/README.md
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-cn.pdf
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-cn.tex
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-en.pdf
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-en.tex
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-fr.pdf
%{_texmfdistdir}/doc/latex/jwjournal/jwjournal-demo-fr.tex

%files -n texlive-jwjournal
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/jwjournal/jwjournal.cls

%package -n texlive-kalendarium
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn48744
Release:        0
License:        LPPL-1.0
Summary:        Print dates according to the classical Latin calendar
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kalendarium-doc >= %{texlive_version}
Provides:       tex(kalendarium.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source121:      kalendarium.tar.xz
Source122:      kalendarium.doc.tar.xz

%description -n texlive-kalendarium
kalendarium is a LaTeX3 package that provides several macros
with which to print dates in classical Latin given days on the
Julian or Gregorian calendars, using the same syntax used by
ancient Roman authors. The format of these dates may be
customised either in the package options or on a per-command
basis; these options also allow for the generation of date
strings according to different eras of the Classical period.

%package -n texlive-kalendarium-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn48744
Release:        0
Summary:        Documentation for texlive-kalendarium
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kalendarium and texlive-alldocumentation)

%description -n texlive-kalendarium-doc
This package includes the documentation for texlive-kalendarium

%post -n texlive-kalendarium
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kalendarium
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kalendarium
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kalendarium-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kalendarium/README.md
%{_texmfdistdir}/doc/latex/kalendarium/kalendarium.pdf

%files -n texlive-kalendarium
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kalendarium/kalendarium.sty

%package -n texlive-kanaparser
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn48052
Release:        0
License:        BSD-3-Clause
Summary:        Kana parser for LuaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kanaparser-doc >= %{texlive_version}
Provides:       tex(kanaparser.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source123:      kanaparser.tar.xz
Source124:      kanaparser.doc.tar.xz

%description -n texlive-kanaparser
The package provides a kana parser for LuaTeX. It is a set of 4
macros that handle transliteration of text: from hiragana and
katakana to Latin from Latin and katakana to hiragana from
Latin and hiragana to katakana It can be used to write kana
directly using only the ASCII character set or for education
purposes. The package has support for obsolete and rarely used
syllables, some only accessible via the provided toggle macro.

%package -n texlive-kanaparser-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn48052
Release:        0
Summary:        Documentation for texlive-kanaparser
License:        BSD-3-Clause
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kanaparser and texlive-alldocumentation)

%description -n texlive-kanaparser-doc
This package includes the documentation for texlive-kanaparser

%post -n texlive-kanaparser
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kanaparser
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kanaparser
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kanaparser-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/luatex/kanaparser/README.md
%{_texmfdistdir}/doc/luatex/kanaparser/description.pdf
%{_texmfdistdir}/doc/luatex/kanaparser/description.tex
%{_texmfdistdir}/doc/luatex/kanaparser/examples.pdf
%{_texmfdistdir}/doc/luatex/kanaparser/examples.tex

%files -n texlive-kanaparser
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/luatex/kanaparser/kanaparser.lua
%{_texmfdistdir}/tex/luatex/kanaparser/kanaparser.tex

%package -n texlive-kanbun
Version:        %{texlive_version}.%{texlive_noarch}.1.2svn62026
Release:        0
License:        LPPL-1.0
Summary:        Typeset kanbun-kundoku with support for kanbun annotation
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kanbun-doc >= %{texlive_version}
Provides:       tex(kanbun.sty)
Requires:       tex(expl3.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source125:      kanbun.tar.xz
Source126:      kanbun.doc.tar.xz

%description -n texlive-kanbun
This package allows users to manually input macros for elements
in a kanbun-kundoku (Han Wen Xun Du ) paragraph. More
importantly, it accepts plain text input in the "kanbun
annotation" form when used with LuaLaTeX, which allows
typesetting kanbun-kundoku paragraphs efficiently.

%package -n texlive-kanbun-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.2svn62026
Release:        0
Summary:        Documentation for texlive-kanbun
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kanbun and texlive-alldocumentation)
Provides:       locale(texlive-kanbun-doc:zh,ja)

%description -n texlive-kanbun-doc
This package includes the documentation for texlive-kanbun

%post -n texlive-kanbun
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kanbun
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kanbun
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kanbun-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kanbun/README.md
%{_texmfdistdir}/doc/latex/kanbun/kanbun-en.pdf
%{_texmfdistdir}/doc/latex/kanbun/kanbun-en.tex
%{_texmfdistdir}/doc/latex/kanbun/kanbun-example.pdf
%{_texmfdistdir}/doc/latex/kanbun/kanbun-example.tex
%{_texmfdistdir}/doc/latex/kanbun/kanbun-ja.pdf
%{_texmfdistdir}/doc/latex/kanbun/kanbun-ja.tex
%{_texmfdistdir}/doc/latex/kanbun/kanbun.tex

%files -n texlive-kanbun
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kanbun/kanbun.lua
%{_texmfdistdir}/tex/latex/kanbun/kanbun.sty

%package -n texlive-kantlipsum
Version:        %{texlive_version}.%{texlive_noarch}.0.0.8asvn51727
Release:        0
License:        LPPL-1.0
Summary:        Generate sentences in Kant's style
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kantlipsum-doc >= %{texlive_version}
Provides:       tex(kantlipsum.sty)
Requires:       tex(expl3.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source127:      kantlipsum.tar.xz
Source128:      kantlipsum.doc.tar.xz

%description -n texlive-kantlipsum
The package spits out sentences in Kantian style; the text is
provided by the Kant generator for Python by Mark Pilgrim,
described in the book "Dive into Python". The package is
modelled on lipsum, and may be used for similar purposes.

%package -n texlive-kantlipsum-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.8asvn51727
Release:        0
Summary:        Documentation for texlive-kantlipsum
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kantlipsum and texlive-alldocumentation)

%description -n texlive-kantlipsum-doc
This package includes the documentation for texlive-kantlipsum

%post -n texlive-kantlipsum
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kantlipsum
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kantlipsum
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kantlipsum-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kantlipsum/README.md
%{_texmfdistdir}/doc/latex/kantlipsum/kantlipsum.pdf

%files -n texlive-kantlipsum
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kantlipsum/kantlipsum.sty

%package -n texlive-karnaugh
Version:        %{texlive_version}.%{texlive_noarch}.svn21338
Release:        0
License:        LPPL-1.0
Summary:        Typeset Karnaugh-Veitch-maps
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-karnaugh-doc >= %{texlive_version}
Provides:       tex(kvmacros.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source129:      karnaugh.tar.xz
Source130:      karnaugh.doc.tar.xz

%description -n texlive-karnaugh
The package provides macros for typesetting Karnaugh-Maps and
Veitch-Charts in a simple and user-friendly way. Karnaugh-Maps
and Veitch-Charts are used to display and simplify logic
functions "manually". These macros can typeset Karnaugh-Maps
and Veitch-Charts with up to ten variables (=1024 entries).

%package -n texlive-karnaugh-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn21338
Release:        0
Summary:        Documentation for texlive-karnaugh
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-karnaugh and texlive-alldocumentation)

%description -n texlive-karnaugh-doc
This package includes the documentation for texlive-karnaugh

%post -n texlive-karnaugh
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-karnaugh
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-karnaugh
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-karnaugh-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/karnaugh/kvdoc.pdf
%{_texmfdistdir}/doc/latex/karnaugh/kvdoc.tex

%files -n texlive-karnaugh
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/karnaugh/kvmacros.tex

%package -n texlive-karnaugh-map
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn61614
Release:        0
License:        LPPL-1.0
Summary:        LaTeX package for drawing karnaugh maps with up to 6 variables
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-karnaugh-map-doc >= %{texlive_version}
Provides:       tex(karnaugh-map.sty)
Requires:       tex(keyval.sty)
Requires:       tex(kvoptions.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source131:      karnaugh-map.tar.xz
Source132:      karnaugh-map.doc.tar.xz

%description -n texlive-karnaugh-map
This package draws karnaugh maps with 2, 3, 4, 5, and 6
variables. It also contains commands for filling the karnaugh
map with terms semi-automatically or manually. Last but not
least it contains commands for drawing implicants on top of the
map. This package depends on the keyval, kvoptions, TikZ,
xparse, and xstring packages.

%package -n texlive-karnaugh-map-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn61614
Release:        0
Summary:        Documentation for texlive-karnaugh-map
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-karnaugh-map and texlive-alldocumentation)

%description -n texlive-karnaugh-map-doc
This package includes the documentation for texlive-karnaugh-map

%post -n texlive-karnaugh-map
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-karnaugh-map
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-karnaugh-map
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-karnaugh-map-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/karnaugh-map/README.md
%{_texmfdistdir}/doc/latex/karnaugh-map/karnaugh-map.pdf

%files -n texlive-karnaugh-map
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/karnaugh-map/karnaugh-map.sty

%package -n texlive-karnaughmap
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn36989
Release:        0
License:        LPPL-1.0
Summary:        Typeset Karnaugh maps
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-karnaughmap-doc >= %{texlive_version}
Provides:       tex(karnaughmap.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source133:      karnaughmap.tar.xz
Source134:      karnaughmap.doc.tar.xz

%description -n texlive-karnaughmap
This package provides an easy to use interface to typeset
Karnaugh maps using TikZ. Though similar to the karnaugh
macros, it provides a key-value system to customize
karnaughmaps and a proper LaTeX package.

%package -n texlive-karnaughmap-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn36989
Release:        0
Summary:        Documentation for texlive-karnaughmap
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-karnaughmap and texlive-alldocumentation)

%description -n texlive-karnaughmap-doc
This package includes the documentation for texlive-karnaughmap

%post -n texlive-karnaughmap
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-karnaughmap
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-karnaughmap
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-karnaughmap-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/karnaughmap/README
%{_texmfdistdir}/doc/latex/karnaughmap/karnaughmap.pdf

%files -n texlive-karnaughmap
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/karnaughmap/karnaughmap.sty

%package -n texlive-kastrup
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
License:        LPPL-1.0
Summary:        Convert numbers into binary, octal and hexadecimal
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kastrup-doc >= %{texlive_version}
Provides:       tex(binhex.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source135:      kastrup.tar.xz
Source136:      kastrup.doc.tar.xz

%description -n texlive-kastrup
Provides expandable macros for both fixed-width and
minimum-width numbers to bases 2, 4, 8 and 16.

%package -n texlive-kastrup-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
Summary:        Documentation for texlive-kastrup
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kastrup and texlive-alldocumentation)

%description -n texlive-kastrup-doc
This package includes the documentation for texlive-kastrup

%post -n texlive-kastrup
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kastrup
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kastrup
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kastrup-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/kastrup/binhex.pdf

%files -n texlive-kastrup
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/generic/kastrup/binhex.tex

%package -n texlive-kaytannollista-latexia
Version:        %{texlive_version}.%{texlive_noarch}.2023svn65461
Release:        0
License:        LPPL-1.0
Summary:        Practical manual for LaTeX (Finnish)
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source137:      kaytannollista-latexia.doc.tar.xz

%description -n texlive-kaytannollista-latexia
"Kaytannollista Latexia" is a practical manual for LaTeX
written in the Finnish language. The manual covers most of the
topics that a typical document author needs. So it can be a
useful guide for beginners as well as a reference manual for
advanced users.

%post -n texlive-kaytannollista-latexia
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kaytannollista-latexia
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kaytannollista-latexia
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kaytannollista-latexia
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/README.md
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/kaytannollista-latexia.pdf
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/kaytannollista-latexia.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/kirjallisuutta.bib
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-asetukset.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-erikoiset.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-esipuhe.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-merkintakieli.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-rakenne.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/luku-valmistautuminen.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/tavutusvihjeet.tex
%{_texmfdistdir}/doc/latex/kaytannollista-latexia/versio.tex

%package -n texlive-kblocks
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn57617
Release:        0
License:        LPPL-1.0
Summary:        Easily typeset Control Block Diagrams and Signal Flow Graphs
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kblocks-doc >= %{texlive_version}
Provides:       tex(kblocks.sty)
Requires:       tex(circuitikz.sty)
Requires:       tex(tikz.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source138:      kblocks.tar.xz
Source139:      kblocks.doc.tar.xz

%description -n texlive-kblocks
Kblocks defines a number of commands to make drawing control
block diagrams using TikZ/PGF more structured and easier. It
reduces the learning curve forTikZ/PGF and serves as a
frontend, by focusing on the block resp. flow diagrams only.

%package -n texlive-kblocks-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn57617
Release:        0
Summary:        Documentation for texlive-kblocks
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kblocks and texlive-alldocumentation)

%description -n texlive-kblocks-doc
This package includes the documentation for texlive-kblocks

%post -n texlive-kblocks
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kblocks
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kblocks
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kblocks-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kblocks/README.md
%{_texmfdistdir}/doc/latex/kblocks/intro.png
%{_texmfdistdir}/doc/latex/kblocks/kblocks-doc.pdf
%{_texmfdistdir}/doc/latex/kblocks/kblocks-doc.tex

%files -n texlive-kblocks
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kblocks/kblocks.sty

%package -n texlive-kdgdocs
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn24498
Release:        0
License:        LPPL-1.0
Summary:        Document classes for Karel de Grote University College
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kdgdocs-doc >= %{texlive_version}
Provides:       tex(kdgcoursetext.cls)
Provides:       tex(kdgmasterthesis.cls)
Requires:       tex(cmbright.sty)
Requires:       tex(color.sty)
Requires:       tex(eso-pic.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(geometry.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(tikz.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source140:      kdgdocs.tar.xz
Source141:      kdgdocs.doc.tar.xz

%description -n texlive-kdgdocs
The bundle provides two classes for usage by KdG professors and
master students: kdgcoursetext: for writing course texts, and
kdgmasterthesis: for writing master's theses. The bundle
replaces the original kdgcoursetext package (now removed from
the archive).

%package -n texlive-kdgdocs-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn24498
Release:        0
Summary:        Documentation for texlive-kdgdocs
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kdgdocs and texlive-alldocumentation)

%description -n texlive-kdgdocs-doc
This package includes the documentation for texlive-kdgdocs

%post -n texlive-kdgdocs
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kdgdocs
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kdgdocs
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kdgdocs-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kdgdocs/LICENSE
%{_texmfdistdir}/doc/latex/kdgdocs/README
%{_texmfdistdir}/doc/latex/kdgdocs/kdg_color.eps
%{_texmfdistdir}/doc/latex/kdgdocs/kdg_color.pdf
%{_texmfdistdir}/doc/latex/kdgdocs/kdgcoursetext-example.pdf
%{_texmfdistdir}/doc/latex/kdgdocs/kdgcoursetext-example.tex
%{_texmfdistdir}/doc/latex/kdgdocs/kdgdocs.pdf
%{_texmfdistdir}/doc/latex/kdgdocs/kdgmasterthesis-example.pdf
%{_texmfdistdir}/doc/latex/kdgdocs/kdgmasterthesis-example.tex
%{_texmfdistdir}/doc/latex/kdgdocs/manifest.txt
%{_texmfdistdir}/doc/latex/kdgdocs/pi-orchid.jpg

%files -n texlive-kdgdocs
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kdgdocs/kdgcoursetext.cls
%{_texmfdistdir}/tex/latex/kdgdocs/kdgmasterthesis.cls

%package -n texlive-kdpcover
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5.1svn65150
Release:        0
License:        LPPL-1.0
Summary:        Covers for books published by Kindle Direct Publishing
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-anyfontsize >= %{texlive_version}
#!BuildIgnore: texlive-anyfontsize
Requires:       texlive-geometry >= %{texlive_version}
#!BuildIgnore: texlive-geometry
Requires:       texlive-graphics >= %{texlive_version}
#!BuildIgnore: texlive-graphics
Requires:       texlive-microtype >= %{texlive_version}
#!BuildIgnore: texlive-microtype
Requires:       texlive-pgf >= %{texlive_version}
#!BuildIgnore: texlive-pgf
Requires:       texlive-setspace >= %{texlive_version}
#!BuildIgnore: texlive-setspace
Requires:       texlive-textpos >= %{texlive_version}
#!BuildIgnore: texlive-textpos
Requires:       texlive-tools >= %{texlive_version}
#!BuildIgnore: texlive-tools
Requires:       texlive-xcolor >= %{texlive_version}
#!BuildIgnore: texlive-xcolor
Requires:       texlive-xifthen >= %{texlive_version}
#!BuildIgnore: texlive-xifthen
Requires:       texlive-xkeyval >= %{texlive_version}
#!BuildIgnore: texlive-xkeyval
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kdpcover-doc >= %{texlive_version}
Provides:       tex(kdpcover.cls)
Requires:       tex(anyfontsize.sty)
Requires:       tex(article.cls)
Requires:       tex(calc.sty)
Requires:       tex(geometry.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(iexec.sty)
Requires:       tex(microtype.sty)
Requires:       tex(setspace.sty)
Requires:       tex(textpos.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source142:      kdpcover.tar.xz
Source143:      kdpcover.doc.tar.xz

%description -n texlive-kdpcover
The problem this class solves is the necessity to change the
size of the cover PDF according to the number of pages in the
book -- the bigger the book, the larger the spine of the book
must be. The provided class makes the necessary calculations
on-the-fly, using the qpdf tool. Obviously, you need to have it
installed. Also, you must run pdflatex with the --shell-escape
option, in order to allow LaTeX to run qpdf.

%package -n texlive-kdpcover-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5.1svn65150
Release:        0
Summary:        Documentation for texlive-kdpcover
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kdpcover and texlive-alldocumentation)

%description -n texlive-kdpcover-doc
This package includes the documentation for texlive-kdpcover

%post -n texlive-kdpcover
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kdpcover
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kdpcover
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kdpcover-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kdpcover/DEPENDS.txt
%{_texmfdistdir}/doc/latex/kdpcover/LICENSE.txt
%{_texmfdistdir}/doc/latex/kdpcover/README.md
%{_texmfdistdir}/doc/latex/kdpcover/cactus.pdf
%{_texmfdistdir}/doc/latex/kdpcover/kdpcover.pdf
%{_texmfdistdir}/doc/latex/kdpcover/yb-book-logo.pdf

%files -n texlive-kdpcover
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover-signature.pdf
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover-vol-1.pdf
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover-vol-2.pdf
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover-vol-3.pdf
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover-vol-4.pdf
%{_texmfdistdir}/tex/latex/kdpcover/kdpcover.cls

%package -n texlive-kerkis
Version:        %{texlive_version}.%{texlive_noarch}.1.11svn56271
Release:        0
License:        LPPL-1.0
Summary:        Kerkis (Greek) font family
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-kerkis-fonts >= %{texlive_version}
Suggests:       texlive-kerkis-doc >= %{texlive_version}
Provides:       tex(ek8a.tfm)
Provides:       tex(ek8a.vf)
Provides:       tex(ek8r.tfm)
Provides:       tex(ekb8a.tfm)
Provides:       tex(ekb8a.vf)
Provides:       tex(ekb8r.tfm)
Provides:       tex(ekbi8a.tfm)
Provides:       tex(ekbi8a.vf)
Provides:       tex(ekbi8r.tfm)
Provides:       tex(ekbo8a.tfm)
Provides:       tex(ekbo8a.vf)
Provides:       tex(ekbo8r.tfm)
Provides:       tex(ekbsc8a.tfm)
Provides:       tex(ekbsc8a.vf)
Provides:       tex(ekbsc8r.tfm)
Provides:       tex(ekbsco8a.tfm)
Provides:       tex(ekbsco8a.vf)
Provides:       tex(ekbsco8r.tfm)
Provides:       tex(ekbui8a.tfm)
Provides:       tex(ekbui8a.vf)
Provides:       tex(ekbui8r.tfm)
Provides:       tex(ekcal8a.tfm)
Provides:       tex(ekcal8a.vf)
Provides:       tex(ekcal8r.tfm)
Provides:       tex(eki8a.tfm)
Provides:       tex(eki8a.vf)
Provides:       tex(eki8r.tfm)
Provides:       tex(eko8a.tfm)
Provides:       tex(eko8a.vf)
Provides:       tex(eko8r.tfm)
Provides:       tex(eksb8a.tfm)
Provides:       tex(eksb8a.vf)
Provides:       tex(eksb8r.tfm)
Provides:       tex(eksbi8a.tfm)
Provides:       tex(eksbi8a.vf)
Provides:       tex(eksbi8r.tfm)
Provides:       tex(eksbo8a.tfm)
Provides:       tex(eksbo8a.vf)
Provides:       tex(eksbo8r.tfm)
Provides:       tex(eksbui8a.tfm)
Provides:       tex(eksbui8a.vf)
Provides:       tex(eksbui8r.tfm)
Provides:       tex(eksc8a.tfm)
Provides:       tex(eksc8a.vf)
Provides:       tex(eksc8r.tfm)
Provides:       tex(eksco8a.tfm)
Provides:       tex(eksco8a.vf)
Provides:       tex(eksco8r.tfm)
Provides:       tex(eksf8a.tfm)
Provides:       tex(eksf8t.tfm)
Provides:       tex(eksf8t.vf)
Provides:       tex(eksfb8a.tfm)
Provides:       tex(eksfb8t.tfm)
Provides:       tex(eksfb8t.vf)
Provides:       tex(eksfbi8a.tfm)
Provides:       tex(eksfbi8t.tfm)
Provides:       tex(eksfbi8t.vf)
Provides:       tex(eksfi8a.tfm)
Provides:       tex(eksfi8t.tfm)
Provides:       tex(eksfi8t.vf)
Provides:       tex(eksfsc8a.tfm)
Provides:       tex(eksfsc8t.tfm)
Provides:       tex(eksfsc8t.vf)
Provides:       tex(ekui8a.tfm)
Provides:       tex(ekui8a.vf)
Provides:       tex(ekui8r.tfm)
Provides:       tex(gk7a.tfm)
Provides:       tex(gk7t.tfm)
Provides:       tex(gk7t.vf)
Provides:       tex(gkb7a.tfm)
Provides:       tex(gkb7t.tfm)
Provides:       tex(gkb7t.vf)
Provides:       tex(gkbi7a.tfm)
Provides:       tex(gkbi7t.tfm)
Provides:       tex(gkbi7t.vf)
Provides:       tex(gkbo7a.tfm)
Provides:       tex(gkbo7t.tfm)
Provides:       tex(gkbo7t.vf)
Provides:       tex(gkbsc8a.tfm)
Provides:       tex(gkbsc8a.vf)
Provides:       tex(gkbsc8r.tfm)
Provides:       tex(gkbsco8a.tfm)
Provides:       tex(gkbsco8a.vf)
Provides:       tex(gkbsco8r.tfm)
Provides:       tex(gkbui7a.tfm)
Provides:       tex(gkbui7t.tfm)
Provides:       tex(gkbui7t.vf)
Provides:       tex(gkcal7a.tfm)
Provides:       tex(gkcal7t.tfm)
Provides:       tex(gkcal7t.vf)
Provides:       tex(gkerkis.enc)
Provides:       tex(gkerkisc.enc)
Provides:       tex(gki7a.tfm)
Provides:       tex(gki7t.tfm)
Provides:       tex(gki7t.vf)
Provides:       tex(gko7a.tfm)
Provides:       tex(gko7t.tfm)
Provides:       tex(gko7t.vf)
Provides:       tex(gksb7a.tfm)
Provides:       tex(gksb7t.tfm)
Provides:       tex(gksb7t.vf)
Provides:       tex(gksbi7a.tfm)
Provides:       tex(gksbi7t.tfm)
Provides:       tex(gksbi7t.vf)
Provides:       tex(gksbo7a.tfm)
Provides:       tex(gksbo7t.tfm)
Provides:       tex(gksbo7t.vf)
Provides:       tex(gksbui7a.tfm)
Provides:       tex(gksbui7t.tfm)
Provides:       tex(gksbui7t.vf)
Provides:       tex(gksc7a.tfm)
Provides:       tex(gksc7t.tfm)
Provides:       tex(gksc7t.vf)
Provides:       tex(gksco7a.tfm)
Provides:       tex(gksco7t.tfm)
Provides:       tex(gksco7t.vf)
Provides:       tex(gksf7a.tfm)
Provides:       tex(gksf7t.tfm)
Provides:       tex(gksf7t.vf)
Provides:       tex(gksfb7a.tfm)
Provides:       tex(gksfb7t.tfm)
Provides:       tex(gksfb7t.vf)
Provides:       tex(gksfbi7a.tfm)
Provides:       tex(gksfbi7t.tfm)
Provides:       tex(gksfbi7t.vf)
Provides:       tex(gksfi7a.tfm)
Provides:       tex(gksfi7t.tfm)
Provides:       tex(gksfi7t.vf)
Provides:       tex(gksfsc7a.tfm)
Provides:       tex(gksfsc7t.tfm)
Provides:       tex(gksfsc7t.vf)
Provides:       tex(gkui7a.tfm)
Provides:       tex(gkui7t.tfm)
Provides:       tex(gkui7t.vf)
Provides:       tex(gpkerkis.enc)
Provides:       tex(gpkerkisc.enc)
Provides:       tex(k8a.tfm)
Provides:       tex(k8a.vf)
Provides:       tex(k8r.tfm)
Provides:       tex(kb8a.tfm)
Provides:       tex(kb8a.vf)
Provides:       tex(kb8r.tfm)
Provides:       tex(kbi8a.tfm)
Provides:       tex(kbi8a.vf)
Provides:       tex(kbi8r.tfm)
Provides:       tex(kbo8a.tfm)
Provides:       tex(kbo8a.vf)
Provides:       tex(kbo8r.tfm)
Provides:       tex(kbsc8a.tfm)
Provides:       tex(kbsc8a.vf)
Provides:       tex(kbsc8r.tfm)
Provides:       tex(kbsco8a.tfm)
Provides:       tex(kbsco8a.vf)
Provides:       tex(kbsco8r.tfm)
Provides:       tex(kbui8a.tfm)
Provides:       tex(kbui8a.vf)
Provides:       tex(kbui8r.tfm)
Provides:       tex(kcal8a.tfm)
Provides:       tex(kcal8a.vf)
Provides:       tex(kcal8r.tfm)
Provides:       tex(kerkis.enc)
Provides:       tex(kerkis.map)
Provides:       tex(kerkis.sty)
Provides:       tex(kerkisc.enc)
Provides:       tex(kerkisec.enc)
Provides:       tex(kerkisecsc.enc)
Provides:       tex(ki8a.tfm)
Provides:       tex(ki8a.vf)
Provides:       tex(ki8r.tfm)
Provides:       tex(kmath.enc)
Provides:       tex(kmath.sty)
Provides:       tex(kmath8a.tfm)
Provides:       tex(kmath8a.vf)
Provides:       tex(kmath8r.tfm)
Provides:       tex(kmex.enc)
Provides:       tex(kmsym.enc)
Provides:       tex(ko8a.tfm)
Provides:       tex(ko8a.vf)
Provides:       tex(ko8r.tfm)
Provides:       tex(ksb8a.tfm)
Provides:       tex(ksb8a.vf)
Provides:       tex(ksb8r.tfm)
Provides:       tex(ksbi8a.tfm)
Provides:       tex(ksbi8a.vf)
Provides:       tex(ksbi8r.tfm)
Provides:       tex(ksbo8a.tfm)
Provides:       tex(ksbo8a.vf)
Provides:       tex(ksbo8r.tfm)
Provides:       tex(ksbui8a.tfm)
Provides:       tex(ksbui8a.vf)
Provides:       tex(ksbui8r.tfm)
Provides:       tex(ksc8a.tfm)
Provides:       tex(ksc8a.vf)
Provides:       tex(ksc8r.tfm)
Provides:       tex(ksco8a.tfm)
Provides:       tex(ksco8a.vf)
Provides:       tex(ksco8r.tfm)
Provides:       tex(ksf8a.tfm)
Provides:       tex(ksf8t.tfm)
Provides:       tex(ksf8t.vf)
Provides:       tex(ksfb8a.tfm)
Provides:       tex(ksfb8t.tfm)
Provides:       tex(ksfb8t.vf)
Provides:       tex(ksfbi8a.tfm)
Provides:       tex(ksfbi8t.tfm)
Provides:       tex(ksfbi8t.vf)
Provides:       tex(ksfi8a.tfm)
Provides:       tex(ksfi8t.tfm)
Provides:       tex(ksfi8t.vf)
Provides:       tex(ksfsc8a.tfm)
Provides:       tex(ksfsc8t.tfm)
Provides:       tex(ksfsc8t.vf)
Provides:       tex(ktsy8a.tfm)
Provides:       tex(ktsy8a.vf)
Provides:       tex(ktsy8r.tfm)
Provides:       tex(kui8a.tfm)
Provides:       tex(kui8a.vf)
Provides:       tex(kui8r.tfm)
Provides:       tex(lgrkfn.fd)
Provides:       tex(lgrmak.fd)
Provides:       tex(lgrmaksf.fd)
Provides:       tex(omlmak.fd)
Provides:       tex(omsmak.fd)
Provides:       tex(ot1kfn.fd)
Provides:       tex(ot1mak.fd)
Provides:       tex(ot1maksf.fd)
Provides:       tex(t1mak.fd)
Provides:       tex(t1maksf.fd)
Requires:       tex(txfonts.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source144:      kerkis.tar.xz
Source145:      kerkis.doc.tar.xz

%description -n texlive-kerkis
Sans-serif Greek fonts to match the URW Bookman set (which are
distributed with Kerkis). The Kerkis font set has some support
for mathematics as well as other glyphs missing from the base
URW Bookman fonts. Macros are provided to use the fonts in OT1,
T1 (only NG/ng glyphs missing) and LGR encodings, as well as in
mathematics; small caps and old-style number glyphs are also
available. The philosophy, and the design process, of the
Kerkis fonts is discussed in a paper in TUGboat 23(3/4), 2002.

%package -n texlive-kerkis-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.11svn56271
Release:        0
Summary:        Documentation for texlive-kerkis
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kerkis and texlive-alldocumentation)

%description -n texlive-kerkis-doc
This package includes the documentation for texlive-kerkis

%package -n texlive-kerkis-fonts
Version:        %{texlive_version}.%{texlive_noarch}.1.11svn56271
Release:        0
Summary:        Severed fonts for texlive-kerkis
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-kerkis-fonts
The  separated fonts package for texlive-kerkis

%post -n texlive-kerkis
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap kerkis.map' >> /var/run/texlive/run-updmap

%postun -n texlive-kerkis
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap kerkis.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-kerkis
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-kerkis-fonts

%files -n texlive-kerkis-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/kerkis/License.txt
%{_texmfdistdir}/doc/fonts/kerkis/README

%files -n texlive-kerkis
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-Bold.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-BoldItalic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-BoldSmallCaps.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-Calligraphic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-Italic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-SemiBold-Italic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-SemiBold.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis-SmallCaps.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/Kerkis.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/KerkisSans-Bold.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/KerkisSans-BoldItalic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/KerkisSans-Italic.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/KerkisSans-SmallCaps.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/KerkisSans.afm
%{_texmfdistdir}/fonts/afm/public/kerkis/ktsy.afm
%{_texmfdistdir}/fonts/enc/dvips/kerkis/gkerkis.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/gkerkisc.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/gpkerkis.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/gpkerkisc.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kerkis.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kerkisc.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kerkisec.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kerkisecsc.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kmath.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kmex.enc
%{_texmfdistdir}/fonts/enc/dvips/kerkis/kmsym.enc
%{_texmfdistdir}/fonts/map/dvips/kerkis/kerkis.map
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-BoldSmallCaps.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-Calligraphic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-SemiBold-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-SemiBold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis-SmallCaps.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/Kerkis.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/KerkisSans-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/KerkisSans-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/KerkisSans-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/KerkisSans-SmallCaps.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kerkis/KerkisSans.otf
%{_texmfdistdir}/fonts/tfm/public/kerkis/ek8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ek8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekb8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbi8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbo8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbo8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbsco8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbsco8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekbui8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekcal8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekcal8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eki8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eki8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eko8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eko8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksb8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbi8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbo8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbo8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksbui8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksco8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksco8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksf8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksf8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfb8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfbi8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfi8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/eksfsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ekui8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gk7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gk7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkb7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkb7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbi7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbi7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbo7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbo7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbsco8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbsco8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbui7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkbui7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkcal7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkcal7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gki7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gki7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gko7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gko7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksb7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksb7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbi7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbi7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbo7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbo7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbui7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksbui7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksc7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksco7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksco7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksf7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksf7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfb7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfb7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfbi7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfbi7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfi7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfi7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfsc7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gksfsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkui7a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/gkui7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/k8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/k8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kb8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbi8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbo8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbo8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbsco8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbsco8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kbui8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kcal8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kcal8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ki8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ki8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kmath8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kmath8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ko8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ko8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksb8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbi8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbo8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbo8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksbui8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksco8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksco8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksf8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksf8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfb8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfb8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfbi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfbi8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfi8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfi8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ksfsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ktsy8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/ktsy8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kui8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kerkis/kui8r.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-Bold.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-BoldItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-BoldSmallCaps.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-Calligraphic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-Italic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-SemiBold-Italic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-SemiBold.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis-SmallCaps.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/Kerkis.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/KerkisSans-Bold.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/KerkisSans-BoldItalic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/KerkisSans-Italic.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/KerkisSans-SmallCaps.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/KerkisSans.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kerkis/ktsy.pfb
%{_texmfdistdir}/fonts/vf/public/kerkis/ek8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekb8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekbi8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekbo8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekbsc8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekbsco8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekbui8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekcal8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eki8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eko8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksb8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksbi8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksbo8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksbui8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksc8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksco8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksf8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksfb8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksfbi8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksfi8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/eksfsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ekui8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gk7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkb7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkbi7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkbo7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkbsc8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkbsco8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkbui7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkcal7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gki7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gko7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksb7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksbi7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksbo7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksbui7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksc7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksco7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksf7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksfb7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksfbi7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksfi7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gksfsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/gkui7t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/k8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kb8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kbi8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kbo8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kbsc8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kbsco8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kbui8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kcal8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ki8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kmath8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ko8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksb8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksbi8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksbo8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksbui8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksc8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksco8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksf8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksfb8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksfbi8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksfi8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ksfsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/ktsy8a.vf
%{_texmfdistdir}/fonts/vf/public/kerkis/kui8a.vf
%{_texmfdistdir}/tex/latex/kerkis/kerkis.sty
%{_texmfdistdir}/tex/latex/kerkis/kmath.sty
%{_texmfdistdir}/tex/latex/kerkis/lgrkfn.fd
%{_texmfdistdir}/tex/latex/kerkis/lgrmak.fd
%{_texmfdistdir}/tex/latex/kerkis/lgrmaksf.fd
%{_texmfdistdir}/tex/latex/kerkis/omlmak.fd
%{_texmfdistdir}/tex/latex/kerkis/omsmak.fd
%{_texmfdistdir}/tex/latex/kerkis/ot1kfn.fd
%{_texmfdistdir}/tex/latex/kerkis/ot1mak.fd
%{_texmfdistdir}/tex/latex/kerkis/ot1maksf.fd
%{_texmfdistdir}/tex/latex/kerkis/t1mak.fd
%{_texmfdistdir}/tex/latex/kerkis/t1maksf.fd

%files -n texlive-kerkis-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-kerkis
%{_datadir}/fontconfig/conf.avail/58-texlive-kerkis.conf
%{_datadir}/fontconfig/conf.avail/55-texlive-kerkis.conf
%config %{_sysconfdir}/fonts/conf.d/55-texlive-kerkis.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kerkis/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kerkis/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kerkis/fonts.scale
%{_datadir}/fonts/texlive-kerkis/Kerkis-Bold.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-BoldItalic.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-BoldSmallCaps.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-Calligraphic.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-Italic.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-SemiBold-Italic.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-SemiBold.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-SmallCaps.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis.otf
%{_datadir}/fonts/texlive-kerkis/KerkisSans-Bold.otf
%{_datadir}/fonts/texlive-kerkis/KerkisSans-BoldItalic.otf
%{_datadir}/fonts/texlive-kerkis/KerkisSans-Italic.otf
%{_datadir}/fonts/texlive-kerkis/KerkisSans-SmallCaps.otf
%{_datadir}/fonts/texlive-kerkis/KerkisSans.otf
%{_datadir}/fonts/texlive-kerkis/Kerkis-Bold.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-BoldItalic.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-BoldSmallCaps.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-Calligraphic.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-Italic.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-SemiBold-Italic.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-SemiBold.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis-SmallCaps.pfb
%{_datadir}/fonts/texlive-kerkis/Kerkis.pfb
%{_datadir}/fonts/texlive-kerkis/KerkisSans-Bold.pfb
%{_datadir}/fonts/texlive-kerkis/KerkisSans-BoldItalic.pfb
%{_datadir}/fonts/texlive-kerkis/KerkisSans-Italic.pfb
%{_datadir}/fonts/texlive-kerkis/KerkisSans-SmallCaps.pfb
%{_datadir}/fonts/texlive-kerkis/KerkisSans.pfb
%{_datadir}/fonts/texlive-kerkis/ktsy.pfb

%package -n texlive-kerntest
Version:        %{texlive_version}.%{texlive_noarch}.1.32svn15878
Release:        0
License:        LPPL-1.0
Summary:        Print tables and generate control files to adjust kernings
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kerntest-doc >= %{texlive_version}
Provides:       tex(kerntest.cls)
Provides:       tex(ly1mtx.clo)
Provides:       tex(ot1mtx.clo)
Provides:       tex(t1cmr-1200.fd)
Provides:       tex(t1mtx.clo)
Provides:       tex(t2amtx.clo)
Provides:       tex(t2bmtx.clo)
Provides:       tex(ts1mtx.clo)
Requires:       tex(array.sty)
Requires:       tex(article.cls)
Requires:       tex(calc.sty)
Requires:       tex(color.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(geometry.sty)
Requires:       tex(helvet.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(keyval.sty)
Requires:       tex(longtable.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source146:      kerntest.tar.xz
Source147:      kerntest.doc.tar.xz

%description -n texlive-kerntest
This class makes it easy to generate tables that show many
different kerning pairs of an arbitrary font, usable by LaTeX.
It shows the kerning values that are used in the font by
default. In addition, this class enables the user to alter the
kernings and to observe the results. Kerning pairs can be
defined for groups of similar glyphs at the same time. An mtx
file is generated automatically. The mtx file may then be
loaded by fontinst to introduce the user-made kernings into the
virtual font for later use in LaTeX.

%package -n texlive-kerntest-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.32svn15878
Release:        0
Summary:        Documentation for texlive-kerntest
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kerntest and texlive-alldocumentation)

%description -n texlive-kerntest-doc
This package includes the documentation for texlive-kerntest

%post -n texlive-kerntest
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kerntest
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kerntest
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kerntest-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kerntest/ChangeLog
%{_texmfdistdir}/doc/latex/kerntest/README
%{_texmfdistdir}/doc/latex/kerntest/ToDo
%{_texmfdistdir}/doc/latex/kerntest/kerntest.pdf
%{_texmfdistdir}/doc/latex/kerntest/krntst-v.tex
%{_texmfdistdir}/doc/latex/kerntest/ot1-XXX-m-n.tex
%{_texmfdistdir}/doc/latex/kerntest/schoolb.map
%{_texmfdistdir}/doc/latex/kerntest/schoolb1.tex
%{_texmfdistdir}/doc/latex/kerntest/schoolb2.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-9nc-m-n-1.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-9nc-m-n-2.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-XXX-m-n.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-cmr-m-n-1200.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-ptm-bx-n-example.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-ptm-m-n-shortexample.tex
%{_texmfdistdir}/doc/latex/kerntest/t1-ptm-m-n.tex
%{_texmfdistdir}/doc/latex/kerntest/testschoolb.tex
%{_texmfdistdir}/doc/latex/kerntest/ts1-XXX-m-n.tex

%files -n texlive-kerntest
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kerntest/kerntest.cls
%{_texmfdistdir}/tex/latex/kerntest/ly1mtx.clo
%{_texmfdistdir}/tex/latex/kerntest/ot1mtx.clo
%{_texmfdistdir}/tex/latex/kerntest/t1cmr-1200.fd
%{_texmfdistdir}/tex/latex/kerntest/t1mtx.clo
%{_texmfdistdir}/tex/latex/kerntest/t2amtx.clo
%{_texmfdistdir}/tex/latex/kerntest/t2bmtx.clo
%{_texmfdistdir}/tex/latex/kerntest/ts1mtx.clo

%package -n texlive-ketcindy
Version:        %{texlive_version}.%{texlive_noarch}.20191225.0svn58661
Release:        0
License:        GPL-2.0-or-later
Summary:        Macros for graphic generation and Cinderella plugin
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-ketcindy-bin >= %{texlive_version}
#!BuildIgnore: texlive-ketcindy-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ketcindy-doc >= %{texlive_version}
Requires:       perl(Digest::MD5)
#!BuildIgnore:  perl(Digest::MD5)
Requires:       perl(File::Copy)
#!BuildIgnore:  perl(File::Copy)
Requires:       perl(strict)
#!BuildIgnore:  perl(strict)
Provides:       tex(KetCindyPlugin.jar)
Provides:       tex(ketlayer.sty)
Provides:       tex(ketlayer2e.sty)
Provides:       tex(ketmedia.sty)
Provides:       tex(ketpic.sty)
Provides:       tex(ketpic2e.sty)
Provides:       tex(ketslide.sty)
Provides:       tex(ketslide2.sty)
Requires:       java
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(color.sty)
Requires:       tex(graphicx.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source148:      ketcindy.tar.xz
Source149:      ketcindy.doc.tar.xz

%description -n texlive-ketcindy
KETpic is a macro package designed for computer algebra systems
(CAS) to generate LaTeX source codes for high-quality
mathematical artwork. KETcindy is a plugin for Cinderella that
allows to generate graphics using KETpic. The generated code
can be included in any LaTeX document.

%package -n texlive-ketcindy-doc
Version:        %{texlive_version}.%{texlive_noarch}.20191225.0svn58661
Release:        0
Summary:        Documentation for texlive-ketcindy
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ketcindy and texlive-alldocumentation)
Provides:       locale(texlive-ketcindy-doc:ja)

%description -n texlive-ketcindy-doc
This package includes the documentation for texlive-ketcindy

%post -n texlive-ketcindy
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ketcindy
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ketcindy
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ketcindy-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/support/ketcindy/HowToInstallE.pdf
%{_texmfdistdir}/doc/support/ketcindy/HowToInstallJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/LICENSE
%{_texmfdistdir}/doc/support/ketcindy/README
%{_texmfdistdir}/doc/support/ketcindy/README.TeXLive
%{_texmfdistdir}/doc/support/ketcindy/Scriptkelib.txt
%{_texmfdistdir}/doc/support/ketcindy/forLinux/ReadmeLinuxE.pdf
%{_texmfdistdir}/doc/support/ketcindy/forLinux/ReadmeLinuxJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/forLinux/setcindyetc.sh
%{_texmfdistdir}/doc/support/ketcindy/forLinux/setketcindy.sh
%{_texmfdistdir}/doc/support/ketcindy/forLinux/setwork.sh
%{_texmfdistdir}/doc/support/ketcindy/forMac/Forsettingmanually/ketcindy.conf
%{_texmfdistdir}/doc/support/ketcindy/forMac/Forsettingmanually/ketcindy.ini
%{_texmfdistdir}/doc/support/ketcindy/forMac/ReadmeMacE.pdf
%{_texmfdistdir}/doc/support/ketcindy/forMac/ReadmeMacJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/forMac/setketcindy.command
%{_texmfdistdir}/doc/support/ketcindy/forMac/setwork.command
%{_texmfdistdir}/doc/support/ketcindy/forWindows/Forsettingmanually/ketcindy.conf
%{_texmfdistdir}/doc/support/ketcindy/forWindows/Forsettingmanually/ketcindy.ini
%{_texmfdistdir}/doc/support/ketcindy/forWindows/ReadmeWinE.pdf
%{_texmfdistdir}/doc/support/ketcindy/forWindows/ReadmeWinJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/3dlist.txt
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/Cindy.js
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/Cindy.js.map
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/CindyJS.css
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/basic1list.txt
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/basic2list.txt
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/basic3list.txt
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/ignoredfun.txt
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex-plugin.js
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Main-Regular.ttf
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Main-Regular.woff
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Main-Regular.woff2
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Math-Italic.ttf
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Math-Italic.woff
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts/KaTeX_Math-Italic.woff2
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/katex.min.css
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/katex.min.js
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/makefunlist.cdy
%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/webfont.js
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTCindyGuideE.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTCindyGuideJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTCindyReferenceE.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTCindyReferenceJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTPicStyleE.pdf
%{_texmfdistdir}/doc/support/ketcindy/ketmanual/KeTPicStyleJ.pdf
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0101figure.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0101figurepdf.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0102figure2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0103polygon.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0104shade.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0105vector.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0106bowdotfill.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0106bowhatch.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0107hyperbolahatch.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0108cycloid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0109epitrochoid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure/s0110hypotrochoid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0201basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0202graph1.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0203graph2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0204graph3.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0205coniccurve.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0206defexp.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0207envelope.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0208intersecthatch.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0209diffeq.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0210diffeq2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0212implicit.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0213implicithatch.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0214inputvalue.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph/s0215quacurve.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0301table.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0302table2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0302table2line.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0303gridpaper.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0303gridpaper1.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0303gridpaperlog.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0303gridpaperloglog.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0304graphforincanddec.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0304multitables.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0305twotables.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s03table/s0306tenkey.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/dogwalk.png
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/heart.png
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/mtfuji.png
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0401bezierbasic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0402ospline.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0403oshimaspline.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0403osplinecrspline.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0404heart.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0405dogwalk.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier/s0406mtfuji.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/DownloadPolyhedrons_objE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/DownloadPolyhedrons_objJ.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0501basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0501plane.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0502spacecurve.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0503perp.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0504embed.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0505bezier3d.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0506embedhatch.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0507polyhedron.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0508concatobj.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0509cubiccut.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0510cubiccut2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0511tetra.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0521totaldiffskeleton.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure/s0522conecutmaxima.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0601cycloid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0602diffeq.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0603envelope.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0604diffeq2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0605cycloid2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0606epitrochoid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0607hypotrochoid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0608ellipsefocus.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0609hyperbolafocus.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0610parabolafocus.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation/s0611generalangle.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/figwall/wallpaper.tex
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/howtouseslideE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/howtouseslideJ.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0701basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0701basic.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0701basicE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0701basicE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0702graph.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0702graph.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0702graphE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0702graphE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0703repeat.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0703repeat.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0703repeatE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0703repeatE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0704thin.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0704thin.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0704thinE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0704thinE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0705para.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0705para.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0705paraE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0705paraE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0706animate.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0706animate.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0706animateE.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/s0706animateE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0801plotR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0802plotR2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0803plotdiscR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0804boxplot.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0805histplot.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0806random.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0807dataframe.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s08R/s0808ttest.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0901paraboloid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0902cone.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0903saddle.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0904mant.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0905sphere.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0906curveonsurf.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0907intersectcrvsf.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0908wiredata.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0909conecut.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0910multisurfaces.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0911saddleskeleton.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0912animesaddle.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0913animeparaboloid.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0914animemobius.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0915discont.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC/s0916multiandcut.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1001basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1001factorial.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1002equation.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1003trig.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1004calcby.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1005diffint.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1005intplot.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1006calculus.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1007linalg.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1008idtable.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1009diffeq.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1010fourier.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1011matrixop.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1012for.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1012odefor.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1013incdec.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima/s1014primenumber.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1100list.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1101calculator1.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1102calculator2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1103calcby.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1104diff.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1105fint101.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1105fzero109.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1106fmmx110.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1110integrate.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1111grobner1.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir/s1112residue.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas/s1201integrate.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas/s1201integrate2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas/s1202calcby.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas/s1202equations.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1301basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1303objparts.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1304symbol.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1305hyperpara.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1306poly.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1307poly2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1308discont.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1309discont2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1310totaldiff.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1311plate.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1312plane.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview/s1313changescale.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing/s1401csvprocessing.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing/s1402copypaste.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing/s1403maketableJ.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing/sample1.csv
%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing/sample2.csv
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1501paraboloidR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1502coneR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1503saddleR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1504mantR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1505sphereR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1506curveonsurfR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1507intersectcrvsfR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1508multisurfacesR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1509wiredataR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR/s1510conecutR.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/howtouseketcindyjsE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/howtouseketcindyjsJ.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1601basic.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1602diffeq2.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1603gamow.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1604putoncurve.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1605triangle.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1606morley.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1607inputbox.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1608texcalc.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc/s1609trigratio.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc/ReadmeE.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc/ReadmeJ.txt
%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc/Spacekc.cdy
%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc/Spacekc.pdf
%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc/SpacekcReference.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/KetCindyPlugin.iml
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/build.xml
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/config/META-INF/services/de.cinderella.api.cs.CindyScriptPlugin
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/lib/cindy2.jar
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/lib/commons-math.jar
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/src/KetCindyPlugin.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin150906.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160515.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160518.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160530.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160601.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160604.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160609.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin160723.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin161019.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin161021.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin161209.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin170605.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin170906.java
%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold/KetCindyPlugin171112.java
%{_texmfdistdir}/doc/support/ketcindy/source/cdy-templates/Makefile
%{_texmfdistdir}/doc/support/ketcindy/source/howtoinstall/HowToInstallE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/howtoinstall/HowToInstallJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/3dscreen.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/3dstart.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/CindyhelpE.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/Dotfill.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-10.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-6.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-7.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-8.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-9.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead-ya1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead2-10.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead2-6.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead2-7.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead2-8.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ForRef-Arrowhead2-9.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/Framedata.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita5E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita6E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita7.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita7E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita8.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/HatchZuKita9.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/Intersectcurvsf.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/IntersectsgpL0.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/IntersectsgpL1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/IntersectsgpL2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/Nearestpt.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/Nearestpt1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/PutcellE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/addax1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/addax2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/addgraph.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/angle-mark.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/angle.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/anglearrow.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/anglearrowscreen.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/anglemark.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/anglemark2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/animestart.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/arrowdata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/arrowhead.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/assign.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/bbdata.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/bezier3d1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/binvsnormal.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/bisector.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/bowdata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/bowdata2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/boxframeslide.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/boxplot.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/boxplot01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/calcbyr01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/calling.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/cardioid1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/changetable.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkCR.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkb10.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkb11.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkb8.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkb9.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe6.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe7.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbe8.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbmain.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbs1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkbs2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checkmc1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checksm1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checksm2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checksy1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/checksy2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circle-by-radius.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circledata1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circledata2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circledata3.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circledata4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/circledata5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/coloring.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/colortable.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/concatobj.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/concept.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/conceptE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/crosspoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/crvsfparadata1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/crvsfparadata2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deffun01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deffun02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deffun03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/delete.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deqplot1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deqplot2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/deqplot3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/derivative.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/diffeq1.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/drawfigures1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/drawpoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/drwxy.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ellipse-by-foci.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ellipsecindy.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ellipseplot1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ellipseplot2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/embed01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/embed02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/embed03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/enclosing.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ewns.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ewsn.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/execcmdc1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/expr.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/exprrot.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/exprrot.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/fontsize.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/fourier.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/fourierseries.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/frustume.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/frustumew.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/frustumewn.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/frustumw.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/gpro01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/gpro02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/greenring.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/grid-less.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/grid-more.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hatch5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/histgram.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/htickmark.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/htickmark01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hyper1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/hyperbola-by-foci.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/implicit.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/implicit1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/incenter01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/incenter02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/incenter02E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/incenter03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/intersectcrvs1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/intersectcrvs2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/intersection.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/intlog.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/inversefun.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/invparapt.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/joincrvs.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/kobayashi.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/kobayashiE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/letter.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/letter2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/letter3d.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/letter4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/lineplot.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/listplot1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/listplot2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/listplot3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/listplot3view.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/makeslide.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/makeslideE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/maxfun01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/maxfun02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/maxima1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/meshlab01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/meshlab02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/meshlab03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/meshlab06.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/middle.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mirror.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mkpttable.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mkpttableE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/move.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/moviedata01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/moviedata02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/multi-add-circle.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/multi-add-line.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/multi-add-parallel.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/multi-add-perp.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mvgaiyou01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mxbatch.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mxtex01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mxtex01E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mxtex02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/mxtex03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/nohiddenbyfaces1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/nohiddenbyfaces2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/numptcrv.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/oresenex01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ospline1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ospline2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ovaldata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/parabola-by-foci.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/parabola.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/parabolaplot.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/parabolaplot.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/parabolaplotE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/paramark.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/paramoncrv.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/paramplot1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/paramplot2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv3d1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv3d2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/partcrv4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/pdexample.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/pdtoconsole.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/periodfun.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/periodfun2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/perpplane.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/perppt.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/phparadata01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/phparadata02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/phparadata03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/phparadata04.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdata1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdata2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdata3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdata4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdata5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdatar1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdatatan1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/plotdatatan2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/pointdata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/pointoncrv.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/pointsize.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/poison01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polar-of-point.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polygon.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polygonplane1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polygonplane2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polygonplot1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/polygonplot2.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ptcrv.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ptselected01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ptselected02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ptstart.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putcell.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putcol.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putcolE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putintersect.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putoncurve.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putoncurve.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putonline1.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/putonseg.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rasen.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/readobj.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/reflectdata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/reflectdata3d01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/reflectdata3d02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/reflectdata3d03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/reflectpoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rotatedata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rotatedata3d01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rotatedata3d02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rotatepoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/rshade.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ruler.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/ruler1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/s106bowhatch.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/s10diffint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/s210diffeq1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/s305graphforincanddec.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/s305incanddec.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/saddle1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/saddle1E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/saddle2E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/scaledata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/scaledata3d.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/scalepoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/scatter.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/segmark.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/segment.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/select-lines.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/select-points.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setax-theta.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setcolor.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setorigin.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setorigin.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setscaling.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/setwindow.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sf3ddata3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sf3ddata4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfbdpara01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfbdpara02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfbdpara03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfbdpara04.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfbdpara05.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sfcut.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/shade.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/shade01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/shade01E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/shadeE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/single-add.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/skeletonparadata01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/skeletonparadata02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/skeletonparadata03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slide01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slide01E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slidepdf1.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slidepdf2.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slidepdf3.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slider.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sliderepeat.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/sliderepeatE.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slidescreen.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slidescript.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slot.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/slotE.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/snap.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/spacelinecurve1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/spacelinecurve2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start04.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start05.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start06.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start07.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start08.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start09.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/start10.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/surfacemodel.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/surfacemodelE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list00.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list001.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list001E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list01E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list02E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list03E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list04.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tab2list04E.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/table01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/table02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/table03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tablesample1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tablesample1E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tablesample2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tablesample2E.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tangent.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/taylor.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/tetrahedron.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/translate-view.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/translate01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/translatedata.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/translatepoint.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/trimarrow.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/trimseg.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/vertex01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wire01.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wire02.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wire03.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wire04.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wirepara1.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wirepara2.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wirepara3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wirepara4.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/wirepara5.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/xsinx.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/xsinx01.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/xsinx02.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/xsinx03.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/zogen3.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/zoom-in.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig/zoom-out.pdf
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTCindyGuideE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTCindyGuideJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTCindyReferenceE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTCindyReferenceJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTPicStyleE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/KeTPicStyleJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeLinuxE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeLinuxJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeMacE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeMacJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeWinE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/readme/ReadmeWinJ.tex
%{_texmfdistdir}/doc/support/ketcindy/source/spacekc/SpacekcReferenceE.tex
%{_texmfdistdir}/doc/support/ketcindy/source/spacekc/SpacekcReferenceJ.tex

%files -n texlive-ketcindy
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/ketcindy/allbuttons.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/0Small.png
%{_texmfdistdir}/scripts/ketcindy/data/fontF/0Smalla-h.png
%{_texmfdistdir}/scripts/ketcindy/data/fontF/0Smalli-o.png
%{_texmfdistdir}/scripts/ketcindy/data/fontF/0Smallp-w.png
%{_texmfdistdir}/scripts/ketcindy/data/fontF/0Smallxyz.png
%{_texmfdistdir}/scripts/ketcindy/data/fontF/nsi.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/nsi.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/pcr.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/pcr.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/qcr.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/qcr.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/rcr.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/rcr.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/tsi.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/tsi.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/xsi.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/xsi.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/ysi.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/ysi.txt
%{_texmfdistdir}/scripts/ketcindy/data/fontF/zsi.cdy
%{_texmfdistdir}/scripts/ketcindy/data/fontF/zsi.txt
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/r01.obj
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/r02.obj
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/r03.obj
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/r04.obj
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/r05.obj
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/readme.pdf
%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj/readme.txt
%{_texmfdistdir}/scripts/ketcindy/ketcindy.conf
%{_texmfdistdir}/scripts/ketcindy/ketcindy.ini
%{_texmfdistdir}/scripts/ketcindy/ketcindy.pl
%{_texmfdistdir}/scripts/ketcindy/ketcindy.sh
%{_texmfdistdir}/scripts/ketcindy/ketjava/KetCindyPlugin.jar
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dhelpE.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dhelpJ.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dlogr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dr.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic1logr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic1r.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic2logr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic2r.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic3logr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibbasic3r.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibhelpE.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibhelpJ.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvhelpE.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvhelpJ.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvlogr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvr.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindyliboutlogr.txt
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindyliboutr.cs
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketpicR/ketpic5_2_4.r
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketpiccurrent.r
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketpiccurrent_rep2e.r
%{_texmfdistdir}/scripts/ketcindy/ketlib/ketpiccurrent_reptikz.r
%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL/fourier_sec.max
%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL/matoperation.max
%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL/pdefourier.mac
%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL/poincare.mac
%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL/rkfun.lisp
%{_texmfdistdir}/scripts/ketcindy/ketlib/oshima/os_muldif.pdf
%{_texmfdistdir}/scripts/ketcindy/ketlib/oshima/os_muldif.rr
%{_texmfdistdir}/scripts/ketcindy/ketlibC/ketcommon.h
%{_texmfdistdir}/scripts/ketcindy/ketlibC/ketcommonhead.h
%{_texmfdistdir}/scripts/ketcindy/ketlibC/ketlibClog.txt
%{_texmfdistdir}/scripts/ketcindy/ketlibC/surflib.h
%{_texmfdistdir}/scripts/ketcindy/ketlibC/surflibhead.h
%{_texmfdistdir}/scripts/ketcindy/ketoutset.txt
%{_texmfdistdir}/scripts/ketcindy/setketcindy.txt
%{_texmfdistdir}/scripts/ketcindy/template0.cdy
%{_texmfdistdir}/scripts/ketcindy/template1basic.cdy
%{_texmfdistdir}/scripts/ketcindy/template3Dfigure.cdy
%{_texmfdistdir}/scripts/ketcindy/template4ketcindyjs.cdy
%{_texmfdistdir}/tex/latex/ketcindy/ketlayer.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketlayer2e.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketmedia.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketpic.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketpic2e.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketslide.sty
%{_texmfdistdir}/tex/latex/ketcindy/ketslide2.sty

%package -n texlive-keycommand
Version:        %{texlive_version}.%{texlive_noarch}.3.1415svn18042
Release:        0
License:        LPPL-1.0
Summary:        Simple creation of commands with key-value arguments
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keycommand-doc >= %{texlive_version}
Provides:       tex(keycommand.sty)
Requires:       tex(etex.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(kvsetkeys.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source150:      keycommand.tar.xz
Source151:      keycommand.doc.tar.xz

%description -n texlive-keycommand
The package (which requires e-TeX) provides a natural way to
define commands with optional keys. The package provides
\newkeycommand, \renewkeycommand, \providekeycommand,
\newkeyenvironment and \renewkeyenvironment, together with
\keycmd for a more advanced interface. The package is based on
kvsetkeys by Heiko Oberdiek.

%package -n texlive-keycommand-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.1415svn18042
Release:        0
Summary:        Documentation for texlive-keycommand
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keycommand and texlive-alldocumentation)

%description -n texlive-keycommand-doc
This package includes the documentation for texlive-keycommand

%post -n texlive-keycommand
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keycommand
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keycommand
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keycommand-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keycommand/README
%{_texmfdistdir}/doc/latex/keycommand/keycommand-example.pdf
%{_texmfdistdir}/doc/latex/keycommand/keycommand-example.tex
%{_texmfdistdir}/doc/latex/keycommand/keycommand.pdf

%files -n texlive-keycommand
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keycommand/keycommand.sty

%package -n texlive-keyfloat
Version:        %{texlive_version}.%{texlive_noarch}.2.08svn65446
Release:        0
License:        LPPL-1.0
Summary:        Provides a key/value interface for generating floats
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyfloat-doc >= %{texlive_version}
Provides:       tex(keyfloat.sty)
Requires:       tex(calc.sty)
Requires:       tex(caption.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(placeins.sty)
Requires:       tex(rotating.sty)
Requires:       tex(subcaption.sty)
Requires:       tex(wrapfig.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source152:      keyfloat.tar.xz
Source153:      keyfloat.doc.tar.xz

%description -n texlive-keyfloat
The keyfloat package provides a key/value user interface for
quickly creating figures with a single image each, figures with
arbitrary contents, tables, subfloats, rows of floats, floats
located [H]ere, floats in the [M]argin, and floats with text
[W]rapped around them. Key/value combinations may specify a
caption and label, a width proportional to \linewidth, a fixed
width and/or height, rotation, scaling, a tight or loose frame,
an \arraystretch, a continued float, additional supplemental
text, and an artist/author's name with automatic index entry.
When used with the tocdata package, the name also appears in
the List of Figures. Floats may be placed into a row
environment, and are typeset to fit within the given number of
columns, continuing to the next row if necessary. Nested
sub-rows may be used to generate layouts such as two small
figures placed vertically next to one larger figure. Subfloats
are supported by two environments.

%package -n texlive-keyfloat-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.08svn65446
Release:        0
Summary:        Documentation for texlive-keyfloat
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyfloat and texlive-alldocumentation)

%description -n texlive-keyfloat-doc
This package includes the documentation for texlive-keyfloat

%post -n texlive-keyfloat
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyfloat
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyfloat
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyfloat-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyfloat/README.txt
%{_texmfdistdir}/doc/latex/keyfloat/images/image.pdf
%{_texmfdistdir}/doc/latex/keyfloat/images/image2.pdf
%{_texmfdistdir}/doc/latex/keyfloat/keyfloat.pdf

%files -n texlive-keyfloat
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyfloat/keyfloat.sty

%package -n texlive-keyindex
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn50828
Release:        0
License:        LPPL-1.0
Summary:        Index entries by key lookup
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyindex-doc >= %{texlive_version}
Provides:       tex(keyindex.sty)
Requires:       tex(ifthen.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source154:      keyindex.tar.xz
Source155:      keyindex.doc.tar.xz

%description -n texlive-keyindex
The package provides functionality for producing an index
without directly entering index entries into the text using the
\index command, but instead by looking up short keys and
printing a predefined string in the main text and adding a
corresponding index entry. The standard use case is the
production of an index of names.

%package -n texlive-keyindex-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn50828
Release:        0
Summary:        Documentation for texlive-keyindex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyindex and texlive-alldocumentation)

%description -n texlive-keyindex-doc
This package includes the documentation for texlive-keyindex

%post -n texlive-keyindex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyindex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyindex
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyindex-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyindex/README.md
%{_texmfdistdir}/doc/latex/keyindex/keyindex.pdf
%{_texmfdistdir}/doc/latex/keyindex/makenameindex

%files -n texlive-keyindex
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyindex/keyindex.sty

%package -n texlive-keyparse
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn60277
Release:        0
License:        LPPL-1.0
Summary:        Key based parser
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyparse-doc >= %{texlive_version}
Provides:       tex(keyparse.sty)
Requires:       tex(expl3.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source156:      keyparse.tar.xz
Source157:      keyparse.doc.tar.xz

%description -n texlive-keyparse
This LaTeX package provides an interface to define and evaluate
key-based replacement rules. It can be used to parse the
argument specification of a document command.

%package -n texlive-keyparse-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn60277
Release:        0
Summary:        Documentation for texlive-keyparse
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyparse and texlive-alldocumentation)

%description -n texlive-keyparse-doc
This package includes the documentation for texlive-keyparse

%post -n texlive-keyparse
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyparse
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyparse
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyparse-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyparse/README.md
%{_texmfdistdir}/doc/latex/keyparse/keyparse.pdf

%files -n texlive-keyparse
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyparse/keyparse.sty

%package -n texlive-keyreader
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5bsvn28195
Release:        0
License:        LPPL-1.0
Summary:        A robust interface to xkeyval
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyreader-doc >= %{texlive_version}
Provides:       tex(keyreader.sty)
Requires:       tex(pdftexcmds.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source158:      keyreader.tar.xz
Source159:      keyreader.doc.tar.xz

%description -n texlive-keyreader
The package provides a robust interface to controlling keys in
xkeyval, removing some of that package's restrictions. The
package also addresses some of the issues now covered by the
author's ltxkeys package, which was assumed to be a replacement
for keyreader. Since keyreader has remained a favourite with
users, it has been reinstated.

%package -n texlive-keyreader-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5bsvn28195
Release:        0
Summary:        Documentation for texlive-keyreader
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyreader and texlive-alldocumentation)

%description -n texlive-keyreader-doc
This package includes the documentation for texlive-keyreader

%post -n texlive-keyreader
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyreader
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyreader
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyreader-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyreader/README
%{_texmfdistdir}/doc/latex/keyreader/keyreader-example1.tex
%{_texmfdistdir}/doc/latex/keyreader/keyreader-guide.pdf
%{_texmfdistdir}/doc/latex/keyreader/keyreader-guide.tex

%files -n texlive-keyreader
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyreader/keyreader.sty

%package -n texlive-keystroke
Version:        %{texlive_version}.%{texlive_noarch}.1.6svn17992
Release:        0
License:        GPL-2.0-or-later
Summary:        Graphical representation of keys on keyboard
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keystroke-doc >= %{texlive_version}
Provides:       tex(keystroke.sty)
Requires:       tex(graphics.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source160:      keystroke.tar.xz
Source161:      keystroke.doc.tar.xz

%description -n texlive-keystroke
A LaTeX package which provides macros for the graphical
representation of the keys on a computer keyboard.

%package -n texlive-keystroke-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.6svn17992
Release:        0
Summary:        Documentation for texlive-keystroke
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keystroke and texlive-alldocumentation)

%description -n texlive-keystroke-doc
This package includes the documentation for texlive-keystroke

%post -n texlive-keystroke
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keystroke
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keystroke
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keystroke-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keystroke/README
%{_texmfdistdir}/doc/latex/keystroke/key-test.pdf
%{_texmfdistdir}/doc/latex/keystroke/key-test.tex

%files -n texlive-keystroke
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keystroke/keystroke.sty
%{_texmfdistdir}/tex/latex/keystroke/keystroke_left.eps
%{_texmfdistdir}/tex/latex/keystroke/keystroke_left.pdf
%{_texmfdistdir}/tex/latex/keystroke/keystroke_middle.eps
%{_texmfdistdir}/tex/latex/keystroke/keystroke_middle.pdf
%{_texmfdistdir}/tex/latex/keystroke/keystroke_right.eps
%{_texmfdistdir}/tex/latex/keystroke/keystroke_right.pdf

%package -n texlive-keyval2e
Version:        %{texlive_version}.%{texlive_noarch}.0.0.0.2svn23698
Release:        0
License:        LPPL-1.0
Summary:        A lightweight and robust key-value parser
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyval2e-doc >= %{texlive_version}
Provides:       tex(keyval2e.sty)
Requires:       tex(catoptions.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source162:      keyval2e.tar.xz
Source163:      keyval2e.doc.tar.xz

%description -n texlive-keyval2e
The package provides lightweight and robust facilities for
creating and managing keys. Its machinery isn't as extensive as
that of, e.g., the ltxkeys package, but it is equally robust;
ease of use and speed of processing are the design aims of the
package.

%package -n texlive-keyval2e-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.0.2svn23698
Release:        0
Summary:        Documentation for texlive-keyval2e
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyval2e and texlive-alldocumentation)

%description -n texlive-keyval2e-doc
This package includes the documentation for texlive-keyval2e

%post -n texlive-keyval2e
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyval2e
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyval2e
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyval2e-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyval2e/README
%{_texmfdistdir}/doc/latex/keyval2e/keyval2e-examples.pdf
%{_texmfdistdir}/doc/latex/keyval2e/keyval2e-examples.tex
%{_texmfdistdir}/doc/latex/keyval2e/keyval2e-guide.pdf
%{_texmfdistdir}/doc/latex/keyval2e/keyval2e-guide.tex

%files -n texlive-keyval2e
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyval2e/keyval2e.sty

%package -n texlive-keyvaltable
Version:        %{texlive_version}.%{texlive_noarch}.2.3svn65416
Release:        0
License:        LPPL-1.0
Summary:        Re-usable table layouts separating content and presentation
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-keyvaltable-doc >= %{texlive_version}
Provides:       tex(keyvaltable.sty)
Requires:       tex(booktabs.sty)
Requires:       tex(colortbl.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(trimspaces.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source164:      keyvaltable.tar.xz
Source165:      keyvaltable.doc.tar.xz

%description -n texlive-keyvaltable
The main goal of this package is to offer means for typesetting
tables easily and yet still looking rather nicely in a way that
separates content from presentation and with re-usable layout
for tables of the same type. For this purpose, the package
provides the environment KeyValTable, which allows one to
typeset tables that have a previously defined column layout and
whose rows can be produced in a key-value fashion.

%package -n texlive-keyvaltable-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.3svn65416
Release:        0
Summary:        Documentation for texlive-keyvaltable
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-keyvaltable and texlive-alldocumentation)

%description -n texlive-keyvaltable-doc
This package includes the documentation for texlive-keyvaltable

%post -n texlive-keyvaltable
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-keyvaltable
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-keyvaltable
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-keyvaltable-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/keyvaltable/README.md
%{_texmfdistdir}/doc/latex/keyvaltable/keyvaltable.pdf

%files -n texlive-keyvaltable
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/keyvaltable/keyvaltable.sty

%package -n texlive-kfupm-math-exam
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1.0svn63977
Release:        0
License:        LPPL-1.0
Summary:        A LaTeX document style to produce homework, quiz and exam papers
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kfupm-math-exam-doc >= %{texlive_version}
Provides:       tex(kfupm-math-exam.cls)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(amsthm.sty)
Requires:       tex(array.sty)
Requires:       tex(article.cls)
Requires:       tex(booktabs.sty)
Requires:       tex(enumitem.sty)
Requires:       tex(environ.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(kvoptions.sty)
Requires:       tex(mathrsfs.sty)
Requires:       tex(pgfplots.sty)
Requires:       tex(tcolorbox.sty)
Requires:       tex(trimspaces.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source166:      kfupm-math-exam.tar.xz
Source167:      kfupm-math-exam.doc.tar.xz

%description -n texlive-kfupm-math-exam
The package provides commands and environments that simplify
and streamline the process of preparing homework, quiz and exam
papers according to apreffered style. The default style is
based on the guidelines set by the department of mathematics at
King Fahd University of Petroleum and Minerals (KFUPM). It can
be easily customized to fit any style for any institution.

%package -n texlive-kfupm-math-exam-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1.0svn63977
Release:        0
Summary:        Documentation for texlive-kfupm-math-exam
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kfupm-math-exam and texlive-alldocumentation)

%description -n texlive-kfupm-math-exam-doc
This package includes the documentation for texlive-kfupm-math-exam

%post -n texlive-kfupm-math-exam
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kfupm-math-exam
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kfupm-math-exam
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kfupm-math-exam-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kfupm-math-exam/LICENSE
%{_texmfdistdir}/doc/latex/kfupm-math-exam/README.txt
%{_texmfdistdir}/doc/latex/kfupm-math-exam/kfupm-math-exam.pdf
%{_texmfdistdir}/doc/latex/kfupm-math-exam/kfupm-math-exam.tex

%files -n texlive-kfupm-math-exam
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kfupm-math-exam/kfupm-math-exam.cls

%package -n texlive-kinematikz
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn61392
Release:        0
License:        LPPL-1.0
Summary:        Design kinematic chains and mechanisms
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kinematikz-doc >= %{texlive_version}
Provides:       tex(kinematikz.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(listofitems.sty)
Requires:       tex(tikz-3dplot.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xpatch.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source168:      kinematikz.tar.xz
Source169:      kinematikz.doc.tar.xz

%description -n texlive-kinematikz
This package provides functionalities to draw kinematic
diagrams for mechanisms using dedicate symbols (some from the
ISO standard and others). The intention is not to represent CAD
mechanical drawings of mechanisms and robots, but only to
represent 2D and 3D kinematic chains. The package provides
links, joints and other symbols, mostly in the form of TikZ pic
objects. These pics can be placed in the canvas either by a
central point for joints, and start and end points for some
links.

%package -n texlive-kinematikz-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn61392
Release:        0
Summary:        Documentation for texlive-kinematikz
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kinematikz and texlive-alldocumentation)

%description -n texlive-kinematikz-doc
This package includes the documentation for texlive-kinematikz

%post -n texlive-kinematikz
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kinematikz
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kinematikz
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kinematikz-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kinematikz/README
%{_texmfdistdir}/doc/latex/kinematikz/README.TEXLIVE

%files -n texlive-kinematikz
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kinematikz/kinematikz.sty

%package -n texlive-kix
Version:        %{texlive_version}.%{texlive_noarch}.svn21606
Release:        0
License:        LPPL-1.0
Summary:        Typeset KIX codes
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kix-doc >= %{texlive_version}
Provides:       tex(kix.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source170:      kix.tar.xz
Source171:      kix.doc.tar.xz

%description -n texlive-kix
Implements KIX codes as used by the Dutch PTT for bulk mail
addressing. (Royal Mail 4 State Code.) KIX is a registered
trade mark of PTT Post Holdings B. V.

%package -n texlive-kix-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn21606
Release:        0
Summary:        Documentation for texlive-kix
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kix and texlive-alldocumentation)

%description -n texlive-kix-doc
This package includes the documentation for texlive-kix

%post -n texlive-kix
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kix
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kix
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kix-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kix/kix.pdf
%{_texmfdistdir}/doc/latex/kix/kix.tex

%files -n texlive-kix
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kix/kix.sty

%package -n texlive-kixfont
Version:        %{texlive_version}.%{texlive_noarch}.svn18488
Release:        0
License:        LPPL-1.0
Summary:        A font for KIX codes
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kixfont-doc >= %{texlive_version}
Provides:       tex(kix.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source172:      kixfont.tar.xz
Source173:      kixfont.doc.tar.xz

%description -n texlive-kixfont
The KIX code is a barcode-like format used by the Dutch PTT to
encode country codes, zip codes and street numbers in a
machine-readable format. If printed below the address line on
bulk mailings, a discount can be obtained. The font is
distributed in Metafont format, and covers the numbers and
upper-case letters.

%package -n texlive-kixfont-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn18488
Release:        0
Summary:        Documentation for texlive-kixfont
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kixfont and texlive-alldocumentation)

%description -n texlive-kixfont-doc
This package includes the documentation for texlive-kixfont

%post -n texlive-kixfont
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kixfont
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kixfont
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kixfont-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/kixfont/kix.mf.asc
%{_texmfdistdir}/doc/fonts/kixfont/kixtable.pdf
%{_texmfdistdir}/doc/fonts/kixfont/kixtable.tex

%files -n texlive-kixfont
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/source/public/kixfont/kix.mf
%{_texmfdistdir}/fonts/tfm/public/kixfont/kix.tfm

%package -n texlive-kluwer
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        0
License:        LPPL-1.0
Summary:        Kluwer publication support
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kluwer-doc >= %{texlive_version}
Provides:       tex(klu10.clo)
Provides:       tex(klu105.clo)
Provides:       tex(klu11.clo)
Provides:       tex(klu12.clo)
Provides:       tex(klu9.clo)
Provides:       tex(klucite.sty)
Provides:       tex(kluedit.sty)
Provides:       tex(klufloa.sty)
Provides:       tex(klulist.sty)
Provides:       tex(klumac.sty)
Provides:       tex(klumath.sty)
Provides:       tex(klumono.sty)
Provides:       tex(klunote.sty)
Provides:       tex(kluopen.sty)
Provides:       tex(klups.sty)
Provides:       tex(kluref.sty)
Provides:       tex(klusec.sty)
Provides:       tex(klut10.clo)
Provides:       tex(klut11.clo)
Provides:       tex(klut12.clo)
Provides:       tex(klut9.clo)
Provides:       tex(klutab.sty)
Provides:       tex(kluwer.cls)
Requires:       tex(amssymb.sty)
Requires:       tex(doc.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(mathptm.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(wasysym.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source174:      kluwer.tar.xz
Source175:      kluwer.doc.tar.xz

%description -n texlive-kluwer
Most likely long obsolete, unfortunately.

%package -n texlive-kluwer-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        0
Summary:        Documentation for texlive-kluwer
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kluwer and texlive-alldocumentation)

%description -n texlive-kluwer-doc
This package includes the documentation for texlive-kluwer

%post -n texlive-kluwer
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kluwer
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kluwer
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kluwer-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kluwer/00readme
%{_texmfdistdir}/doc/latex/kluwer/mouse.eps
%{_texmfdistdir}/doc/latex/kluwer/sampkluw.dvi
%{_texmfdistdir}/doc/latex/kluwer/sampkluw.ent
%{_texmfdistdir}/doc/latex/kluwer/sampkluw.tex
%{_texmfdistdir}/doc/latex/kluwer/sampopen.dvi
%{_texmfdistdir}/doc/latex/kluwer/sampopen.tex
%{_texmfdistdir}/doc/latex/kluwer/usrman.dvi
%{_texmfdistdir}/doc/latex/kluwer/usrman.ent
%{_texmfdistdir}/doc/latex/kluwer/usrman.tex

%files -n texlive-kluwer
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/kluwer/klunamed.bst
%{_texmfdistdir}/bibtex/bst/kluwer/klunum.bst
%{_texmfdistdir}/tex/latex/kluwer/klu10.clo
%{_texmfdistdir}/tex/latex/kluwer/klu105.clo
%{_texmfdistdir}/tex/latex/kluwer/klu11.clo
%{_texmfdistdir}/tex/latex/kluwer/klu12.clo
%{_texmfdistdir}/tex/latex/kluwer/klu9.clo
%{_texmfdistdir}/tex/latex/kluwer/klucite.sty
%{_texmfdistdir}/tex/latex/kluwer/kluedit.sty
%{_texmfdistdir}/tex/latex/kluwer/klufloa.sty
%{_texmfdistdir}/tex/latex/kluwer/klulist.sty
%{_texmfdistdir}/tex/latex/kluwer/klumac.sty
%{_texmfdistdir}/tex/latex/kluwer/klumath.sty
%{_texmfdistdir}/tex/latex/kluwer/klumono.sty
%{_texmfdistdir}/tex/latex/kluwer/klunote.sty
%{_texmfdistdir}/tex/latex/kluwer/kluopen.sty
%{_texmfdistdir}/tex/latex/kluwer/klups.sty
%{_texmfdistdir}/tex/latex/kluwer/kluref.sty
%{_texmfdistdir}/tex/latex/kluwer/klusec.sty
%{_texmfdistdir}/tex/latex/kluwer/klut10.clo
%{_texmfdistdir}/tex/latex/kluwer/klut11.clo
%{_texmfdistdir}/tex/latex/kluwer/klut12.clo
%{_texmfdistdir}/tex/latex/kluwer/klut9.clo
%{_texmfdistdir}/tex/latex/kluwer/klutab.sty
%{_texmfdistdir}/tex/latex/kluwer/kluwer.cls

%package -n texlive-knitting
Version:        %{texlive_version}.%{texlive_noarch}.3.0svn50782
Release:        0
License:        LPPL-1.0
Summary:        Produce knitting charts, in Plain TeX or LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-knitting-fonts >= %{texlive_version}
Suggests:       texlive-knitting-doc >= %{texlive_version}
Provides:       tex(knitfont.map)
Provides:       tex(knitg_sc_in.tfm)
Provides:       tex(knitg_sc_out.tfm)
Provides:       tex(knitgg.tfm)
Provides:       tex(knitgn.tfm)
Provides:       tex(knitgp.tfm)
Provides:       tex(knitmg.tfm)
Provides:       tex(knitml.tfm)
Provides:       tex(knitmn.tfm)
Provides:       tex(knitmp.tfm)
Provides:       tex(knitmr.tfm)
Provides:       tex(knitn_sc_in.tfm)
Provides:       tex(knitn_sc_out.tfm)
Provides:       tex(knitnl.tfm)
Provides:       tex(knitnn.tfm)
Provides:       tex(knitnp.tfm)
Provides:       tex(knitnr.tfm)
Provides:       tex(knitting.sty)
Provides:       tex(knitting.tex)
Provides:       tex(knitwg.tfm)
Provides:       tex(knitwn.tfm)
Provides:       tex(knitwp.tfm)
Provides:       tex(uknit.fd)
Requires:       tex(color.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source176:      knitting.tar.xz
Source177:      knitting.doc.tar.xz

%description -n texlive-knitting
The package provides symbol fonts and commands to write charted
instructions for cable and lace knitting patterns, using either
plain TeX or LaTeX. The fonts are available both as Metafont
source and in Adobe Type 1 format.

%package -n texlive-knitting-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.0svn50782
Release:        0
Summary:        Documentation for texlive-knitting
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-knitting and texlive-alldocumentation)

%description -n texlive-knitting-doc
This package includes the documentation for texlive-knitting

%package -n texlive-knitting-fonts
Version:        %{texlive_version}.%{texlive_noarch}.3.0svn50782
Release:        0
Summary:        Severed fonts for texlive-knitting
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-knitting-fonts
The  separated fonts package for texlive-knitting

%post -n texlive-knitting
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap knitfont.map' >> /var/run/texlive/run-updmap

%postun -n texlive-knitting
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap knitfont.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-knitting
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-knitting-fonts

%files -n texlive-knitting-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/knitting/README
%{_texmfdistdir}/doc/fonts/knitting/knitexamples.pdf
%{_texmfdistdir}/doc/fonts/knitting/knitexamples.tex
%{_texmfdistdir}/doc/fonts/knitting/knitkey.pdf
%{_texmfdistdir}/doc/fonts/knitting/knitkey.tex
%{_texmfdistdir}/doc/fonts/knitting/knitting-doc.pdf
%{_texmfdistdir}/doc/fonts/knitting/knitting-doc.tex

%files -n texlive-knitting
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/public/knitting/knitg_sc_in.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitg_sc_out.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitgg.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitgn.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitgp.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitmg.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitml.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitmn.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitmp.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitmr.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitn_sc_in.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitn_sc_out.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitnl.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitnn.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitnp.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitnr.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitwg.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitwn.afm
%{_texmfdistdir}/fonts/afm/public/knitting/knitwp.afm
%{_texmfdistdir}/fonts/map/dvips/knitting/knitfont.map
%{_texmfdistdir}/fonts/source/public/knitting/knit_dimens.mf
%{_texmfdistdir}/fonts/source/public/knitting/knit_grid_cables.mf
%{_texmfdistdir}/fonts/source/public/knitting/knit_nogrid_cables.mf
%{_texmfdistdir}/fonts/source/public/knitting/knit_symbols.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitg_sc_in.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitg_sc_out.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitgg.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitgn.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitgp.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitmg.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitml.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitmn.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitmp.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitmr.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitn_sc_in.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitn_sc_out.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitnl.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitnn.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitnp.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitnr.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitwg.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitwn.mf
%{_texmfdistdir}/fonts/source/public/knitting/knitwp.mf
%{_texmfdistdir}/fonts/tfm/public/knitting/knitg_sc_in.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitg_sc_out.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitgg.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitgn.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitgp.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitmg.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitml.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitmn.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitmp.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitmr.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitn_sc_in.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitn_sc_out.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitnl.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitnn.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitnp.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitnr.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitwg.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitwn.tfm
%{_texmfdistdir}/fonts/tfm/public/knitting/knitwp.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitg_sc_in.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitg_sc_out.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitgg.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitgn.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitgp.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitmg.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitml.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitmn.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitmp.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitmr.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitn_sc_in.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitn_sc_out.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitnl.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitnn.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitnp.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitnr.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitwg.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitwn.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/knitting/knitwp.pfb
%{_texmfdistdir}/tex/latex/knitting/knitting.sty
%{_texmfdistdir}/tex/latex/knitting/uknit.fd
%{_texmfdistdir}/tex/plain/knitting/knitting.tex

%files -n texlive-knitting-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-knitting
%{_datadir}/fontconfig/conf.avail/58-texlive-knitting.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-knitting/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-knitting/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-knitting/fonts.scale
%{_datadir}/fonts/texlive-knitting/knitg_sc_in.pfb
%{_datadir}/fonts/texlive-knitting/knitg_sc_out.pfb
%{_datadir}/fonts/texlive-knitting/knitgg.pfb
%{_datadir}/fonts/texlive-knitting/knitgn.pfb
%{_datadir}/fonts/texlive-knitting/knitgp.pfb
%{_datadir}/fonts/texlive-knitting/knitmg.pfb
%{_datadir}/fonts/texlive-knitting/knitml.pfb
%{_datadir}/fonts/texlive-knitting/knitmn.pfb
%{_datadir}/fonts/texlive-knitting/knitmp.pfb
%{_datadir}/fonts/texlive-knitting/knitmr.pfb
%{_datadir}/fonts/texlive-knitting/knitn_sc_in.pfb
%{_datadir}/fonts/texlive-knitting/knitn_sc_out.pfb
%{_datadir}/fonts/texlive-knitting/knitnl.pfb
%{_datadir}/fonts/texlive-knitting/knitnn.pfb
%{_datadir}/fonts/texlive-knitting/knitnp.pfb
%{_datadir}/fonts/texlive-knitting/knitnr.pfb
%{_datadir}/fonts/texlive-knitting/knitwg.pfb
%{_datadir}/fonts/texlive-knitting/knitwn.pfb
%{_datadir}/fonts/texlive-knitting/knitwp.pfb

%package -n texlive-knittingpattern
Version:        %{texlive_version}.%{texlive_noarch}.svn17205
Release:        0
License:        LPPL-1.0
Summary:        Create knitting patterns
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-knittingpattern-doc >= %{texlive_version}
Provides:       tex(knittingpattern.cls)
Requires:       tex(article.cls)
Requires:       tex(calc.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(float.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(longtable.sty)
Requires:       tex(xcolor.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source178:      knittingpattern.tar.xz
Source179:      knittingpattern.doc.tar.xz

%description -n texlive-knittingpattern
The class provides a simple, effective method for knitters to
produce high-quality, attractive patterns using LaTeX. It does
this by providing commands to handle as much of the layout of
the document as possible, leaving the author free to
concentrate on the pattern.

%package -n texlive-knittingpattern-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn17205
Release:        0
Summary:        Documentation for texlive-knittingpattern
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-knittingpattern and texlive-alldocumentation)

%description -n texlive-knittingpattern-doc
This package includes the documentation for texlive-knittingpattern

%post -n texlive-knittingpattern
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knittingpattern
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knittingpattern
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knittingpattern-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/knittingpattern/README
%{_texmfdistdir}/doc/latex/knittingpattern/introduction.pdf
%{_texmfdistdir}/doc/latex/knittingpattern/introduction.tex
%{_texmfdistdir}/doc/latex/knittingpattern/lion.png
%{_texmfdistdir}/doc/latex/knittingpattern/template.pdf
%{_texmfdistdir}/doc/latex/knittingpattern/template.tex

%files -n texlive-knittingpattern
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/knittingpattern/knittingpattern.cls

%package -n texlive-knowledge
Version:        %{texlive_version}.%{texlive_noarch}.1.28svn61991
Release:        0
License:        LPPL-1.0
Summary:        Displaying, hyperlinking, and indexing notions in a document
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-knowledge-doc >= %{texlive_version}
Provides:       tex(knowledge.sty)
Requires:       tex(currfile.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(expl3.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source180:      knowledge.tar.xz
Source181:      knowledge.doc.tar.xz

%description -n texlive-knowledge
The package offers a systematic way to handle
notions/concepts/terms throughout a document. It helps building
an index. In combination with hyperref it makes it easy to have
every reference of a concept linked to its introduction. It
also offers simple notations.

%package -n texlive-knowledge-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.28svn61991
Release:        0
Summary:        Documentation for texlive-knowledge
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-knowledge and texlive-alldocumentation)

%description -n texlive-knowledge-doc
This package includes the documentation for texlive-knowledge

%post -n texlive-knowledge
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knowledge
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knowledge
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knowledge-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/knowledge/README.md
%{_texmfdistdir}/doc/latex/knowledge/knowledge-example.tex
%{_texmfdistdir}/doc/latex/knowledge/knowledge.pdf
%{_texmfdistdir}/doc/latex/knowledge/knowledge.tex
%{_texmfdistdir}/doc/latex/knowledge/makefile

%files -n texlive-knowledge
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/knowledge/knowledge.sty

%package -n texlive-knuth-errata
Version:        %{texlive_version}.%{texlive_noarch}.svn58682
Release:        0
License:        SUSE-TeX
Summary:        Knuth's published errata
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source182:      knuth-errata.doc.tar.xz

%description -n texlive-knuth-errata
These files record details of problems reported in Knuth's
'Computers and Typesetting' series of books, for the Computer
Modern fonts, and for TeX, Metafont and related programs.

%post -n texlive-knuth-errata
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knuth-errata
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knuth-errata
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knuth-errata
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/knuth-errata/cm85.bug
%{_texmfdistdir}/doc/generic/knuth-errata/errata.eight
%{_texmfdistdir}/doc/generic/knuth-errata/errata.eleven
%{_texmfdistdir}/doc/generic/knuth-errata/errata.five
%{_texmfdistdir}/doc/generic/knuth-errata/errata.four
%{_texmfdistdir}/doc/generic/knuth-errata/errata.nine
%{_texmfdistdir}/doc/generic/knuth-errata/errata.one
%{_texmfdistdir}/doc/generic/knuth-errata/errata.seven
%{_texmfdistdir}/doc/generic/knuth-errata/errata.six
%{_texmfdistdir}/doc/generic/knuth-errata/errata.ten
%{_texmfdistdir}/doc/generic/knuth-errata/errata.tex
%{_texmfdistdir}/doc/generic/knuth-errata/errata.three
%{_texmfdistdir}/doc/generic/knuth-errata/errata.twelve
%{_texmfdistdir}/doc/generic/knuth-errata/errata.two
%{_texmfdistdir}/doc/generic/knuth-errata/errorlog.tex
%{_texmfdistdir}/doc/generic/knuth-errata/logmac.tex
%{_texmfdistdir}/doc/generic/knuth-errata/mf84.bug
%{_texmfdistdir}/doc/generic/knuth-errata/tex82.bug

%package -n texlive-knuth-hint
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn62971
Release:        0
License:        SUSE-Public-Domain
Summary:        HINT collection of typeset C/WEB sources in TeX Live
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source183:      knuth-hint.doc.tar.xz

%description -n texlive-knuth-hint
The knuth-hint package contains the large collection of HINT
documents for many of the CWEB amd WEB sources of programs in
the TeX Live distribution (and, for technical reasons, PDF
documents for CTWILL and XeTeX). Each program is presented in
its original form as written by the respective authors, and in
the "changed" form as used in TeX Live. Care has been taken to
keep the section numbering intact, so that you can study the
codes and the changes in parallel. Also included are the
"errata" for Donald Knuth's "Computers & Typesetting". HINT is
the dynamic document format created by Martin Ruckert's HiTeX
engine that was added to TeX Live 2022. The HINT files can be
viewed on Linux, Windows, and Android with the hintview
application. The knuth-hint package is a showcase of HiTeX's
capabilities.

%post -n texlive-knuth-hint
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knuth-hint
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knuth-hint
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knuth-hint
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/knuth-hint/README.md
%{_texmfdistdir}/doc/generic/knuth-hint/bibtex/bibtex-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/bibtex/bibtex.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/ctie/ctie-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/ctie/ctie.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/common-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/common.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/ctangle-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/ctangle.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/ctwill.pdf
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/cweave-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/cweave.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/cwebman.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/refsort-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/refsort.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/twinx-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/cweb/twinx.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.eight.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.eleven.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.five.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.four.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.nine.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.one.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.seven.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.six.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.ten.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.three.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.twelve.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errata.two.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/errata/errorlog.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/etc/vftovp-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/etc/vftovp.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/etc/vptovf-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/etc/vptovf.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/index.html
%{_texmfdistdir}/doc/generic/knuth-hint/index.pdf
%{_texmfdistdir}/doc/generic/knuth-hint/mf/mf-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mf/mf.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mf/trapman.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftodvi-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftodvi.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftopk-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftopk.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftype-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/gftype.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/mft-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/mfware/mft.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/dvicopy-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/dvicopy.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/patgen-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/patgen.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/pktogf-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/pktogf.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/pktype-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/other/pktype.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/pdftex/pdftex-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/pdftex/pdftex.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tex/glue.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tex/tex-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tex/tex.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tex/tripman.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/dvitype-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/dvitype.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/pltotf-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/pltotf.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/pooltype-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/pooltype.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/tftopl-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/texware/tftopl.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tie/tie-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/tie/tie.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/tangle-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/tangle.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/twill.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/weave-changes.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/weave.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/web/webman.hnt
%{_texmfdistdir}/doc/generic/knuth-hint/xetex/xetex-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-hint/xetex/xetex.pdf

%package -n texlive-knuth-lib
Version:        %{texlive_version}.%{texlive_noarch}.svn57963
Release:        0
License:        SUSE-TeX
Summary:        Core TeX and Metafont sources from Knuth
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-misc < 2015
Provides:       texlive-misc = %{texlive_version}
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       tex(logo10.tfm)
Provides:       tex(logo8.tfm)
Provides:       tex(logo9.tfm)
Provides:       tex(logobf10.tfm)
Provides:       tex(logosl10.tfm)
Provides:       tex(manfnt.tfm)
Provides:       tex(manmac.tex)
Provides:       tex(mftmac.tex)
Provides:       tex(null.tex)
Provides:       tex(story.tex)
Provides:       tex(testfont.tex)
Provides:       tex(webmac.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source184:      knuth-lib.tar.xz

%description -n texlive-knuth-lib
A collection of core TeX and Metafont macro files from DEK,
apart from the plain format and base. Includes the MF logo
font(s), webmac.tex, etc.

%post -n texlive-knuth-lib
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knuth-lib
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knuth-lib
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knuth-lib
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/source/public/knuth-lib/3test.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/6test.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/expr.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/grayf.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/io.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logo.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logo10.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logo8.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logo9.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logobf10.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/logosl10.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/manfnt.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/null.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/rtest.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/slant.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/test.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/waits.mf
%{_texmfdistdir}/fonts/source/public/knuth-lib/ztest.mf
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/logo10.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/logo8.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/logo9.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/logobf10.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/logosl10.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-lib/manfnt.tfm
%{_texmfdistdir}/tex/generic/knuth-lib/null.tex
%{_texmfdistdir}/tex/plain/knuth-lib/manmac.tex
%{_texmfdistdir}/tex/plain/knuth-lib/mftmac.tex
%{_texmfdistdir}/tex/plain/knuth-lib/story.tex
%{_texmfdistdir}/tex/plain/knuth-lib/testfont.tex
%{_texmfdistdir}/tex/plain/knuth-lib/webmac.tex

%package -n texlive-knuth-local
Version:        %{texlive_version}.%{texlive_noarch}.svn57963
Release:        0
License:        SUSE-Public-Domain
Summary:        Knuth's local information
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       tex(domino.tfm)
Provides:       tex(logod10.tfm)
Provides:       tex(logosl9.tfm)
Provides:       tex(random.tfm)
Provides:       tex(snfont.tfm)
Provides:       tex(xepsf.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source185:      knuth-local.tar.xz

%description -n texlive-knuth-local
A collection of experimental programs and developments based
on, or complementary to, the matter in his distribution
directories.

%post -n texlive-knuth-local
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knuth-local
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knuth-local
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knuth-local
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/source/public/knuth-local/black.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/blackaps.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/blackimagen.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/blacklino.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/blacklj.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/domino.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/gray.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/grayaps.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/grayimagen.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/grayimagen3.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/grayimagenlight.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/graylj.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/local.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/logod10.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/logosl9.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/mfman.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/oneone.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/random.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/slantaps4.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/slantimagen4.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/slantimagen6.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/slantlino4.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/slantlj4.mf
%{_texmfdistdir}/fonts/source/public/knuth-local/snfont.mf
%{_texmfdistdir}/fonts/tfm/public/knuth-local/domino.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-local/logod10.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-local/logosl9.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-local/random.tfm
%{_texmfdistdir}/fonts/tfm/public/knuth-local/snfont.tfm
%{_texmfdistdir}/mft/knuth-local/e.mft
%{_texmfdistdir}/tex/plain/knuth-local/xepsf.tex

%package -n texlive-knuth-pdf
Version:        %{texlive_version}.%{texlive_noarch}.2.0svn62969
Release:        0
License:        SUSE-Public-Domain
Summary:        PDF collection of typeset C/WEB sources in TeX Live
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source186:      knuth-pdf.doc.tar.xz

%description -n texlive-knuth-pdf
Here you find a large collection of PDF documents for many
C/WEB programs in TeX Live, both in their original form as
written by their respective authors, and in the changed form as
they are actually used in the TeX Live system. Care has been
taken to keep the section numbering intact, so that you can
study the sources and their changes in parallel. Also included
is the collection of "errata" for Donald Knuth's "Computers &
Typesetting series". Although not all the texts here are
written or maintained by Donald Knuth, it is more convenient
for everything to be collected in one place for reading and
searching. They all stem from the system that Knuth created.
The central entry point is the "index" file, with links to the
individual documents, either in HTML or in PDF format.

%post -n texlive-knuth-pdf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-knuth-pdf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-knuth-pdf
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-knuth-pdf
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/knuth-pdf/README.md
%{_texmfdistdir}/doc/generic/knuth-pdf/bibtex/bibtex-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/bibtex/bibtex.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/ctie/ctie-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/ctie/ctie.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/common-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/common.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/ctangle-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/ctangle.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/ctwill.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/cweave-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/cweave.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/cwebman.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/refsort-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/refsort.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/twinx-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/cweb/twinx.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.eight.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.eleven.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.five.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.four.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.nine.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.one.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.seven.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.six.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.ten.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.three.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.twelve.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errata.two.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/errata/errorlog.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/etc/vftovp-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/etc/vftovp.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/etc/vptovf-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/etc/vptovf.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/index.html
%{_texmfdistdir}/doc/generic/knuth-pdf/index.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mf/mf-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mf/mf.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mf/trapman.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftodvi-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftodvi.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftopk-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftopk.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftype-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/gftype.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/mft-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/mfware/mft.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/dvicopy-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/dvicopy.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/patgen-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/patgen.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/pktogf-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/pktogf.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/pktype-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/other/pktype.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/pdftex/pdftex-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/pdftex/pdftex.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tex/glue.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tex/tex-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tex/tex.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tex/tripman.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/dvitype-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/dvitype.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/pltotf-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/pltotf.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/pooltype-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/pooltype.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/tftopl-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/texware/tftopl.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tie/tie-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/tie/tie.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/tangle-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/tangle.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/twill.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/weave-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/weave.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/web/webman.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/xetex/xetex-changes.pdf
%{_texmfdistdir}/doc/generic/knuth-pdf/xetex/xetex.pdf

%package -n texlive-koma-moderncvclassic
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5svn25025
Release:        0
License:        LPPL-1.0
Summary:        Makes the style and command of moderncv (style classic) available for koma-classes and thus compatible with BibLaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-koma-moderncvclassic-doc >= %{texlive_version}
Provides:       tex(koma-moderncvclassic.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source187:      koma-moderncvclassic.tar.xz
Source188:      koma-moderncvclassic.doc.tar.xz

%description -n texlive-koma-moderncvclassic
This package provides an imitation of the moderncv class with
the classic style (by Xavier Danaux), to be used in conjunction
with the koma-classes. Thus it is possible to configure
pagelayout, headings etc. the way it is done in koma-classes.
Moreover, it is possible to use BibLaTeX, while the original
moderncv-class is incompatible with BibLaTeX.

%package -n texlive-koma-moderncvclassic-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5svn25025
Release:        0
Summary:        Documentation for texlive-koma-moderncvclassic
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-koma-moderncvclassic and texlive-alldocumentation)

%description -n texlive-koma-moderncvclassic-doc
This package includes the documentation for texlive-koma-moderncvclassic

%post -n texlive-koma-moderncvclassic
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-koma-moderncvclassic
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-koma-moderncvclassic
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-koma-moderncvclassic-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/koma-moderncvclassic/README
%{_texmfdistdir}/doc/latex/koma-moderncvclassic/changelog
%{_texmfdistdir}/doc/latex/koma-moderncvclassic/cvbasic.pdf
%{_texmfdistdir}/doc/latex/koma-moderncvclassic/cvbasic.tex

%files -n texlive-koma-moderncvclassic
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/koma-moderncvclassic/koma-moderncvclassic.sty

%package -n texlive-koma-script
Version:        %{texlive_version}.%{texlive_noarch}.3.38svn64685
Release:        0
License:        LPPL-1.0
Summary:        A bundle of versatile classes and packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-footmisc >= %{texlive_version}
#!BuildIgnore: texlive-footmisc
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-koma-script-doc >= %{texlive_version}
Provides:       tex(authorpart-de.tex)
Provides:       tex(authorpart-en.tex)
Provides:       tex(common-compatibility-de.tex)
Provides:       tex(common-compatibility-en.tex)
Provides:       tex(common-dictum-de.tex)
Provides:       tex(common-dictum-en.tex)
Provides:       tex(common-draftmode-de.tex)
Provides:       tex(common-draftmode-en.tex)
Provides:       tex(common-fontsize-de.tex)
Provides:       tex(common-fontsize-en.tex)
Provides:       tex(common-footnotes-de.tex)
Provides:       tex(common-footnotes-en.tex)
Provides:       tex(common-footnotes-experts-de.tex)
Provides:       tex(common-footnotes-experts-en.tex)
Provides:       tex(common-headfootheight-de.tex)
Provides:       tex(common-headfootheight-en.tex)
Provides:       tex(common-interleafpage-de.tex)
Provides:       tex(common-interleafpage-en.tex)
Provides:       tex(common-lists-de.tex)
Provides:       tex(common-lists-en.tex)
Provides:       tex(common-marginpar-de.tex)
Provides:       tex(common-marginpar-en.tex)
Provides:       tex(common-oddorevenpage-de.tex)
Provides:       tex(common-oddorevenpage-en.tex)
Provides:       tex(common-options-de.tex)
Provides:       tex(common-options-en.tex)
Provides:       tex(common-pagestylemanipulation-de.tex)
Provides:       tex(common-pagestylemanipulation-en.tex)
Provides:       tex(common-parmarkup-de.tex)
Provides:       tex(common-parmarkup-en.tex)
Provides:       tex(common-textmarkup-de.tex)
Provides:       tex(common-textmarkup-en.tex)
Provides:       tex(common-titles-de.tex)
Provides:       tex(common-titles-en.tex)
Provides:       tex(common-typearea-de.tex)
Provides:       tex(common-typearea-en.tex)
Provides:       tex(expertpart-de.tex)
Provides:       tex(expertpart-en.tex)
Provides:       tex(introduction-de.tex)
Provides:       tex(introduction-en.tex)
Provides:       tex(japanlco-en.tex)
Provides:       tex(koma-script-source-doc.cls)
Provides:       tex(letter-example-00-de.tex)
Provides:       tex(letter-example-00-en.tex)
Provides:       tex(letter-example-01-de.tex)
Provides:       tex(letter-example-01-en.tex)
Provides:       tex(letter-example-02-de.tex)
Provides:       tex(letter-example-02-en.tex)
Provides:       tex(letter-example-03-de.tex)
Provides:       tex(letter-example-03-en.tex)
Provides:       tex(letter-example-04-de.tex)
Provides:       tex(letter-example-04-en.tex)
Provides:       tex(letter-example-05-de.tex)
Provides:       tex(letter-example-05-en.tex)
Provides:       tex(letter-example-06-de.tex)
Provides:       tex(letter-example-06-en.tex)
Provides:       tex(letter-example-07-de.tex)
Provides:       tex(letter-example-07-en.tex)
Provides:       tex(letter-example-08-de.tex)
Provides:       tex(letter-example-08-en.tex)
Provides:       tex(letter-example-09-de.tex)
Provides:       tex(letter-example-09-en.tex)
Provides:       tex(letter-example-10-de.tex)
Provides:       tex(letter-example-10-en.tex)
Provides:       tex(letter-example-11-de.tex)
Provides:       tex(letter-example-11-en.tex)
Provides:       tex(letter-example-12-de.tex)
Provides:       tex(letter-example-12-en.tex)
Provides:       tex(letter-example-13-de.tex)
Provides:       tex(letter-example-13-en.tex)
Provides:       tex(letter-example-14-de.tex)
Provides:       tex(letter-example-14-en.tex)
Provides:       tex(letter-example-15-de.tex)
Provides:       tex(letter-example-15-en.tex)
Provides:       tex(letter-example-16-de.tex)
Provides:       tex(letter-example-16-en.tex)
Provides:       tex(letter-example-17-de.tex)
Provides:       tex(letter-example-17-en.tex)
Provides:       tex(letter-example-18-de.tex)
Provides:       tex(letter-example-18-en.tex)
Provides:       tex(letter-example-19-de.tex)
Provides:       tex(letter-example-19-en.tex)
Provides:       tex(letter-example-20-de.tex)
Provides:       tex(letter-example-20-en.tex)
Provides:       tex(letter-example-21-de.tex)
Provides:       tex(letter-example-21-en.tex)
Provides:       tex(letter-example-22-de.tex)
Provides:       tex(letter-example-22-en.tex)
Provides:       tex(letter-example-23-de.tex)
Provides:       tex(letter-example-23-en.tex)
Provides:       tex(linkalias.tex)
Provides:       tex(plength-tikz.tex)
Provides:       tex(preface-de.tex)
Provides:       tex(preface-en.tex)
Provides:       tex(scraddr-de.tex)
Provides:       tex(scraddr-en.tex)
Provides:       tex(scraddr.sty)
Provides:       tex(scrartcl.cls)
Provides:       tex(scrarticle.cls)
Provides:       tex(scrbase-de.tex)
Provides:       tex(scrbase-en.tex)
Provides:       tex(scrbase.sty)
Provides:       tex(scrbook.cls)
Provides:       tex(scrbookreportarticle-de.tex)
Provides:       tex(scrbookreportarticle-en.tex)
Provides:       tex(scrbookreportarticle-experts-de.tex)
Provides:       tex(scrbookreportarticle-experts-en.tex)
Provides:       tex(scrdate-de.tex)
Provides:       tex(scrdate-en.tex)
Provides:       tex(scrdate.sty)
Provides:       tex(scrdoc.cls)
Provides:       tex(scrdocstrip.tex)
Provides:       tex(scrextend-de.tex)
Provides:       tex(scrextend-en.tex)
Provides:       tex(scrextend.sty)
Provides:       tex(scrfontsizes.sty)
Provides:       tex(scrguide-body.tex)
Provides:       tex(scrguide-de.tex)
Provides:       tex(scrguide-en.tex)
Provides:       tex(scrguide.cls)
Provides:       tex(scrhack-de.tex)
Provides:       tex(scrhack-en.tex)
Provides:       tex(scrhack.sty)
Provides:       tex(scrjura-de.tex)
Provides:       tex(scrjura-en.tex)
Provides:       tex(scrjura-example-de.tex)
Provides:       tex(scrjura-example-de.tex)
Provides:       tex(scrjura-example-en.tex)
Provides:       tex(scrjura-example-en.tex)
Provides:       tex(scrjura.sty)
Provides:       tex(scrkbase.sty)
Provides:       tex(scrlayer-de.tex)
Provides:       tex(scrlayer-en.tex)
Provides:       tex(scrlayer-notecolumn-de.tex)
Provides:       tex(scrlayer-notecolumn-en.tex)
Provides:       tex(scrlayer-notecolumn-example-de.tex)
Provides:       tex(scrlayer-notecolumn-example-de.tex)
Provides:       tex(scrlayer-notecolumn-example-en.tex)
Provides:       tex(scrlayer-notecolumn-example-en.tex)
Provides:       tex(scrlayer-notecolumn.sty)
Provides:       tex(scrlayer-scrpage-de.tex)
Provides:       tex(scrlayer-scrpage-en.tex)
Provides:       tex(scrlayer-scrpage-experts-de.tex)
Provides:       tex(scrlayer-scrpage-experts-en.tex)
Provides:       tex(scrlayer-scrpage.sty)
Provides:       tex(scrlayer.sty)
Provides:       tex(scrletter.cls)
Provides:       tex(scrletter.sty)
Provides:       tex(scrlfile-de.tex)
Provides:       tex(scrlfile-en.tex)
Provides:       tex(scrlfile-hook-3.34.sty)
Provides:       tex(scrlfile-hook.sty)
Provides:       tex(scrlfile-patcholdlatex.sty)
Provides:       tex(scrlfile.sty)
Provides:       tex(scrlogo-de.tex)
Provides:       tex(scrlogo-en.tex)
Provides:       tex(scrlogo.sty)
Provides:       tex(scrlttr2-de.tex)
Provides:       tex(scrlttr2-en.tex)
Provides:       tex(scrlttr2-experts-de.tex)
Provides:       tex(scrlttr2-experts-en.tex)
Provides:       tex(scrlttr2.cls)
Provides:       tex(scrreport.cls)
Provides:       tex(scrreprt.cls)
Provides:       tex(scrsize10pt.clo)
Provides:       tex(scrsize11pt.clo)
Provides:       tex(scrsize12pt.clo)
Provides:       tex(scrtime-de.tex)
Provides:       tex(scrtime-en.tex)
Provides:       tex(scrtime.sty)
Provides:       tex(scrwfile-de.tex)
Provides:       tex(scrwfile-en.tex)
Provides:       tex(scrwfile.sty)
Provides:       tex(terms-de.tex)
Provides:       tex(terms-en.tex)
Provides:       tex(tocbasic-de.tex)
Provides:       tex(tocbasic-en.tex)
Provides:       tex(tocbasic.sty)
Provides:       tex(typearea-de.tex)
Provides:       tex(typearea-en.tex)
Provides:       tex(typearea-experts-de.tex)
Provides:       tex(typearea-experts-en.tex)
Provides:       tex(typearea.sty)
Provides:       tex(variables-tikz.tex)
Requires:       tex(afterpage.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(auxhook.sty)
Requires:       tex(babelbib.sty)
Requires:       tex(biblatex.sty)
Requires:       tex(bookmark.sty)
Requires:       tex(booktabs.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(geometry.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(iftex.sty)
Requires:       tex(keyval.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(listings.sty)
Requires:       tex(lmodern.sty)
Requires:       tex(longtable.sty)
Requires:       tex(makeidx.sty)
Requires:       tex(marginnote.sty)
Requires:       tex(mparhack.sty)
Requires:       tex(multicol.sty)
Requires:       tex(picture.sty)
Requires:       tex(tabularx.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xpatch.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source189:      koma-script.tar.xz

%description -n texlive-koma-script
The KOMA-Script bundle provides replacements for the article,
report, and book classes with emphasis on typography and
versatility. There is also a letter class. The bundle also
offers: a package for calculating type areas in the way laid
down by the typographer Jan Tschichold, packages for easily
changing and defining page styles, a package scrdate for
getting not only the current date but also the name of the day,
and a package scrtime for getting the current time. All these
packages may be used not only with KOMA-Script classes but also
with the standard classes. Since every package has its own
version number, the version number quoted only refers to the
version of scrbook, scrreprt, scrartcl, scrlttr2 and typearea
(which are the main parts of the bundle).

%package -n texlive-koma-script-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.38svn64685
Release:        0
Summary:        Documentation for texlive-koma-script
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-koma-script and texlive-alldocumentation)

%description -n texlive-koma-script-doc
This package includes the documentation for texlive-koma-script

%post -n texlive-koma-script
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-koma-script
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-koma-script
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-koma-script-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/koma-script/MANIFEST.md
%{_texmfdistdir}/doc/latex/koma-script/README.md
%{_texmfdistdir}/doc/latex/koma-script/examples/ich.lco
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-00-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-00-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-00-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-00-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-01-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-01-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-01-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-01-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-02-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-02-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-02-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-02-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-03-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-03-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-03-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-03-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-04-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-04-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-04-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-04-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-05-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-05-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-05-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-05-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-06-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-06-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-06-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-06-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-07-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-07-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-07-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-07-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-08-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-08-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-08-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-08-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-09-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-09-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-09-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-09-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-10-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-10-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-10-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-10-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-11-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-11-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-11-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-11-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-12-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-12-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-12-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-12-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-13-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-13-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-13-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-13-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-14-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-14-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-14-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-14-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-15-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-15-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-15-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-15-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-16-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-16-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-16-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-16-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-17-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-17-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-17-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-17-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-18-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-18-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-18-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-18-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-19-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-19-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-19-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-19-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-20-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-20-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-20-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-20-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-21-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-21-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-21-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-21-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-22-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-22-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-22-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-22-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-23-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-23-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-23-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/letter-example-23-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/me.lco
%{_texmfdistdir}/doc/latex/koma-script/examples/musterlogo.eps
%{_texmfdistdir}/doc/latex/koma-script/examples/scrjura-example-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/scrjura-example-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/scrjura-example-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/scrjura-example-en.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/scrlayer-notecolumn-example-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/scrlayer-notecolumn-example-de.tex
%{_texmfdistdir}/doc/latex/koma-script/examples/scrlayer-notecolumn-example-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/examples/scrlayer-notecolumn-example-en.tex
%{_texmfdistdir}/doc/latex/koma-script/lppl-de.txt
%{_texmfdistdir}/doc/latex/koma-script/lppl.txt
%{_texmfdistdir}/doc/latex/koma-script/scraddr.html
%{_texmfdistdir}/doc/latex/koma-script/scrartcl.html
%{_texmfdistdir}/doc/latex/koma-script/scrarticle.html
%{_texmfdistdir}/doc/latex/koma-script/scrbase.html
%{_texmfdistdir}/doc/latex/koma-script/scrbook.html
%{_texmfdistdir}/doc/latex/koma-script/scrdate.html
%{_texmfdistdir}/doc/latex/koma-script/scrextend.html
%{_texmfdistdir}/doc/latex/koma-script/scrguide-de.pdf
%{_texmfdistdir}/doc/latex/koma-script/scrguide-en.pdf
%{_texmfdistdir}/doc/latex/koma-script/scrhack.html
%{_texmfdistdir}/doc/latex/koma-script/scrjura.html
%{_texmfdistdir}/doc/latex/koma-script/scrkbase.html
%{_texmfdistdir}/doc/latex/koma-script/scrlayer-notecolumn.html
%{_texmfdistdir}/doc/latex/koma-script/scrlayer-scrpage.html
%{_texmfdistdir}/doc/latex/koma-script/scrlayer.html
%{_texmfdistdir}/doc/latex/koma-script/scrletter.html
%{_texmfdistdir}/doc/latex/koma-script/scrlfile-hook-3.34.html
%{_texmfdistdir}/doc/latex/koma-script/scrlfile-hook.html
%{_texmfdistdir}/doc/latex/koma-script/scrlfile-patcholdlatex.html
%{_texmfdistdir}/doc/latex/koma-script/scrlfile.html
%{_texmfdistdir}/doc/latex/koma-script/scrlogo.html
%{_texmfdistdir}/doc/latex/koma-script/scrlttr2.html
%{_texmfdistdir}/doc/latex/koma-script/scrreport.html
%{_texmfdistdir}/doc/latex/koma-script/scrreprt.html
%{_texmfdistdir}/doc/latex/koma-script/scrtime.html
%{_texmfdistdir}/doc/latex/koma-script/scrwfile.html
%{_texmfdistdir}/doc/latex/koma-script/tocbasic.html
%{_texmfdistdir}/doc/latex/koma-script/typearea.html

%files -n texlive-koma-script
%defattr(-,root,root,755)
%{_texmfdistdir}/source/latex/koma-script/doc/authorpart-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/authorpart-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-compatibility-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-compatibility-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-dictum-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-dictum-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-draftmode-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-draftmode-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-fontsize-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-fontsize-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-footnotes-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-footnotes-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-footnotes-experts-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-footnotes-experts-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-headfootheight-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-headfootheight-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-interleafpage-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-interleafpage-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-lists-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-lists-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-marginpar-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-marginpar-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-oddorevenpage-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-oddorevenpage-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-options-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-options-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-pagestylemanipulation-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-pagestylemanipulation-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-parmarkup-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-parmarkup-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-textmarkup-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-textmarkup-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-titles-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-titles-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-typearea-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/common-typearea-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/expertpart-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/expertpart-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/introduction-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/introduction-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/japanlco-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/linkalias.tex
%{_texmfdistdir}/source/latex/koma-script/doc/plength-tikz.tex
%{_texmfdistdir}/source/latex/koma-script/doc/preface-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/preface-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scraddr-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scraddr-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbase-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbase-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbookreportarticle-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbookreportarticle-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbookreportarticle-experts-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrbookreportarticle-experts-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrdate-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrdate-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrdocstrip.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrextend-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrextend-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide-body.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide.bib
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide.cls
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide.gst
%{_texmfdistdir}/source/latex/koma-script/doc/scrguide.ist
%{_texmfdistdir}/source/latex/koma-script/doc/scrhack-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrhack-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrjura-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrjura-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrjura-example-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrjura-example-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-notecolumn-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-notecolumn-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-notecolumn-example-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-notecolumn-example-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-scrpage-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-scrpage-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-scrpage-experts-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlayer-scrpage-experts-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlfile-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlfile-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlogo-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlogo-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlttr2-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlttr2-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlttr2-examples.dtx
%{_texmfdistdir}/source/latex/koma-script/doc/scrlttr2-experts-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrlttr2-experts-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrtime-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrtime-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrwfile-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/scrwfile-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/terms-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/terms-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/tocbasic-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/tocbasic-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/typearea-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/typearea-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/typearea-experts-de.tex
%{_texmfdistdir}/source/latex/koma-script/doc/typearea-experts-en.tex
%{_texmfdistdir}/source/latex/koma-script/doc/variables-tikz.tex
%{_texmfdistdir}/source/latex/koma-script/japanlco.dtx
%{_texmfdistdir}/source/latex/koma-script/koma-script-source-doc.dtx
%{_texmfdistdir}/source/latex/koma-script/scraddr.dtx
%{_texmfdistdir}/source/latex/koma-script/scrextend.dtx
%{_texmfdistdir}/source/latex/koma-script/scrhack.dtx
%{_texmfdistdir}/source/latex/koma-script/scrjura.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-addressfiles.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-basics.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-bibliography.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-compatibility.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-floats.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-fonts.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-footnotes.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-index.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-language.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-letterclassoptions.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-listsandtabulars.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-listsof.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-miscellaneous.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-notepaper.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-pagestyles.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-paragraphs.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-pseudolengths.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-sections.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-title.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-tocstyle.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-typearea.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-variables.dtx
%{_texmfdistdir}/source/latex/koma-script/scrkernel-version.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlayer-notecolumn.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlayer-scrpage.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlayer.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlfile-hook.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlfile-patcholdlatex.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlfile.dtx
%{_texmfdistdir}/source/latex/koma-script/scrlogo.dtx
%{_texmfdistdir}/source/latex/koma-script/scrmain.ins
%{_texmfdistdir}/source/latex/koma-script/scrstrip.inc
%{_texmfdistdir}/source/latex/koma-script/scrstrop.inc
%{_texmfdistdir}/source/latex/koma-script/scrtime.dtx
%{_texmfdistdir}/source/latex/koma-script/scrwfile.dtx
%{_texmfdistdir}/source/latex/koma-script/tocbasic.dtx
%dir %{_texmfdistdir}/source/latex/koma-script
%dir %{_texmfdistdir}/source/latex/koma-script/doc
%dir %{_texmfdistdir}/source/latex/koma-script/doc/bin
%dir %{_texmfdistdir}/source/latex/koma-script/doc/english
%dir %{_texmfdistdir}/source/latex/koma-script/doc/ngerman
%{_texmfdistdir}/tex/latex/koma-script/DIN.lco
%{_texmfdistdir}/tex/latex/koma-script/DIN5008A.lco
%{_texmfdistdir}/tex/latex/koma-script/DIN5008B.lco
%{_texmfdistdir}/tex/latex/koma-script/DINmtext.lco
%{_texmfdistdir}/tex/latex/koma-script/KOMAold.lco
%{_texmfdistdir}/tex/latex/koma-script/KakuLL.lco
%{_texmfdistdir}/tex/latex/koma-script/NF.lco
%{_texmfdistdir}/tex/latex/koma-script/NipponEH.lco
%{_texmfdistdir}/tex/latex/koma-script/NipponEL.lco
%{_texmfdistdir}/tex/latex/koma-script/NipponLH.lco
%{_texmfdistdir}/tex/latex/koma-script/NipponLL.lco
%{_texmfdistdir}/tex/latex/koma-script/NipponRL.lco
%{_texmfdistdir}/tex/latex/koma-script/SN.lco
%{_texmfdistdir}/tex/latex/koma-script/SNleft.lco
%{_texmfdistdir}/tex/latex/koma-script/UScommercial9.lco
%{_texmfdistdir}/tex/latex/koma-script/UScommercial9DW.lco
%{_texmfdistdir}/tex/latex/koma-script/float.hak
%{_texmfdistdir}/tex/latex/koma-script/floatrow.hak
%{_texmfdistdir}/tex/latex/koma-script/hyperref.hak
%{_texmfdistdir}/tex/latex/koma-script/koma-script-source-doc.cls
%{_texmfdistdir}/tex/latex/koma-script/listings.hak
%{_texmfdistdir}/tex/latex/koma-script/lscape.hak
%{_texmfdistdir}/tex/latex/koma-script/nomencl.hak
%{_texmfdistdir}/tex/latex/koma-script/scraddr.sty
%{_texmfdistdir}/tex/latex/koma-script/scrartcl.cls
%{_texmfdistdir}/tex/latex/koma-script/scrarticle.cls
%{_texmfdistdir}/tex/latex/koma-script/scrbase.sty
%{_texmfdistdir}/tex/latex/koma-script/scrbook.cls
%{_texmfdistdir}/tex/latex/koma-script/scrdate.sty
%{_texmfdistdir}/tex/latex/koma-script/scrdoc.cls
%{_texmfdistdir}/tex/latex/koma-script/scrextend.sty
%{_texmfdistdir}/tex/latex/koma-script/scrfontsizes.sty
%{_texmfdistdir}/tex/latex/koma-script/scrhack.sty
%{_texmfdistdir}/tex/latex/koma-script/scrjura.sty
%{_texmfdistdir}/tex/latex/koma-script/scrkbase.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlayer-notecolumn.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlayer-scrpage.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlayer.sty
%{_texmfdistdir}/tex/latex/koma-script/scrletter.cls
%{_texmfdistdir}/tex/latex/koma-script/scrletter.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlfile-hook-3.34.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlfile-hook.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlfile-patcholdlatex.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlfile.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlogo.sty
%{_texmfdistdir}/tex/latex/koma-script/scrlttr2.cls
%{_texmfdistdir}/tex/latex/koma-script/scrreport.cls
%{_texmfdistdir}/tex/latex/koma-script/scrreprt.cls
%{_texmfdistdir}/tex/latex/koma-script/scrsize10pt.clo
%{_texmfdistdir}/tex/latex/koma-script/scrsize11pt.clo
%{_texmfdistdir}/tex/latex/koma-script/scrsize12pt.clo
%{_texmfdistdir}/tex/latex/koma-script/scrtime.sty
%{_texmfdistdir}/tex/latex/koma-script/scrwfile.sty
%{_texmfdistdir}/tex/latex/koma-script/setspace.hak
%{_texmfdistdir}/tex/latex/koma-script/standardsections.hak
%{_texmfdistdir}/tex/latex/koma-script/tocbasic.sty
%{_texmfdistdir}/tex/latex/koma-script/typearea.sty
%{_texmfdistdir}/tex/latex/koma-script/visualize.lco

%package -n texlive-koma-script-examples
Version:        %{texlive_version}.%{texlive_noarch}.svn63833
Release:        0
License:        LPPL-1.0
Summary:        Examples from the KOMA-Script book
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source190:      koma-script-examples.doc.tar.xz

%description -n texlive-koma-script-examples
This package contains some examples from the 6th edition of the
book >>KOMA-Script<<, >>Eine Sammlung von Klassen und Paketen
fur LaTeX2e<< by Markus Kohm, published by Lehmanns Media.
There are no further descriptions of these examples.

%post -n texlive-koma-script-examples
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-koma-script-examples
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-koma-script-examples
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-koma-script-examples
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/result/chapterthumbexample.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/source/chapterthumb.sty
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/source/chapterthumbexample.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefDIN.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefSN.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefbak3.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefdup.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/brieflft.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/brieflfu.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefnow.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefrag2.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefwbk.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefwbk2.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/briefwbt2.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/letter-nipponA.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result/letter-nipponB.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/CaptainHook-1.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/SNslhead.lco
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/asymTypB.lco
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefDIN.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefSN.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefbak3.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefdup.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/brieflft.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/brieflfu.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefnow.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefrag2.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/brieftemplate.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefwbk.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefwbk2.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/briefwbt2.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/dateup.lco
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/letter-nipponA.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/letter-nipponB.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source/nowindow.lco
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/result/scrjuraexample.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/source/scrjuraexample.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/result/remarkexample.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/source/remarkbox.sty
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/source/remarkexample.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/result/scrlayer-notecolumn-example.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/source/scrlayer-notecolumn-example.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-0.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-1.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-10.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-11.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-12.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-13.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-14.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-15.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-16.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-17.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-18.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-19.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-2.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-20.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-21.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-22.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-23.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-3.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-4.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-5.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-6.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-7.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-8.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result/letter-9.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/ich.lco
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-0.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-1.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-10.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-11.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-12.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-13.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-14.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-15.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-16.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-17.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-18.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-19.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-2.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-20.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-21.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-22.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-23.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-3.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-4.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-5.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-6.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-7.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-8.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/letter-9.tex
%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source/musterlogo.pdf
%{_texmfdistdir}/doc/latex/koma-script-examples/LEGAL.txt
%{_texmfdistdir}/doc/latex/koma-script-examples/LEGAL_DE.txt
%{_texmfdistdir}/doc/latex/koma-script-examples/LIESMICH.txt
%{_texmfdistdir}/doc/latex/koma-script-examples/README.txt

%package -n texlive-koma-script-sfs
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn26137
Release:        0
License:        LPPL-1.0
Summary:        Koma-script letter class option for Finnish
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-koma-script-sfs-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source191:      koma-script-sfs.tar.xz
Source192:      koma-script-sfs.doc.tar.xz

%description -n texlive-koma-script-sfs
A koma-script parameter set for letters on A4 paper, complying
with Finnish standards SFS 2486, 2487 and 2488; suitable for
window envelopes with window on the left size in the sizes C5,
C65, E5 and E65 (although, because the address window is
smaller, for sizes E5 and E65 the address may not fit within
the window, but ordinary 3-line address should fit).

%package -n texlive-koma-script-sfs-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn26137
Release:        0
Summary:        Documentation for texlive-koma-script-sfs
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-koma-script-sfs and texlive-alldocumentation)
Provides:       locale(texlive-koma-script-sfs-doc:fi)

%description -n texlive-koma-script-sfs-doc
This package includes the documentation for texlive-koma-script-sfs

%post -n texlive-koma-script-sfs
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-koma-script-sfs
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-koma-script-sfs
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-koma-script-sfs-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/koma-script-sfs/README
%{_texmfdistdir}/doc/latex/koma-script-sfs/SFSesim.pdf
%{_texmfdistdir}/doc/latex/koma-script-sfs/SFSesim.tex

%files -n texlive-koma-script-sfs
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/koma-script-sfs/SFS.lco

%package -n texlive-komacv
Version:        %{texlive_version}.%{texlive_noarch}.1.1.2svn57721
Release:        0
License:        LPPL-1.0
Summary:        Typesetting a beautiful CV with various style options
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-komacv-doc >= %{texlive_version}
Provides:       tex(komacv-casual.sty)
Provides:       tex(komacv-classic.sty)
Provides:       tex(komacv-oldstyle.sty)
Provides:       tex(komacv.cls)
Requires:       tex(calc.sty)
Requires:       tex(fontawesome.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(kvoptions.sty)
Requires:       tex(lastpage.sty)
Requires:       tex(ragged2e.sty)
Requires:       tex(scrartcl.cls)
Requires:       tex(xcolor.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source193:      komacv.tar.xz
Source194:      komacv.doc.tar.xz

%description -n texlive-komacv
The class simplifies the creation of beautiful CV. The user may
choose between different styles, and may adjust settings to
tune the output.

%package -n texlive-komacv-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1.2svn57721
Release:        0
Summary:        Documentation for texlive-komacv
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-komacv and texlive-alldocumentation)

%description -n texlive-komacv-doc
This package includes the documentation for texlive-komacv

%post -n texlive-komacv
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-komacv
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-komacv
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-komacv-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/komacv/README
%{_texmfdistdir}/doc/latex/komacv/examples/jeyre.jpg
%{_texmfdistdir}/doc/latex/komacv/examples/komacv.bib
%{_texmfdistdir}/doc/latex/komacv/examples/komacv_example.tex
%{_texmfdistdir}/doc/latex/komacv/examples/komacv_example_casual.pdf
%{_texmfdistdir}/doc/latex/komacv/examples/komacv_example_classic.pdf
%{_texmfdistdir}/doc/latex/komacv/examples/komacv_example_oldstyle.pdf
%{_texmfdistdir}/doc/latex/komacv/komacv.pdf

%files -n texlive-komacv
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/komacv/komacv-casual.sty
%{_texmfdistdir}/tex/latex/komacv/komacv-classic.sty
%{_texmfdistdir}/tex/latex/komacv/komacv-oldstyle.sty
%{_texmfdistdir}/tex/latex/komacv/komacv.cls

%package -n texlive-komacv-rg
Version:        %{texlive_version}.%{texlive_noarch}.0.0.9.2svn49064
Release:        0
License:        LPPL-1.0
Summary:        LaTeX packages that aid in creating CVs based on the komacv class and creating related documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-komacv-rg-doc >= %{texlive_version}
Provides:       tex(komacv-addons.sty)
Provides:       tex(komacv-lco.sty)
Provides:       tex(komacv-multilang.sty)
Requires:       tex(datetime2-calc.sty)
Requires:       tex(datetime2.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(fontawesome.sty)
Requires:       tex(letltxmacro.sty)
Requires:       tex(marvosym.sty)
Requires:       tex(multilang-sect.sty)
Requires:       tex(multilang-tags.sty)
Requires:       tex(multilang.sty)
Requires:       tex(scrkbase.sty)
Requires:       tex(translations.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source195:      komacv-rg.tar.xz
Source196:      komacv-rg.doc.tar.xz

%description -n texlive-komacv-rg
The komacv-rg bundle provides packages that aid in creating CVs
based on the komacv class and creating related documents, such
as cover letters and cover sheets for job applications.
Concretely, the bundle consists of three packages:
komacv-addons, komacv-lco, and komacv-multilang. komacv-addons
is a small collection of add-ons and fixes for the komacv
class; komacv-lco enables the use of letter class options from
scrlttr2 also in komacv-based and other non-scrlttr2-based
documents; komacv-multilang enables the provisioning of CVs in
multiple languages and the selection of a language via babel or
polyglossia.

%package -n texlive-komacv-rg-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.9.2svn49064
Release:        0
Summary:        Documentation for texlive-komacv-rg
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-komacv-rg and texlive-alldocumentation)

%description -n texlive-komacv-rg-doc
This package includes the documentation for texlive-komacv-rg

%post -n texlive-komacv-rg
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-komacv-rg
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-komacv-rg
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-komacv-rg-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/komacv-rg/README.md
%{_texmfdistdir}/doc/latex/komacv-rg/komacv-addons.pdf
%{_texmfdistdir}/doc/latex/komacv-rg/komacv-lco.pdf
%{_texmfdistdir}/doc/latex/komacv-rg/komacv-multilang.pdf

%files -n texlive-komacv-rg
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/komacv-rg/komacv-addons.sty
%{_texmfdistdir}/tex/latex/komacv-rg/komacv-lco.sty
%{_texmfdistdir}/tex/latex/komacv-rg/komacv-multilang.sty

%package -n texlive-kotex-oblivoir
Version:        %{texlive_version}.%{texlive_noarch}.3.2.1svn66513
Release:        0
License:        LPPL-1.0
Summary:        A LaTeX document class for typesetting Korean documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-kotex-utf >= %{texlive_version}
#!BuildIgnore: texlive-kotex-utf
Requires:       texlive-memoir >= %{texlive_version}
#!BuildIgnore: texlive-memoir
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kotex-oblivoir-doc >= %{texlive_version}
Provides:       tex(10_5.sty)
Provides:       tex(fapapersize.sty)
Provides:       tex(hfontsel.sty)
Provides:       tex(memhangul-common.sty)
Provides:       tex(memhangul-patch.sty)
Provides:       tex(memhangul-ucs.sty)
Provides:       tex(memhangul-x.sty)
Provides:       tex(memucs-enumerate.sty)
Provides:       tex(memucs-gremph.sty)
Provides:       tex(memucs-interword-x.sty)
Provides:       tex(memucs-interword.sty)
Provides:       tex(memucs-setspace.sty)
Provides:       tex(nanumfontsel.sty)
Provides:       tex(ob-koreanappendix.sty)
Provides:       tex(ob-mathleading.sty)
Provides:       tex(ob-nokoreanappendix.sty)
Provides:       tex(ob-toclof.sty)
Provides:       tex(ob-unfontsdefault.sty)
Provides:       tex(obchaptertoc.sty)
Provides:       tex(oblivoir-misc.sty)
Provides:       tex(oblivoir-utf.cls)
Provides:       tex(oblivoir-xl.cls)
Provides:       tex(oblivoir.cls)
Provides:       tex(xetexko-var.sty)
Provides:       tex(xob-amssymb.sty)
Provides:       tex(xob-dotemph.sty)
Provides:       tex(xob-font.sty)
Provides:       tex(xob-hyper.sty)
Provides:       tex(xob-lwarp.sty)
Provides:       tex(xob-paralist.sty)
Provides:       tex(xoblivoir.cls)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(babel.sty)
Requires:       tex(bookmark.sty)
Requires:       tex(cjkutf8-ko.sty)
Requires:       tex(dhucs-cmap.sty)
Requires:       tex(dhucs-paralist.sty)
Requires:       tex(dhucs.sty)
Requires:       tex(enumerate.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(expl3.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(hologo.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifluatex.sty)
Requires:       tex(iftex.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(kolabels-utf.sty)
Requires:       tex(konames-utf.sty)
Requires:       tex(kotex.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(luatexko.sty)
Requires:       tex(lwarp.sty)
Requires:       tex(memhfixc.sty)
Requires:       tex(memoir.cls)
Requires:       tex(microtype.sty)
Requires:       tex(moreverb.sty)
Requires:       tex(paralist.sty)
Requires:       tex(polyglossia.sty)
Requires:       tex(type1cm.sty)
Requires:       tex(type1ec.sty)
Requires:       tex(xetexko-font.sty)
Requires:       tex(xetexko-hanging.sty)
Requires:       tex(xetexko-josa.sty)
Requires:       tex(xetexko-space.sty)
Requires:       tex(xetexko-vertical.sty)
Requires:       tex(xetexko.sty)
Requires:       tex(xkeyval.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source197:      kotex-oblivoir.tar.xz
Source198:      kotex-oblivoir.doc.tar.xz

%description -n texlive-kotex-oblivoir
The class is based on memoir, and is adapted to typesetting
Korean documents. The bundle (of class and associated packages)
belongs to the ko.TeX bundle. It depends on memoir and
kotex-utf to function.

%package -n texlive-kotex-oblivoir-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.2.1svn66513
Release:        0
Summary:        Documentation for texlive-kotex-oblivoir
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kotex-oblivoir and texlive-alldocumentation)
Provides:       locale(texlive-kotex-oblivoir-doc:ko)

%description -n texlive-kotex-oblivoir-doc
This package includes the documentation for texlive-kotex-oblivoir

%post -n texlive-kotex-oblivoir
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kotex-oblivoir
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kotex-oblivoir
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kotex-oblivoir-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kotex-oblivoir/ChangeLog
%{_texmfdistdir}/doc/latex/kotex-oblivoir/README
%{_texmfdistdir}/doc/latex/kotex-oblivoir/chapstyfig.pdf
%{_texmfdistdir}/doc/latex/kotex-oblivoir/ob-mathleading-doc.pdf
%{_texmfdistdir}/doc/latex/kotex-oblivoir/ob-mathleading-doc.tex
%{_texmfdistdir}/doc/latex/kotex-oblivoir/obchaptertoc-doc.pdf
%{_texmfdistdir}/doc/latex/kotex-oblivoir/obchaptertoc-doc.tex
%{_texmfdistdir}/doc/latex/kotex-oblivoir/oblivoir-simpledoc.pdf
%{_texmfdistdir}/doc/latex/kotex-oblivoir/oblivoir-simpledoc.tex
%{_texmfdistdir}/doc/latex/kotex-oblivoir/oblivoir-test.tex

%files -n texlive-kotex-oblivoir
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/10_5.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/fapapersize.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/memhangul-common.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/memhangul-patch.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/memucs-enumerate.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/memucs-setspace.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/ob-koreanappendix.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/ob-nokoreanappendix.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/ob-toclof.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/obchaptertoc.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common/oblivoir-misc.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/hfontsel.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/hfontspec.nanum
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/memhangul-ucs.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/memucs-gremph.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/memucs-interword.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs/nanumfontsel.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/memhangul-x.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/memucs-interword-x.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/ob-mathleading.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/ob-unfontsdefault.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xetexko-var.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-amssymb.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-dotemph.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-font.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-hyper.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-lwarp.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x/xob-paralist.sty
%{_texmfdistdir}/tex/latex/kotex-oblivoir/oblivoir-utf.cls
%{_texmfdistdir}/tex/latex/kotex-oblivoir/oblivoir-xl.cls
%{_texmfdistdir}/tex/latex/kotex-oblivoir/oblivoir.cls
%{_texmfdistdir}/tex/latex/kotex-oblivoir/xoblivoir.cls

%package -n texlive-kotex-plain
Version:        %{texlive_version}.%{texlive_noarch}.3.0.0svn63689
Release:        0
License:        LPPL-1.0
Summary:        Macros for typesetting Korean under Plain TeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kotex-plain-doc >= %{texlive_version}
Provides:       tex(hangulcweb.tex)
Provides:       tex(kotexplain.tex)
Provides:       tex(kotexutf-core.tex)
Provides:       tex(kotexutf.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source199:      kotex-plain.tar.xz
Source200:      kotex-plain.doc.tar.xz

%description -n texlive-kotex-plain
The package provides macros for typesetting Hangul, the native
alphabet of the Korean language, using plain *TeX. Input Korean
text should be encoded in UTF-8. The package belongs to the
ko.TeX bundle.

%package -n texlive-kotex-plain-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.0.0svn63689
Release:        0
Summary:        Documentation for texlive-kotex-plain
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kotex-plain and texlive-alldocumentation)

%description -n texlive-kotex-plain-doc
This package includes the documentation for texlive-kotex-plain

%post -n texlive-kotex-plain
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kotex-plain
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kotex-plain
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kotex-plain-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/plain/kotex-plain/ChangeLog
%{_texmfdistdir}/doc/plain/kotex-plain/README

%files -n texlive-kotex-plain
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/plain/kotex-plain/hangulcweb.tex
%{_texmfdistdir}/tex/plain/kotex-plain/kotexplain.tex
%{_texmfdistdir}/tex/plain/kotex-plain/kotexutf-core.tex
%{_texmfdistdir}/tex/plain/kotex-plain/kotexutf.tex

%package -n texlive-kotex-utf
Version:        %{texlive_version}.%{texlive_noarch}.3.0.0svn63690
Release:        0
License:        LPPL-1.0
Summary:        Typeset Hangul, coded in UTF-8
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-cjk-ko >= %{texlive_version}
#!BuildIgnore: texlive-cjk-ko
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kotex-utf-doc >= %{texlive_version}
Provides:       tex(dhucs-cmap.sty)
Provides:       tex(dhucs-enumerate.sty)
Provides:       tex(dhucs-enumitem.sty)
Provides:       tex(dhucs-gremph.sty)
Provides:       tex(dhucs-interword.sty)
Provides:       tex(dhucs-nanumfont.sty)
Provides:       tex(dhucs-paralist.sty)
Provides:       tex(dhucs-sectsty.sty)
Provides:       tex(dhucs-setspace.sty)
Provides:       tex(dhucs-trivcj.sty)
Provides:       tex(dhucs-ucshyper.sty)
Provides:       tex(dhucs.cfg)
Provides:       tex(dhucs.sty)
Provides:       tex(dhucsfn.sty)
Provides:       tex(kosections-utf.sty)
Provides:       tex(kotex-logo.sty)
Provides:       tex(kotex-sections.sty)
Provides:       tex(kotex-varioref.sty)
Provides:       tex(kotex.cfg)
Provides:       tex(kotexutf.sty)
Provides:       tex(lucuhcmj.fd)
Requires:       tex(enumerate.sty)
Requires:       tex(enumitem.sty)
Requires:       tex(fnpara.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(hologo.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifpdf.sty)
Requires:       tex(iftex.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(kolabels-utf.sty)
Requires:       tex(konames-utf.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(luatexko.sty)
Requires:       tex(paralist.sty)
Requires:       tex(sectsty.sty)
Requires:       tex(setspace.sty)
Requires:       tex(varioref.sty)
Requires:       tex(verbatim.sty)
Requires:       tex(xetexko.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source201:      kotex-utf.tar.xz
Source202:      kotex-utf.doc.tar.xz

%description -n texlive-kotex-utf
The package typesets Hangul, which is the native alphabet of
the Korean language; input Korean text should be encoded in
UTF-8. The bundle (of class and associated packages) belongs to
the ko.TeX bundle.

%package -n texlive-kotex-utf-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.0.0svn63690
Release:        0
Summary:        Documentation for texlive-kotex-utf
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kotex-utf and texlive-alldocumentation)
Provides:       locale(texlive-kotex-utf-doc:ko)

%description -n texlive-kotex-utf-doc
This package includes the documentation for texlive-kotex-utf

%post -n texlive-kotex-utf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kotex-utf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kotex-utf
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kotex-utf-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kotex-utf/ChangeLog
%{_texmfdistdir}/doc/latex/kotex-utf/README
%{_texmfdistdir}/doc/latex/kotex-utf/fig/allowbreak-dhucs.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/fig/fntexp.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/fig/fntnormal.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/fig/histkotex.jpg
%{_texmfdistdir}/doc/latex/kotex-utf/fig/linebreaktest.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/fig/testdhucsallowbreak.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/fig/yettext.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/kotex-doc.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/kotex-doc.tex
%{_texmfdistdir}/doc/latex/kotex-utf/kotex-utf-doc.pdf
%{_texmfdistdir}/doc/latex/kotex-utf/kotex-utf-doc.tex
%{_texmfdistdir}/doc/latex/kotex-utf/sample-finemath-setup.tex

%files -n texlive-kotex-utf
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-cmap.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-enumerate.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-enumitem.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-gremph.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-interword.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-paralist.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-sectsty.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-setspace.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-trivcj.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucs-ucshyper.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/dhucsfn.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/kotex-logo.sty
%{_texmfdistdir}/tex/latex/kotex-utf/contrib/kotex-varioref.sty
%{_texmfdistdir}/tex/latex/kotex-utf/dhucs-nanumfont.sty
%{_texmfdistdir}/tex/latex/kotex-utf/dhucs.sty
%{_texmfdistdir}/tex/latex/kotex-utf/hfontspec.default
%{_texmfdistdir}/tex/latex/kotex-utf/kosections-utf.sty
%{_texmfdistdir}/tex/latex/kotex-utf/kotex-sections.sty
%{_texmfdistdir}/tex/latex/kotex-utf/kotex.cfg
%{_texmfdistdir}/tex/latex/kotex-utf/kotexutf.sty
%{_texmfdistdir}/tex/latex/kotex-utf/lucenc.dfu
%{_texmfdistdir}/tex/latex/kotex-utf/lucuhcmj.fd
%{_texmfdistdir}/tex/latex/kotex-utf/tex4ht/dhucs.4ht
%{_texmfdistdir}/tex/latex/kotex-utf/tex4ht/dhucs.cfg
%{_texmfdistdir}/tex/latex/kotex-utf/tex4ht/kosections-utf.4ht

%package -n texlive-kotex-utils
Version:        %{texlive_version}.%{texlive_noarch}.2.1.0svn38727
Release:        0
License:        LPPL-1.0
Summary:        Utility scripts and support files for typesetting Korean
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-kotex-utf >= %{texlive_version}
#!BuildIgnore: texlive-kotex-utf
Requires(pre):  texlive-kotex-utils-bin >= %{texlive_version}
#!BuildIgnore: texlive-kotex-utils-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kotex-utils-doc >= %{texlive_version}
Requires:       perl(File::Copy)
#!BuildIgnore:  perl(File::Copy)
Requires:       perl(File::Path)
#!BuildIgnore:  perl(File::Path)
Requires:       perl(Getopt::Std)
#!BuildIgnore:  perl(Getopt::Std)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source203:      kotex-utils.tar.xz
Source204:      kotex-utils.doc.tar.xz

%description -n texlive-kotex-utils
The bundle provides scripts and support files for index
generation in Korean language typesetting. The files belong to
the ko.TeX bundle.

%package -n texlive-kotex-utils-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.1.0svn38727
Release:        0
Summary:        Documentation for texlive-kotex-utils
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kotex-utils and texlive-alldocumentation)

%description -n texlive-kotex-utils-doc
This package includes the documentation for texlive-kotex-utils

%post -n texlive-kotex-utils
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kotex-utils
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kotex-utils
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kotex-utils-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kotex-utils/ChangeLog
%{_texmfdistdir}/doc/latex/kotex-utils/README
%{_texmfdistdir}/doc/latex/kotex-utils/utf8-lang.xdy
%{_texmfdistdir}/doc/latex/kotex-utils/utf8.xdy

%files -n texlive-kotex-utils
%defattr(-,root,root,755)
%{_texmfdistdir}/makeindex/kotex-utils/kotex.ist
%{_texmfdistdir}/makeindex/kotex-utils/memucs-manual.ist
%{_texmfdistdir}/scripts/kotex-utils/jamo-normalize.pl
%{_texmfdistdir}/scripts/kotex-utils/komkindex.pl
%{_texmfdistdir}/scripts/kotex-utils/ttf2kotexfont.pl

%package -n texlive-kpathsea
#!BuildIgnore:   texlive-scripts
#!BuildIgnore:   texlive-kpathsea
Version:        %{texlive_version}.%{texlive_noarch}.svn66209
Release:        0
License:        LGPL-2.1-or-later
Summary:        Path searching library for TeX-related files
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-kpathsea-bin >= %{texlive_version}
#!BuildIgnore: texlive-kpathsea-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires:       texlive-gsftopk >= %{texlive_version}
Requires:       texlive-updmap-map >= %{texlive_version}
#!BuildIgnore: texlive-gsftopk
#!BuildIgnore: texlive-gsftopk-bin
#!BuildIgnore: texlive-updmap-map
Requires(pre):  texlive-scripts-bin >= %{texlive_version}
Requires(pre):  texlive-scripts >= %{texlive_version}
Requires(post): diffutils
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Suggests:       texlive-kpathsea-doc >= %{texlive_version}
Provides:       tex(fmtutil.cnf)
Provides:       tex(mktex.cnf)
Provides:       tex(texmf.cnf)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source205:      kpathsea.tar.xz
Source206:      kpathsea.doc.tar.xz
Source207:      kpathsea_cnf.dif

%description -n texlive-kpathsea
Kpathsea is a library and utility programs which provide path
searching facilities for TeX file types, including the
self-locating feature required for movable installations,
layered on top of a general search mechanism. It is not
distributed separately, but rather is released and maintained
as part of the TeX Live sources.

%package -n texlive-kpathsea-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66209
Release:        0
Summary:        Documentation for texlive-kpathsea
License:        LGPL-2.1-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kpathsea and texlive-alldocumentation)
Provides:       man(kpseaccess.1)
Provides:       man(kpsereadlink.1)
Provides:       man(kpsestat.1)
Provides:       man(kpsewhich.1)
Requires(preun):%install_info_prereq
Requires(post): %install_info_prereq

%description -n texlive-kpathsea-doc
This package includes the documentation for texlive-kpathsea

%post -n texlive-kpathsea
mkdir -p /var/run/texlive
mkdir -p /var/run/texlive/scriptlets
cat > /var/run/texlive/scriptlets/kpathsea << 'EOF'
if test -s %{_texmfconfdir}/web2c/fmtutil.cnf.rpmnew ; then
    old=$(mktemp ${TMPDIR-${TEMP-${TMP-/tmp}}}/pool-old.XXXXXXXX) || exit -2
    new=$(mktemp ${TMPDIR-${TEMP-${TMP-/tmp}}}/pool-new.XXXXXXXX) || exit -2
    sed -rn '\@^TEXMFMAIN\s*=@p;\@Part 3:@,${\@^[a-z]@p}'  < %{_texmfconfdir}/web2c/fmtutil.cnf.rpmnew > $new
    sed -rn '\@^TEXMFMAIN\s*=@p;\@Part 3:@,${\@^[a-z]@p}'  < %{_texmfconfdir}/web2c/fmtutil.cnf > $old
    if ! cmp -s $new $old; then
	mv %{_texmfconfdir}/web2c/fmtutil.cnf %{_texmfconfdir}/web2c/fmtutil.cnf.rpmold
	mv %{_texmfconfdir}/web2c/fmtutil.cnf.rpmnew %{_texmfconfdir}/web2c/fmtutil.cnf
	> /var/run/texlive/run-fmtutil.refresh
    fi
    rm -f $new $old
fi
if test -s %{_texmfconfdir}/web2c/texmf.cnf.rpmnew ; then
    sed -ri '/^shell_escape_commands = \\/,/^mpost,\\/{ /mpost,\\/d }' %{_texmfconfdir}/web2c/texmf.cnf || :
fi
EOF
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kpathsea
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kpathsea
test -d /var/run/texlive || exit 0
test -e /var/run/texlive/run-mktexlsr || exit 0
%{_bindir}/mktexlsr > /dev/null 2>&1 || :
rm -f /var/run/texlive/run-mktexlsr

%preun -n texlive-kpathsea-doc
if test $1 = 0; then
    %install_info_delete --info-dir=%{_infodir} %{_infodir}/kpathsea.info
    %install_info_delete --info-dir=%{_infodir} %{_infodir}/web2c.info
fi

%post -n texlive-kpathsea-doc
%install_info --info-dir=%{_infodir} %{_infodir}/kpathsea.info
%install_info --info-dir=%{_infodir} %{_infodir}/web2c.info

%files -n texlive-kpathsea-doc
%defattr(-,root,root,755)
%{_infodir}/kpathsea.info*
%{_infodir}/web2c.info*
%{_texmfdistdir}/doc/kpathsea/NEWS
%{_texmfdistdir}/doc/kpathsea/kpathsea.html
%{_texmfdistdir}/doc/kpathsea/kpathsea.pdf
%{_mandir}/man1/kpseaccess.1*
%{_mandir}/man1/kpsereadlink.1*
%{_mandir}/man1/kpsestat.1*
%{_mandir}/man1/kpsewhich.1*
%{_texmfdistdir}/doc/web2c/NEWS
%{_texmfdistdir}/doc/web2c/web2c.html
%{_texmfdistdir}/doc/web2c/web2c.pdf

%files -n texlive-kpathsea
%defattr(-,root,root,755)
%{_texmfdistdir}/web2c/amiga-pl.tcx
%{_texmfdistdir}/web2c/cp1250cs.tcx
%{_texmfdistdir}/web2c/cp1250pl.tcx
%{_texmfdistdir}/web2c/cp1250t1.tcx
%{_texmfdistdir}/web2c/cp227.tcx
%{_texmfdistdir}/web2c/cp852-cs.tcx
%{_texmfdistdir}/web2c/cp852-pl.tcx
%{_texmfdistdir}/web2c/cp8bit.tcx
%{_texmfdistdir}/web2c/empty.tcx
%verify(link) %{_texmfdistdir}/web2c/fmtutil.cnf
%{_texmfdistdir}/web2c/il1-t1.tcx
%{_texmfdistdir}/web2c/il2-cs.tcx
%{_texmfdistdir}/web2c/il2-pl.tcx
%{_texmfdistdir}/web2c/il2-t1.tcx
%{_texmfdistdir}/web2c/kam-cs.tcx
%{_texmfdistdir}/web2c/kam-t1.tcx
%{_texmfdistdir}/web2c/macce-pl.tcx
%{_texmfdistdir}/web2c/macce-t1.tcx
%{_texmfdistdir}/web2c/maz-pl.tcx
%verify(link) %{_texmfdistdir}/web2c/mktex.cnf
%{_texmfdistdir}/web2c/mktex.opt
%{_texmfdistdir}/web2c/mktexdir
%{_texmfdistdir}/web2c/mktexdir.opt
%{_texmfdistdir}/web2c/mktexnam
%{_texmfdistdir}/web2c/mktexnam.opt
%{_texmfdistdir}/web2c/mktexupd
%{_texmfdistdir}/web2c/natural.tcx
%{_texmfdistdir}/web2c/tcvn-t5.tcx
%verify(link) %{_texmfdistdir}/web2c/texmf.cnf
%{_texmfdistdir}/web2c/viscii-t5.tcx
%config(noreplace) %verify(not md5 mtime size) %{_texmfconfdir}/web2c/fmtutil.cnf
%config %verify(not md5 mtime size) %{_texmfconfdir}/web2c/mktex.cnf
%config(noreplace) %verify(not md5 mtime size) %{_texmfconfdir}/web2c/texmf.cnf

%package -n texlive-kpfonts
Version:        %{texlive_version}.%{texlive_noarch}.3.35svn65583
Release:        0
License:        LPPL-1.0
Summary:        A complete set of fonts for text and mathematics
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-kpfonts-fonts >= %{texlive_version}
Suggests:       texlive-kpfonts-doc >= %{texlive_version}
Provides:       tex(jkpbex.tfm)
Provides:       tex(jkpbexa.tfm)
Provides:       tex(jkpbit7c.tfm)
Provides:       tex(jkpbit7c.vf)
Provides:       tex(jkpbit7t.tfm)
Provides:       tex(jkpbit7t.vf)
Provides:       tex(jkpbit8a.tfm)
Provides:       tex(jkpbit8r.tfm)
Provides:       tex(jkpbit8t.tfm)
Provides:       tex(jkpbit8t.vf)
Provides:       tex(jkpbitc.tfm)
Provides:       tex(jkpbite.tfm)
Provides:       tex(jkpbmi.tfm)
Provides:       tex(jkpbmia.tfm)
Provides:       tex(jkpbmiaw.tfm)
Provides:       tex(jkpbmiaw.vf)
Provides:       tex(jkpbmif.tfm)
Provides:       tex(jkpbmif.vf)
Provides:       tex(jkpbmifw.tfm)
Provides:       tex(jkpbmifw.vf)
Provides:       tex(jkpbmiw.tfm)
Provides:       tex(jkpbmiw.vf)
Provides:       tex(jkpbn7c.tfm)
Provides:       tex(jkpbn7c.vf)
Provides:       tex(jkpbn7t.tfm)
Provides:       tex(jkpbn7t.vf)
Provides:       tex(jkpbn8a.tfm)
Provides:       tex(jkpbn8r.tfm)
Provides:       tex(jkpbn8t.tfm)
Provides:       tex(jkpbn8t.vf)
Provides:       tex(jkpbnc.tfm)
Provides:       tex(jkpbne.tfm)
Provides:       tex(jkpbsc7c.tfm)
Provides:       tex(jkpbsc7c.vf)
Provides:       tex(jkpbsc7t.tfm)
Provides:       tex(jkpbsc7t.vf)
Provides:       tex(jkpbsc8a.tfm)
Provides:       tex(jkpbsc8r.tfm)
Provides:       tex(jkpbsc8t.tfm)
Provides:       tex(jkpbsc8t.vf)
Provides:       tex(jkpbsce.tfm)
Provides:       tex(jkpbscsl7c.tfm)
Provides:       tex(jkpbscsl7c.vf)
Provides:       tex(jkpbscsl7t.tfm)
Provides:       tex(jkpbscsl7t.vf)
Provides:       tex(jkpbscsl8r.tfm)
Provides:       tex(jkpbscsl8t.tfm)
Provides:       tex(jkpbscsl8t.vf)
Provides:       tex(jkpbscsle.tfm)
Provides:       tex(jkpbsl7c.tfm)
Provides:       tex(jkpbsl7c.vf)
Provides:       tex(jkpbsl7t.tfm)
Provides:       tex(jkpbsl7t.vf)
Provides:       tex(jkpbsl8r.tfm)
Provides:       tex(jkpbsl8t.tfm)
Provides:       tex(jkpbsl8t.vf)
Provides:       tex(jkpbslc.tfm)
Provides:       tex(jkpbsle.tfm)
Provides:       tex(jkpbsy.tfm)
Provides:       tex(jkpbsya.tfm)
Provides:       tex(jkpbsyb.tfm)
Provides:       tex(jkpbsybw.tfm)
Provides:       tex(jkpbsybw.vf)
Provides:       tex(jkpbsyc.tfm)
Provides:       tex(jkpbsyd.tfm)
Provides:       tex(jkpbsydw.tfm)
Provides:       tex(jkpbsydw.vf)
Provides:       tex(jkpbsyw.tfm)
Provides:       tex(jkpbsyw.vf)
Provides:       tex(jkpbxit7c.tfm)
Provides:       tex(jkpbxit7c.vf)
Provides:       tex(jkpbxit7t.tfm)
Provides:       tex(jkpbxit7t.vf)
Provides:       tex(jkpbxit8r.tfm)
Provides:       tex(jkpbxit8t.tfm)
Provides:       tex(jkpbxit8t.vf)
Provides:       tex(jkpbxitc.tfm)
Provides:       tex(jkpbxite.tfm)
Provides:       tex(jkpbxn7c.tfm)
Provides:       tex(jkpbxn7c.vf)
Provides:       tex(jkpbxn7t.tfm)
Provides:       tex(jkpbxn7t.vf)
Provides:       tex(jkpbxn8r.tfm)
Provides:       tex(jkpbxn8t.tfm)
Provides:       tex(jkpbxn8t.vf)
Provides:       tex(jkpbxnc.tfm)
Provides:       tex(jkpbxne.tfm)
Provides:       tex(jkpbxsc7c.tfm)
Provides:       tex(jkpbxsc7c.vf)
Provides:       tex(jkpbxsc7t.tfm)
Provides:       tex(jkpbxsc7t.vf)
Provides:       tex(jkpbxsc8r.tfm)
Provides:       tex(jkpbxsc8t.tfm)
Provides:       tex(jkpbxsc8t.vf)
Provides:       tex(jkpbxsce.tfm)
Provides:       tex(jkpbxscsl7c.tfm)
Provides:       tex(jkpbxscsl7c.vf)
Provides:       tex(jkpbxscsl7t.tfm)
Provides:       tex(jkpbxscsl7t.vf)
Provides:       tex(jkpbxscsl8r.tfm)
Provides:       tex(jkpbxscsl8t.tfm)
Provides:       tex(jkpbxscsl8t.vf)
Provides:       tex(jkpbxscsle.tfm)
Provides:       tex(jkpbxsl7c.tfm)
Provides:       tex(jkpbxsl7c.vf)
Provides:       tex(jkpbxsl7t.tfm)
Provides:       tex(jkpbxsl7t.vf)
Provides:       tex(jkpbxsl8r.tfm)
Provides:       tex(jkpbxsl8t.tfm)
Provides:       tex(jkpbxsl8t.vf)
Provides:       tex(jkpbxslc.tfm)
Provides:       tex(jkpbxsle.tfm)
Provides:       tex(jkpex.tfm)
Provides:       tex(jkpexa.tfm)
Provides:       tex(jkpfbit7t.tfm)
Provides:       tex(jkpfbit7t.vf)
Provides:       tex(jkpfbit8t.tfm)
Provides:       tex(jkpfbit8t.vf)
Provides:       tex(jkpfbn7t.tfm)
Provides:       tex(jkpfbn7t.vf)
Provides:       tex(jkpfbn8t.tfm)
Provides:       tex(jkpfbn8t.vf)
Provides:       tex(jkpfbsl7t.tfm)
Provides:       tex(jkpfbsl7t.vf)
Provides:       tex(jkpfbsl8t.tfm)
Provides:       tex(jkpfbsl8t.vf)
Provides:       tex(jkpfbxit7t.tfm)
Provides:       tex(jkpfbxit7t.vf)
Provides:       tex(jkpfbxit8t.tfm)
Provides:       tex(jkpfbxit8t.vf)
Provides:       tex(jkpfbxn7t.tfm)
Provides:       tex(jkpfbxn7t.vf)
Provides:       tex(jkpfbxn8t.tfm)
Provides:       tex(jkpfbxn8t.vf)
Provides:       tex(jkpfbxsl7t.tfm)
Provides:       tex(jkpfbxsl7t.vf)
Provides:       tex(jkpfbxsl8t.tfm)
Provides:       tex(jkpfbxsl8t.vf)
Provides:       tex(jkpfmit7t.tfm)
Provides:       tex(jkpfmit7t.vf)
Provides:       tex(jkpfmit8t.tfm)
Provides:       tex(jkpfmit8t.vf)
Provides:       tex(jkpfmn7t.tfm)
Provides:       tex(jkpfmn7t.vf)
Provides:       tex(jkpfmn8t.tfm)
Provides:       tex(jkpfmn8t.vf)
Provides:       tex(jkpfmsl7t.tfm)
Provides:       tex(jkpfmsl7t.vf)
Provides:       tex(jkpfmsl8t.tfm)
Provides:       tex(jkpfmsl8t.vf)
Provides:       tex(jkpfosnbit7t.tfm)
Provides:       tex(jkpfosnbit7t.vf)
Provides:       tex(jkpfosnbit8t.tfm)
Provides:       tex(jkpfosnbit8t.vf)
Provides:       tex(jkpfosnbn7t.tfm)
Provides:       tex(jkpfosnbn7t.vf)
Provides:       tex(jkpfosnbn8t.tfm)
Provides:       tex(jkpfosnbn8t.vf)
Provides:       tex(jkpfosnbsl7t.tfm)
Provides:       tex(jkpfosnbsl7t.vf)
Provides:       tex(jkpfosnbsl8t.tfm)
Provides:       tex(jkpfosnbsl8t.vf)
Provides:       tex(jkpfosnbxit7t.tfm)
Provides:       tex(jkpfosnbxit7t.vf)
Provides:       tex(jkpfosnbxit8t.tfm)
Provides:       tex(jkpfosnbxit8t.vf)
Provides:       tex(jkpfosnbxn7t.tfm)
Provides:       tex(jkpfosnbxn7t.vf)
Provides:       tex(jkpfosnbxn8t.tfm)
Provides:       tex(jkpfosnbxn8t.vf)
Provides:       tex(jkpfosnbxsl7t.tfm)
Provides:       tex(jkpfosnbxsl7t.vf)
Provides:       tex(jkpfosnbxsl8t.tfm)
Provides:       tex(jkpfosnbxsl8t.vf)
Provides:       tex(jkpfosnmit7t.tfm)
Provides:       tex(jkpfosnmit7t.vf)
Provides:       tex(jkpfosnmit8t.tfm)
Provides:       tex(jkpfosnmit8t.vf)
Provides:       tex(jkpfosnmn7t.tfm)
Provides:       tex(jkpfosnmn7t.vf)
Provides:       tex(jkpfosnmn8t.tfm)
Provides:       tex(jkpfosnmn8t.vf)
Provides:       tex(jkpfosnmsl7t.tfm)
Provides:       tex(jkpfosnmsl7t.vf)
Provides:       tex(jkpfosnmsl8t.tfm)
Provides:       tex(jkpfosnmsl8t.vf)
Provides:       tex(jkpfssosnbn7t.tfm)
Provides:       tex(jkpfssosnbn7t.vf)
Provides:       tex(jkpfssosnbn8t.tfm)
Provides:       tex(jkpfssosnbn8t.vf)
Provides:       tex(jkpfssosnbsl7t.tfm)
Provides:       tex(jkpfssosnbsl7t.vf)
Provides:       tex(jkpfssosnbsl8t.tfm)
Provides:       tex(jkpfssosnbsl8t.vf)
Provides:       tex(jkpfssosnbxn7t.tfm)
Provides:       tex(jkpfssosnbxn7t.vf)
Provides:       tex(jkpfssosnbxn8t.tfm)
Provides:       tex(jkpfssosnbxn8t.vf)
Provides:       tex(jkpfssosnbxsl7t.tfm)
Provides:       tex(jkpfssosnbxsl7t.vf)
Provides:       tex(jkpfssosnbxsl8t.tfm)
Provides:       tex(jkpfssosnbxsl8t.vf)
Provides:       tex(jkpfssosnmn7t.tfm)
Provides:       tex(jkpfssosnmn7t.vf)
Provides:       tex(jkpfssosnmn8t.tfm)
Provides:       tex(jkpfssosnmn8t.vf)
Provides:       tex(jkpfssosnmsl7t.tfm)
Provides:       tex(jkpfssosnmsl7t.vf)
Provides:       tex(jkpfssosnmsl8t.tfm)
Provides:       tex(jkpfssosnmsl8t.vf)
Provides:       tex(jkpkbsc.tfm)
Provides:       tex(jkpkbsc7t.tfm)
Provides:       tex(jkpkbsc7t.vf)
Provides:       tex(jkpkbsc8t.tfm)
Provides:       tex(jkpkbsc8t.vf)
Provides:       tex(jkpkbscsl.tfm)
Provides:       tex(jkpkbscsl7t.tfm)
Provides:       tex(jkpkbscsl7t.vf)
Provides:       tex(jkpkbscsl8t.tfm)
Provides:       tex(jkpkbscsl8t.vf)
Provides:       tex(jkpkbxsc.tfm)
Provides:       tex(jkpkbxsc7t.tfm)
Provides:       tex(jkpkbxsc7t.vf)
Provides:       tex(jkpkbxsc8t.tfm)
Provides:       tex(jkpkbxsc8t.vf)
Provides:       tex(jkpkbxscsl.tfm)
Provides:       tex(jkpkbxscsl7t.tfm)
Provides:       tex(jkpkbxscsl7t.vf)
Provides:       tex(jkpkbxscsl8t.tfm)
Provides:       tex(jkpkbxscsl8t.vf)
Provides:       tex(jkpkmsc.tfm)
Provides:       tex(jkpkmsc7t.tfm)
Provides:       tex(jkpkmsc7t.vf)
Provides:       tex(jkpkmsc8t.tfm)
Provides:       tex(jkpkmsc8t.vf)
Provides:       tex(jkpkmscsl.tfm)
Provides:       tex(jkpkmscsl7t.tfm)
Provides:       tex(jkpkmscsl7t.vf)
Provides:       tex(jkpkmscsl8t.tfm)
Provides:       tex(jkpkmscsl8t.vf)
Provides:       tex(jkpkosbsc7t.tfm)
Provides:       tex(jkpkosbsc7t.vf)
Provides:       tex(jkpkosbsc8t.tfm)
Provides:       tex(jkpkosbsc8t.vf)
Provides:       tex(jkpkosbscsl7t.tfm)
Provides:       tex(jkpkosbscsl7t.vf)
Provides:       tex(jkpkosbscsl8t.tfm)
Provides:       tex(jkpkosbscsl8t.vf)
Provides:       tex(jkpkosbxsc7t.tfm)
Provides:       tex(jkpkosbxsc7t.vf)
Provides:       tex(jkpkosbxsc8t.tfm)
Provides:       tex(jkpkosbxsc8t.vf)
Provides:       tex(jkpkosbxscsl7t.tfm)
Provides:       tex(jkpkosbxscsl7t.vf)
Provides:       tex(jkpkosbxscsl8t.tfm)
Provides:       tex(jkpkosbxscsl8t.vf)
Provides:       tex(jkpkosmsc7t.tfm)
Provides:       tex(jkpkosmsc7t.vf)
Provides:       tex(jkpkosmsc8t.tfm)
Provides:       tex(jkpkosmsc8t.vf)
Provides:       tex(jkpkosmscsl7t.tfm)
Provides:       tex(jkpkosmscsl7t.vf)
Provides:       tex(jkpkosmscsl8t.tfm)
Provides:       tex(jkpkosmscsl8t.vf)
Provides:       tex(jkpkosnbsc7t.tfm)
Provides:       tex(jkpkosnbsc7t.vf)
Provides:       tex(jkpkosnbsc8t.tfm)
Provides:       tex(jkpkosnbsc8t.vf)
Provides:       tex(jkpkosnbscsl7t.tfm)
Provides:       tex(jkpkosnbscsl7t.vf)
Provides:       tex(jkpkosnbscsl8t.tfm)
Provides:       tex(jkpkosnbscsl8t.vf)
Provides:       tex(jkpkosnbxsc7t.tfm)
Provides:       tex(jkpkosnbxsc7t.vf)
Provides:       tex(jkpkosnbxsc8t.tfm)
Provides:       tex(jkpkosnbxsc8t.vf)
Provides:       tex(jkpkosnbxscsl7t.tfm)
Provides:       tex(jkpkosnbxscsl7t.vf)
Provides:       tex(jkpkosnbxscsl8t.tfm)
Provides:       tex(jkpkosnbxscsl8t.vf)
Provides:       tex(jkpkosnmsc7t.tfm)
Provides:       tex(jkpkosnmsc7t.vf)
Provides:       tex(jkpkosnmsc8t.tfm)
Provides:       tex(jkpkosnmsc8t.vf)
Provides:       tex(jkpkosnmscsl7t.tfm)
Provides:       tex(jkpkosnmscsl7t.vf)
Provides:       tex(jkpkosnmscsl8t.tfm)
Provides:       tex(jkpkosnmscsl8t.vf)
Provides:       tex(jkplbex.tfm)
Provides:       tex(jkplbexa.tfm)
Provides:       tex(jkplbit7c.tfm)
Provides:       tex(jkplbit7c.vf)
Provides:       tex(jkplbit7t.tfm)
Provides:       tex(jkplbit7t.vf)
Provides:       tex(jkplbit8a.tfm)
Provides:       tex(jkplbit8r.tfm)
Provides:       tex(jkplbit8t.tfm)
Provides:       tex(jkplbit8t.vf)
Provides:       tex(jkplbitc.tfm)
Provides:       tex(jkplbite.tfm)
Provides:       tex(jkplbmi.tfm)
Provides:       tex(jkplbmia.tfm)
Provides:       tex(jkplbmiaw.tfm)
Provides:       tex(jkplbmiaw.vf)
Provides:       tex(jkplbmif.tfm)
Provides:       tex(jkplbmif.vf)
Provides:       tex(jkplbmifw.tfm)
Provides:       tex(jkplbmifw.vf)
Provides:       tex(jkplbmiw.tfm)
Provides:       tex(jkplbmiw.vf)
Provides:       tex(jkplbn7c.tfm)
Provides:       tex(jkplbn7c.vf)
Provides:       tex(jkplbn7t.tfm)
Provides:       tex(jkplbn7t.vf)
Provides:       tex(jkplbn8a.tfm)
Provides:       tex(jkplbn8r.tfm)
Provides:       tex(jkplbn8t.tfm)
Provides:       tex(jkplbn8t.vf)
Provides:       tex(jkplbnc.tfm)
Provides:       tex(jkplbne.tfm)
Provides:       tex(jkplbsc7c.tfm)
Provides:       tex(jkplbsc7c.vf)
Provides:       tex(jkplbsc7t.tfm)
Provides:       tex(jkplbsc7t.vf)
Provides:       tex(jkplbsc8a.tfm)
Provides:       tex(jkplbsc8r.tfm)
Provides:       tex(jkplbsc8t.tfm)
Provides:       tex(jkplbsc8t.vf)
Provides:       tex(jkplbsce.tfm)
Provides:       tex(jkplbscsl7c.tfm)
Provides:       tex(jkplbscsl7c.vf)
Provides:       tex(jkplbscsl7t.tfm)
Provides:       tex(jkplbscsl7t.vf)
Provides:       tex(jkplbscsl8r.tfm)
Provides:       tex(jkplbscsl8t.tfm)
Provides:       tex(jkplbscsl8t.vf)
Provides:       tex(jkplbscsle.tfm)
Provides:       tex(jkplbsl7c.tfm)
Provides:       tex(jkplbsl7c.vf)
Provides:       tex(jkplbsl7t.tfm)
Provides:       tex(jkplbsl7t.vf)
Provides:       tex(jkplbsl8r.tfm)
Provides:       tex(jkplbsl8t.tfm)
Provides:       tex(jkplbsl8t.vf)
Provides:       tex(jkplbslc.tfm)
Provides:       tex(jkplbsle.tfm)
Provides:       tex(jkplbsy.tfm)
Provides:       tex(jkplbsyb.tfm)
Provides:       tex(jkplbsybw.tfm)
Provides:       tex(jkplbsybw.vf)
Provides:       tex(jkplbsyc.tfm)
Provides:       tex(jkplbsyd.tfm)
Provides:       tex(jkplbsydw.tfm)
Provides:       tex(jkplbsydw.vf)
Provides:       tex(jkplbsyw.tfm)
Provides:       tex(jkplbsyw.vf)
Provides:       tex(jkplbxit7c.tfm)
Provides:       tex(jkplbxit7c.vf)
Provides:       tex(jkplbxit7t.tfm)
Provides:       tex(jkplbxit7t.vf)
Provides:       tex(jkplbxit8r.tfm)
Provides:       tex(jkplbxit8t.tfm)
Provides:       tex(jkplbxit8t.vf)
Provides:       tex(jkplbxitc.tfm)
Provides:       tex(jkplbxite.tfm)
Provides:       tex(jkplbxn7c.tfm)
Provides:       tex(jkplbxn7c.vf)
Provides:       tex(jkplbxn7t.tfm)
Provides:       tex(jkplbxn7t.vf)
Provides:       tex(jkplbxn8r.tfm)
Provides:       tex(jkplbxn8t.tfm)
Provides:       tex(jkplbxn8t.vf)
Provides:       tex(jkplbxnc.tfm)
Provides:       tex(jkplbxne.tfm)
Provides:       tex(jkplbxsc7c.tfm)
Provides:       tex(jkplbxsc7c.vf)
Provides:       tex(jkplbxsc7t.tfm)
Provides:       tex(jkplbxsc7t.vf)
Provides:       tex(jkplbxsc8r.tfm)
Provides:       tex(jkplbxsc8t.tfm)
Provides:       tex(jkplbxsc8t.vf)
Provides:       tex(jkplbxsce.tfm)
Provides:       tex(jkplbxscsl7c.tfm)
Provides:       tex(jkplbxscsl7c.vf)
Provides:       tex(jkplbxscsl7t.tfm)
Provides:       tex(jkplbxscsl7t.vf)
Provides:       tex(jkplbxscsl8r.tfm)
Provides:       tex(jkplbxscsl8t.tfm)
Provides:       tex(jkplbxscsl8t.vf)
Provides:       tex(jkplbxscsle.tfm)
Provides:       tex(jkplbxsl7c.tfm)
Provides:       tex(jkplbxsl7c.vf)
Provides:       tex(jkplbxsl7t.tfm)
Provides:       tex(jkplbxsl7t.vf)
Provides:       tex(jkplbxsl8r.tfm)
Provides:       tex(jkplbxsl8t.tfm)
Provides:       tex(jkplbxsl8t.vf)
Provides:       tex(jkplbxslc.tfm)
Provides:       tex(jkplbxsle.tfm)
Provides:       tex(jkplex.tfm)
Provides:       tex(jkplexa.tfm)
Provides:       tex(jkplfbit7t.tfm)
Provides:       tex(jkplfbit7t.vf)
Provides:       tex(jkplfbit8t.tfm)
Provides:       tex(jkplfbit8t.vf)
Provides:       tex(jkplfbn7t.tfm)
Provides:       tex(jkplfbn7t.vf)
Provides:       tex(jkplfbn8t.tfm)
Provides:       tex(jkplfbn8t.vf)
Provides:       tex(jkplfbsl7t.tfm)
Provides:       tex(jkplfbsl7t.vf)
Provides:       tex(jkplfbsl8t.tfm)
Provides:       tex(jkplfbsl8t.vf)
Provides:       tex(jkplfbxit7t.tfm)
Provides:       tex(jkplfbxit7t.vf)
Provides:       tex(jkplfbxit8t.tfm)
Provides:       tex(jkplfbxit8t.vf)
Provides:       tex(jkplfbxn7t.tfm)
Provides:       tex(jkplfbxn7t.vf)
Provides:       tex(jkplfbxn8t.tfm)
Provides:       tex(jkplfbxn8t.vf)
Provides:       tex(jkplfbxsl7t.tfm)
Provides:       tex(jkplfbxsl7t.vf)
Provides:       tex(jkplfbxsl8t.tfm)
Provides:       tex(jkplfbxsl8t.vf)
Provides:       tex(jkplfmit7t.tfm)
Provides:       tex(jkplfmit7t.vf)
Provides:       tex(jkplfmit8t.tfm)
Provides:       tex(jkplfmit8t.vf)
Provides:       tex(jkplfmn7t.tfm)
Provides:       tex(jkplfmn7t.vf)
Provides:       tex(jkplfmn8t.tfm)
Provides:       tex(jkplfmn8t.vf)
Provides:       tex(jkplfmsl7t.tfm)
Provides:       tex(jkplfmsl7t.vf)
Provides:       tex(jkplfmsl8t.tfm)
Provides:       tex(jkplfmsl8t.vf)
Provides:       tex(jkplfosnbit7t.tfm)
Provides:       tex(jkplfosnbit7t.vf)
Provides:       tex(jkplfosnbit8t.tfm)
Provides:       tex(jkplfosnbit8t.vf)
Provides:       tex(jkplfosnbn7t.tfm)
Provides:       tex(jkplfosnbn7t.vf)
Provides:       tex(jkplfosnbn8t.tfm)
Provides:       tex(jkplfosnbn8t.vf)
Provides:       tex(jkplfosnbsl7t.tfm)
Provides:       tex(jkplfosnbsl7t.vf)
Provides:       tex(jkplfosnbsl8t.tfm)
Provides:       tex(jkplfosnbsl8t.vf)
Provides:       tex(jkplfosnbxit7t.tfm)
Provides:       tex(jkplfosnbxit7t.vf)
Provides:       tex(jkplfosnbxit8t.tfm)
Provides:       tex(jkplfosnbxit8t.vf)
Provides:       tex(jkplfosnbxn7t.tfm)
Provides:       tex(jkplfosnbxn7t.vf)
Provides:       tex(jkplfosnbxn8t.tfm)
Provides:       tex(jkplfosnbxn8t.vf)
Provides:       tex(jkplfosnbxsl7t.tfm)
Provides:       tex(jkplfosnbxsl7t.vf)
Provides:       tex(jkplfosnbxsl8t.tfm)
Provides:       tex(jkplfosnbxsl8t.vf)
Provides:       tex(jkplfosnmit7t.tfm)
Provides:       tex(jkplfosnmit7t.vf)
Provides:       tex(jkplfosnmit8t.tfm)
Provides:       tex(jkplfosnmit8t.vf)
Provides:       tex(jkplfosnmn7t.tfm)
Provides:       tex(jkplfosnmn7t.vf)
Provides:       tex(jkplfosnmn8t.tfm)
Provides:       tex(jkplfosnmn8t.vf)
Provides:       tex(jkplfosnmsl7t.tfm)
Provides:       tex(jkplfosnmsl7t.vf)
Provides:       tex(jkplfosnmsl8t.tfm)
Provides:       tex(jkplfosnmsl8t.vf)
Provides:       tex(jkplkbsc.tfm)
Provides:       tex(jkplkbsc7t.tfm)
Provides:       tex(jkplkbsc7t.vf)
Provides:       tex(jkplkbsc8t.tfm)
Provides:       tex(jkplkbsc8t.vf)
Provides:       tex(jkplkbscsl.tfm)
Provides:       tex(jkplkbscsl7t.tfm)
Provides:       tex(jkplkbscsl7t.vf)
Provides:       tex(jkplkbscsl8t.tfm)
Provides:       tex(jkplkbscsl8t.vf)
Provides:       tex(jkplkbxsc.tfm)
Provides:       tex(jkplkbxsc7t.tfm)
Provides:       tex(jkplkbxsc7t.vf)
Provides:       tex(jkplkbxsc8t.tfm)
Provides:       tex(jkplkbxsc8t.vf)
Provides:       tex(jkplkbxscsl.tfm)
Provides:       tex(jkplkbxscsl7t.tfm)
Provides:       tex(jkplkbxscsl7t.vf)
Provides:       tex(jkplkbxscsl8t.tfm)
Provides:       tex(jkplkbxscsl8t.vf)
Provides:       tex(jkplkmsc.tfm)
Provides:       tex(jkplkmsc7t.tfm)
Provides:       tex(jkplkmsc7t.vf)
Provides:       tex(jkplkmsc8t.tfm)
Provides:       tex(jkplkmsc8t.vf)
Provides:       tex(jkplkmscsl.tfm)
Provides:       tex(jkplkmscsl7t.tfm)
Provides:       tex(jkplkmscsl7t.vf)
Provides:       tex(jkplkmscsl8t.tfm)
Provides:       tex(jkplkmscsl8t.vf)
Provides:       tex(jkplkosbsc7t.tfm)
Provides:       tex(jkplkosbsc7t.vf)
Provides:       tex(jkplkosbsc8t.tfm)
Provides:       tex(jkplkosbsc8t.vf)
Provides:       tex(jkplkosbscsl7t.tfm)
Provides:       tex(jkplkosbscsl7t.vf)
Provides:       tex(jkplkosbscsl8t.tfm)
Provides:       tex(jkplkosbscsl8t.vf)
Provides:       tex(jkplkosbxsc7t.tfm)
Provides:       tex(jkplkosbxsc7t.vf)
Provides:       tex(jkplkosbxsc8t.tfm)
Provides:       tex(jkplkosbxsc8t.vf)
Provides:       tex(jkplkosbxscsl7t.tfm)
Provides:       tex(jkplkosbxscsl7t.vf)
Provides:       tex(jkplkosbxscsl8t.tfm)
Provides:       tex(jkplkosbxscsl8t.vf)
Provides:       tex(jkplkosmsc7t.tfm)
Provides:       tex(jkplkosmsc7t.vf)
Provides:       tex(jkplkosmsc8t.tfm)
Provides:       tex(jkplkosmsc8t.vf)
Provides:       tex(jkplkosmscsl7t.tfm)
Provides:       tex(jkplkosmscsl7t.vf)
Provides:       tex(jkplkosmscsl8t.tfm)
Provides:       tex(jkplkosmscsl8t.vf)
Provides:       tex(jkplkosnbsc7t.tfm)
Provides:       tex(jkplkosnbsc7t.vf)
Provides:       tex(jkplkosnbsc8t.tfm)
Provides:       tex(jkplkosnbsc8t.vf)
Provides:       tex(jkplkosnbscsl7t.tfm)
Provides:       tex(jkplkosnbscsl7t.vf)
Provides:       tex(jkplkosnbscsl8t.tfm)
Provides:       tex(jkplkosnbscsl8t.vf)
Provides:       tex(jkplkosnbxsc7t.tfm)
Provides:       tex(jkplkosnbxsc7t.vf)
Provides:       tex(jkplkosnbxsc8t.tfm)
Provides:       tex(jkplkosnbxsc8t.vf)
Provides:       tex(jkplkosnbxscsl7t.tfm)
Provides:       tex(jkplkosnbxscsl7t.vf)
Provides:       tex(jkplkosnbxscsl8t.tfm)
Provides:       tex(jkplkosnbxscsl8t.vf)
Provides:       tex(jkplkosnmsc7t.tfm)
Provides:       tex(jkplkosnmsc7t.vf)
Provides:       tex(jkplkosnmsc8t.tfm)
Provides:       tex(jkplkosnmsc8t.vf)
Provides:       tex(jkplkosnmscsl7t.tfm)
Provides:       tex(jkplkosnmscsl7t.vf)
Provides:       tex(jkplkosnmscsl8t.tfm)
Provides:       tex(jkplkosnmscsl8t.vf)
Provides:       tex(jkplmi.tfm)
Provides:       tex(jkplmia.tfm)
Provides:       tex(jkplmiaw.tfm)
Provides:       tex(jkplmiaw.vf)
Provides:       tex(jkplmif.tfm)
Provides:       tex(jkplmif.vf)
Provides:       tex(jkplmifw.tfm)
Provides:       tex(jkplmifw.vf)
Provides:       tex(jkplmit7c.tfm)
Provides:       tex(jkplmit7c.vf)
Provides:       tex(jkplmit7t.tfm)
Provides:       tex(jkplmit7t.vf)
Provides:       tex(jkplmit8a.tfm)
Provides:       tex(jkplmit8r.tfm)
Provides:       tex(jkplmit8t.tfm)
Provides:       tex(jkplmit8t.vf)
Provides:       tex(jkplmitc.tfm)
Provides:       tex(jkplmite.tfm)
Provides:       tex(jkplmiw.tfm)
Provides:       tex(jkplmiw.vf)
Provides:       tex(jkplmn7c.tfm)
Provides:       tex(jkplmn7c.vf)
Provides:       tex(jkplmn7t.tfm)
Provides:       tex(jkplmn7t.vf)
Provides:       tex(jkplmn8a.tfm)
Provides:       tex(jkplmn8r.tfm)
Provides:       tex(jkplmn8t.tfm)
Provides:       tex(jkplmn8t.vf)
Provides:       tex(jkplmnc.tfm)
Provides:       tex(jkplmne.tfm)
Provides:       tex(jkplmsc7c.tfm)
Provides:       tex(jkplmsc7c.vf)
Provides:       tex(jkplmsc7t.tfm)
Provides:       tex(jkplmsc7t.vf)
Provides:       tex(jkplmsc8a.tfm)
Provides:       tex(jkplmsc8r.tfm)
Provides:       tex(jkplmsc8t.tfm)
Provides:       tex(jkplmsc8t.vf)
Provides:       tex(jkplmsce.tfm)
Provides:       tex(jkplmscsl7c.tfm)
Provides:       tex(jkplmscsl7c.vf)
Provides:       tex(jkplmscsl7t.tfm)
Provides:       tex(jkplmscsl7t.vf)
Provides:       tex(jkplmscsl8r.tfm)
Provides:       tex(jkplmscsl8t.tfm)
Provides:       tex(jkplmscsl8t.vf)
Provides:       tex(jkplmscsle.tfm)
Provides:       tex(jkplmsl7c.tfm)
Provides:       tex(jkplmsl7c.vf)
Provides:       tex(jkplmsl7t.tfm)
Provides:       tex(jkplmsl7t.vf)
Provides:       tex(jkplmsl8r.tfm)
Provides:       tex(jkplmsl8t.tfm)
Provides:       tex(jkplmsl8t.vf)
Provides:       tex(jkplmslc.tfm)
Provides:       tex(jkplmsle.tfm)
Provides:       tex(jkplosbit7c.tfm)
Provides:       tex(jkplosbit7c.vf)
Provides:       tex(jkplosbit7t.tfm)
Provides:       tex(jkplosbit7t.vf)
Provides:       tex(jkplosbit8t.tfm)
Provides:       tex(jkplosbit8t.vf)
Provides:       tex(jkplosbn7c.tfm)
Provides:       tex(jkplosbn7c.vf)
Provides:       tex(jkplosbn7t.tfm)
Provides:       tex(jkplosbn7t.vf)
Provides:       tex(jkplosbn8t.tfm)
Provides:       tex(jkplosbn8t.vf)
Provides:       tex(jkplosbsc7c.tfm)
Provides:       tex(jkplosbsc7c.vf)
Provides:       tex(jkplosbsc7t.tfm)
Provides:       tex(jkplosbsc7t.vf)
Provides:       tex(jkplosbsc8t.tfm)
Provides:       tex(jkplosbsc8t.vf)
Provides:       tex(jkplosbscsl7t.tfm)
Provides:       tex(jkplosbscsl7t.vf)
Provides:       tex(jkplosbscsl8t.tfm)
Provides:       tex(jkplosbscsl8t.vf)
Provides:       tex(jkplosbsl7c.tfm)
Provides:       tex(jkplosbsl7c.vf)
Provides:       tex(jkplosbsl7t.tfm)
Provides:       tex(jkplosbsl7t.vf)
Provides:       tex(jkplosbsl8t.tfm)
Provides:       tex(jkplosbsl8t.vf)
Provides:       tex(jkplosbxit7c.tfm)
Provides:       tex(jkplosbxit7c.vf)
Provides:       tex(jkplosbxit7t.tfm)
Provides:       tex(jkplosbxit7t.vf)
Provides:       tex(jkplosbxit8t.tfm)
Provides:       tex(jkplosbxit8t.vf)
Provides:       tex(jkplosbxn7c.tfm)
Provides:       tex(jkplosbxn7c.vf)
Provides:       tex(jkplosbxn7t.tfm)
Provides:       tex(jkplosbxn7t.vf)
Provides:       tex(jkplosbxn8t.tfm)
Provides:       tex(jkplosbxn8t.vf)
Provides:       tex(jkplosbxsc7c.tfm)
Provides:       tex(jkplosbxsc7c.vf)
Provides:       tex(jkplosbxsc7t.tfm)
Provides:       tex(jkplosbxsc7t.vf)
Provides:       tex(jkplosbxsc8t.tfm)
Provides:       tex(jkplosbxsc8t.vf)
Provides:       tex(jkplosbxscsl7t.tfm)
Provides:       tex(jkplosbxscsl7t.vf)
Provides:       tex(jkplosbxscsl8t.tfm)
Provides:       tex(jkplosbxscsl8t.vf)
Provides:       tex(jkplosbxsl7c.tfm)
Provides:       tex(jkplosbxsl7c.vf)
Provides:       tex(jkplosbxsl7t.tfm)
Provides:       tex(jkplosbxsl7t.vf)
Provides:       tex(jkplosbxsl8t.tfm)
Provides:       tex(jkplosbxsl8t.vf)
Provides:       tex(jkplosmit7c.tfm)
Provides:       tex(jkplosmit7c.vf)
Provides:       tex(jkplosmit7t.tfm)
Provides:       tex(jkplosmit7t.vf)
Provides:       tex(jkplosmit8t.tfm)
Provides:       tex(jkplosmit8t.vf)
Provides:       tex(jkplosmn7c.tfm)
Provides:       tex(jkplosmn7c.vf)
Provides:       tex(jkplosmn7t.tfm)
Provides:       tex(jkplosmn7t.vf)
Provides:       tex(jkplosmn8t.tfm)
Provides:       tex(jkplosmn8t.vf)
Provides:       tex(jkplosmsc7c.tfm)
Provides:       tex(jkplosmsc7c.vf)
Provides:       tex(jkplosmsc7t.tfm)
Provides:       tex(jkplosmsc7t.vf)
Provides:       tex(jkplosmsc8t.tfm)
Provides:       tex(jkplosmsc8t.vf)
Provides:       tex(jkplosmscsl7t.tfm)
Provides:       tex(jkplosmscsl7t.vf)
Provides:       tex(jkplosmscsl8t.tfm)
Provides:       tex(jkplosmscsl8t.vf)
Provides:       tex(jkplosmsl7c.tfm)
Provides:       tex(jkplosmsl7c.vf)
Provides:       tex(jkplosmsl7t.tfm)
Provides:       tex(jkplosmsl7t.vf)
Provides:       tex(jkplosmsl8t.tfm)
Provides:       tex(jkplosmsl8t.vf)
Provides:       tex(jkplosnbit7t.tfm)
Provides:       tex(jkplosnbit7t.vf)
Provides:       tex(jkplosnbit8t.tfm)
Provides:       tex(jkplosnbit8t.vf)
Provides:       tex(jkplosnbn7t.tfm)
Provides:       tex(jkplosnbn7t.vf)
Provides:       tex(jkplosnbn8t.tfm)
Provides:       tex(jkplosnbn8t.vf)
Provides:       tex(jkplosnbsc7t.tfm)
Provides:       tex(jkplosnbsc7t.vf)
Provides:       tex(jkplosnbsc8t.tfm)
Provides:       tex(jkplosnbsc8t.vf)
Provides:       tex(jkplosnbscsl7t.tfm)
Provides:       tex(jkplosnbscsl7t.vf)
Provides:       tex(jkplosnbscsl8t.tfm)
Provides:       tex(jkplosnbscsl8t.vf)
Provides:       tex(jkplosnbsl7t.tfm)
Provides:       tex(jkplosnbsl7t.vf)
Provides:       tex(jkplosnbsl8t.tfm)
Provides:       tex(jkplosnbsl8t.vf)
Provides:       tex(jkplosnbxit7t.tfm)
Provides:       tex(jkplosnbxit7t.vf)
Provides:       tex(jkplosnbxit8t.tfm)
Provides:       tex(jkplosnbxit8t.vf)
Provides:       tex(jkplosnbxn7t.tfm)
Provides:       tex(jkplosnbxn7t.vf)
Provides:       tex(jkplosnbxn8t.tfm)
Provides:       tex(jkplosnbxn8t.vf)
Provides:       tex(jkplosnbxsc7t.tfm)
Provides:       tex(jkplosnbxsc7t.vf)
Provides:       tex(jkplosnbxsc8t.tfm)
Provides:       tex(jkplosnbxsc8t.vf)
Provides:       tex(jkplosnbxscsl7t.tfm)
Provides:       tex(jkplosnbxscsl7t.vf)
Provides:       tex(jkplosnbxscsl8t.tfm)
Provides:       tex(jkplosnbxscsl8t.vf)
Provides:       tex(jkplosnbxsl7t.tfm)
Provides:       tex(jkplosnbxsl7t.vf)
Provides:       tex(jkplosnbxsl8t.tfm)
Provides:       tex(jkplosnbxsl8t.vf)
Provides:       tex(jkplosnmit7t.tfm)
Provides:       tex(jkplosnmit7t.vf)
Provides:       tex(jkplosnmit8t.tfm)
Provides:       tex(jkplosnmit8t.vf)
Provides:       tex(jkplosnmn7t.tfm)
Provides:       tex(jkplosnmn7t.vf)
Provides:       tex(jkplosnmn8t.tfm)
Provides:       tex(jkplosnmn8t.vf)
Provides:       tex(jkplosnmsc7t.tfm)
Provides:       tex(jkplosnmsc7t.vf)
Provides:       tex(jkplosnmsc8t.tfm)
Provides:       tex(jkplosnmsc8t.vf)
Provides:       tex(jkplosnmscsl7t.tfm)
Provides:       tex(jkplosnmscsl7t.vf)
Provides:       tex(jkplosnmscsl8t.tfm)
Provides:       tex(jkplosnmscsl8t.vf)
Provides:       tex(jkplosnmsl7t.tfm)
Provides:       tex(jkplosnmsl7t.vf)
Provides:       tex(jkplosnmsl8t.tfm)
Provides:       tex(jkplosnmsl8t.vf)
Provides:       tex(jkplsy.tfm)
Provides:       tex(jkplsyb.tfm)
Provides:       tex(jkplsybw.tfm)
Provides:       tex(jkplsybw.vf)
Provides:       tex(jkplsyc.tfm)
Provides:       tex(jkplsyd.tfm)
Provides:       tex(jkplsydw.tfm)
Provides:       tex(jkplsydw.vf)
Provides:       tex(jkplsyw.tfm)
Provides:       tex(jkplsyw.vf)
Provides:       tex(jkplvosbit7t.tfm)
Provides:       tex(jkplvosbit7t.vf)
Provides:       tex(jkplvosbit8t.tfm)
Provides:       tex(jkplvosbit8t.vf)
Provides:       tex(jkplvosbmi.tfm)
Provides:       tex(jkplvosbmi.vf)
Provides:       tex(jkplvosbmif.tfm)
Provides:       tex(jkplvosbmif.vf)
Provides:       tex(jkplvosbmifw.tfm)
Provides:       tex(jkplvosbmifw.vf)
Provides:       tex(jkplvosbmiw.tfm)
Provides:       tex(jkplvosbmiw.vf)
Provides:       tex(jkplvosbn7t.tfm)
Provides:       tex(jkplvosbn7t.vf)
Provides:       tex(jkplvosbn8t.tfm)
Provides:       tex(jkplvosbn8t.vf)
Provides:       tex(jkplvosbsl7t.tfm)
Provides:       tex(jkplvosbsl7t.vf)
Provides:       tex(jkplvosbsl8t.tfm)
Provides:       tex(jkplvosbsl8t.vf)
Provides:       tex(jkplvosbxit7t.tfm)
Provides:       tex(jkplvosbxit7t.vf)
Provides:       tex(jkplvosbxit8t.tfm)
Provides:       tex(jkplvosbxit8t.vf)
Provides:       tex(jkplvosbxn7t.tfm)
Provides:       tex(jkplvosbxn7t.vf)
Provides:       tex(jkplvosbxn8t.tfm)
Provides:       tex(jkplvosbxn8t.vf)
Provides:       tex(jkplvosbxsl7t.tfm)
Provides:       tex(jkplvosbxsl7t.vf)
Provides:       tex(jkplvosbxsl8t.tfm)
Provides:       tex(jkplvosbxsl8t.vf)
Provides:       tex(jkplvosmi.tfm)
Provides:       tex(jkplvosmi.vf)
Provides:       tex(jkplvosmif.tfm)
Provides:       tex(jkplvosmif.vf)
Provides:       tex(jkplvosmifw.tfm)
Provides:       tex(jkplvosmifw.vf)
Provides:       tex(jkplvosmit7t.tfm)
Provides:       tex(jkplvosmit7t.vf)
Provides:       tex(jkplvosmit8t.tfm)
Provides:       tex(jkplvosmit8t.vf)
Provides:       tex(jkplvosmiw.tfm)
Provides:       tex(jkplvosmiw.vf)
Provides:       tex(jkplvosmn7t.tfm)
Provides:       tex(jkplvosmn7t.vf)
Provides:       tex(jkplvosmn8t.tfm)
Provides:       tex(jkplvosmn8t.vf)
Provides:       tex(jkplvosmsl7t.tfm)
Provides:       tex(jkplvosmsl7t.vf)
Provides:       tex(jkplvosmsl8t.tfm)
Provides:       tex(jkplvosmsl8t.vf)
Provides:       tex(jkpmi.tfm)
Provides:       tex(jkpmia.tfm)
Provides:       tex(jkpmiaw.tfm)
Provides:       tex(jkpmiaw.vf)
Provides:       tex(jkpmif.tfm)
Provides:       tex(jkpmif.vf)
Provides:       tex(jkpmifw.tfm)
Provides:       tex(jkpmifw.vf)
Provides:       tex(jkpmit7c.tfm)
Provides:       tex(jkpmit7c.vf)
Provides:       tex(jkpmit7t.tfm)
Provides:       tex(jkpmit7t.vf)
Provides:       tex(jkpmit8a.tfm)
Provides:       tex(jkpmit8r.tfm)
Provides:       tex(jkpmit8t.tfm)
Provides:       tex(jkpmit8t.vf)
Provides:       tex(jkpmitc.tfm)
Provides:       tex(jkpmite.tfm)
Provides:       tex(jkpmiw.tfm)
Provides:       tex(jkpmiw.vf)
Provides:       tex(jkpmn7c.tfm)
Provides:       tex(jkpmn7c.vf)
Provides:       tex(jkpmn7t.tfm)
Provides:       tex(jkpmn7t.vf)
Provides:       tex(jkpmn8a.tfm)
Provides:       tex(jkpmn8r.tfm)
Provides:       tex(jkpmn8t.tfm)
Provides:       tex(jkpmn8t.vf)
Provides:       tex(jkpmnc.tfm)
Provides:       tex(jkpmne.tfm)
Provides:       tex(jkpmsc7c.tfm)
Provides:       tex(jkpmsc7c.vf)
Provides:       tex(jkpmsc7t.tfm)
Provides:       tex(jkpmsc7t.vf)
Provides:       tex(jkpmsc8a.tfm)
Provides:       tex(jkpmsc8r.tfm)
Provides:       tex(jkpmsc8t.tfm)
Provides:       tex(jkpmsc8t.vf)
Provides:       tex(jkpmsce.tfm)
Provides:       tex(jkpmscsl7c.tfm)
Provides:       tex(jkpmscsl7c.vf)
Provides:       tex(jkpmscsl7t.tfm)
Provides:       tex(jkpmscsl7t.vf)
Provides:       tex(jkpmscsl8r.tfm)
Provides:       tex(jkpmscsl8t.tfm)
Provides:       tex(jkpmscsl8t.vf)
Provides:       tex(jkpmscsle.tfm)
Provides:       tex(jkpmsl7c.tfm)
Provides:       tex(jkpmsl7c.vf)
Provides:       tex(jkpmsl7t.tfm)
Provides:       tex(jkpmsl7t.vf)
Provides:       tex(jkpmsl8r.tfm)
Provides:       tex(jkpmsl8t.tfm)
Provides:       tex(jkpmsl8t.vf)
Provides:       tex(jkpmslc.tfm)
Provides:       tex(jkpmsle.tfm)
Provides:       tex(jkposbit7c.tfm)
Provides:       tex(jkposbit7c.vf)
Provides:       tex(jkposbit7t.tfm)
Provides:       tex(jkposbit7t.vf)
Provides:       tex(jkposbit8t.tfm)
Provides:       tex(jkposbit8t.vf)
Provides:       tex(jkposbn7c.tfm)
Provides:       tex(jkposbn7c.vf)
Provides:       tex(jkposbn7t.tfm)
Provides:       tex(jkposbn7t.vf)
Provides:       tex(jkposbn8t.tfm)
Provides:       tex(jkposbn8t.vf)
Provides:       tex(jkposbsc7c.tfm)
Provides:       tex(jkposbsc7c.vf)
Provides:       tex(jkposbsc7t.tfm)
Provides:       tex(jkposbsc7t.vf)
Provides:       tex(jkposbsc8t.tfm)
Provides:       tex(jkposbsc8t.vf)
Provides:       tex(jkposbscsl7t.tfm)
Provides:       tex(jkposbscsl7t.vf)
Provides:       tex(jkposbscsl8t.tfm)
Provides:       tex(jkposbscsl8t.vf)
Provides:       tex(jkposbsl7c.tfm)
Provides:       tex(jkposbsl7c.vf)
Provides:       tex(jkposbsl7t.tfm)
Provides:       tex(jkposbsl7t.vf)
Provides:       tex(jkposbsl8t.tfm)
Provides:       tex(jkposbsl8t.vf)
Provides:       tex(jkposbxit7c.tfm)
Provides:       tex(jkposbxit7c.vf)
Provides:       tex(jkposbxit7t.tfm)
Provides:       tex(jkposbxit7t.vf)
Provides:       tex(jkposbxit8t.tfm)
Provides:       tex(jkposbxit8t.vf)
Provides:       tex(jkposbxn7c.tfm)
Provides:       tex(jkposbxn7c.vf)
Provides:       tex(jkposbxn7t.tfm)
Provides:       tex(jkposbxn7t.vf)
Provides:       tex(jkposbxn8t.tfm)
Provides:       tex(jkposbxn8t.vf)
Provides:       tex(jkposbxsc7c.tfm)
Provides:       tex(jkposbxsc7c.vf)
Provides:       tex(jkposbxsc7t.tfm)
Provides:       tex(jkposbxsc7t.vf)
Provides:       tex(jkposbxsc8t.tfm)
Provides:       tex(jkposbxsc8t.vf)
Provides:       tex(jkposbxscsl7t.tfm)
Provides:       tex(jkposbxscsl7t.vf)
Provides:       tex(jkposbxscsl8t.tfm)
Provides:       tex(jkposbxscsl8t.vf)
Provides:       tex(jkposbxsl7c.tfm)
Provides:       tex(jkposbxsl7c.vf)
Provides:       tex(jkposbxsl7t.tfm)
Provides:       tex(jkposbxsl7t.vf)
Provides:       tex(jkposbxsl8t.tfm)
Provides:       tex(jkposbxsl8t.vf)
Provides:       tex(jkposmit7c.tfm)
Provides:       tex(jkposmit7c.vf)
Provides:       tex(jkposmit7t.tfm)
Provides:       tex(jkposmit7t.vf)
Provides:       tex(jkposmit8t.tfm)
Provides:       tex(jkposmit8t.vf)
Provides:       tex(jkposmn7c.tfm)
Provides:       tex(jkposmn7c.vf)
Provides:       tex(jkposmn7t.tfm)
Provides:       tex(jkposmn7t.vf)
Provides:       tex(jkposmn8t.tfm)
Provides:       tex(jkposmn8t.vf)
Provides:       tex(jkposmsc7c.tfm)
Provides:       tex(jkposmsc7c.vf)
Provides:       tex(jkposmsc7t.tfm)
Provides:       tex(jkposmsc7t.vf)
Provides:       tex(jkposmsc8t.tfm)
Provides:       tex(jkposmsc8t.vf)
Provides:       tex(jkposmscsl7t.tfm)
Provides:       tex(jkposmscsl7t.vf)
Provides:       tex(jkposmscsl8t.tfm)
Provides:       tex(jkposmscsl8t.vf)
Provides:       tex(jkposmsl7c.tfm)
Provides:       tex(jkposmsl7c.vf)
Provides:       tex(jkposmsl7t.tfm)
Provides:       tex(jkposmsl7t.vf)
Provides:       tex(jkposmsl8t.tfm)
Provides:       tex(jkposmsl8t.vf)
Provides:       tex(jkposnbit7t.tfm)
Provides:       tex(jkposnbit7t.vf)
Provides:       tex(jkposnbit8t.tfm)
Provides:       tex(jkposnbit8t.vf)
Provides:       tex(jkposnbn7t.tfm)
Provides:       tex(jkposnbn7t.vf)
Provides:       tex(jkposnbn8t.tfm)
Provides:       tex(jkposnbn8t.vf)
Provides:       tex(jkposnbsc7t.tfm)
Provides:       tex(jkposnbsc7t.vf)
Provides:       tex(jkposnbsc8t.tfm)
Provides:       tex(jkposnbsc8t.vf)
Provides:       tex(jkposnbscsl7t.tfm)
Provides:       tex(jkposnbscsl7t.vf)
Provides:       tex(jkposnbscsl8t.tfm)
Provides:       tex(jkposnbscsl8t.vf)
Provides:       tex(jkposnbsl7t.tfm)
Provides:       tex(jkposnbsl7t.vf)
Provides:       tex(jkposnbsl8t.tfm)
Provides:       tex(jkposnbsl8t.vf)
Provides:       tex(jkposnbxit7t.tfm)
Provides:       tex(jkposnbxit7t.vf)
Provides:       tex(jkposnbxit8t.tfm)
Provides:       tex(jkposnbxit8t.vf)
Provides:       tex(jkposnbxn7t.tfm)
Provides:       tex(jkposnbxn7t.vf)
Provides:       tex(jkposnbxn8t.tfm)
Provides:       tex(jkposnbxn8t.vf)
Provides:       tex(jkposnbxsc7t.tfm)
Provides:       tex(jkposnbxsc7t.vf)
Provides:       tex(jkposnbxsc8t.tfm)
Provides:       tex(jkposnbxsc8t.vf)
Provides:       tex(jkposnbxscsl7t.tfm)
Provides:       tex(jkposnbxscsl7t.vf)
Provides:       tex(jkposnbxscsl8t.tfm)
Provides:       tex(jkposnbxscsl8t.vf)
Provides:       tex(jkposnbxsl7t.tfm)
Provides:       tex(jkposnbxsl7t.vf)
Provides:       tex(jkposnbxsl8t.tfm)
Provides:       tex(jkposnbxsl8t.vf)
Provides:       tex(jkposnmit7t.tfm)
Provides:       tex(jkposnmit7t.vf)
Provides:       tex(jkposnmit8t.tfm)
Provides:       tex(jkposnmit8t.vf)
Provides:       tex(jkposnmn7t.tfm)
Provides:       tex(jkposnmn7t.vf)
Provides:       tex(jkposnmn8t.tfm)
Provides:       tex(jkposnmn8t.vf)
Provides:       tex(jkposnmsc7t.tfm)
Provides:       tex(jkposnmsc7t.vf)
Provides:       tex(jkposnmsc8t.tfm)
Provides:       tex(jkposnmsc8t.vf)
Provides:       tex(jkposnmscsl7t.tfm)
Provides:       tex(jkposnmscsl7t.vf)
Provides:       tex(jkposnmscsl8t.tfm)
Provides:       tex(jkposnmscsl8t.vf)
Provides:       tex(jkposnmsl7t.tfm)
Provides:       tex(jkposnmsl7t.vf)
Provides:       tex(jkposnmsl8t.tfm)
Provides:       tex(jkposnmsl8t.vf)
Provides:       tex(jkpssbex.tfm)
Provides:       tex(jkpssbex.vf)
Provides:       tex(jkpssbmi.tfm)
Provides:       tex(jkpssbmi.vf)
Provides:       tex(jkpssbmia.tfm)
Provides:       tex(jkpssbmia.vf)
Provides:       tex(jkpssbmif.tfm)
Provides:       tex(jkpssbmif.vf)
Provides:       tex(jkpssbn7c.tfm)
Provides:       tex(jkpssbn7c.vf)
Provides:       tex(jkpssbn7t.tfm)
Provides:       tex(jkpssbn7t.vf)
Provides:       tex(jkpssbn8a.tfm)
Provides:       tex(jkpssbn8r.tfm)
Provides:       tex(jkpssbn8t.tfm)
Provides:       tex(jkpssbn8t.vf)
Provides:       tex(jkpssbnc.tfm)
Provides:       tex(jkpssbne.tfm)
Provides:       tex(jkpssbsc7c.tfm)
Provides:       tex(jkpssbsc7c.vf)
Provides:       tex(jkpssbsc7t.tfm)
Provides:       tex(jkpssbsc7t.vf)
Provides:       tex(jkpssbsc8a.tfm)
Provides:       tex(jkpssbsc8r.tfm)
Provides:       tex(jkpssbsc8t.tfm)
Provides:       tex(jkpssbsc8t.vf)
Provides:       tex(jkpssbsce.tfm)
Provides:       tex(jkpssbscsl7c.tfm)
Provides:       tex(jkpssbscsl7c.vf)
Provides:       tex(jkpssbscsl7t.tfm)
Provides:       tex(jkpssbscsl7t.vf)
Provides:       tex(jkpssbscsl8r.tfm)
Provides:       tex(jkpssbscsl8t.tfm)
Provides:       tex(jkpssbscsl8t.vf)
Provides:       tex(jkpssbscsle.tfm)
Provides:       tex(jkpssbsl7c.tfm)
Provides:       tex(jkpssbsl7c.vf)
Provides:       tex(jkpssbsl7t.tfm)
Provides:       tex(jkpssbsl7t.vf)
Provides:       tex(jkpssbsl8r.tfm)
Provides:       tex(jkpssbsl8t.tfm)
Provides:       tex(jkpssbsl8t.vf)
Provides:       tex(jkpssbslc.tfm)
Provides:       tex(jkpssbsle.tfm)
Provides:       tex(jkpssbsyb.tfm)
Provides:       tex(jkpssbsyb.vf)
Provides:       tex(jkpssbsybw.tfm)
Provides:       tex(jkpssbsybw.vf)
Provides:       tex(jkpssbxn7c.tfm)
Provides:       tex(jkpssbxn7c.vf)
Provides:       tex(jkpssbxn7t.tfm)
Provides:       tex(jkpssbxn7t.vf)
Provides:       tex(jkpssbxn8r.tfm)
Provides:       tex(jkpssbxn8t.tfm)
Provides:       tex(jkpssbxn8t.vf)
Provides:       tex(jkpssbxnc.tfm)
Provides:       tex(jkpssbxne.tfm)
Provides:       tex(jkpssbxsc7c.tfm)
Provides:       tex(jkpssbxsc7c.vf)
Provides:       tex(jkpssbxsc7t.tfm)
Provides:       tex(jkpssbxsc7t.vf)
Provides:       tex(jkpssbxsc8r.tfm)
Provides:       tex(jkpssbxsc8t.tfm)
Provides:       tex(jkpssbxsc8t.vf)
Provides:       tex(jkpssbxsce.tfm)
Provides:       tex(jkpssbxscsl7c.tfm)
Provides:       tex(jkpssbxscsl7c.vf)
Provides:       tex(jkpssbxscsl7t.tfm)
Provides:       tex(jkpssbxscsl7t.vf)
Provides:       tex(jkpssbxscsl8r.tfm)
Provides:       tex(jkpssbxscsl8t.tfm)
Provides:       tex(jkpssbxscsl8t.vf)
Provides:       tex(jkpssbxscsle.tfm)
Provides:       tex(jkpssbxsl7c.tfm)
Provides:       tex(jkpssbxsl7c.vf)
Provides:       tex(jkpssbxsl7t.tfm)
Provides:       tex(jkpssbxsl7t.vf)
Provides:       tex(jkpssbxsl8r.tfm)
Provides:       tex(jkpssbxsl8t.tfm)
Provides:       tex(jkpssbxsl8t.vf)
Provides:       tex(jkpssbxslc.tfm)
Provides:       tex(jkpssbxsle.tfm)
Provides:       tex(jkpssex.tfm)
Provides:       tex(jkpssex.vf)
Provides:       tex(jkpssfbn7t.tfm)
Provides:       tex(jkpssfbn7t.vf)
Provides:       tex(jkpssfbn8t.tfm)
Provides:       tex(jkpssfbn8t.vf)
Provides:       tex(jkpssfbsl7t.tfm)
Provides:       tex(jkpssfbsl7t.vf)
Provides:       tex(jkpssfbsl8t.tfm)
Provides:       tex(jkpssfbsl8t.vf)
Provides:       tex(jkpssfbxn7t.tfm)
Provides:       tex(jkpssfbxn7t.vf)
Provides:       tex(jkpssfbxn8t.tfm)
Provides:       tex(jkpssfbxn8t.vf)
Provides:       tex(jkpssfbxsl7t.tfm)
Provides:       tex(jkpssfbxsl7t.vf)
Provides:       tex(jkpssfbxsl8t.tfm)
Provides:       tex(jkpssfbxsl8t.vf)
Provides:       tex(jkpssfmn7t.tfm)
Provides:       tex(jkpssfmn7t.vf)
Provides:       tex(jkpssfmn8t.tfm)
Provides:       tex(jkpssfmn8t.vf)
Provides:       tex(jkpssfmsl7t.tfm)
Provides:       tex(jkpssfmsl7t.vf)
Provides:       tex(jkpssfmsl8t.tfm)
Provides:       tex(jkpssfmsl8t.vf)
Provides:       tex(jkpssfosnbn7t.tfm)
Provides:       tex(jkpssfosnbn7t.vf)
Provides:       tex(jkpssfosnbn8t.tfm)
Provides:       tex(jkpssfosnbn8t.vf)
Provides:       tex(jkpssfosnbsl7t.tfm)
Provides:       tex(jkpssfosnbsl7t.vf)
Provides:       tex(jkpssfosnbsl8t.tfm)
Provides:       tex(jkpssfosnbsl8t.vf)
Provides:       tex(jkpssfosnbxn7t.tfm)
Provides:       tex(jkpssfosnbxn7t.vf)
Provides:       tex(jkpssfosnbxn8t.tfm)
Provides:       tex(jkpssfosnbxn8t.vf)
Provides:       tex(jkpssfosnbxsl7t.tfm)
Provides:       tex(jkpssfosnbxsl7t.vf)
Provides:       tex(jkpssfosnbxsl8t.tfm)
Provides:       tex(jkpssfosnbxsl8t.vf)
Provides:       tex(jkpssfosnmn7t.tfm)
Provides:       tex(jkpssfosnmn7t.vf)
Provides:       tex(jkpssfosnmn8t.tfm)
Provides:       tex(jkpssfosnmn8t.vf)
Provides:       tex(jkpssfosnmsl7t.tfm)
Provides:       tex(jkpssfosnmsl7t.vf)
Provides:       tex(jkpssfosnmsl8t.tfm)
Provides:       tex(jkpssfosnmsl8t.vf)
Provides:       tex(jkpsskbsc.tfm)
Provides:       tex(jkpsskbsc7t.tfm)
Provides:       tex(jkpsskbsc7t.vf)
Provides:       tex(jkpsskbsc8t.tfm)
Provides:       tex(jkpsskbsc8t.vf)
Provides:       tex(jkpsskbscsl.tfm)
Provides:       tex(jkpsskbscsl7t.tfm)
Provides:       tex(jkpsskbscsl7t.vf)
Provides:       tex(jkpsskbscsl8t.tfm)
Provides:       tex(jkpsskbscsl8t.vf)
Provides:       tex(jkpsskbxsc.tfm)
Provides:       tex(jkpsskbxsc7t.tfm)
Provides:       tex(jkpsskbxsc7t.vf)
Provides:       tex(jkpsskbxsc8t.tfm)
Provides:       tex(jkpsskbxsc8t.vf)
Provides:       tex(jkpsskbxscsl.tfm)
Provides:       tex(jkpsskbxscsl7t.tfm)
Provides:       tex(jkpsskbxscsl7t.vf)
Provides:       tex(jkpsskbxscsl8t.tfm)
Provides:       tex(jkpsskbxscsl8t.vf)
Provides:       tex(jkpsskmsc.tfm)
Provides:       tex(jkpsskmsc7t.tfm)
Provides:       tex(jkpsskmsc7t.vf)
Provides:       tex(jkpsskmsc8t.tfm)
Provides:       tex(jkpsskmsc8t.vf)
Provides:       tex(jkpsskmscsl.tfm)
Provides:       tex(jkpsskmscsl7t.tfm)
Provides:       tex(jkpsskmscsl7t.vf)
Provides:       tex(jkpsskmscsl8t.tfm)
Provides:       tex(jkpsskmscsl8t.vf)
Provides:       tex(jkpsskosbsc7t.tfm)
Provides:       tex(jkpsskosbsc7t.vf)
Provides:       tex(jkpsskosbsc8t.tfm)
Provides:       tex(jkpsskosbsc8t.vf)
Provides:       tex(jkpsskosbscsl7t.tfm)
Provides:       tex(jkpsskosbscsl7t.vf)
Provides:       tex(jkpsskosbscsl8t.tfm)
Provides:       tex(jkpsskosbscsl8t.vf)
Provides:       tex(jkpsskosbxsc7t.tfm)
Provides:       tex(jkpsskosbxsc7t.vf)
Provides:       tex(jkpsskosbxsc8t.tfm)
Provides:       tex(jkpsskosbxsc8t.vf)
Provides:       tex(jkpsskosbxscsl7t.tfm)
Provides:       tex(jkpsskosbxscsl7t.vf)
Provides:       tex(jkpsskosbxscsl8t.tfm)
Provides:       tex(jkpsskosbxscsl8t.vf)
Provides:       tex(jkpsskosmsc7t.tfm)
Provides:       tex(jkpsskosmsc7t.vf)
Provides:       tex(jkpsskosmsc8t.tfm)
Provides:       tex(jkpsskosmsc8t.vf)
Provides:       tex(jkpsskosmscsl7t.tfm)
Provides:       tex(jkpsskosmscsl7t.vf)
Provides:       tex(jkpsskosmscsl8t.tfm)
Provides:       tex(jkpsskosmscsl8t.vf)
Provides:       tex(jkpsskosnbsc7t.tfm)
Provides:       tex(jkpsskosnbsc7t.vf)
Provides:       tex(jkpsskosnbsc8t.tfm)
Provides:       tex(jkpsskosnbsc8t.vf)
Provides:       tex(jkpsskosnbscsl7t.tfm)
Provides:       tex(jkpsskosnbscsl7t.vf)
Provides:       tex(jkpsskosnbscsl8t.tfm)
Provides:       tex(jkpsskosnbscsl8t.vf)
Provides:       tex(jkpsskosnbxsc7t.tfm)
Provides:       tex(jkpsskosnbxsc7t.vf)
Provides:       tex(jkpsskosnbxsc8t.tfm)
Provides:       tex(jkpsskosnbxsc8t.vf)
Provides:       tex(jkpsskosnbxscsl7t.tfm)
Provides:       tex(jkpsskosnbxscsl7t.vf)
Provides:       tex(jkpsskosnbxscsl8t.tfm)
Provides:       tex(jkpsskosnbxscsl8t.vf)
Provides:       tex(jkpsskosnmsc7t.tfm)
Provides:       tex(jkpsskosnmsc7t.vf)
Provides:       tex(jkpsskosnmsc8t.tfm)
Provides:       tex(jkpsskosnmsc8t.vf)
Provides:       tex(jkpsskosnmscsl7t.tfm)
Provides:       tex(jkpsskosnmscsl7t.vf)
Provides:       tex(jkpsskosnmscsl8t.tfm)
Provides:       tex(jkpsskosnmscsl8t.vf)
Provides:       tex(jkpsslbsyb.tfm)
Provides:       tex(jkpsslbsyb.vf)
Provides:       tex(jkpsslbsybw.tfm)
Provides:       tex(jkpsslbsybw.vf)
Provides:       tex(jkpsslsyb.tfm)
Provides:       tex(jkpsslsyb.vf)
Provides:       tex(jkpsslsybw.tfm)
Provides:       tex(jkpsslsybw.vf)
Provides:       tex(jkpssmi.tfm)
Provides:       tex(jkpssmi.vf)
Provides:       tex(jkpssmia.tfm)
Provides:       tex(jkpssmia.vf)
Provides:       tex(jkpssmif.tfm)
Provides:       tex(jkpssmif.vf)
Provides:       tex(jkpssmn7c.tfm)
Provides:       tex(jkpssmn7c.vf)
Provides:       tex(jkpssmn7t.tfm)
Provides:       tex(jkpssmn7t.vf)
Provides:       tex(jkpssmn8a.tfm)
Provides:       tex(jkpssmn8r.tfm)
Provides:       tex(jkpssmn8t.tfm)
Provides:       tex(jkpssmn8t.vf)
Provides:       tex(jkpssmnc.tfm)
Provides:       tex(jkpssmne.tfm)
Provides:       tex(jkpssmsc7c.tfm)
Provides:       tex(jkpssmsc7c.vf)
Provides:       tex(jkpssmsc7t.tfm)
Provides:       tex(jkpssmsc7t.vf)
Provides:       tex(jkpssmsc8a.tfm)
Provides:       tex(jkpssmsc8r.tfm)
Provides:       tex(jkpssmsc8t.tfm)
Provides:       tex(jkpssmsc8t.vf)
Provides:       tex(jkpssmsce.tfm)
Provides:       tex(jkpssmscsl7c.tfm)
Provides:       tex(jkpssmscsl7c.vf)
Provides:       tex(jkpssmscsl7t.tfm)
Provides:       tex(jkpssmscsl7t.vf)
Provides:       tex(jkpssmscsl8r.tfm)
Provides:       tex(jkpssmscsl8t.tfm)
Provides:       tex(jkpssmscsl8t.vf)
Provides:       tex(jkpssmscsle.tfm)
Provides:       tex(jkpssmsl7c.tfm)
Provides:       tex(jkpssmsl7c.vf)
Provides:       tex(jkpssmsl7t.tfm)
Provides:       tex(jkpssmsl7t.vf)
Provides:       tex(jkpssmsl8r.tfm)
Provides:       tex(jkpssmsl8t.tfm)
Provides:       tex(jkpssmsl8t.vf)
Provides:       tex(jkpssmslc.tfm)
Provides:       tex(jkpssmsle.tfm)
Provides:       tex(jkpssosbn7t.tfm)
Provides:       tex(jkpssosbn7t.vf)
Provides:       tex(jkpssosbn8t.tfm)
Provides:       tex(jkpssosbn8t.vf)
Provides:       tex(jkpssosbsc7t.tfm)
Provides:       tex(jkpssosbsc7t.vf)
Provides:       tex(jkpssosbsc8t.tfm)
Provides:       tex(jkpssosbsc8t.vf)
Provides:       tex(jkpssosbscsl7t.tfm)
Provides:       tex(jkpssosbscsl7t.vf)
Provides:       tex(jkpssosbscsl8t.tfm)
Provides:       tex(jkpssosbscsl8t.vf)
Provides:       tex(jkpssosbsl7t.tfm)
Provides:       tex(jkpssosbsl7t.vf)
Provides:       tex(jkpssosbsl8t.tfm)
Provides:       tex(jkpssosbsl8t.vf)
Provides:       tex(jkpssosbxn7t.tfm)
Provides:       tex(jkpssosbxn7t.vf)
Provides:       tex(jkpssosbxn8t.tfm)
Provides:       tex(jkpssosbxn8t.vf)
Provides:       tex(jkpssosbxsc7t.tfm)
Provides:       tex(jkpssosbxsc7t.vf)
Provides:       tex(jkpssosbxsc8t.tfm)
Provides:       tex(jkpssosbxsc8t.vf)
Provides:       tex(jkpssosbxscsl7t.tfm)
Provides:       tex(jkpssosbxscsl7t.vf)
Provides:       tex(jkpssosbxscsl8t.tfm)
Provides:       tex(jkpssosbxscsl8t.vf)
Provides:       tex(jkpssosbxsl7t.tfm)
Provides:       tex(jkpssosbxsl7t.vf)
Provides:       tex(jkpssosbxsl8t.tfm)
Provides:       tex(jkpssosbxsl8t.vf)
Provides:       tex(jkpssosmn7t.tfm)
Provides:       tex(jkpssosmn7t.vf)
Provides:       tex(jkpssosmn8t.tfm)
Provides:       tex(jkpssosmn8t.vf)
Provides:       tex(jkpssosmsc7t.tfm)
Provides:       tex(jkpssosmsc7t.vf)
Provides:       tex(jkpssosmsc8t.tfm)
Provides:       tex(jkpssosmsc8t.vf)
Provides:       tex(jkpssosmscsl7t.tfm)
Provides:       tex(jkpssosmscsl7t.vf)
Provides:       tex(jkpssosmscsl8t.tfm)
Provides:       tex(jkpssosmscsl8t.vf)
Provides:       tex(jkpssosmsl7t.tfm)
Provides:       tex(jkpssosmsl7t.vf)
Provides:       tex(jkpssosmsl8t.tfm)
Provides:       tex(jkpssosmsl8t.vf)
Provides:       tex(jkpssosnbn7t.tfm)
Provides:       tex(jkpssosnbn7t.vf)
Provides:       tex(jkpssosnbn8t.tfm)
Provides:       tex(jkpssosnbn8t.vf)
Provides:       tex(jkpssosnbsc7t.tfm)
Provides:       tex(jkpssosnbsc7t.vf)
Provides:       tex(jkpssosnbsc8t.tfm)
Provides:       tex(jkpssosnbsc8t.vf)
Provides:       tex(jkpssosnbscsl7t.tfm)
Provides:       tex(jkpssosnbscsl7t.vf)
Provides:       tex(jkpssosnbscsl8t.tfm)
Provides:       tex(jkpssosnbscsl8t.vf)
Provides:       tex(jkpssosnbsl7t.tfm)
Provides:       tex(jkpssosnbsl7t.vf)
Provides:       tex(jkpssosnbsl8t.tfm)
Provides:       tex(jkpssosnbsl8t.vf)
Provides:       tex(jkpssosnbxn7t.tfm)
Provides:       tex(jkpssosnbxn7t.vf)
Provides:       tex(jkpssosnbxn8t.tfm)
Provides:       tex(jkpssosnbxn8t.vf)
Provides:       tex(jkpssosnbxsc7t.tfm)
Provides:       tex(jkpssosnbxsc7t.vf)
Provides:       tex(jkpssosnbxsc8t.tfm)
Provides:       tex(jkpssosnbxsc8t.vf)
Provides:       tex(jkpssosnbxscsl7t.tfm)
Provides:       tex(jkpssosnbxscsl7t.vf)
Provides:       tex(jkpssosnbxscsl8t.tfm)
Provides:       tex(jkpssosnbxscsl8t.vf)
Provides:       tex(jkpssosnbxsl7t.tfm)
Provides:       tex(jkpssosnbxsl7t.vf)
Provides:       tex(jkpssosnbxsl8t.tfm)
Provides:       tex(jkpssosnbxsl8t.vf)
Provides:       tex(jkpssosnmn7t.tfm)
Provides:       tex(jkpssosnmn7t.vf)
Provides:       tex(jkpssosnmn8t.tfm)
Provides:       tex(jkpssosnmn8t.vf)
Provides:       tex(jkpssosnmsc7t.tfm)
Provides:       tex(jkpssosnmsc7t.vf)
Provides:       tex(jkpssosnmsc8t.tfm)
Provides:       tex(jkpssosnmsc8t.vf)
Provides:       tex(jkpssosnmscsl7t.tfm)
Provides:       tex(jkpssosnmscsl7t.vf)
Provides:       tex(jkpssosnmscsl8t.tfm)
Provides:       tex(jkpssosnmscsl8t.vf)
Provides:       tex(jkpssosnmsl7t.tfm)
Provides:       tex(jkpssosnmsl7t.vf)
Provides:       tex(jkpssosnmsl8t.tfm)
Provides:       tex(jkpssosnmsl8t.vf)
Provides:       tex(jkpsssyb.tfm)
Provides:       tex(jkpsssyb.vf)
Provides:       tex(jkpsssybw.tfm)
Provides:       tex(jkpsssybw.vf)
Provides:       tex(jkpssvosbmi.tfm)
Provides:       tex(jkpssvosbmi.vf)
Provides:       tex(jkpssvosbmif.tfm)
Provides:       tex(jkpssvosbmif.vf)
Provides:       tex(jkpssvosbn7t.tfm)
Provides:       tex(jkpssvosbn7t.vf)
Provides:       tex(jkpssvosbn8t.tfm)
Provides:       tex(jkpssvosbn8t.vf)
Provides:       tex(jkpssvosbsc7t.tfm)
Provides:       tex(jkpssvosbsc7t.vf)
Provides:       tex(jkpssvosbsc8t.tfm)
Provides:       tex(jkpssvosbsc8t.vf)
Provides:       tex(jkpssvosbsl7t.tfm)
Provides:       tex(jkpssvosbsl7t.vf)
Provides:       tex(jkpssvosbsl8t.tfm)
Provides:       tex(jkpssvosbsl8t.vf)
Provides:       tex(jkpssvosbxn7t.tfm)
Provides:       tex(jkpssvosbxn7t.vf)
Provides:       tex(jkpssvosbxn8t.tfm)
Provides:       tex(jkpssvosbxn8t.vf)
Provides:       tex(jkpssvosbxsc7t.tfm)
Provides:       tex(jkpssvosbxsc7t.vf)
Provides:       tex(jkpssvosbxsc8t.tfm)
Provides:       tex(jkpssvosbxsc8t.vf)
Provides:       tex(jkpssvosbxsl7t.tfm)
Provides:       tex(jkpssvosbxsl7t.vf)
Provides:       tex(jkpssvosbxsl8t.tfm)
Provides:       tex(jkpssvosbxsl8t.vf)
Provides:       tex(jkpssvosmi.tfm)
Provides:       tex(jkpssvosmi.vf)
Provides:       tex(jkpssvosmif.tfm)
Provides:       tex(jkpssvosmif.vf)
Provides:       tex(jkpssvosmn7t.tfm)
Provides:       tex(jkpssvosmn7t.vf)
Provides:       tex(jkpssvosmn8t.tfm)
Provides:       tex(jkpssvosmn8t.vf)
Provides:       tex(jkpssvosmsc7t.tfm)
Provides:       tex(jkpssvosmsc7t.vf)
Provides:       tex(jkpssvosmsc8t.tfm)
Provides:       tex(jkpssvosmsc8t.vf)
Provides:       tex(jkpssvosmsl7t.tfm)
Provides:       tex(jkpssvosmsl7t.vf)
Provides:       tex(jkpssvosmsl8t.tfm)
Provides:       tex(jkpssvosmsl8t.vf)
Provides:       tex(jkpsy.tfm)
Provides:       tex(jkpsya.tfm)
Provides:       tex(jkpsyb.tfm)
Provides:       tex(jkpsybw.tfm)
Provides:       tex(jkpsybw.vf)
Provides:       tex(jkpsyc.tfm)
Provides:       tex(jkpsyd.tfm)
Provides:       tex(jkpsydw.tfm)
Provides:       tex(jkpsydw.vf)
Provides:       tex(jkpsyw.tfm)
Provides:       tex(jkpsyw.vf)
Provides:       tex(jkpttbn7c.tfm)
Provides:       tex(jkpttbn7c.vf)
Provides:       tex(jkpttbn7t.tfm)
Provides:       tex(jkpttbn7t.vf)
Provides:       tex(jkpttbn8a.tfm)
Provides:       tex(jkpttbn8r.tfm)
Provides:       tex(jkpttbn8t.tfm)
Provides:       tex(jkpttbn8t.vf)
Provides:       tex(jkpttbnc.tfm)
Provides:       tex(jkpttbne.tfm)
Provides:       tex(jkpttbsl7c.tfm)
Provides:       tex(jkpttbsl7c.vf)
Provides:       tex(jkpttbsl7t.tfm)
Provides:       tex(jkpttbsl7t.vf)
Provides:       tex(jkpttbsl8r.tfm)
Provides:       tex(jkpttbsl8t.tfm)
Provides:       tex(jkpttbsl8t.vf)
Provides:       tex(jkpttbslc.tfm)
Provides:       tex(jkpttbsle.tfm)
Provides:       tex(jkpttmn7c.tfm)
Provides:       tex(jkpttmn7c.vf)
Provides:       tex(jkpttmn7t.tfm)
Provides:       tex(jkpttmn7t.vf)
Provides:       tex(jkpttmn8a.tfm)
Provides:       tex(jkpttmn8r.tfm)
Provides:       tex(jkpttmn8t.tfm)
Provides:       tex(jkpttmn8t.vf)
Provides:       tex(jkpttmnc.tfm)
Provides:       tex(jkpttmne.tfm)
Provides:       tex(jkpttmsl7c.tfm)
Provides:       tex(jkpttmsl7c.vf)
Provides:       tex(jkpttmsl7t.tfm)
Provides:       tex(jkpttmsl7t.vf)
Provides:       tex(jkpttmsl8r.tfm)
Provides:       tex(jkpttmsl8t.tfm)
Provides:       tex(jkpttmsl8t.vf)
Provides:       tex(jkpttmslc.tfm)
Provides:       tex(jkpttmsle.tfm)
Provides:       tex(jkpttosbn7t.tfm)
Provides:       tex(jkpttosbn7t.vf)
Provides:       tex(jkpttosbn8t.tfm)
Provides:       tex(jkpttosbn8t.vf)
Provides:       tex(jkpttosbsl7t.tfm)
Provides:       tex(jkpttosbsl7t.vf)
Provides:       tex(jkpttosbsl8t.tfm)
Provides:       tex(jkpttosbsl8t.vf)
Provides:       tex(jkpttosmn7t.tfm)
Provides:       tex(jkpttosmn7t.vf)
Provides:       tex(jkpttosmn8t.tfm)
Provides:       tex(jkpttosmn8t.vf)
Provides:       tex(jkpttosmsl7t.tfm)
Provides:       tex(jkpttosmsl7t.vf)
Provides:       tex(jkpttosmsl8t.tfm)
Provides:       tex(jkpttosmsl8t.vf)
Provides:       tex(jkpttosnbn7t.tfm)
Provides:       tex(jkpttosnbn7t.vf)
Provides:       tex(jkpttosnbn8t.tfm)
Provides:       tex(jkpttosnbn8t.vf)
Provides:       tex(jkpttosnbsl7t.tfm)
Provides:       tex(jkpttosnbsl7t.vf)
Provides:       tex(jkpttosnbsl8t.tfm)
Provides:       tex(jkpttosnbsl8t.vf)
Provides:       tex(jkpttosnmn7t.tfm)
Provides:       tex(jkpttosnmn7t.vf)
Provides:       tex(jkpttosnmn8t.tfm)
Provides:       tex(jkpttosnmn8t.vf)
Provides:       tex(jkpttosnmsl7t.tfm)
Provides:       tex(jkpttosnmsl7t.vf)
Provides:       tex(jkpttosnmsl8t.tfm)
Provides:       tex(jkpttosnmsl8t.vf)
Provides:       tex(jkpttvosbn7t.tfm)
Provides:       tex(jkpttvosbn7t.vf)
Provides:       tex(jkpttvosbn8t.tfm)
Provides:       tex(jkpttvosbn8t.vf)
Provides:       tex(jkpttvosbsl7t.tfm)
Provides:       tex(jkpttvosbsl7t.vf)
Provides:       tex(jkpttvosbsl8t.tfm)
Provides:       tex(jkpttvosbsl8t.vf)
Provides:       tex(jkpttvosmn7t.tfm)
Provides:       tex(jkpttvosmn7t.vf)
Provides:       tex(jkpttvosmn8t.tfm)
Provides:       tex(jkpttvosmn8t.vf)
Provides:       tex(jkpttvosmsl7t.tfm)
Provides:       tex(jkpttvosmsl7t.vf)
Provides:       tex(jkpttvosmsl8t.tfm)
Provides:       tex(jkpttvosmsl8t.vf)
Provides:       tex(jkpvosbit7t.tfm)
Provides:       tex(jkpvosbit7t.vf)
Provides:       tex(jkpvosbit8t.tfm)
Provides:       tex(jkpvosbit8t.vf)
Provides:       tex(jkpvosbmi.tfm)
Provides:       tex(jkpvosbmi.vf)
Provides:       tex(jkpvosbmif.tfm)
Provides:       tex(jkpvosbmif.vf)
Provides:       tex(jkpvosbmifw.tfm)
Provides:       tex(jkpvosbmifw.vf)
Provides:       tex(jkpvosbmiw.tfm)
Provides:       tex(jkpvosbmiw.vf)
Provides:       tex(jkpvosbn7t.tfm)
Provides:       tex(jkpvosbn7t.vf)
Provides:       tex(jkpvosbn8t.tfm)
Provides:       tex(jkpvosbn8t.vf)
Provides:       tex(jkpvosbsl7t.tfm)
Provides:       tex(jkpvosbsl7t.vf)
Provides:       tex(jkpvosbsl8t.tfm)
Provides:       tex(jkpvosbsl8t.vf)
Provides:       tex(jkpvosbxit7t.tfm)
Provides:       tex(jkpvosbxit7t.vf)
Provides:       tex(jkpvosbxit8t.tfm)
Provides:       tex(jkpvosbxit8t.vf)
Provides:       tex(jkpvosbxn7t.tfm)
Provides:       tex(jkpvosbxn7t.vf)
Provides:       tex(jkpvosbxn8t.tfm)
Provides:       tex(jkpvosbxn8t.vf)
Provides:       tex(jkpvosbxsl7t.tfm)
Provides:       tex(jkpvosbxsl7t.vf)
Provides:       tex(jkpvosbxsl8t.tfm)
Provides:       tex(jkpvosbxsl8t.vf)
Provides:       tex(jkpvosmi.tfm)
Provides:       tex(jkpvosmi.vf)
Provides:       tex(jkpvosmif.tfm)
Provides:       tex(jkpvosmif.vf)
Provides:       tex(jkpvosmifw.tfm)
Provides:       tex(jkpvosmifw.vf)
Provides:       tex(jkpvosmit7t.tfm)
Provides:       tex(jkpvosmit7t.vf)
Provides:       tex(jkpvosmit8t.tfm)
Provides:       tex(jkpvosmit8t.vf)
Provides:       tex(jkpvosmiw.tfm)
Provides:       tex(jkpvosmiw.vf)
Provides:       tex(jkpvosmn7t.tfm)
Provides:       tex(jkpvosmn7t.vf)
Provides:       tex(jkpvosmn8t.tfm)
Provides:       tex(jkpvosmn8t.vf)
Provides:       tex(jkpvosmsl7t.tfm)
Provides:       tex(jkpvosmsl7t.vf)
Provides:       tex(jkpvosmsl8t.tfm)
Provides:       tex(jkpvosmsl8t.vf)
Provides:       tex(kpfonts-expert-sc.enc)
Provides:       tex(kpfonts-expert-tt.enc)
Provides:       tex(kpfonts-expert.enc)
Provides:       tex(kpfonts-large-sc.enc)
Provides:       tex(kpfonts.map)
Provides:       tex(kpfonts.sty)
Provides:       tex(omljkp.fd)
Provides:       tex(omljkpl.fd)
Provides:       tex(omljkplvos.fd)
Provides:       tex(omljkplvosw.fd)
Provides:       tex(omljkplw.fd)
Provides:       tex(omljkpss.fd)
Provides:       tex(omljkpssvos.fd)
Provides:       tex(omljkpvos.fd)
Provides:       tex(omljkpvosw.fd)
Provides:       tex(omljkpw.fd)
Provides:       tex(omsjkp.fd)
Provides:       tex(omsjkpl.fd)
Provides:       tex(omsjkplw.fd)
Provides:       tex(omsjkpw.fd)
Provides:       tex(omxjkp.fd)
Provides:       tex(omxjkpl.fd)
Provides:       tex(omxjkpss.fd)
Provides:       tex(ot1jkp.fd)
Provides:       tex(ot1jkpf.fd)
Provides:       tex(ot1jkpfosn.fd)
Provides:       tex(ot1jkpk.fd)
Provides:       tex(ot1jkpkf.fd)
Provides:       tex(ot1jkpkfosn.fd)
Provides:       tex(ot1jkpkos.fd)
Provides:       tex(ot1jkpkosn.fd)
Provides:       tex(ot1jkpkvos.fd)
Provides:       tex(ot1jkpl.fd)
Provides:       tex(ot1jkplf.fd)
Provides:       tex(ot1jkplfosn.fd)
Provides:       tex(ot1jkplk.fd)
Provides:       tex(ot1jkplkf.fd)
Provides:       tex(ot1jkplkfosn.fd)
Provides:       tex(ot1jkplkos.fd)
Provides:       tex(ot1jkplkosn.fd)
Provides:       tex(ot1jkplkvos.fd)
Provides:       tex(ot1jkplos.fd)
Provides:       tex(ot1jkplosn.fd)
Provides:       tex(ot1jkplvos.fd)
Provides:       tex(ot1jkpos.fd)
Provides:       tex(ot1jkposn.fd)
Provides:       tex(ot1jkpss.fd)
Provides:       tex(ot1jkpssf.fd)
Provides:       tex(ot1jkpssfosn.fd)
Provides:       tex(ot1jkpssk.fd)
Provides:       tex(ot1jkpsskf.fd)
Provides:       tex(ot1jkpsskfosn.fd)
Provides:       tex(ot1jkpsskos.fd)
Provides:       tex(ot1jkpsskosn.fd)
Provides:       tex(ot1jkpsskvos.fd)
Provides:       tex(ot1jkpssos.fd)
Provides:       tex(ot1jkpssosn.fd)
Provides:       tex(ot1jkpssvos.fd)
Provides:       tex(ot1jkptt.fd)
Provides:       tex(ot1jkpttos.fd)
Provides:       tex(ot1jkpttosn.fd)
Provides:       tex(ot1jkpttvos.fd)
Provides:       tex(ot1jkpvos.fd)
Provides:       tex(ot1jkpx.fd)
Provides:       tex(ot1jkpxf.fd)
Provides:       tex(ot1jkpxfosn.fd)
Provides:       tex(ot1jkpxk.fd)
Provides:       tex(ot1jkpxkf.fd)
Provides:       tex(ot1jkpxkfosn.fd)
Provides:       tex(ot1jkpxkos.fd)
Provides:       tex(ot1jkpxkosn.fd)
Provides:       tex(ot1jkpxkvos.fd)
Provides:       tex(ot1jkpxos.fd)
Provides:       tex(ot1jkpxosn.fd)
Provides:       tex(ot1jkpxvos.fd)
Provides:       tex(t1jkp.fd)
Provides:       tex(t1jkpf.fd)
Provides:       tex(t1jkpfosn.fd)
Provides:       tex(t1jkpk.fd)
Provides:       tex(t1jkpkf.fd)
Provides:       tex(t1jkpkfosn.fd)
Provides:       tex(t1jkpkos.fd)
Provides:       tex(t1jkpkosn.fd)
Provides:       tex(t1jkpkvos.fd)
Provides:       tex(t1jkpl.fd)
Provides:       tex(t1jkplf.fd)
Provides:       tex(t1jkplfosn.fd)
Provides:       tex(t1jkplk.fd)
Provides:       tex(t1jkplkf.fd)
Provides:       tex(t1jkplkfosn.fd)
Provides:       tex(t1jkplkos.fd)
Provides:       tex(t1jkplkosn.fd)
Provides:       tex(t1jkplkvos.fd)
Provides:       tex(t1jkplos.fd)
Provides:       tex(t1jkplosn.fd)
Provides:       tex(t1jkplvos.fd)
Provides:       tex(t1jkpos.fd)
Provides:       tex(t1jkposn.fd)
Provides:       tex(t1jkpss.fd)
Provides:       tex(t1jkpssf.fd)
Provides:       tex(t1jkpssfosn.fd)
Provides:       tex(t1jkpssk.fd)
Provides:       tex(t1jkpsskf.fd)
Provides:       tex(t1jkpsskfosn.fd)
Provides:       tex(t1jkpsskos.fd)
Provides:       tex(t1jkpsskosn.fd)
Provides:       tex(t1jkpsskvos.fd)
Provides:       tex(t1jkpssos.fd)
Provides:       tex(t1jkpssosn.fd)
Provides:       tex(t1jkpssvos.fd)
Provides:       tex(t1jkptt.fd)
Provides:       tex(t1jkpttos.fd)
Provides:       tex(t1jkpttosn.fd)
Provides:       tex(t1jkpttvos.fd)
Provides:       tex(t1jkpvos.fd)
Provides:       tex(t1jkpx.fd)
Provides:       tex(t1jkpxf.fd)
Provides:       tex(t1jkpxfosn.fd)
Provides:       tex(t1jkpxk.fd)
Provides:       tex(t1jkpxkf.fd)
Provides:       tex(t1jkpxkfosn.fd)
Provides:       tex(t1jkpxkos.fd)
Provides:       tex(t1jkpxkosn.fd)
Provides:       tex(t1jkpxkvos.fd)
Provides:       tex(t1jkpxos.fd)
Provides:       tex(t1jkpxosn.fd)
Provides:       tex(t1jkpxvos.fd)
Provides:       tex(ts1jkp.fd)
Provides:       tex(ts1jkpf.fd)
Provides:       tex(ts1jkpfosn.fd)
Provides:       tex(ts1jkpk.fd)
Provides:       tex(ts1jkpkf.fd)
Provides:       tex(ts1jkpkfosn.fd)
Provides:       tex(ts1jkpkos.fd)
Provides:       tex(ts1jkpkosn.fd)
Provides:       tex(ts1jkpkvos.fd)
Provides:       tex(ts1jkpl.fd)
Provides:       tex(ts1jkplf.fd)
Provides:       tex(ts1jkplfosn.fd)
Provides:       tex(ts1jkplk.fd)
Provides:       tex(ts1jkplkf.fd)
Provides:       tex(ts1jkplkfosn.fd)
Provides:       tex(ts1jkplkos.fd)
Provides:       tex(ts1jkplkosn.fd)
Provides:       tex(ts1jkplkvos.fd)
Provides:       tex(ts1jkplos.fd)
Provides:       tex(ts1jkplosn.fd)
Provides:       tex(ts1jkplvos.fd)
Provides:       tex(ts1jkpos.fd)
Provides:       tex(ts1jkposn.fd)
Provides:       tex(ts1jkpss.fd)
Provides:       tex(ts1jkpssf.fd)
Provides:       tex(ts1jkpssfosn.fd)
Provides:       tex(ts1jkpssk.fd)
Provides:       tex(ts1jkpsskf.fd)
Provides:       tex(ts1jkpsskfosn.fd)
Provides:       tex(ts1jkpsskos.fd)
Provides:       tex(ts1jkpsskosn.fd)
Provides:       tex(ts1jkpsskvos.fd)
Provides:       tex(ts1jkpssos.fd)
Provides:       tex(ts1jkpssosn.fd)
Provides:       tex(ts1jkpssvos.fd)
Provides:       tex(ts1jkptt.fd)
Provides:       tex(ts1jkpttos.fd)
Provides:       tex(ts1jkpttosn.fd)
Provides:       tex(ts1jkpttvos.fd)
Provides:       tex(ts1jkpvos.fd)
Provides:       tex(ts1jkpx.fd)
Provides:       tex(ts1jkpxf.fd)
Provides:       tex(ts1jkpxfosn.fd)
Provides:       tex(ts1jkpxk.fd)
Provides:       tex(ts1jkpxkf.fd)
Provides:       tex(ts1jkpxkfosn.fd)
Provides:       tex(ts1jkpxkos.fd)
Provides:       tex(ts1jkpxkosn.fd)
Provides:       tex(ts1jkpxkvos.fd)
Provides:       tex(ts1jkpxos.fd)
Provides:       tex(ts1jkpxosn.fd)
Provides:       tex(ts1jkpxvos.fd)
Provides:       tex(ujkpexa.fd)
Provides:       tex(ujkplexa.fd)
Provides:       tex(ujkplmia.fd)
Provides:       tex(ujkplmiaw.fd)
Provides:       tex(ujkplsyb.fd)
Provides:       tex(ujkplsybw.fd)
Provides:       tex(ujkplsyc.fd)
Provides:       tex(ujkplsyd.fd)
Provides:       tex(ujkplsydw.fd)
Provides:       tex(ujkpmia.fd)
Provides:       tex(ujkpmiaw.fd)
Provides:       tex(ujkpsslsyb.fd)
Provides:       tex(ujkpsslsybw.fd)
Provides:       tex(ujkpssmia.fd)
Provides:       tex(ujkpsssyb.fd)
Provides:       tex(ujkpsssybw.fd)
Provides:       tex(ujkpsya.fd)
Provides:       tex(ujkpsyb.fd)
Provides:       tex(ujkpsybw.fd)
Provides:       tex(ujkpsyc.fd)
Provides:       tex(ujkpsyd.fd)
Provides:       tex(ujkpsydw.fd)
Requires:       tex(amsmath.sty)
Requires:       tex(iftex.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(kpfonts-otf.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source208:      kpfonts.tar.xz
Source209:      kpfonts.doc.tar.xz

%description -n texlive-kpfonts
The family contains text fonts in roman, sans-serif and
monospaced shapes, with true small caps and old-style numbers;
the package offers full support of the textcomp package. The
mathematics fonts include all the AMS fonts, in both normal and
bold weights. Each of the font types is available in two main
versions: default and 'light'. Each version is available in
four variants: default; oldstyle numbers; oldstyle numbers with
old ligatures such as ct and st, and long-tailed capital Q; and
veryoldstyle with long s. Other variants include small caps as
default or 'large small caps', and for mathematics both upright
and slanted shapes for Greek letters, as well as default and
narrow versions of multiple integrals. The fonts were
originally derived from URW Palladio (with URW's agreement)
though the fonts are very clearly different in appearance from
their parent.

%package -n texlive-kpfonts-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.35svn65583
Release:        0
Summary:        Documentation for texlive-kpfonts
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kpfonts and texlive-alldocumentation)
Provides:       locale(texlive-kpfonts-doc:en)

%description -n texlive-kpfonts-doc
This package includes the documentation for texlive-kpfonts

%package -n texlive-kpfonts-fonts
Version:        %{texlive_version}.%{texlive_noarch}.3.35svn65583
Release:        0
Summary:        Severed fonts for texlive-kpfonts
License:        LPPL-1.0
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-kpfonts-fonts
The  separated fonts package for texlive-kpfonts

%post -n texlive-kpfonts
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap kpfonts.map' >> /var/run/texlive/run-updmap

%postun -n texlive-kpfonts
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap kpfonts.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-kpfonts
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-kpfonts-fonts

%files -n texlive-kpfonts-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/kpfonts/Changes
%{_texmfdistdir}/doc/fonts/kpfonts/README.txt
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts-abstract.pdf
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts-abstract.tex
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts-math-symbols-tables.pdf
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts-math-symbols-tables.tex
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts.pdf
%{_texmfdistdir}/doc/fonts/kpfonts/kpfonts.tex

%files -n texlive-kpfonts
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbit8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbitc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbite.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpbsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpkbsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpkmsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbit8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbitc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbite.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplbsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplkbsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplkmsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmit8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmitc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmite.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkplmsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmit8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmitc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmite.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpmsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssbn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssbnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssbne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssbsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssbsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpsskbsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpsskmsc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssmn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssmnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssmne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssmsc8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpssmsce.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttbn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttbnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttbne.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttmn8a.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttmnc.afm
%{_texmfdistdir}/fonts/afm/public/kpfonts/jkpttmne.afm
%{_texmfdistdir}/fonts/enc/dvips/kpfonts/kpfonts-expert-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kpfonts/kpfonts-expert-tt.enc
%{_texmfdistdir}/fonts/enc/dvips/kpfonts/kpfonts-expert.enc
%{_texmfdistdir}/fonts/enc/dvips/kpfonts/kpfonts-large-sc.enc
%{_texmfdistdir}/fonts/map/dvips/kpfonts/kpfonts.map
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbexa.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbit8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmiaw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsy.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsya.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsyc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsyd.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsydw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbsyw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpbxsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpexa.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpfssosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpkosnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbexa.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbit8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmiaw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsy.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsyc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsyd.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsydw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbsyw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplbxsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplexa.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplfosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplkosnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmiaw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmit8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplmsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsy.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsyc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsyd.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsydw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplsyw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkplvosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmiaw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmit8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmit8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmitc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmite.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpmsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmit7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkposnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssbxsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssex.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssfosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmsc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmscsl.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsskosnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsslbsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsslbsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsslsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsslsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmia.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsc7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsc8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsc8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsce.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmscsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmscsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmscsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssmsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmscsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmscsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsssyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsssybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmsc7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmsc8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpssvosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsy.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsya.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsyb.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsybw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsyc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsyd.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsydw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpsyw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttbsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmn7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmn8a.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmn8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmnc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmne.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmsl7c.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmsl8r.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmslc.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttmsle.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttosnmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpttvosmsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosbxsl8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmi.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmif.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmifw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmit7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmit8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmiw.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmn7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmn8t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmsl7t.tfm
%{_texmfdistdir}/fonts/tfm/public/kpfonts/jkpvosmsl8t.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbex.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbexa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbit8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbitc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbite.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbmia.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsy.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsya.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsyb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsyc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpbsyd.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpex.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpexa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpkbsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpkmsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbex.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbexa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbit8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbitc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbite.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbmia.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsy.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsyb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsyc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplbsyd.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplex.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplexa.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplkbsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplkmsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmia.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmit8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmitc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmite.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplmsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplsy.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplsyb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplsyc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkplsyd.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmia.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmit8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmitc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmite.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpmsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssbn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssbnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssbne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssbsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssbsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsskbsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsskmsc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssmn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssmnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssmne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssmsc8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpssmsce.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsy.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsya.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsyb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsyc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpsyd.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttbn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttbnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttbne.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttmn8a.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttmnc.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/public/kpfonts/jkpttmne.pfb
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbmiaw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsydw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbsyw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpfssosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpkosnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbmiaw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsydw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbsyw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplfosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplkosnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmiaw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplsydw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplsyw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkplvosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmiaw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmit7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkposnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbex.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbmia.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsyb.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssex.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssfosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsskosnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsslbsyb.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsslbsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsslsyb.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsslsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmia.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsc7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmscsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmscsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmscsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsssyb.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsssybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmsc7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmsc8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpssvosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsybw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsydw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpsyw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmn7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmsl7c.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttosnmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpttvosmsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosbxsl8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmi.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmif.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmifw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmit7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmit8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmiw.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmn7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmn8t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmsl7t.vf
%{_texmfdistdir}/fonts/vf/public/kpfonts/jkpvosmsl8t.vf
%{_texmfdistdir}/tex/latex/kpfonts/kpfonts.sty
%{_texmfdistdir}/tex/latex/kpfonts/omljkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkplvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkplvosw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkplw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpss.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpssvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpvosw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omljkpw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omsjkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/omsjkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/omsjkplw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omsjkpw.fd
%{_texmfdistdir}/tex/latex/kpfonts/omxjkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/omxjkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/omxjkpss.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkplvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkposn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpss.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpsskf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpsskfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpsskos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpsskosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpsskvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpssvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkptt.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpttos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpttosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpttvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpx.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ot1jkpxvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpk.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplk.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkplvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkposn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpss.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssk.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpsskf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpsskfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpsskos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpsskosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpsskvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpssvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkptt.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpttos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpttosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpttvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpx.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxk.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxos.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/t1jkpxvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkp.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpl.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkplvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkposn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpss.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpsskf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpsskfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpsskos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpsskosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpsskvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpssvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkptt.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpttos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpttosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpttvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpx.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxk.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxkf.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxkfosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxkos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxkosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxkvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxosn.fd
%{_texmfdistdir}/tex/latex/kpfonts/ts1jkpxvos.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpexa.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplexa.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplmia.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplmiaw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplsyb.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplsybw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplsyc.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplsyd.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkplsydw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpmia.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpmiaw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsslsyb.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsslsybw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpssmia.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsssyb.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsssybw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsya.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsyb.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsybw.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsyc.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsyd.fd
%{_texmfdistdir}/tex/latex/kpfonts/ujkpsydw.fd

%files -n texlive-kpfonts-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-kpfonts
%{_datadir}/fontconfig/conf.avail/58-texlive-kpfonts.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts/fonts.scale
%{_datadir}/fonts/texlive-kpfonts/jkpbex.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbexa.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbit8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbitc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbite.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbmi.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbmia.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsy.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsya.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsyb.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsyc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpbsyd.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpex.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpexa.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpkbsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpkmsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbex.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbexa.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbit8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbitc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbite.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbmi.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbmia.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsy.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsyb.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsyc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplbsyd.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplex.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplexa.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplkbsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplkmsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmi.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmia.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmit8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmitc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmite.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplmsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplsy.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplsyb.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplsyc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkplsyd.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmi.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmia.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmit8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmitc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmite.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpmsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssbn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssbnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssbne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssbsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssbsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsskbsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsskmsc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssmn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssmnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssmne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssmsc8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpssmsce.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsy.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsya.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsyb.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsyc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpsyd.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttbn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttbnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttbne.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttmn8a.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttmnc.pfb
%{_datadir}/fonts/texlive-kpfonts/jkpttmne.pfb

%package -n texlive-kpfonts-otf
Version:        %{texlive_version}.%{texlive_noarch}.0.0.48svn65560
Release:        0
License:        OFL-1.1
Summary:        OTF version of the Kp-fonts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-kpfonts-otf-fonts >= %{texlive_version}
Suggests:       texlive-kpfonts-otf-doc >= %{texlive_version}
Provides:       tex(kpfonts-otf.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(iftex.sty)
Requires:       tex(realscripts.sty)
Requires:       tex(unicode-math.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source210:      kpfonts-otf.tar.xz
Source211:      kpfonts-otf.doc.tar.xz

%description -n texlive-kpfonts-otf
This bundle provides OpenType versions of the Type1 Kp-fonts
designed by Christophe Caignaert. It is usable with LuaTeX or
XeTeX engines only. It consists of sixteen Text fonts (eight
Serif, four Sans-Serif, four Monotype) and six Math fonts.
Serif and Sans-Serif families have small caps available in two
sizes (SmallCaps and PetitesCaps), upper and lowercase digits,
real superscripts and subscripts; ancient ligatures (ct and
st), ancient long-s and a long-tailed capital Q are available
via font features. Math fonts cover all usual symbols including
AMS'; a full list of available symbols is provided, see the
'List of glyphs'.

%package -n texlive-kpfonts-otf-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.48svn65560
Release:        0
Summary:        Documentation for texlive-kpfonts-otf
License:        OFL-1.1
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kpfonts-otf and texlive-alldocumentation)
Provides:       locale(texlive-kpfonts-otf-doc:en;fr)

%description -n texlive-kpfonts-otf-doc
This package includes the documentation for texlive-kpfonts-otf

%package -n texlive-kpfonts-otf-fonts
Version:        %{texlive_version}.%{texlive_noarch}.0.0.48svn65560
Release:        0
Summary:        Severed fonts for texlive-kpfonts-otf
License:        OFL-1.1
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-kpfonts-otf-fonts
The  separated fonts package for texlive-kpfonts-otf

%post -n texlive-kpfonts-otf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kpfonts-otf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kpfonts-otf
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-kpfonts-otf-fonts

%files -n texlive-kpfonts-otf-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/kpfonts-otf/Kpfonts-OTF-Doc-English.ltx
%{_texmfdistdir}/doc/fonts/kpfonts-otf/Kpfonts-OTF-Doc-English.pdf
%{_texmfdistdir}/doc/fonts/kpfonts-otf/Kpfonts-OTF-Doc-French.ltx
%{_texmfdistdir}/doc/fonts/kpfonts-otf/Kpfonts-OTF-Doc-French.pdf
%{_texmfdistdir}/doc/fonts/kpfonts-otf/README.md
%{_texmfdistdir}/doc/fonts/kpfonts-otf/unimath-kpfonts.ltx
%{_texmfdistdir}/doc/fonts/kpfonts-otf/unimath-kpfonts.pdf

%files -n texlive-kpfonts-otf
%defattr(-,root,root,755)
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-Light.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-Sans.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-SansBold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMath-Semibold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMono-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMono-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMono-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpMono-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-Light.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-LightItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-Semibold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpRoman-SemiboldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpSans-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpSans-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpSans-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/KpSans-Regular.otf
%{_texmfdistdir}/tex/latex/kpfonts-otf/KpLight.fontspec
%{_texmfdistdir}/tex/latex/kpfonts-otf/KpMono.fontspec
%{_texmfdistdir}/tex/latex/kpfonts-otf/KpRoman.fontspec
%{_texmfdistdir}/tex/latex/kpfonts-otf/KpSans.fontspec
%{_texmfdistdir}/tex/latex/kpfonts-otf/kpfonts-otf.sty

%files -n texlive-kpfonts-otf-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-kpfonts-otf
%{_datadir}/fontconfig/conf.avail/58-texlive-kpfonts-otf.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts-otf/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts-otf/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kpfonts-otf/fonts.scale
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-Bold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-Light.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-Regular.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-Sans.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-SansBold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMath-Semibold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMono-Bold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMono-BoldItalic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMono-Italic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpMono-Regular.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-Bold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-BoldItalic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-Italic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-Light.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-LightItalic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-Regular.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-Semibold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpRoman-SemiboldItalic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpSans-Bold.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpSans-BoldItalic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpSans-Italic.otf
%{_datadir}/fonts/texlive-kpfonts-otf/KpSans-Regular.otf

%package -n texlive-ksfh_nat
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn24825
Release:        0
License:        LPPL-1.0
Summary:        BibTeX style for KSFH Munich
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source212:      ksfh_nat.tar.xz

%description -n texlive-ksfh_nat
The package supports bibliographies as standard for KSFH
(Katholische Stiftungsfachhochschule) Munich. BibTeX entries in
article, book, inbook, incollection and misc formats are
supported.

%post -n texlive-ksfh_nat
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ksfh_nat
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ksfh_nat
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ksfh_nat
%defattr(-,root,root,755)
%{_texmfdistdir}/bibtex/bst/ksfh_nat/ksfh_nat.bst

%package -n texlive-ksp-thesis
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn39080
Release:        0
License:        LPPL-1.0
Summary:        A LaTeX class for theses published with KIT Scientific Publishing
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ksp-thesis-doc >= %{texlive_version}
Provides:       tex(ksp-thesis.cls)
Requires:       tex(arsclassica.sty)
Requires:       tex(classicthesis.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ragged2e.sty)
Requires:       tex(scrbook.cls)
Requires:       tex(scrlayer-scrpage.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source213:      ksp-thesis.tar.xz
Source214:      ksp-thesis.doc.tar.xz

%description -n texlive-ksp-thesis
This package provides a LaTeX class intended for authors who
want to publish their thesis or other scientific work with KIT
Scientific Publishing (KSP). The class is based on the scrbook
class of the KOMA-script bundle in combination with the
ClassicThesis and ArsClassica packages. It modifies some of the
layout and style definitions of these packages in order to
provide a document layout that should be compatible with the
requirements by KSP.

%package -n texlive-ksp-thesis-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn39080
Release:        0
Summary:        Documentation for texlive-ksp-thesis
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ksp-thesis and texlive-alldocumentation)

%description -n texlive-ksp-thesis-doc
This package includes the documentation for texlive-ksp-thesis

%post -n texlive-ksp-thesis
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ksp-thesis
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ksp-thesis
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ksp-thesis-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/ksp-thesis/LISTOFFILES
%{_texmfdistdir}/doc/latex/ksp-thesis/README.md
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/appendix.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/appendix/bibliography.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/appendix/lists.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/docinfo.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/abstract.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/acknowledgments.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/dirtytitle.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/lists.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/publications.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/titlepage.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front/toc.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/frontmatter.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/mainmatter.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/example.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/preamble/layout.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/demo/minimal/example.tex
%{_texmfdistdir}/doc/latex/ksp-thesis/ksp-thesis.pdf
%{_texmfdistdir}/doc/latex/ksp-thesis/ksp-thesis.tex

%files -n texlive-ksp-thesis
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/ksp-thesis/ksp-thesis.cls

%package -n texlive-ktv-texdata
Version:        %{texlive_version}.%{texlive_noarch}.05.34svn27369
Release:        0
License:        GPL-2.0-or-later
Summary:        Extract subsets of documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ktv-texdata-doc >= %{texlive_version}
Provides:       tex(ktv-buildnum.sty)
Provides:       tex(ktv-texdata.sty)
Requires:       tex(verbatim.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source215:      ktv-texdata.tar.xz
Source216:      ktv-texdata.doc.tar.xz

%description -n texlive-ktv-texdata
The package defines an exercice environment which numbers every
exercise, and a command \get to extract a collection whose
argument is a comma-separated set of exercise index numbers.
While the package was designed for teachers constructing tables
of exercises, it plainly has more general application.

%package -n texlive-ktv-texdata-doc
Version:        %{texlive_version}.%{texlive_noarch}.05.34svn27369
Release:        0
Summary:        Documentation for texlive-ktv-texdata
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ktv-texdata and texlive-alldocumentation)

%description -n texlive-ktv-texdata-doc
This package includes the documentation for texlive-ktv-texdata

%post -n texlive-ktv-texdata
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ktv-texdata
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ktv-texdata
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ktv-texdata-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/ktv-texdata/README
%{_texmfdistdir}/doc/latex/ktv-texdata/README.txt.doc
%{_texmfdistdir}/doc/latex/ktv-texdata/ktv-data.tex
%{_texmfdistdir}/doc/latex/ktv-texdata/ktv-test.KTVhint
%{_texmfdistdir}/doc/latex/ktv-texdata/ktv-test.tex
%{_texmfdistdir}/doc/latex/ktv-texdata/ktv-texdata.ktvnum
%{_texmfdistdir}/doc/latex/ktv-texdata/ktv-texdata.pdf

%files -n texlive-ktv-texdata
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/ktv-texdata/ktv-buildnum.sty
%{_texmfdistdir}/tex/latex/ktv-texdata/ktv-texdata.sty

%package -n texlive-ku-template
Version:        %{texlive_version}.%{texlive_noarch}.0.0.02svn45935
Release:        0
License:        LPPL-1.0
Summary:        Copenhagen University or faculty logo for front page
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ku-template-doc >= %{texlive_version}
Provides:       tex(ku-template.sty)
Requires:       tex(titling.sty)
Requires:       tex(wallpaper.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source217:      ku-template.tar.xz
Source218:      ku-template.doc.tar.xz

%description -n texlive-ku-template
A comprehensive package for adding University of Copenhagen or
faculty logo to your front page. For use by student or staff at
University of Copenhagen (Kobenhavns Universitet).

%package -n texlive-ku-template-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.02svn45935
Release:        0
Summary:        Documentation for texlive-ku-template
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ku-template and texlive-alldocumentation)

%description -n texlive-ku-template-doc
This package includes the documentation for texlive-ku-template

%post -n texlive-ku-template
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ku-template
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ku-template
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ku-template-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/ku-template/README.txt
%{_texmfdistdir}/doc/latex/ku-template/images/hum-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/hum-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/jur-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/jur-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/ku-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/ku-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sam-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sam-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sci-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sci-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sun-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/sun-en.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/teo-da.pdf
%{_texmfdistdir}/doc/latex/ku-template/images/teo-en.pdf

%files -n texlive-ku-template
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/ku-template/ku-template.sty

%package -n texlive-kurdishlipsum
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn47518
Release:        0
License:        LPPL-1.0
Summary:        A 'lipsum' package for the Kurdish language
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kurdishlipsum-doc >= %{texlive_version}
Provides:       tex(kurdishlipsum.sty)
Requires:       tex(biditools.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source219:      kurdishlipsum.tar.xz
Source220:      kurdishlipsum.doc.tar.xz

%description -n texlive-kurdishlipsum
This package provides lipsum-like facilities for the Kurdish
language. The package gives you easy access to the Kurdish
poetry and balladry texts of the Diwany Vafaiy, Ahmedy Xani,
Naly, Mahwy,.... The package needs to be run under XeLaTeX.

%package -n texlive-kurdishlipsum-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn47518
Release:        0
Summary:        Documentation for texlive-kurdishlipsum
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kurdishlipsum and texlive-alldocumentation)

%description -n texlive-kurdishlipsum-doc
This package includes the documentation for texlive-kurdishlipsum

%post -n texlive-kurdishlipsum
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kurdishlipsum
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kurdishlipsum
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kurdishlipsum-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/xelatex/kurdishlipsum/README
%{_texmfdistdir}/doc/xelatex/kurdishlipsum/kurdishlipsum.pdf
%{_texmfdistdir}/doc/xelatex/kurdishlipsum/kurdishlipsum.tex

%files -n texlive-kurdishlipsum
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/xelatex/kurdishlipsum/kurdishlipsum.sty

%package -n texlive-kurier
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19612
Release:        0
License:        LPPL-1.3c
Summary:        A two-element sans-serif typeface
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(updmap.cfg)
#!BuildIgnore:  tex(updmap.cfg)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(updmap.cfg)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires:       texlive-kurier-fonts >= %{texlive_version}
Suggests:       texlive-kurier-doc >= %{texlive_version}
Provides:       tex(cs-kurier-sc.enc)
Provides:       tex(cs-kurier.enc)
Provides:       tex(cs-kurierb-sc.tfm)
Provides:       tex(cs-kurierb.tfm)
Provides:       tex(cs-kurierbi-sc.tfm)
Provides:       tex(cs-kurierbi.tfm)
Provides:       tex(cs-kuriercb-sc.tfm)
Provides:       tex(cs-kuriercb.tfm)
Provides:       tex(cs-kuriercbi-sc.tfm)
Provides:       tex(cs-kuriercbi.tfm)
Provides:       tex(cs-kurierch-sc.tfm)
Provides:       tex(cs-kurierch.tfm)
Provides:       tex(cs-kurierchi-sc.tfm)
Provides:       tex(cs-kurierchi.tfm)
Provides:       tex(cs-kuriercl-sc.tfm)
Provides:       tex(cs-kuriercl.tfm)
Provides:       tex(cs-kuriercli-sc.tfm)
Provides:       tex(cs-kuriercli.tfm)
Provides:       tex(cs-kuriercm-sc.tfm)
Provides:       tex(cs-kuriercm.tfm)
Provides:       tex(cs-kuriercmi-sc.tfm)
Provides:       tex(cs-kuriercmi.tfm)
Provides:       tex(cs-kuriercr-sc.tfm)
Provides:       tex(cs-kuriercr.tfm)
Provides:       tex(cs-kuriercri-sc.tfm)
Provides:       tex(cs-kuriercri.tfm)
Provides:       tex(cs-kurierh-sc.tfm)
Provides:       tex(cs-kurierh.tfm)
Provides:       tex(cs-kurierhi-sc.tfm)
Provides:       tex(cs-kurierhi.tfm)
Provides:       tex(cs-kurierl-sc.tfm)
Provides:       tex(cs-kurierl.tfm)
Provides:       tex(cs-kurierli-sc.tfm)
Provides:       tex(cs-kurierli.tfm)
Provides:       tex(cs-kurierm-sc.tfm)
Provides:       tex(cs-kurierm.tfm)
Provides:       tex(cs-kuriermi-sc.tfm)
Provides:       tex(cs-kuriermi.tfm)
Provides:       tex(cs-kurierr-sc.tfm)
Provides:       tex(cs-kurierr.tfm)
Provides:       tex(cs-kurierri-sc.tfm)
Provides:       tex(cs-kurierri.tfm)
Provides:       tex(ec-kurier-sc.enc)
Provides:       tex(ec-kurier.enc)
Provides:       tex(ec-kurierb-sc.tfm)
Provides:       tex(ec-kurierb.tfm)
Provides:       tex(ec-kurierbi-sc.tfm)
Provides:       tex(ec-kurierbi.tfm)
Provides:       tex(ec-kuriercb-sc.tfm)
Provides:       tex(ec-kuriercb.tfm)
Provides:       tex(ec-kuriercbi-sc.tfm)
Provides:       tex(ec-kuriercbi.tfm)
Provides:       tex(ec-kurierch-sc.tfm)
Provides:       tex(ec-kurierch.tfm)
Provides:       tex(ec-kurierchi-sc.tfm)
Provides:       tex(ec-kurierchi.tfm)
Provides:       tex(ec-kuriercl-sc.tfm)
Provides:       tex(ec-kuriercl.tfm)
Provides:       tex(ec-kuriercli-sc.tfm)
Provides:       tex(ec-kuriercli.tfm)
Provides:       tex(ec-kuriercm-sc.tfm)
Provides:       tex(ec-kuriercm.tfm)
Provides:       tex(ec-kuriercmi-sc.tfm)
Provides:       tex(ec-kuriercmi.tfm)
Provides:       tex(ec-kuriercr-sc.tfm)
Provides:       tex(ec-kuriercr.tfm)
Provides:       tex(ec-kuriercri-sc.tfm)
Provides:       tex(ec-kuriercri.tfm)
Provides:       tex(ec-kurierh-sc.tfm)
Provides:       tex(ec-kurierh.tfm)
Provides:       tex(ec-kurierhi-sc.tfm)
Provides:       tex(ec-kurierhi.tfm)
Provides:       tex(ec-kurierl-sc.tfm)
Provides:       tex(ec-kurierl.tfm)
Provides:       tex(ec-kurierli-sc.tfm)
Provides:       tex(ec-kurierli.tfm)
Provides:       tex(ec-kurierm-sc.tfm)
Provides:       tex(ec-kurierm.tfm)
Provides:       tex(ec-kuriermi-sc.tfm)
Provides:       tex(ec-kuriermi.tfm)
Provides:       tex(ec-kurierr-sc.tfm)
Provides:       tex(ec-kurierr.tfm)
Provides:       tex(ec-kurierri-sc.tfm)
Provides:       tex(ec-kurierri.tfm)
Provides:       tex(ex-kurier.enc)
Provides:       tex(ex-kurierb.tfm)
Provides:       tex(ex-kuriercb.tfm)
Provides:       tex(ex-kurierch.tfm)
Provides:       tex(ex-kuriercl.tfm)
Provides:       tex(ex-kuriercm.tfm)
Provides:       tex(ex-kuriercr.tfm)
Provides:       tex(ex-kurierh.tfm)
Provides:       tex(ex-kurierl.tfm)
Provides:       tex(ex-kurierm.tfm)
Provides:       tex(ex-kurierr.tfm)
Provides:       tex(greek-kurier.enc)
Provides:       tex(greek-kurierb.tfm)
Provides:       tex(greek-kurierbi.tfm)
Provides:       tex(greek-kuriercb.tfm)
Provides:       tex(greek-kuriercbi.tfm)
Provides:       tex(greek-kurierch.tfm)
Provides:       tex(greek-kurierchi.tfm)
Provides:       tex(greek-kuriercl.tfm)
Provides:       tex(greek-kuriercli.tfm)
Provides:       tex(greek-kuriercm.tfm)
Provides:       tex(greek-kuriercmi.tfm)
Provides:       tex(greek-kuriercr.tfm)
Provides:       tex(greek-kuriercri.tfm)
Provides:       tex(greek-kurierh.tfm)
Provides:       tex(greek-kurierhi.tfm)
Provides:       tex(greek-kurierl.tfm)
Provides:       tex(greek-kurierli.tfm)
Provides:       tex(greek-kurierm.tfm)
Provides:       tex(greek-kuriermi.tfm)
Provides:       tex(greek-kurierr.tfm)
Provides:       tex(greek-kurierri.tfm)
Provides:       tex(il2kurier.fd)
Provides:       tex(il2kurierc.fd)
Provides:       tex(il2kurierl.fd)
Provides:       tex(il2kurierlc.fd)
Provides:       tex(kurier-cs.map)
Provides:       tex(kurier-ec.map)
Provides:       tex(kurier-ex.map)
Provides:       tex(kurier-greek.map)
Provides:       tex(kurier-l7x.map)
Provides:       tex(kurier-math.tex)
Provides:       tex(kurier-mi.map)
Provides:       tex(kurier-qx.map)
Provides:       tex(kurier-rm.map)
Provides:       tex(kurier-sy.map)
Provides:       tex(kurier-t2a.map)
Provides:       tex(kurier-t2b.map)
Provides:       tex(kurier-t2c.map)
Provides:       tex(kurier-t5.map)
Provides:       tex(kurier-texnansi.map)
Provides:       tex(kurier-ts1.map)
Provides:       tex(kurier-wncy.map)
Provides:       tex(kurier.map)
Provides:       tex(kurier.sty)
Provides:       tex(l7x-kurier-sc.enc)
Provides:       tex(l7x-kurier.enc)
Provides:       tex(l7x-kurierb-sc.tfm)
Provides:       tex(l7x-kurierb.tfm)
Provides:       tex(l7x-kurierbi-sc.tfm)
Provides:       tex(l7x-kurierbi.tfm)
Provides:       tex(l7x-kuriercb-sc.tfm)
Provides:       tex(l7x-kuriercb.tfm)
Provides:       tex(l7x-kuriercbi-sc.tfm)
Provides:       tex(l7x-kuriercbi.tfm)
Provides:       tex(l7x-kurierch-sc.tfm)
Provides:       tex(l7x-kurierch.tfm)
Provides:       tex(l7x-kurierchi-sc.tfm)
Provides:       tex(l7x-kurierchi.tfm)
Provides:       tex(l7x-kuriercl-sc.tfm)
Provides:       tex(l7x-kuriercl.tfm)
Provides:       tex(l7x-kuriercli-sc.tfm)
Provides:       tex(l7x-kuriercli.tfm)
Provides:       tex(l7x-kuriercm-sc.tfm)
Provides:       tex(l7x-kuriercm.tfm)
Provides:       tex(l7x-kuriercmi-sc.tfm)
Provides:       tex(l7x-kuriercmi.tfm)
Provides:       tex(l7x-kuriercr-sc.tfm)
Provides:       tex(l7x-kuriercr.tfm)
Provides:       tex(l7x-kuriercri-sc.tfm)
Provides:       tex(l7x-kuriercri.tfm)
Provides:       tex(l7x-kurierh-sc.tfm)
Provides:       tex(l7x-kurierh.tfm)
Provides:       tex(l7x-kurierhi-sc.tfm)
Provides:       tex(l7x-kurierhi.tfm)
Provides:       tex(l7x-kurierl-sc.tfm)
Provides:       tex(l7x-kurierl.tfm)
Provides:       tex(l7x-kurierli-sc.tfm)
Provides:       tex(l7x-kurierli.tfm)
Provides:       tex(l7x-kurierm-sc.tfm)
Provides:       tex(l7x-kurierm.tfm)
Provides:       tex(l7x-kuriermi-sc.tfm)
Provides:       tex(l7x-kuriermi.tfm)
Provides:       tex(l7x-kurierr-sc.tfm)
Provides:       tex(l7x-kurierr.tfm)
Provides:       tex(l7x-kurierri-sc.tfm)
Provides:       tex(l7x-kurierri.tfm)
Provides:       tex(l7xkurier.fd)
Provides:       tex(l7xkurierc.fd)
Provides:       tex(l7xkurierl.fd)
Provides:       tex(l7xkurierlc.fd)
Provides:       tex(ly1kurier.fd)
Provides:       tex(ly1kurierc.fd)
Provides:       tex(ly1kurierl.fd)
Provides:       tex(ly1kurierlc.fd)
Provides:       tex(mi-kurier.enc)
Provides:       tex(mi-kurierbi.tfm)
Provides:       tex(mi-kuriercbi.tfm)
Provides:       tex(mi-kurierchi.tfm)
Provides:       tex(mi-kuriercli.tfm)
Provides:       tex(mi-kuriercmi.tfm)
Provides:       tex(mi-kuriercri.tfm)
Provides:       tex(mi-kurierhi.tfm)
Provides:       tex(mi-kurierli.tfm)
Provides:       tex(mi-kuriermi.tfm)
Provides:       tex(mi-kurierri.tfm)
Provides:       tex(omlkurier.fd)
Provides:       tex(omlkurierc.fd)
Provides:       tex(omlkurierl.fd)
Provides:       tex(omlkurierlc.fd)
Provides:       tex(omskurier.fd)
Provides:       tex(omskurierc.fd)
Provides:       tex(omskurierl.fd)
Provides:       tex(omskurierlc.fd)
Provides:       tex(omxkurier.fd)
Provides:       tex(omxkurierc.fd)
Provides:       tex(omxkurierl.fd)
Provides:       tex(omxkurierlc.fd)
Provides:       tex(ot1kurier.fd)
Provides:       tex(ot1kurierc.fd)
Provides:       tex(ot1kuriercm.fd)
Provides:       tex(ot1kurierl.fd)
Provides:       tex(ot1kurierlc.fd)
Provides:       tex(ot1kurierlcm.fd)
Provides:       tex(ot1kurierlm.fd)
Provides:       tex(ot1kurierm.fd)
Provides:       tex(ot2kurier.fd)
Provides:       tex(ot2kurierc.fd)
Provides:       tex(ot2kurierl.fd)
Provides:       tex(ot2kurierlc.fd)
Provides:       tex(ot4kurier.fd)
Provides:       tex(ot4kurierc.fd)
Provides:       tex(ot4kurierl.fd)
Provides:       tex(ot4kurierlc.fd)
Provides:       tex(qx-kurier-sc.enc)
Provides:       tex(qx-kurier.enc)
Provides:       tex(qx-kurierb-sc.tfm)
Provides:       tex(qx-kurierb.tfm)
Provides:       tex(qx-kurierbi-sc.tfm)
Provides:       tex(qx-kurierbi.tfm)
Provides:       tex(qx-kuriercb-sc.tfm)
Provides:       tex(qx-kuriercb.tfm)
Provides:       tex(qx-kuriercbi-sc.tfm)
Provides:       tex(qx-kuriercbi.tfm)
Provides:       tex(qx-kurierch-sc.tfm)
Provides:       tex(qx-kurierch.tfm)
Provides:       tex(qx-kurierchi-sc.tfm)
Provides:       tex(qx-kurierchi.tfm)
Provides:       tex(qx-kuriercl-sc.tfm)
Provides:       tex(qx-kuriercl.tfm)
Provides:       tex(qx-kuriercli-sc.tfm)
Provides:       tex(qx-kuriercli.tfm)
Provides:       tex(qx-kuriercm-sc.tfm)
Provides:       tex(qx-kuriercm.tfm)
Provides:       tex(qx-kuriercmi-sc.tfm)
Provides:       tex(qx-kuriercmi.tfm)
Provides:       tex(qx-kuriercr-sc.tfm)
Provides:       tex(qx-kuriercr.tfm)
Provides:       tex(qx-kuriercri-sc.tfm)
Provides:       tex(qx-kuriercri.tfm)
Provides:       tex(qx-kurierh-sc.tfm)
Provides:       tex(qx-kurierh.tfm)
Provides:       tex(qx-kurierhi-sc.tfm)
Provides:       tex(qx-kurierhi.tfm)
Provides:       tex(qx-kurierl-sc.tfm)
Provides:       tex(qx-kurierl.tfm)
Provides:       tex(qx-kurierli-sc.tfm)
Provides:       tex(qx-kurierli.tfm)
Provides:       tex(qx-kurierm-sc.tfm)
Provides:       tex(qx-kurierm.tfm)
Provides:       tex(qx-kuriermi-sc.tfm)
Provides:       tex(qx-kuriermi.tfm)
Provides:       tex(qx-kurierr-sc.tfm)
Provides:       tex(qx-kurierr.tfm)
Provides:       tex(qx-kurierri-sc.tfm)
Provides:       tex(qx-kurierri.tfm)
Provides:       tex(qxkurier.fd)
Provides:       tex(qxkurierc.fd)
Provides:       tex(qxkurierl.fd)
Provides:       tex(qxkurierlc.fd)
Provides:       tex(rm-kurier-sc.enc)
Provides:       tex(rm-kurier.enc)
Provides:       tex(rm-kurierb-sc.tfm)
Provides:       tex(rm-kurierb.tfm)
Provides:       tex(rm-kurierbi-sc.tfm)
Provides:       tex(rm-kurierbi.tfm)
Provides:       tex(rm-kuriercb-sc.tfm)
Provides:       tex(rm-kuriercb.tfm)
Provides:       tex(rm-kuriercbi-sc.tfm)
Provides:       tex(rm-kuriercbi.tfm)
Provides:       tex(rm-kurierch-sc.tfm)
Provides:       tex(rm-kurierch.tfm)
Provides:       tex(rm-kurierchi-sc.tfm)
Provides:       tex(rm-kurierchi.tfm)
Provides:       tex(rm-kuriercl-sc.tfm)
Provides:       tex(rm-kuriercl.tfm)
Provides:       tex(rm-kuriercli-sc.tfm)
Provides:       tex(rm-kuriercli.tfm)
Provides:       tex(rm-kuriercm-sc.tfm)
Provides:       tex(rm-kuriercm.tfm)
Provides:       tex(rm-kuriercmi-sc.tfm)
Provides:       tex(rm-kuriercmi.tfm)
Provides:       tex(rm-kuriercr-sc.tfm)
Provides:       tex(rm-kuriercr.tfm)
Provides:       tex(rm-kuriercri-sc.tfm)
Provides:       tex(rm-kuriercri.tfm)
Provides:       tex(rm-kurierh-sc.tfm)
Provides:       tex(rm-kurierh.tfm)
Provides:       tex(rm-kurierhi-sc.tfm)
Provides:       tex(rm-kurierhi.tfm)
Provides:       tex(rm-kurierl-sc.tfm)
Provides:       tex(rm-kurierl.tfm)
Provides:       tex(rm-kurierli-sc.tfm)
Provides:       tex(rm-kurierli.tfm)
Provides:       tex(rm-kurierm-sc.tfm)
Provides:       tex(rm-kurierm.tfm)
Provides:       tex(rm-kuriermi-sc.tfm)
Provides:       tex(rm-kuriermi.tfm)
Provides:       tex(rm-kurierr-sc.tfm)
Provides:       tex(rm-kurierr.tfm)
Provides:       tex(rm-kurierri-sc.tfm)
Provides:       tex(rm-kurierri.tfm)
Provides:       tex(sy-kurier.enc)
Provides:       tex(sy-kurierbz.tfm)
Provides:       tex(sy-kuriercbz.tfm)
Provides:       tex(sy-kurierchz.tfm)
Provides:       tex(sy-kurierclz.tfm)
Provides:       tex(sy-kuriercmz.tfm)
Provides:       tex(sy-kuriercrz.tfm)
Provides:       tex(sy-kurierhz.tfm)
Provides:       tex(sy-kurierlz.tfm)
Provides:       tex(sy-kuriermz.tfm)
Provides:       tex(sy-kurierrz.tfm)
Provides:       tex(t1kurier.fd)
Provides:       tex(t1kurierc.fd)
Provides:       tex(t1kurierl.fd)
Provides:       tex(t1kurierlc.fd)
Provides:       tex(t2a-kurier.enc)
Provides:       tex(t2a-kurierb.tfm)
Provides:       tex(t2a-kurierbi.tfm)
Provides:       tex(t2a-kuriercb.tfm)
Provides:       tex(t2a-kuriercbi.tfm)
Provides:       tex(t2a-kurierch.tfm)
Provides:       tex(t2a-kurierchi.tfm)
Provides:       tex(t2a-kuriercl.tfm)
Provides:       tex(t2a-kuriercli.tfm)
Provides:       tex(t2a-kuriercm.tfm)
Provides:       tex(t2a-kuriercmi.tfm)
Provides:       tex(t2a-kuriercr.tfm)
Provides:       tex(t2a-kuriercri.tfm)
Provides:       tex(t2a-kurierh.tfm)
Provides:       tex(t2a-kurierhi.tfm)
Provides:       tex(t2a-kurierl.tfm)
Provides:       tex(t2a-kurierli.tfm)
Provides:       tex(t2a-kurierm.tfm)
Provides:       tex(t2a-kuriermi.tfm)
Provides:       tex(t2a-kurierr.tfm)
Provides:       tex(t2a-kurierri.tfm)
Provides:       tex(t2akurier.fd)
Provides:       tex(t2akurierc.fd)
Provides:       tex(t2akurierl.fd)
Provides:       tex(t2akurierlc.fd)
Provides:       tex(t2b-kurier.enc)
Provides:       tex(t2b-kurierb.tfm)
Provides:       tex(t2b-kurierbi.tfm)
Provides:       tex(t2b-kuriercb.tfm)
Provides:       tex(t2b-kuriercbi.tfm)
Provides:       tex(t2b-kurierch.tfm)
Provides:       tex(t2b-kurierchi.tfm)
Provides:       tex(t2b-kuriercl.tfm)
Provides:       tex(t2b-kuriercli.tfm)
Provides:       tex(t2b-kuriercm.tfm)
Provides:       tex(t2b-kuriercmi.tfm)
Provides:       tex(t2b-kuriercr.tfm)
Provides:       tex(t2b-kuriercri.tfm)
Provides:       tex(t2b-kurierh.tfm)
Provides:       tex(t2b-kurierhi.tfm)
Provides:       tex(t2b-kurierl.tfm)
Provides:       tex(t2b-kurierli.tfm)
Provides:       tex(t2b-kurierm.tfm)
Provides:       tex(t2b-kuriermi.tfm)
Provides:       tex(t2b-kurierr.tfm)
Provides:       tex(t2b-kurierri.tfm)
Provides:       tex(t2bkurier.fd)
Provides:       tex(t2bkurierc.fd)
Provides:       tex(t2bkurierl.fd)
Provides:       tex(t2bkurierlc.fd)
Provides:       tex(t2c-kurier.enc)
Provides:       tex(t2c-kurierb.tfm)
Provides:       tex(t2c-kurierbi.tfm)
Provides:       tex(t2c-kuriercb.tfm)
Provides:       tex(t2c-kuriercbi.tfm)
Provides:       tex(t2c-kurierch.tfm)
Provides:       tex(t2c-kurierchi.tfm)
Provides:       tex(t2c-kuriercl.tfm)
Provides:       tex(t2c-kuriercli.tfm)
Provides:       tex(t2c-kuriercm.tfm)
Provides:       tex(t2c-kuriercmi.tfm)
Provides:       tex(t2c-kuriercr.tfm)
Provides:       tex(t2c-kuriercri.tfm)
Provides:       tex(t2c-kurierh.tfm)
Provides:       tex(t2c-kurierhi.tfm)
Provides:       tex(t2c-kurierl.tfm)
Provides:       tex(t2c-kurierli.tfm)
Provides:       tex(t2c-kurierm.tfm)
Provides:       tex(t2c-kuriermi.tfm)
Provides:       tex(t2c-kurierr.tfm)
Provides:       tex(t2c-kurierri.tfm)
Provides:       tex(t2ckurier.fd)
Provides:       tex(t2ckurierc.fd)
Provides:       tex(t2ckurierl.fd)
Provides:       tex(t2ckurierlc.fd)
Provides:       tex(t5-kurier-sc.enc)
Provides:       tex(t5-kurier.enc)
Provides:       tex(t5-kurierb-sc.tfm)
Provides:       tex(t5-kurierb.tfm)
Provides:       tex(t5-kurierbi-sc.tfm)
Provides:       tex(t5-kurierbi.tfm)
Provides:       tex(t5-kuriercb-sc.tfm)
Provides:       tex(t5-kuriercb.tfm)
Provides:       tex(t5-kuriercbi-sc.tfm)
Provides:       tex(t5-kuriercbi.tfm)
Provides:       tex(t5-kurierch-sc.tfm)
Provides:       tex(t5-kurierch.tfm)
Provides:       tex(t5-kurierchi-sc.tfm)
Provides:       tex(t5-kurierchi.tfm)
Provides:       tex(t5-kuriercl-sc.tfm)
Provides:       tex(t5-kuriercl.tfm)
Provides:       tex(t5-kuriercli-sc.tfm)
Provides:       tex(t5-kuriercli.tfm)
Provides:       tex(t5-kuriercm-sc.tfm)
Provides:       tex(t5-kuriercm.tfm)
Provides:       tex(t5-kuriercmi-sc.tfm)
Provides:       tex(t5-kuriercmi.tfm)
Provides:       tex(t5-kuriercr-sc.tfm)
Provides:       tex(t5-kuriercr.tfm)
Provides:       tex(t5-kuriercri-sc.tfm)
Provides:       tex(t5-kuriercri.tfm)
Provides:       tex(t5-kurierh-sc.tfm)
Provides:       tex(t5-kurierh.tfm)
Provides:       tex(t5-kurierhi-sc.tfm)
Provides:       tex(t5-kurierhi.tfm)
Provides:       tex(t5-kurierl-sc.tfm)
Provides:       tex(t5-kurierl.tfm)
Provides:       tex(t5-kurierli-sc.tfm)
Provides:       tex(t5-kurierli.tfm)
Provides:       tex(t5-kurierm-sc.tfm)
Provides:       tex(t5-kurierm.tfm)
Provides:       tex(t5-kuriermi-sc.tfm)
Provides:       tex(t5-kuriermi.tfm)
Provides:       tex(t5-kurierr-sc.tfm)
Provides:       tex(t5-kurierr.tfm)
Provides:       tex(t5-kurierri-sc.tfm)
Provides:       tex(t5-kurierri.tfm)
Provides:       tex(t5kurier.fd)
Provides:       tex(t5kurierc.fd)
Provides:       tex(t5kurierl.fd)
Provides:       tex(t5kurierlc.fd)
Provides:       tex(texnansi-kurier-sc.enc)
Provides:       tex(texnansi-kurier.enc)
Provides:       tex(texnansi-kurierb-sc.tfm)
Provides:       tex(texnansi-kurierb.tfm)
Provides:       tex(texnansi-kurierbi-sc.tfm)
Provides:       tex(texnansi-kurierbi.tfm)
Provides:       tex(texnansi-kuriercb-sc.tfm)
Provides:       tex(texnansi-kuriercb.tfm)
Provides:       tex(texnansi-kuriercbi-sc.tfm)
Provides:       tex(texnansi-kuriercbi.tfm)
Provides:       tex(texnansi-kurierch-sc.tfm)
Provides:       tex(texnansi-kurierch.tfm)
Provides:       tex(texnansi-kurierchi-sc.tfm)
Provides:       tex(texnansi-kurierchi.tfm)
Provides:       tex(texnansi-kuriercl-sc.tfm)
Provides:       tex(texnansi-kuriercl.tfm)
Provides:       tex(texnansi-kuriercli-sc.tfm)
Provides:       tex(texnansi-kuriercli.tfm)
Provides:       tex(texnansi-kuriercm-sc.tfm)
Provides:       tex(texnansi-kuriercm.tfm)
Provides:       tex(texnansi-kuriercmi-sc.tfm)
Provides:       tex(texnansi-kuriercmi.tfm)
Provides:       tex(texnansi-kuriercr-sc.tfm)
Provides:       tex(texnansi-kuriercr.tfm)
Provides:       tex(texnansi-kuriercri-sc.tfm)
Provides:       tex(texnansi-kuriercri.tfm)
Provides:       tex(texnansi-kurierh-sc.tfm)
Provides:       tex(texnansi-kurierh.tfm)
Provides:       tex(texnansi-kurierhi-sc.tfm)
Provides:       tex(texnansi-kurierhi.tfm)
Provides:       tex(texnansi-kurierl-sc.tfm)
Provides:       tex(texnansi-kurierl.tfm)
Provides:       tex(texnansi-kurierli-sc.tfm)
Provides:       tex(texnansi-kurierli.tfm)
Provides:       tex(texnansi-kurierm-sc.tfm)
Provides:       tex(texnansi-kurierm.tfm)
Provides:       tex(texnansi-kuriermi-sc.tfm)
Provides:       tex(texnansi-kuriermi.tfm)
Provides:       tex(texnansi-kurierr-sc.tfm)
Provides:       tex(texnansi-kurierr.tfm)
Provides:       tex(texnansi-kurierri-sc.tfm)
Provides:       tex(texnansi-kurierri.tfm)
Provides:       tex(ts1-kurier.enc)
Provides:       tex(ts1-kurierb.tfm)
Provides:       tex(ts1-kurierbi.tfm)
Provides:       tex(ts1-kuriercb.tfm)
Provides:       tex(ts1-kuriercbi.tfm)
Provides:       tex(ts1-kurierch.tfm)
Provides:       tex(ts1-kurierchi.tfm)
Provides:       tex(ts1-kuriercl.tfm)
Provides:       tex(ts1-kuriercli.tfm)
Provides:       tex(ts1-kuriercm.tfm)
Provides:       tex(ts1-kuriercmi.tfm)
Provides:       tex(ts1-kuriercr.tfm)
Provides:       tex(ts1-kuriercri.tfm)
Provides:       tex(ts1-kurierh.tfm)
Provides:       tex(ts1-kurierhi.tfm)
Provides:       tex(ts1-kurierl.tfm)
Provides:       tex(ts1-kurierli.tfm)
Provides:       tex(ts1-kurierm.tfm)
Provides:       tex(ts1-kuriermi.tfm)
Provides:       tex(ts1-kurierr.tfm)
Provides:       tex(ts1-kurierri.tfm)
Provides:       tex(ts1kurier.fd)
Provides:       tex(ts1kurierc.fd)
Provides:       tex(ts1kurierl.fd)
Provides:       tex(ts1kurierlc.fd)
Provides:       tex(wncy-kurier.enc)
Provides:       tex(wncy-kurierb.tfm)
Provides:       tex(wncy-kurierbi.tfm)
Provides:       tex(wncy-kuriercb.tfm)
Provides:       tex(wncy-kuriercbi.tfm)
Provides:       tex(wncy-kurierch.tfm)
Provides:       tex(wncy-kurierchi.tfm)
Provides:       tex(wncy-kuriercl.tfm)
Provides:       tex(wncy-kuriercli.tfm)
Provides:       tex(wncy-kuriercm.tfm)
Provides:       tex(wncy-kuriercmi.tfm)
Provides:       tex(wncy-kuriercr.tfm)
Provides:       tex(wncy-kuriercri.tfm)
Provides:       tex(wncy-kurierh.tfm)
Provides:       tex(wncy-kurierhi.tfm)
Provides:       tex(wncy-kurierl.tfm)
Provides:       tex(wncy-kurierli.tfm)
Provides:       tex(wncy-kurierm.tfm)
Provides:       tex(wncy-kuriermi.tfm)
Provides:       tex(wncy-kurierr.tfm)
Provides:       tex(wncy-kurierri.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source221:      kurier.tar.xz
Source222:      kurier.doc.tar.xz

%description -n texlive-kurier
Kurier is a two-element sans-serif typeface. It was designed
for a diploma in typeface design at the Warsaw Academy of Fine
Arts under the supervision of Roman Tomaszewski. This
distribution contains a significantly extended set of
characters covering the following modern alphabets: latin
(including Vietnamese), Cyrillic and Greek as well as a number
of additional symbols (including mathematical symbols). The
fonts are prepared in Type 1 and OpenType formats. For use with
TeX the following encoding files have been prepared: T1 (ec),
T2 (abc), and OT2--Cyrillic, T5 (Vietnamese), OT4, QX, texansi
and--nonstandard (IL2 for the Czech fonts), as well as
supporting macros and files defining fonts for LaTeX.

%package -n texlive-kurier-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19612
Release:        0
Summary:        Documentation for texlive-kurier
License:        LPPL-1.3c
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kurier and texlive-alldocumentation)
Provides:       locale(texlive-kurier-doc:en;pl)

%description -n texlive-kurier-doc
This package includes the documentation for texlive-kurier

%package -n texlive-kurier-fonts
Version:        %{texlive_version}.%{texlive_noarch}.0.0.995bsvn19612
Release:        0
Summary:        Severed fonts for texlive-kurier
License:        LPPL-1.3c
URL:            https://www.tug.org/texlive/
Group:          Productivity/Publishing/TeX/Fonts
%reconfigure_fonts_prereq
Requires(posttrans):fontconfig
Requires(posttrans):ghostscript-fonts-std
Suggests:       xorg-x11-fonts-core

%description -n texlive-kurier-fonts
The  separated fonts package for texlive-kurier

%post -n texlive-kurier
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
echo 'addMap kurier.map' >> /var/run/texlive/run-updmap

%postun -n texlive-kurier
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    echo 'deleteMap kurier.map' >> /var/run/texlive/run-updmap
    exit 0
fi

%posttrans -n texlive-kurier
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%reconfigure_fonts_scriptlets -n texlive-kurier-fonts

%files -n texlive-kurier-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/kurier/00readme.eng
%{_texmfdistdir}/doc/fonts/kurier/00readme.pol
%{_texmfdistdir}/doc/fonts/kurier/GUST-FONT-LICENSE.txt
%{_texmfdistdir}/doc/fonts/kurier/kurier-info-src.zip
%{_texmfdistdir}/doc/fonts/kurier/kurier-info.pdf
%{_texmfdistdir}/doc/fonts/kurier/kurier-latex-cyr.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-latex-math.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-latex-pl.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-latex-t2a.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-latex-t5.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-mathtest.tex
%{_texmfdistdir}/doc/fonts/kurier/kurier-table.tex
%{_texmfdistdir}/doc/fonts/kurier/manifest.txt

%files -n texlive-kurier
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierb.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierbi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercb.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercbi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierch.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierchi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercl.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercli.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercm.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercmi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercr.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriercri.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierh.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierhi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierl.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierli.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierm.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kuriermi.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierr.afm
%{_texmfdistdir}/fonts/afm/nowacki/kurier/kurierri.afm
%{_texmfdistdir}/fonts/enc/dvips/kurier/cs-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/cs-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/ec-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/ec-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/ex-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/greek-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/l7x-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/l7x-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/mi-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/qx-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/qx-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/rm-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/rm-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/sy-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/t2a-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/t2b-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/t2c-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/t5-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/t5-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/texnansi-kurier-sc.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/texnansi-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/ts1-kurier.enc
%{_texmfdistdir}/fonts/enc/dvips/kurier/wncy-kurier.enc
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-cs.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-ec.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-ex.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-greek.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-l7x.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-mi.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-qx.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-rm.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-sy.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-t2a.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-t2b.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-t2c.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-t5.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-texnansi.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-ts1.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier-wncy.map
%{_texmfdistdir}/fonts/map/dvips/kurier/kurier.map
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/Kurier-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/Kurier-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/Kurier-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/Kurier-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCond-Bold.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCond-BoldItalic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCond-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCond-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondHeavy-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondHeavy-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondLight-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondLight-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondMedium-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierCondMedium-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierHeavy-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierHeavy-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierLight-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierLight-Regular.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierMedium-Italic.otf
%verify(link) %{_texmfdistdir}/fonts/opentype/nowacki/kurier/KurierMedium-Regular.otf
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/cs-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ec-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ex-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/greek-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/l7x-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/mi-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/qx-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/rm-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierbz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kuriercbz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierchz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierclz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kuriercmz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kuriercrz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierhz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierlz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kuriermz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/sy-kurierrz.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2a-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2b-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t2c-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/t5-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercb-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercbi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierch-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierchi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercmi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierh-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierhi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierl-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierli-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierm-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriermi-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierr-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierri-sc.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/texnansi-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/ts1-kurierri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercb.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercbi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierch.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierchi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercmi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriercri.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierh.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierhi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierl.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierli.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierm.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kuriermi.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierr.tfm
%{_texmfdistdir}/fonts/tfm/nowacki/kurier/wncy-kurierri.tfm
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierbi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercb.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercbi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierch.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierchi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercl.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercli.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercm.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercmi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercr.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriercri.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierh.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierhi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierl.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierli.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierm.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kuriermi.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierr.pfb
%verify(link) %{_texmfdistdir}/fonts/type1/nowacki/kurier/kurierri.pfb
%{_texmfdistdir}/tex/latex/kurier/il2kurier.fd
%{_texmfdistdir}/tex/latex/kurier/il2kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/il2kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/il2kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/kurier.sty
%{_texmfdistdir}/tex/latex/kurier/l7xkurier.fd
%{_texmfdistdir}/tex/latex/kurier/l7xkurierc.fd
%{_texmfdistdir}/tex/latex/kurier/l7xkurierl.fd
%{_texmfdistdir}/tex/latex/kurier/l7xkurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/ly1kurier.fd
%{_texmfdistdir}/tex/latex/kurier/ly1kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/ly1kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/ly1kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/omlkurier.fd
%{_texmfdistdir}/tex/latex/kurier/omlkurierc.fd
%{_texmfdistdir}/tex/latex/kurier/omlkurierl.fd
%{_texmfdistdir}/tex/latex/kurier/omlkurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/omskurier.fd
%{_texmfdistdir}/tex/latex/kurier/omskurierc.fd
%{_texmfdistdir}/tex/latex/kurier/omskurierl.fd
%{_texmfdistdir}/tex/latex/kurier/omskurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/omxkurier.fd
%{_texmfdistdir}/tex/latex/kurier/omxkurierc.fd
%{_texmfdistdir}/tex/latex/kurier/omxkurierl.fd
%{_texmfdistdir}/tex/latex/kurier/omxkurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurier.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kuriercm.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierlcm.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierlm.fd
%{_texmfdistdir}/tex/latex/kurier/ot1kurierm.fd
%{_texmfdistdir}/tex/latex/kurier/ot2kurier.fd
%{_texmfdistdir}/tex/latex/kurier/ot2kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/ot2kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/ot2kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/ot4kurier.fd
%{_texmfdistdir}/tex/latex/kurier/ot4kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/ot4kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/ot4kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/qxkurier.fd
%{_texmfdistdir}/tex/latex/kurier/qxkurierc.fd
%{_texmfdistdir}/tex/latex/kurier/qxkurierl.fd
%{_texmfdistdir}/tex/latex/kurier/qxkurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/t1kurier.fd
%{_texmfdistdir}/tex/latex/kurier/t1kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/t1kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/t1kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/t2akurier.fd
%{_texmfdistdir}/tex/latex/kurier/t2akurierc.fd
%{_texmfdistdir}/tex/latex/kurier/t2akurierl.fd
%{_texmfdistdir}/tex/latex/kurier/t2akurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/t2bkurier.fd
%{_texmfdistdir}/tex/latex/kurier/t2bkurierc.fd
%{_texmfdistdir}/tex/latex/kurier/t2bkurierl.fd
%{_texmfdistdir}/tex/latex/kurier/t2bkurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/t2ckurier.fd
%{_texmfdistdir}/tex/latex/kurier/t2ckurierc.fd
%{_texmfdistdir}/tex/latex/kurier/t2ckurierl.fd
%{_texmfdistdir}/tex/latex/kurier/t2ckurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/t5kurier.fd
%{_texmfdistdir}/tex/latex/kurier/t5kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/t5kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/t5kurierlc.fd
%{_texmfdistdir}/tex/latex/kurier/ts1kurier.fd
%{_texmfdistdir}/tex/latex/kurier/ts1kurierc.fd
%{_texmfdistdir}/tex/latex/kurier/ts1kurierl.fd
%{_texmfdistdir}/tex/latex/kurier/ts1kurierlc.fd
%{_texmfdistdir}/tex/plain/kurier/kurier-math.tex

%files -n texlive-kurier-fonts
%defattr(-,root,root,755)
%dir %{_datadir}/fonts/texlive-kurier
%{_datadir}/fontconfig/conf.avail/58-texlive-kurier.conf
%{_datadir}/fontconfig/conf.avail/55-texlive-kurier.conf
%config %{_sysconfdir}/fonts/conf.d/55-texlive-kurier.conf
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kurier/encodings.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kurier/fonts.dir
%verify(not md5 size mtime) %{_datadir}/fonts/texlive-kurier/fonts.scale
%{_datadir}/fonts/texlive-kurier/Kurier-Bold.otf
%{_datadir}/fonts/texlive-kurier/Kurier-BoldItalic.otf
%{_datadir}/fonts/texlive-kurier/Kurier-Italic.otf
%{_datadir}/fonts/texlive-kurier/Kurier-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierCond-Bold.otf
%{_datadir}/fonts/texlive-kurier/KurierCond-BoldItalic.otf
%{_datadir}/fonts/texlive-kurier/KurierCond-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierCond-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierCondHeavy-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierCondHeavy-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierCondLight-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierCondLight-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierCondMedium-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierCondMedium-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierHeavy-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierHeavy-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierLight-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierLight-Regular.otf
%{_datadir}/fonts/texlive-kurier/KurierMedium-Italic.otf
%{_datadir}/fonts/texlive-kurier/KurierMedium-Regular.otf
%{_datadir}/fonts/texlive-kurier/kurierb.pfb
%{_datadir}/fonts/texlive-kurier/kurierbi.pfb
%{_datadir}/fonts/texlive-kurier/kuriercb.pfb
%{_datadir}/fonts/texlive-kurier/kuriercbi.pfb
%{_datadir}/fonts/texlive-kurier/kurierch.pfb
%{_datadir}/fonts/texlive-kurier/kurierchi.pfb
%{_datadir}/fonts/texlive-kurier/kuriercl.pfb
%{_datadir}/fonts/texlive-kurier/kuriercli.pfb
%{_datadir}/fonts/texlive-kurier/kuriercm.pfb
%{_datadir}/fonts/texlive-kurier/kuriercmi.pfb
%{_datadir}/fonts/texlive-kurier/kuriercr.pfb
%{_datadir}/fonts/texlive-kurier/kuriercri.pfb
%{_datadir}/fonts/texlive-kurier/kurierh.pfb
%{_datadir}/fonts/texlive-kurier/kurierhi.pfb
%{_datadir}/fonts/texlive-kurier/kurierl.pfb
%{_datadir}/fonts/texlive-kurier/kurierli.pfb
%{_datadir}/fonts/texlive-kurier/kurierm.pfb
%{_datadir}/fonts/texlive-kurier/kuriermi.pfb
%{_datadir}/fonts/texlive-kurier/kurierr.pfb
%{_datadir}/fonts/texlive-kurier/kurierri.pfb

%package -n texlive-kvdefinekeys
Version:        %{texlive_version}.%{texlive_noarch}.1.6svn53193
Release:        0
License:        LPPL-1.0
Summary:        Define keys for use in the kvsetkeys package
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kvdefinekeys-doc >= %{texlive_version}
Provides:       tex(kvdefinekeys.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source223:      kvdefinekeys.tar.xz
Source224:      kvdefinekeys.doc.tar.xz

%description -n texlive-kvdefinekeys
The package provides a macro \kv@define@key (analogous to
keyval's \define@key, to define keys for use by kvsetkeys.

%package -n texlive-kvdefinekeys-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.6svn53193
Release:        0
Summary:        Documentation for texlive-kvdefinekeys
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kvdefinekeys and texlive-alldocumentation)

%description -n texlive-kvdefinekeys-doc
This package includes the documentation for texlive-kvdefinekeys

%post -n texlive-kvdefinekeys
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kvdefinekeys
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kvdefinekeys
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kvdefinekeys-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kvdefinekeys/README.md
%{_texmfdistdir}/doc/latex/kvdefinekeys/kvdefinekeys.pdf

%files -n texlive-kvdefinekeys
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/generic/kvdefinekeys/kvdefinekeys.sty

%package -n texlive-kvmap
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.5svn56361
Release:        0
License:        LPPL-1.0
Summary:        Create Karnaugh maps with LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-amsmath >= %{texlive_version}
#!BuildIgnore: texlive-amsmath
Requires:       texlive-l3experimental >= %{texlive_version}
#!BuildIgnore: texlive-l3experimental
Requires:       texlive-pgf >= %{texlive_version}
#!BuildIgnore: texlive-pgf
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kvmap-doc >= %{texlive_version}
Provides:       tex(kvmap.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(expl3.sty)
Requires:       tex(tikz.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source225:      kvmap.tar.xz
Source226:      kvmap.doc.tar.xz

%description -n texlive-kvmap
This LaTeX package allows the creation of (even large) Karnaugh
maps. It provides a tabular-like input syntax and support for
drawing bundles (implicants) around adjacent values. It is
based on an answer at StackExchange.

%package -n texlive-kvmap-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.5svn56361
Release:        0
Summary:        Documentation for texlive-kvmap
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kvmap and texlive-alldocumentation)

%description -n texlive-kvmap-doc
This package includes the documentation for texlive-kvmap

%post -n texlive-kvmap
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kvmap
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kvmap
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kvmap-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kvmap/DEPENDS.txt
%{_texmfdistdir}/doc/latex/kvmap/README.md
%{_texmfdistdir}/doc/latex/kvmap/kvmap.pdf

%files -n texlive-kvmap
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kvmap/kvmap.sty

%package -n texlive-kvoptions
Version:        %{texlive_version}.%{texlive_noarch}.3.15svn63622
Release:        0
License:        LPPL-1.0
Summary:        Key value format for package options
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kvoptions-doc >= %{texlive_version}
Provides:       tex(kvoptions-patch.sty)
Provides:       tex(kvoptions.sty)
Requires:       tex(etexcmds.sty)
Requires:       tex(keyval.sty)
Requires:       tex(kvsetkeys.sty)
Requires:       tex(ltxcmds.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source227:      kvoptions.tar.xz
Source228:      kvoptions.doc.tar.xz

%description -n texlive-kvoptions
This package offers support for package authors who want to use
options in key-value format for their package options.

%package -n texlive-kvoptions-doc
Version:        %{texlive_version}.%{texlive_noarch}.3.15svn63622
Release:        0
Summary:        Documentation for texlive-kvoptions
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kvoptions and texlive-alldocumentation)
Provides:       locale(texlive-kvoptions-doc:en)

%description -n texlive-kvoptions-doc
This package includes the documentation for texlive-kvoptions

%post -n texlive-kvoptions
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kvoptions
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kvoptions
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kvoptions-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kvoptions/README.md
%{_texmfdistdir}/doc/latex/kvoptions/example-mycolorsetup.sty
%{_texmfdistdir}/doc/latex/kvoptions/kvoptions.pdf

%files -n texlive-kvoptions
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kvoptions/kvoptions-patch.sty
%{_texmfdistdir}/tex/latex/kvoptions/kvoptions.sty

%package -n texlive-kvsetkeys
Version:        %{texlive_version}.%{texlive_noarch}.1.19svn64632
Release:        0
License:        LPPL-1.0
Summary:        Key value parser with default handler support
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-kvsetkeys-doc >= %{texlive_version}
Provides:       tex(kvsetkeys.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source229:      kvsetkeys.tar.xz
Source230:      kvsetkeys.doc.tar.xz

%description -n texlive-kvsetkeys
This package provides \kvsetkeys, a variant of package keyval's
\setkeys. It allows the user to specify a handler that deals
with unknown options. Active commas and equal signs may be used
(e.g. see babel's shorthands) and only one level of curly
braces are removed from the values.

%package -n texlive-kvsetkeys-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.19svn64632
Release:        0
Summary:        Documentation for texlive-kvsetkeys
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-kvsetkeys and texlive-alldocumentation)
Provides:       locale(texlive-kvsetkeys-doc:en)

%description -n texlive-kvsetkeys-doc
This package includes the documentation for texlive-kvsetkeys

%post -n texlive-kvsetkeys
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-kvsetkeys
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-kvsetkeys
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-kvsetkeys-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/kvsetkeys/README.md
%{_texmfdistdir}/doc/latex/kvsetkeys/kvsetkeys-example.tex
%{_texmfdistdir}/doc/latex/kvsetkeys/kvsetkeys.pdf

%files -n texlive-kvsetkeys
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/kvsetkeys/kvsetkeys.sty

%package -n texlive-l2picfaq
Version:        %{texlive_version}.%{texlive_noarch}.1.50svn19601
Release:        0
License:        GFDL-1.3-or-later
Summary:        LaTeX pictures "how-to" (German)
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source231:      l2picfaq.doc.tar.xz

%description -n texlive-l2picfaq
The document (in German) is a collection of "how-to" notes
about LaTeX and pictures. The aim of the document is to provide
a solution, in the form of some sample code, for every problem.

%post -n texlive-l2picfaq
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2picfaq
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2picfaq
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2picfaq
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2picfaq/README
%{_texmfdistdir}/doc/latex/l2picfaq/ctanlion.pdf
%{_texmfdistdir}/doc/latex/l2picfaq/gfdl.tex
%{_texmfdistdir}/doc/latex/l2picfaq/l2picfaq.pdf
%{_texmfdistdir}/doc/latex/l2picfaq/l2picfaq.tex

%package -n texlive-l2tabu
Version:        %{texlive_version}.%{texlive_noarch}.2.4svn63708
Release:        0
License:        LPPL-1.0
Summary:        Obsolete packages and commands
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source232:      l2tabu.doc.tar.xz

%description -n texlive-l2tabu
The "sins" of LaTeX users, and how to correct them. The
document provides a list of obsolete packages and commands.
This original is in German; it has been translated into
English, French, Italian, and Spanish.

%post -n texlive-l2tabu
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2tabu
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2tabu
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2tabu
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2tabu/CHANGES
%{_texmfdistdir}/doc/latex/l2tabu/README
%{_texmfdistdir}/doc/latex/l2tabu/l2tabu.pdf
%{_texmfdistdir}/doc/latex/l2tabu/l2tabu.tex

%package -n texlive-l2tabu-english
Version:        %{texlive_version}.%{texlive_noarch}.1.8.5.7svn15878
Release:        0
License:        GPL-2.0-or-later
Summary:        English translation of "Obsolete packages and commands"
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source233:      l2tabu-english.doc.tar.xz

%description -n texlive-l2tabu-english
English translation of the l2tabu practical guide to LaTeX2e by
Mark Trettin. A list of obsolete packages and commands.

%post -n texlive-l2tabu-english
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2tabu-english
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2tabu-english
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2tabu-english
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2tabu-english/l2tabuen.pdf
%{_texmfdistdir}/doc/latex/l2tabu-english/l2tabuen.tex

%package -n texlive-l2tabu-french
Version:        %{texlive_version}.%{texlive_noarch}.2.3svn31315
Release:        0
License:        GPL-2.0-or-later
Summary:        French translation of l2tabu
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source234:      l2tabu-french.doc.tar.xz

%description -n texlive-l2tabu-french
French translation of l2tabu.

%post -n texlive-l2tabu-french
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2tabu-french
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2tabu-french
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2tabu-french
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2tabu-french/README
%{_texmfdistdir}/doc/latex/l2tabu-french/l2tabufr.pdf
%{_texmfdistdir}/doc/latex/l2tabu-french/l2tabufr.tex

%package -n texlive-l2tabu-italian
Version:        %{texlive_version}.%{texlive_noarch}.2.3svn25218
Release:        0
License:        LPPL-1.0
Summary:        Italian Translation of Obsolete packages and commands
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source235:      l2tabu-italian.doc.tar.xz

%description -n texlive-l2tabu-italian
Italian translation of the l2tabu practical guide to LaTeX2e (a
list of obsolete packages and commands).

%post -n texlive-l2tabu-italian
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2tabu-italian
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2tabu-italian
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2tabu-italian
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2tabu-italian/l2tabuit.pdf
%{_texmfdistdir}/doc/latex/l2tabu-italian/l2tabuit.tex

%package -n texlive-l2tabu-spanish
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn15878
Release:        0
License:        SUSE-Public-Domain
Summary:        Spanish translation of "Obsolete packages and commands"
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source236:      l2tabu-spanish.doc.tar.xz

%description -n texlive-l2tabu-spanish
A Spanish translation of the l2tabu practical guide to LaTeX2e
by Mark Trettin. A list of obsolete packages, commands and
usages.

%post -n texlive-l2tabu-spanish
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l2tabu-spanish
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l2tabu-spanish
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l2tabu-spanish
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l2tabu-spanish/README
%{_texmfdistdir}/doc/latex/l2tabu-spanish/l2tabues.pdf
%{_texmfdistdir}/doc/latex/l2tabu-spanish/l2tabues.tex

%package -n texlive-l3backend
Version:        %{texlive_version}.%{texlive_noarch}.svn65573
Release:        0
License:        LPPL-1.0
Summary:        LaTeX3 backend drivers
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-l3backend-doc >= %{texlive_version}
Provides:       tex(l3backend-dvipdfmx.def)
Provides:       tex(l3backend-dvips.def)
Provides:       tex(l3backend-dvisvgm.def)
Provides:       tex(l3backend-luatex.def)
Provides:       tex(l3backend-pdftex.def)
Provides:       tex(l3backend-xetex.def)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source237:      l3backend.tar.xz
Source238:      l3backend.doc.tar.xz

%description -n texlive-l3backend
This package forms parts of expl3, and contains the code used
to interface with backends (drivers) across the expl3 codebase.
The functions here are defined differently depending on the
engine in use. As such, these are distributed separately from
l3kernel to allow this code to be updated on an independent
schedule.

%package -n texlive-l3backend-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65573
Release:        0
Summary:        Documentation for texlive-l3backend
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-l3backend and texlive-alldocumentation)

%description -n texlive-l3backend-doc
This package includes the documentation for texlive-l3backend

%post -n texlive-l3backend
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l3backend
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l3backend
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l3backend-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l3backend/CHANGELOG.md
%{_texmfdistdir}/doc/latex/l3backend/README.md
%{_texmfdistdir}/doc/latex/l3backend/l3backend-code.pdf
%{_texmfdistdir}/doc/latex/l3backend/l3backend-code.tex

%files -n texlive-l3backend
%defattr(-,root,root,755)
%{_texmfdistdir}/dvips/l3backend/l3backend-dvips.pro
%{_texmfdistdir}/tex/latex/l3backend/l3backend-dvipdfmx.def
%{_texmfdistdir}/tex/latex/l3backend/l3backend-dvips.def
%{_texmfdistdir}/tex/latex/l3backend/l3backend-dvisvgm.def
%{_texmfdistdir}/tex/latex/l3backend/l3backend-luatex.def
%{_texmfdistdir}/tex/latex/l3backend/l3backend-pdftex.def
%{_texmfdistdir}/tex/latex/l3backend/l3backend-xetex.def

%package -n texlive-l3build
Version:        %{texlive_version}.%{texlive_noarch}.svn66471
Release:        0
License:        LPPL-1.0
Summary:        A testing and building system for (La)TeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-l3build-bin >= %{texlive_version}
#!BuildIgnore: texlive-l3build-bin
Requires:       texlive-luatex >= %{texlive_version}
#!BuildIgnore: texlive-luatex
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-l3build-doc >= %{texlive_version}
Provides:       tex(regression-test.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source239:      l3build.tar.xz
Source240:      l3build.doc.tar.xz

%description -n texlive-l3build
The build system supports testing and building LaTeX3 code, on
Linux, Mac OS X and Windows systems. The package offers: A unit
testing system for (La)TeX code (whether kernel code or
contributed packages); A system for typesetting package
documentation; and An automated process for creating CTAN
releases. The package is essentially independent of other
material released by the LaTeX3 team, and may be updated on a
different schedule.

%package -n texlive-l3build-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66471
Release:        0
Summary:        Documentation for texlive-l3build
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-l3build and texlive-alldocumentation)
Provides:       man(l3build.1)

%description -n texlive-l3build-doc
This package includes the documentation for texlive-l3build

%post -n texlive-l3build
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l3build
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l3build
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l3build-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l3build/CHANGELOG.md
%{_texmfdistdir}/doc/latex/l3build/README.md
%{_texmfdistdir}/doc/latex/l3build/l3build.pdf
%{_mandir}/man1/l3build.1*

%files -n texlive-l3build
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/l3build/l3build-arguments.lua
%{_texmfdistdir}/scripts/l3build/l3build-aux.lua
%{_texmfdistdir}/scripts/l3build/l3build-check.lua
%{_texmfdistdir}/scripts/l3build/l3build-clean.lua
%{_texmfdistdir}/scripts/l3build/l3build-ctan.lua
%{_texmfdistdir}/scripts/l3build/l3build-file-functions.lua
%{_texmfdistdir}/scripts/l3build/l3build-help.lua
%{_texmfdistdir}/scripts/l3build/l3build-install.lua
%{_texmfdistdir}/scripts/l3build/l3build-manifest-setup.lua
%{_texmfdistdir}/scripts/l3build/l3build-manifest.lua
%{_texmfdistdir}/scripts/l3build/l3build-stdmain.lua
%{_texmfdistdir}/scripts/l3build/l3build-tagging.lua
%{_texmfdistdir}/scripts/l3build/l3build-typesetting.lua
%{_texmfdistdir}/scripts/l3build/l3build-unpack.lua
%{_texmfdistdir}/scripts/l3build/l3build-upload.lua
%{_texmfdistdir}/scripts/l3build/l3build-variables.lua
%{_texmfdistdir}/scripts/l3build/l3build-zip.lua
%{_texmfdistdir}/scripts/l3build/l3build.lua
%{_texmfdistdir}/tex/latex/l3build/regression-test.tex

%package -n texlive-l3experimental
Version:        %{texlive_version}.%{texlive_noarch}.svn65621
Release:        0
License:        LPPL-1.0
Summary:        Experimental LaTeX3 concepts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-l3experimental-doc >= %{texlive_version}
Provides:       tex(l3benchmark.sty)
Provides:       tex(l3bitset.sty)
Provides:       tex(l3draw.sty)
Provides:       tex(l3galley.sty)
Provides:       tex(l3graphics.sty)
Provides:       tex(l3opacity.sty)
Provides:       tex(l3str-format.sty)
Provides:       tex(l3sys-shell.sty)
Provides:       tex(xcoffins.sty)
Provides:       tex(xgalley.sty)
Requires:       tex(expl3.sty)
Requires:       tex(xtemplate.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source241:      l3experimental.tar.xz
Source242:      l3experimental.doc.tar.xz

%description -n texlive-l3experimental
The l3experimental packages are a collection of experimental
implementations for aspects of the LaTeX3 kernel, dealing with
higher-level ideas such as the Designer Interface. Some of them
work as stand alone packages, providing new functionality, and
can be used on top of LaTeX2e with no changes to the existing
kernel. The present release includes: l3benchmark for measuring
the time taken by TeX to run certain code; l3draw, a code-level
interface for constructing drawings; l3graphics, an interfaces
for the inclusion of graphics files; l3opacity, support for
opacity in PDF output; l3str, support for string manipulation;
l3bitset, support for bit vectors; l3sys-shell, which provides
abstractions for common shell functions like file deletion and
copying; xcoffins, which allows the alignment of boxes using a
series of 'handle' positions, supplementing the simple TeX
reference point; xgalley, which controls boxes receiving text
for typesetting.

%package -n texlive-l3experimental-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65621
Release:        0
Summary:        Documentation for texlive-l3experimental
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-l3experimental and texlive-alldocumentation)

%description -n texlive-l3experimental-doc
This package includes the documentation for texlive-l3experimental

%post -n texlive-l3experimental
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l3experimental
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l3experimental
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l3experimental-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l3experimental/CHANGELOG.md
%{_texmfdistdir}/doc/latex/l3experimental/README.md
%{_texmfdistdir}/doc/latex/l3experimental/l3benchmark/l3benchmark.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3bitset/l3bitset.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3draw/l3draw-code.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3draw/l3draw-code.tex
%{_texmfdistdir}/doc/latex/l3experimental/l3draw/l3draw.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3graphics/l3graphics.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3opacity/l3opacity.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3str/l3str-format.pdf
%{_texmfdistdir}/doc/latex/l3experimental/l3sys-shell/l3sys-shell.pdf
%{_texmfdistdir}/doc/latex/l3experimental/xcoffins/xcoffins.pdf
%{_texmfdistdir}/doc/latex/l3experimental/xgalley/l3galley.pdf
%{_texmfdistdir}/doc/latex/l3experimental/xgalley/xgalley.pdf

%files -n texlive-l3experimental
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/l3experimental/l3benchmark/l3benchmark.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3bitset/l3bitset.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3draw/l3draw.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3graphics/l3graphics.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3opacity/l3opacity.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3str/l3str-format.sty
%{_texmfdistdir}/tex/latex/l3experimental/l3sys-shell/l3sys-shell.sty
%{_texmfdistdir}/tex/latex/l3experimental/xcoffins/xcoffins.sty
%{_texmfdistdir}/tex/latex/l3experimental/xgalley/l3galley.sty
%{_texmfdistdir}/tex/latex/l3experimental/xgalley/xgalley.sty

%package -n texlive-l3kernel
Version:        %{texlive_version}.%{texlive_noarch}.svn66094
Release:        0
License:        LPPL-1.0
Summary:        LaTeX3 programming conventions
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-l3backend >= %{texlive_version}
#!BuildIgnore: texlive-l3backend
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-l3kernel-doc >= %{texlive_version}
Provides:       tex(expl3-code.tex)
Provides:       tex(expl3-generic.tex)
Provides:       tex(expl3.sty)
Provides:       tex(l3debug.def)
Provides:       tex(l3doc.cls)
Provides:       tex(l3docstrip.tex)
Provides:       tex(l3str-enc-iso88591.def)
Provides:       tex(l3str-enc-iso885910.def)
Provides:       tex(l3str-enc-iso885911.def)
Provides:       tex(l3str-enc-iso885913.def)
Provides:       tex(l3str-enc-iso885914.def)
Provides:       tex(l3str-enc-iso885915.def)
Provides:       tex(l3str-enc-iso885916.def)
Provides:       tex(l3str-enc-iso88592.def)
Provides:       tex(l3str-enc-iso88593.def)
Provides:       tex(l3str-enc-iso88594.def)
Provides:       tex(l3str-enc-iso88595.def)
Provides:       tex(l3str-enc-iso88596.def)
Provides:       tex(l3str-enc-iso88597.def)
Provides:       tex(l3str-enc-iso88598.def)
Provides:       tex(l3str-enc-iso88599.def)
Requires:       tex(article.cls)
Requires:       tex(calc.sty)
Requires:       tex(doc.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(hypdoc.sty)
Requires:       tex(lmodern.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source243:      l3kernel.tar.xz
Source244:      l3kernel.doc.tar.xz

%description -n texlive-l3kernel
The l3kernel bundle provides an implementation of the LaTeX3
programmers' interface, as a set of packages that run under
LaTeX2e. The interface provides the foundation on which the
LaTeX3 kernel and other future code are built: it is an API for
TeX programmers. The packages are set up so that the LaTeX3
conventions can be used with regular LaTeX2e packages.

%package -n texlive-l3kernel-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn66094
Release:        0
Summary:        Documentation for texlive-l3kernel
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-l3kernel and texlive-alldocumentation)

%description -n texlive-l3kernel-doc
This package includes the documentation for texlive-l3kernel

%post -n texlive-l3kernel
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l3kernel
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l3kernel
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l3kernel-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l3kernel/CHANGELOG.md
%{_texmfdistdir}/doc/latex/l3kernel/README.md
%{_texmfdistdir}/doc/latex/l3kernel/expl3.pdf
%{_texmfdistdir}/doc/latex/l3kernel/interface3.pdf
%{_texmfdistdir}/doc/latex/l3kernel/interface3.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3doc.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3docstrip.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news01.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news01.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news02.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news02.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news03.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news03.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news04.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news04.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news05.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news05.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news06.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news06.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news07.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news07.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news08.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news08.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news09.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news09.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news10.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news10.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news11.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news11.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3news12.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3news12.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3obsolete.txt
%{_texmfdistdir}/doc/latex/l3kernel/l3prefixes.csv
%{_texmfdistdir}/doc/latex/l3kernel/l3prefixes.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3prefixes.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3styleguide.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3styleguide.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3syntax-changes.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3syntax-changes.tex
%{_texmfdistdir}/doc/latex/l3kernel/l3term-glossary.pdf
%{_texmfdistdir}/doc/latex/l3kernel/l3term-glossary.tex
%{_texmfdistdir}/doc/latex/l3kernel/source3.pdf
%{_texmfdistdir}/doc/latex/l3kernel/source3.tex
%{_texmfdistdir}/doc/latex/l3kernel/source3body.tex

%files -n texlive-l3kernel
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/l3kernel/expl3-code.tex
%{_texmfdistdir}/tex/latex/l3kernel/expl3-generic.tex
%{_texmfdistdir}/tex/latex/l3kernel/expl3.ltx
%{_texmfdistdir}/tex/latex/l3kernel/expl3.lua
%{_texmfdistdir}/tex/latex/l3kernel/expl3.sty
%{_texmfdistdir}/tex/latex/l3kernel/l3debug.def
%{_texmfdistdir}/tex/latex/l3kernel/l3doc.cls
%{_texmfdistdir}/tex/latex/l3kernel/l3docstrip.tex
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88591.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885910.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885911.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885913.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885914.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885915.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso885916.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88592.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88593.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88594.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88595.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88596.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88597.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88598.def
%{_texmfdistdir}/tex/latex/l3kernel/l3str-enc-iso88599.def

%package -n texlive-l3packages
Version:        %{texlive_version}.%{texlive_noarch}.svn65722
Release:        0
License:        LPPL-1.0
Summary:        High-level LaTeX3 concepts
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-l3packages-doc >= %{texlive_version}
Provides:       tex(l3keys2e.sty)
Provides:       tex(xfp.sty)
Provides:       tex(xfrac.sty)
Provides:       tex(xparse-2018-04-12.sty)
Provides:       tex(xparse-2020-10-01.sty)
Provides:       tex(xparse-generic.tex)
Provides:       tex(xparse.sty)
Provides:       tex(xtemplate.sty)
Requires:       tex(amstext.sty)
Requires:       tex(expl3.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(textcomp.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source245:      l3packages.tar.xz
Source246:      l3packages.doc.tar.xz

%description -n texlive-l3packages
This collection contains implementations for aspects of the
LaTeX3 kernel, dealing with higher-level ideas such as the
Designer Interface. The packages here are considered broadly
stable (The LaTeX3 Project does not expect the interfaces to
alter radically). These packages are built on LaTeX2e
conventions at the interface level, and so may not migrate in
the current form to a stand-alone LaTeX3 format. Packages
provided: xparse, which provides a high-level interface for
declaring document commands xfp, an expandable IEEE 754 FPU for
LaTeX l3keys2e, which makes the facilities of the kernel module
l3keys available for use by LaTeX 2e packages xtemplate, which
provides a means of defining generic functions using a
key-value syntax xfrac, which provides flexible split-level
fractions

%package -n texlive-l3packages-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65722
Release:        0
Summary:        Documentation for texlive-l3packages
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-l3packages and texlive-alldocumentation)

%description -n texlive-l3packages-doc
This package includes the documentation for texlive-l3packages

%post -n texlive-l3packages
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-l3packages
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-l3packages
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-l3packages-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/l3packages/CHANGELOG.md
%{_texmfdistdir}/doc/latex/l3packages/README.md
%{_texmfdistdir}/doc/latex/l3packages/l3keys2e/l3keys2e-demo.tex
%{_texmfdistdir}/doc/latex/l3packages/l3keys2e/l3keys2e.pdf
%{_texmfdistdir}/doc/latex/l3packages/xfp/xfp.pdf
%{_texmfdistdir}/doc/latex/l3packages/xfrac/xfrac.pdf
%{_texmfdistdir}/doc/latex/l3packages/xparse/xparse.pdf
%{_texmfdistdir}/doc/latex/l3packages/xtemplate/xtemplate.pdf

%files -n texlive-l3packages
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/l3packages/l3keys2e/l3keys2e.sty
%{_texmfdistdir}/tex/latex/l3packages/xfp/xfp.sty
%{_texmfdistdir}/tex/latex/l3packages/xfrac/xfrac.sty
%{_texmfdistdir}/tex/latex/l3packages/xparse/xparse-2018-04-12.sty
%{_texmfdistdir}/tex/latex/l3packages/xparse/xparse-2020-10-01.sty
%{_texmfdistdir}/tex/latex/l3packages/xparse/xparse-generic.tex
%{_texmfdistdir}/tex/latex/l3packages/xparse/xparse.ltx
%{_texmfdistdir}/tex/latex/l3packages/xparse/xparse.sty
%{_texmfdistdir}/tex/latex/l3packages/xtemplate/xtemplate.sty

%package -n texlive-labbook
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
License:        LPPL-1.0
Summary:        Typeset laboratory journals
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-labbook-doc >= %{texlive_version}
Provides:       tex(labbook.cls)
Requires:       tex(makeidx.sty)
Requires:       tex(scrbook.cls)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source247:      labbook.tar.xz
Source248:      labbook.doc.tar.xz

%description -n texlive-labbook
This class is designed to typeset laboratory journals that
contain chronologically ordered records about experiments. From
the sectioning commands, an experiment index is generated. The
class is based on the KOMA-Script class scrbook.cls. There can
be several index entries for one experiment.

%package -n texlive-labbook-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn15878
Release:        0
Summary:        Documentation for texlive-labbook
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-labbook and texlive-alldocumentation)
Provides:       locale(texlive-labbook-doc:de;en)

%description -n texlive-labbook-doc
This package includes the documentation for texlive-labbook

%post -n texlive-labbook
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-labbook
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-labbook
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-labbook-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/labbook/README
%{_texmfdistdir}/doc/latex/labbook/boilerplates.tex
%{_texmfdistdir}/doc/latex/labbook/examplde.tex
%{_texmfdistdir}/doc/latex/labbook/examplen.tex
%{_texmfdistdir}/doc/latex/labbook/labboode.pdf
%{_texmfdistdir}/doc/latex/labbook/labboode.tex
%{_texmfdistdir}/doc/latex/labbook/labbook.el
%{_texmfdistdir}/doc/latex/labbook/labbook.pdf

%files -n texlive-labbook
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/labbook/labbook.cls

%package -n texlive-labels
Version:        %{texlive_version}.%{texlive_noarch}.0.0.13svn15878
Release:        0
License:        LPPL-1.0
Summary:        Print sheets of sticky labels
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-labels-doc >= %{texlive_version}
Provides:       tex(labels.sty)
Provides:       tex(olabels.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source249:      labels.tar.xz
Source250:      labels.doc.tar.xz

%description -n texlive-labels
A LaTeX package to print a regular grid of ragged-right labels
on a page, suitable for sheets of labels which can be fed
through a printer. Macros are provided to allow easy input of
names and addresses in a form free of TeX markup. Equally
useful is a feature for making multiple copies of a single
label, e.g., return address stickers to go with the labels.
Rows, columns, borders can all be specified to match the label
sheet being used.

%package -n texlive-labels-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.13svn15878
Release:        0
Summary:        Documentation for texlive-labels
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-labels and texlive-alldocumentation)

%description -n texlive-labels-doc
This package includes the documentation for texlive-labels

%post -n texlive-labels
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-labels
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-labels
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-labels-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/labels/README
%{_texmfdistdir}/doc/latex/labels/labels.pdf
%{_texmfdistdir}/doc/latex/labels/test/avery5162.tex
%{_texmfdistdir}/doc/latex/labels/test/badge.tex
%{_texmfdistdir}/doc/latex/labels/test/beebe.tex
%{_texmfdistdir}/doc/latex/labels/test/door.tex
%{_texmfdistdir}/doc/latex/labels/test/door209.tex
%{_texmfdistdir}/doc/latex/labels/test/names.dat
%{_texmfdistdir}/doc/latex/labels/test/news.tex
%{_texmfdistdir}/doc/latex/labels/test/test.tex
%{_texmfdistdir}/doc/latex/labels/test/test1.tex
%{_texmfdistdir}/doc/latex/labels/test/test10.tex
%{_texmfdistdir}/doc/latex/labels/test/test11.tex
%{_texmfdistdir}/doc/latex/labels/test/test12.tex
%{_texmfdistdir}/doc/latex/labels/test/test2.tex
%{_texmfdistdir}/doc/latex/labels/test/test3.tex
%{_texmfdistdir}/doc/latex/labels/test/test4.tex
%{_texmfdistdir}/doc/latex/labels/test/test5.tex
%{_texmfdistdir}/doc/latex/labels/test/test6.tex
%{_texmfdistdir}/doc/latex/labels/test/test7.tex
%{_texmfdistdir}/doc/latex/labels/test/test8.tex
%{_texmfdistdir}/doc/latex/labels/test/test9.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew1.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew10.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew11.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew12.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew13.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew2.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew3.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew4.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew5.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew6.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew7.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew8.tex
%{_texmfdistdir}/doc/latex/labels/test/testnew9.tex
%{_texmfdistdir}/doc/latex/labels/test/zwekform.tex

%files -n texlive-labels
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/labels/labels.sty
%{_texmfdistdir}/tex/latex/labels/olabels.sty

%package -n texlive-labels4easylist
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn51124
Release:        0
License:        LPPL-1.0
Summary:        Add reference labels to easylist items
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-labels4easylist-doc >= %{texlive_version}
Provides:       tex(labels4easylist.sty)
Requires:       tex(easylist.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source251:      labels4easylist.tar.xz
Source252:      labels4easylist.doc.tar.xz

%description -n texlive-labels4easylist
This package provides the \itemLabel macro for adding
configurable reference labels to easylist items.

%package -n texlive-labels4easylist-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn51124
Release:        0
Summary:        Documentation for texlive-labels4easylist
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-labels4easylist and texlive-alldocumentation)

%description -n texlive-labels4easylist-doc
This package includes the documentation for texlive-labels4easylist

%post -n texlive-labels4easylist
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-labels4easylist
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-labels4easylist
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-labels4easylist-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/labels4easylist/README
%{_texmfdistdir}/doc/latex/labels4easylist/labels4easylist.pdf
%{_texmfdistdir}/doc/latex/labels4easylist/labels4easylist.tex

%files -n texlive-labels4easylist
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/labels4easylist/labels4easylist.sty

%package -n texlive-labelschanged
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn46040
Release:        0
License:        SUSE-Public-Domain
Summary:        Identify labels which cause endless "may have changed" warnings
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-labelschanged-doc >= %{texlive_version}
Provides:       tex(labelschanged.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source253:      labelschanged.tar.xz
Source254:      labelschanged.doc.tar.xz

%description -n texlive-labelschanged
Several conditions can cause LaTeX labels to keep changing, no
matter how many times a document is recompiled. This package
helps diagnose the cause of repeated "Label(s) may have
changed" warnings. The names and before/after definitions of
changing labels are printed at the end of each compile.
Multiply-defined labels are printed as well.

%package -n texlive-labelschanged-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn46040
Release:        0
Summary:        Documentation for texlive-labelschanged
License:        SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-labelschanged and texlive-alldocumentation)

%description -n texlive-labelschanged-doc
This package includes the documentation for texlive-labelschanged

%post -n texlive-labelschanged
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-labelschanged
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-labelschanged
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-labelschanged-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/labelschanged/README.txt
%{_texmfdistdir}/doc/latex/labelschanged/labelschanged.pdf

%files -n texlive-labelschanged
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/labelschanged/labelschanged.sty

%package -n texlive-labyrinth
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn33454
Release:        0
License:        LPPL-1.0
Summary:        Draw labyrinths and solution paths
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-labyrinth-doc >= %{texlive_version}
Provides:       tex(labyrinth.sty)
Requires:       tex(calc.sty)
Requires:       tex(picture.sty)
Requires:       tex(xkeyval.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source255:      labyrinth.tar.xz
Source256:      labyrinth.doc.tar.xz

%description -n texlive-labyrinth
The labyrinth package provides code and an environment for
typesetting simple labyrinths with LaTeX, and generating an
automatic or manual solution path.

%package -n texlive-labyrinth-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn33454
Release:        0
Summary:        Documentation for texlive-labyrinth
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-labyrinth and texlive-alldocumentation)

%description -n texlive-labyrinth-doc
This package includes the documentation for texlive-labyrinth

%post -n texlive-labyrinth
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-labyrinth
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-labyrinth
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-labyrinth-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/labyrinth/README
%{_texmfdistdir}/doc/latex/labyrinth/classic-en.ist
%{_texmfdistdir}/doc/latex/labyrinth/labyrinth.pdf
%{_texmfdistdir}/doc/latex/labyrinth/labyrinth.tex
%{_texmfdistdir}/doc/latex/labyrinth/lstlocal.cfg

%files -n texlive-labyrinth
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/labyrinth/labyrinth.sty

%package -n texlive-lacheck
Version:        %{texlive_version}.%{texlive_noarch}.svn66186
Release:        0
License:        GPL-2.0-or-later
Summary:        LaTeX checker
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-lacheck-bin >= %{texlive_version}
#!BuildIgnore: texlive-lacheck-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       man(lacheck.1)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source257:      lacheck.doc.tar.xz

%description -n texlive-lacheck
Lacheck is a tool for finding common mistakes in LaTeX
documents. The distribution includes sources, and executables
for OS/2 and Win32 environments.

%post -n texlive-lacheck
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lacheck
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lacheck
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lacheck
%defattr(-,root,root,755)
%{_mandir}/man1/lacheck.1*

%package -n texlive-ladder
Version:        %{texlive_version}.%{texlive_noarch}.svn44394
Release:        0
License:        LPPL-1.0
Summary:        Draw simple ladder diagrams using TikZ
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-ladder-doc >= %{texlive_version}
Provides:       tex(ladder.sty)
Requires:       tex(calc.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(tikz.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source258:      ladder.tar.xz
Source259:      ladder.doc.tar.xz

%description -n texlive-ladder
This package permits the creation of simple ladder diagrams
within LaTeX documents. Required packages are tikz, ifthen, and
calc.

%package -n texlive-ladder-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn44394
Release:        0
Summary:        Documentation for texlive-ladder
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-ladder and texlive-alldocumentation)

%description -n texlive-ladder-doc
This package includes the documentation for texlive-ladder

%post -n texlive-ladder
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-ladder
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-ladder
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-ladder-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/ladder/README.md
%{_texmfdistdir}/doc/latex/ladder/ladder.pdf
%{_texmfdistdir}/doc/latex/ladder/ladder.tex

%files -n texlive-ladder
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/ladder/ladder.sty

%package -n texlive-lambda
Version:        %{texlive_version}.%{texlive_noarch}.svn45756
Release:        0
License:        LPPL-1.0
Summary:        LaTeX for Omega and Aleph
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       tex(UT1cmr.fd)
Provides:       tex(UT1omlgc.fd)
Provides:       tex(elhyph16.tex)
Provides:       tex(grcodes.tex)
Provides:       tex(grmhyph.tex)
Provides:       tex(lambda.tex)
Provides:       tex(language.dat)
Provides:       tex(lchcmr.fd)
Provides:       tex(lchenc.def)
Provides:       tex(ocherokee.sty)
Provides:       tex(odev.sty)
Provides:       tex(ojapan.sty)
Provides:       tex(omarab.cfg)
Provides:       tex(omega.sty)
Provides:       tex(omlgc.cfg)
Provides:       tex(ot1omarb.fd)
Provides:       tex(ot1omlgc.fd)
Provides:       tex(ot1uctt.fd)
Provides:       tex(ut1enc.def)
Requires:       tex(grlccode.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source260:      lambda.tar.xz

%description -n texlive-lambda
The lambda package

%post -n texlive-lambda
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lambda
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lambda
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lambda
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/lambda/base/UT1cmr.fd
%{_texmfdistdir}/tex/lambda/base/UT1omlgc.fd
%{_texmfdistdir}/tex/lambda/base/elhyph16.tex
%{_texmfdistdir}/tex/lambda/base/french.bgd
%{_texmfdistdir}/tex/lambda/base/french.lay
%{_texmfdistdir}/tex/lambda/base/grcodes.tex
%{_texmfdistdir}/tex/lambda/base/greek.bgd
%{_texmfdistdir}/tex/lambda/base/greek.lay
%{_texmfdistdir}/tex/lambda/base/grmhyph.tex
%{_texmfdistdir}/tex/lambda/base/inuit.hpn
%{_texmfdistdir}/tex/lambda/base/lambda.tex
%{_texmfdistdir}/tex/lambda/base/lchcmr.fd
%{_texmfdistdir}/tex/lambda/base/lchenc.def
%{_texmfdistdir}/tex/lambda/base/ocherokee.sty
%{_texmfdistdir}/tex/lambda/base/odev.sty
%{_texmfdistdir}/tex/lambda/base/ojapan.sty
%{_texmfdistdir}/tex/lambda/base/omarab.cfg
%{_texmfdistdir}/tex/lambda/base/omega.sty
%{_texmfdistdir}/tex/lambda/base/omlgc.cfg
%{_texmfdistdir}/tex/lambda/base/ot1omarb.fd
%{_texmfdistdir}/tex/lambda/base/ot1omlgc.fd
%{_texmfdistdir}/tex/lambda/base/ot1uctt.fd
%{_texmfdistdir}/tex/lambda/base/usenglish.bgd
%{_texmfdistdir}/tex/lambda/base/usenglish.lay
%{_texmfdistdir}/tex/lambda/base/ut1enc.def
%{_texmfdistdir}/tex/lambda/config/lambda.ini
%verify(link) %{_texmfdistdir}/tex/lambda/config/language.dat
%config %verify(not md5 mtime size) %{_texmfconfdir}/tex/lambda/config/language.dat

%package -n texlive-lambda-lists
Version:        %{texlive_version}.%{texlive_noarch}.svn31402
Release:        0
License:        LPPL-1.0
Summary:        Lists in TeX's mouth
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-lambda-lists-doc >= %{texlive_version}
Provides:       tex(lambda.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source261:      lambda-lists.tar.xz
Source262:      lambda-lists.doc.tar.xz

%description -n texlive-lambda-lists
These list-processing macros avoid the reassignments employed
in the macros shown in Appendix D of the TeXbook: all the
manipulations take place in what Knuth is pleased to call
"TeX's mouth".

%package -n texlive-lambda-lists-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn31402
Release:        0
Summary:        Documentation for texlive-lambda-lists
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-lambda-lists and texlive-alldocumentation)

%description -n texlive-lambda-lists-doc
This package includes the documentation for texlive-lambda-lists

%post -n texlive-lambda-lists
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lambda-lists
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lambda-lists
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lambda-lists-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/plain/lambda-lists/README
%{_texmfdistdir}/doc/plain/lambda-lists/lambda-lists.pdf
%{_texmfdistdir}/doc/plain/lambda-lists/lambda-lists.tex

%files -n texlive-lambda-lists
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/plain/lambda-lists/lambda.sty

%package -n texlive-lambdax
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn60278
Release:        0
License:        LPPL-1.0
Summary:        Use Lambda expression within LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-lambdax-doc >= %{texlive_version}
Provides:       tex(lambdax.sty)
Requires:       tex(expl3.sty)
Requires:       tex(keyparse.sty)
Requires:       tex(l3keys2e.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xtemplate.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source263:      lambdax.tar.xz
Source264:      lambdax.doc.tar.xz

%description -n texlive-lambdax
This package provides Lambda expressions. It is an interface to
specify the parameters and replacement code of a
document-command, and then to evaluate it with compatible
arguments. Optionally, it can be used recursively.

%package -n texlive-lambdax-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn60278
Release:        0
Summary:        Documentation for texlive-lambdax
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-lambdax and texlive-alldocumentation)

%description -n texlive-lambdax-doc
This package includes the documentation for texlive-lambdax

%post -n texlive-lambdax
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lambdax
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lambdax
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lambdax-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/lambdax/README.md
%{_texmfdistdir}/doc/latex/lambdax/lambdax.bib
%{_texmfdistdir}/doc/latex/lambdax/lambdax.pdf

%files -n texlive-lambdax
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/lambdax/lambdax.sty

%package -n texlive-langcode
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2svn27764
Release:        0
License:        LPPL-1.0
Summary:        Simple language-dependent settings based on language codes
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-langcode-doc >= %{texlive_version}
Provides:       tex(langcode.sty)
Requires:       tex(dowith.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source265:      langcode.tar.xz
Source266:      langcode.doc.tar.xz

%description -n texlive-langcode
The package provides a command \uselangcode{<code>} to adjust
language-dependent settings such as key words, typographical
conventions and language codes (ISO 639-1). The package
provides a means of selecting macros according to the specified
code, for preparing a document that is to be separately typeset
in different laguages. The package is dependent on the plainpkg
package, and is already in use in the morehype and catcodes
packages.

%package -n texlive-langcode-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.2svn27764
Release:        0
Summary:        Documentation for texlive-langcode
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-langcode and texlive-alldocumentation)

%description -n texlive-langcode-doc
This package includes the documentation for texlive-langcode

%post -n texlive-langcode
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-langcode
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-langcode
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-langcode-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/langcode/README
%{_texmfdistdir}/doc/generic/langcode/SrcFILEs.txt
%{_texmfdistdir}/doc/generic/langcode/langcode.pdf

%files -n texlive-langcode
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/generic/langcode/langcode.sty

%package -n texlive-langnames
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn65502
Release:        0
License:        LPPL-1.0
Summary:        Name languages and their genetic affiliations consistently
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-langnames-doc >= %{texlive_version}
Provides:       tex(langnames.sty)
Provides:       tex(ln_fams_glot.tex)
Provides:       tex(ln_fams_wals.tex)
Provides:       tex(ln_langs_glot.tex)
Provides:       tex(ln_langs_glot_native.tex)
Provides:       tex(ln_langs_wals.tex)
Provides:       tex(ln_langs_wals_native.tex)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source267:      langnames.tar.xz
Source268:      langnames.doc.tar.xz

%description -n texlive-langnames
This package attempts to make the typing of language names,
codes, and families slightly easier by providing macros to
access pre-defined language--code--family combinations from two
important databases, as well as the possibility to create new
combinations. It may be particularly useful for large,
collaborative projects as well as typologically minded ones
with a variety of language examples.

%package -n texlive-langnames-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.1svn65502
Release:        0
Summary:        Documentation for texlive-langnames
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-langnames and texlive-alldocumentation)

%description -n texlive-langnames-doc
This package includes the documentation for texlive-langnames

%post -n texlive-langnames
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-langnames
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-langnames
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-langnames-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/langnames/README.md
%{_texmfdistdir}/doc/latex/langnames/langnames.pdf

%files -n texlive-langnames
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/langnames/langnames.sty
%{_texmfdistdir}/tex/latex/langnames/ln_fams_glot.tex
%{_texmfdistdir}/tex/latex/langnames/ln_fams_wals.tex
%{_texmfdistdir}/tex/latex/langnames/ln_langs_glot.tex
%{_texmfdistdir}/tex/latex/langnames/ln_langs_glot_native.tex
%{_texmfdistdir}/tex/latex/langnames/ln_langs_wals.tex
%{_texmfdistdir}/tex/latex/langnames/ln_langs_wals_native.tex

%package -n texlive-langsci
Version:        %{texlive_version}.%{texlive_noarch}.svn65793
Release:        0
License:        LPPL-1.0
Summary:        Typeset books for publication with Language Science Press
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-langsci-doc >= %{texlive_version}
Provides:       tex(langsci-affiliations.sty)
Provides:       tex(langsci-bidi.sty)
Provides:       tex(langsci-gb4e.sty)
Provides:       tex(langsci-lgr.sty)
Provides:       tex(langsci-optional.sty)
Provides:       tex(langsci-series.def)
Provides:       tex(langsci-subparts.sty)
Provides:       tex(langsci-tbls.sty)
Provides:       tex(langsci-textipa.sty)
Provides:       tex(langsci-unified.bbx)
Provides:       tex(langsci-unified.cbx)
Provides:       tex(langscibook.cls)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(array.sty)
Requires:       tex(authorindex.sty)
Requires:       tex(authoryear.bbx)
Requires:       tex(babel.sty)
Requires:       tex(bookmark.sty)
Requires:       tex(booktabs.sty)
Requires:       tex(calc.sty)
Requires:       tex(caption.sty)
Requires:       tex(chngcntr.sty)
Requires:       tex(colortbl.sty)
Requires:       tex(datetime.sty)
Requires:       tex(epigraph.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(fancyvrb.sty)
Requires:       tex(floatrow.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyphenat.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(index.sty)
Requires:       tex(kvoptions.sty)
Requires:       tex(lineno.sty)
Requires:       tex(mdframed.sty)
Requires:       tex(microtype.sty)
Requires:       tex(newtxmath.sty)
Requires:       tex(pbox.sty)
Requires:       tex(pifont.sty)
Requires:       tex(pst-barcode.sty)
Requires:       tex(rotating.sty)
Requires:       tex(scrlayer-scrpage.sty)
Requires:       tex(setspace.sty)
Requires:       tex(silence.sty)
Requires:       tex(soul.sty)
Requires:       tex(tabularx.sty)
Requires:       tex(tcolorbox.sty)
Requires:       tex(tikz.sty)
Requires:       tex(titlesec.sty)
Requires:       tex(titletoc.sty)
Requires:       tex(todonotes.sty)
Requires:       tex(ulem.sty)
Requires:       tex(unicode-math.sty)
Requires:       tex(url.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xeCJK.sty)
Requires:       tex(xparse.sty)
Requires:       tex(xpatch.sty)
Requires:       tex(xspace.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source269:      langsci.tar.xz
Source270:      langsci.doc.tar.xz

%description -n texlive-langsci
This package allows you to typeset monographs and edited
volumes for publication with Language Science Press
(http://www.langsci-press.org). It includes all necessary files
for title pages, frontmatter, main content, list of references
and indexes. Dust jackets for BoD and Createspace
(print-on-demand service providers) can also be produced.

%package -n texlive-langsci-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn65793
Release:        0
Summary:        Documentation for texlive-langsci
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-langsci and texlive-alldocumentation)

%description -n texlive-langsci-doc
This package includes the documentation for texlive-langsci

%post -n texlive-langsci
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-langsci
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-langsci
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-langsci-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/xelatex/langsci/README.md
%{_texmfdistdir}/doc/xelatex/langsci/documentation/langsci-doc.pdf
%{_texmfdistdir}/doc/xelatex/langsci/documentation/langsci-doc.tex
%{_texmfdistdir}/doc/xelatex/langsci/documentation/langsci-gb4.pdf
%{_texmfdistdir}/doc/xelatex/langsci/examples/langsci-test.bib
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplemonograph.pdf
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplemonograph.tex
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplepaper.pdf
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplepaper.tex
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplevolume.pdf
%{_texmfdistdir}/doc/xelatex/langsci/examples/samplevolume.tex

%files -n texlive-langsci
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/xelatex/langsci/langsci-affiliations.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-bidi.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-gb4e.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-lgr.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-optional.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-series.def
%{_texmfdistdir}/tex/xelatex/langsci/langsci-subparts.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-tbls.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-textipa.sty
%{_texmfdistdir}/tex/xelatex/langsci/langsci-unified.bbx
%{_texmfdistdir}/tex/xelatex/langsci/langsci-unified.cbx
%{_texmfdistdir}/tex/xelatex/langsci/langsci-unified.dbx
%{_texmfdistdir}/tex/xelatex/langsci/langscibook.cls
%{_texmfdistdir}/tex/xelatex/langsci/tbls-alarm.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-book.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-bulb.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-bulbon.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-code.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-explore.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-filter.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-glass.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-glass2.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-law.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-more.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-pencil.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-people.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-plus.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-r.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-receipt.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-refresh.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-report.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-test.pdf
%{_texmfdistdir}/tex/xelatex/langsci/tbls-tree.pdf

%package -n texlive-langsci-avm
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.0svn66016
Release:        0
License:        LPPL-1.0
Summary:        Feature structures and attribute-value matrices (AVM)
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-langsci-avm-doc >= %{texlive_version}
Provides:       tex(langsci-avm.sty)
Requires:       tex(array.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(tikz.sty)
Requires:       tex(unicode-math.sty)
Requires:       tex(xparse.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source271:      langsci-avm.tar.xz
Source272:      langsci-avm.doc.tar.xz

%description -n texlive-langsci-avm
A package for typesetting feature structures, also known as
attribute-value matrices (AVMs), for use in linguistics. The
package provides a minimal and easy to read syntax. It depends
only on the array package and can be placed almost everywhere,
in particular in footnotes or graphs and tree structures. The
package serves the same purpose as, Christopher Manning's avm
package, but shares no code base with that package.

%package -n texlive-langsci-avm-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.3.0svn66016
Release:        0
Summary:        Documentation for texlive-langsci-avm
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-langsci-avm and texlive-alldocumentation)

%description -n texlive-langsci-avm-doc
This package includes the documentation for texlive-langsci-avm

%post -n texlive-langsci-avm
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-langsci-avm
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-langsci-avm
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-langsci-avm-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/langsci-avm/README
%{_texmfdistdir}/doc/latex/langsci-avm/langsci-avm.pdf

%files -n texlive-langsci-avm
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/langsci-avm/langsci-avm.sty

%package -n texlive-lapdf
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn23806
Release:        0
License:        GPL-2.0-or-later
Summary:        PDF drawing directly in TeX documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-lapdf-doc >= %{texlive_version}
Provides:       tex(lapdf.sty)
Requires:       tex(calc.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source273:      lapdf.tar.xz
Source274:      lapdf.doc.tar.xz

%description -n texlive-lapdf
The package provides the means to use PDF drawing primitives to
produce high quality, colored graphics. It uses Bezier curves
(integral and rational) from degree one to seven, allows TeX
typesetting in the graphic, offers most of the standard math
functions, allows plotting normal, parametric and polar
functions. The package has linear, logx, logy, logxy and polar
grids with many specs; it can rotate, clip and do many nice
things easily it has two looping commands for programming and
many instructive example files. The package requires pdfTeX but
otherwise only depends on the calc package.

%package -n texlive-lapdf-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.1svn23806
Release:        0
Summary:        Documentation for texlive-lapdf
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-lapdf and texlive-alldocumentation)

%description -n texlive-lapdf-doc
This package includes the documentation for texlive-lapdf

%post -n texlive-lapdf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lapdf
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lapdf
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lapdf-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/lapdf/README
%{_texmfdistdir}/doc/latex/lapdf/arcs.pdf
%{_texmfdistdir}/doc/latex/lapdf/arcs.tex
%{_texmfdistdir}/doc/latex/lapdf/bezier.pdf
%{_texmfdistdir}/doc/latex/lapdf/bezier.tex
%{_texmfdistdir}/doc/latex/lapdf/bezinfo.pdf
%{_texmfdistdir}/doc/latex/lapdf/bezinfo.tex
%{_texmfdistdir}/doc/latex/lapdf/buttrfly.pdf
%{_texmfdistdir}/doc/latex/lapdf/buttrfly.tex
%{_texmfdistdir}/doc/latex/lapdf/cfamily.pdf
%{_texmfdistdir}/doc/latex/lapdf/cfamily.tex
%{_texmfdistdir}/doc/latex/lapdf/chrysant.pdf
%{_texmfdistdir}/doc/latex/lapdf/chrysant.tex
%{_texmfdistdir}/doc/latex/lapdf/circle.pdf
%{_texmfdistdir}/doc/latex/lapdf/circle.tex
%{_texmfdistdir}/doc/latex/lapdf/colors.pdf
%{_texmfdistdir}/doc/latex/lapdf/colors.tex
%{_texmfdistdir}/doc/latex/lapdf/conic.pdf
%{_texmfdistdir}/doc/latex/lapdf/conic.tex
%{_texmfdistdir}/doc/latex/lapdf/curve.pdf
%{_texmfdistdir}/doc/latex/lapdf/curve.tex
%{_texmfdistdir}/doc/latex/lapdf/curveto.pdf
%{_texmfdistdir}/doc/latex/lapdf/curveto.tex
%{_texmfdistdir}/doc/latex/lapdf/cycloid.pdf
%{_texmfdistdir}/doc/latex/lapdf/cycloid.tex
%{_texmfdistdir}/doc/latex/lapdf/drawing.pdf
%{_texmfdistdir}/doc/latex/lapdf/drawing.tex
%{_texmfdistdir}/doc/latex/lapdf/ellipse.pdf
%{_texmfdistdir}/doc/latex/lapdf/ellipse.tex
%{_texmfdistdir}/doc/latex/lapdf/fplot.pdf
%{_texmfdistdir}/doc/latex/lapdf/fplot.tex
%{_texmfdistdir}/doc/latex/lapdf/geometry.pdf
%{_texmfdistdir}/doc/latex/lapdf/geometry.tex
%{_texmfdistdir}/doc/latex/lapdf/grids.pdf
%{_texmfdistdir}/doc/latex/lapdf/grids.tex
%{_texmfdistdir}/doc/latex/lapdf/hippo.pdf
%{_texmfdistdir}/doc/latex/lapdf/hippo.tex
%{_texmfdistdir}/doc/latex/lapdf/lapdf.pdf
%{_texmfdistdir}/doc/latex/lapdf/lapdf.tex
%{_texmfdistdir}/doc/latex/lapdf/licence.txt
%{_texmfdistdir}/doc/latex/lapdf/line.pdf
%{_texmfdistdir}/doc/latex/lapdf/line.tex
%{_texmfdistdir}/doc/latex/lapdf/polygon.pdf
%{_texmfdistdir}/doc/latex/lapdf/polygon.tex
%{_texmfdistdir}/doc/latex/lapdf/polynom.pdf
%{_texmfdistdir}/doc/latex/lapdf/polynom.tex
%{_texmfdistdir}/doc/latex/lapdf/pplot.pdf
%{_texmfdistdir}/doc/latex/lapdf/pplot.tex
%{_texmfdistdir}/doc/latex/lapdf/preamble.tex
%{_texmfdistdir}/doc/latex/lapdf/pythagor.pdf
%{_texmfdistdir}/doc/latex/lapdf/pythagor.tex
%{_texmfdistdir}/doc/latex/lapdf/qcircle.pdf
%{_texmfdistdir}/doc/latex/lapdf/qcircle.tex
%{_texmfdistdir}/doc/latex/lapdf/quartic.pdf
%{_texmfdistdir}/doc/latex/lapdf/quartic.tex
%{_texmfdistdir}/doc/latex/lapdf/rational.pdf
%{_texmfdistdir}/doc/latex/lapdf/rational.tex
%{_texmfdistdir}/doc/latex/lapdf/rcircle.pdf
%{_texmfdistdir}/doc/latex/lapdf/rcircle.tex
%{_texmfdistdir}/doc/latex/lapdf/rcurve.pdf
%{_texmfdistdir}/doc/latex/lapdf/rcurve.tex
%{_texmfdistdir}/doc/latex/lapdf/recttria.pdf
%{_texmfdistdir}/doc/latex/lapdf/recttria.tex
%{_texmfdistdir}/doc/latex/lapdf/roundtri.pdf
%{_texmfdistdir}/doc/latex/lapdf/roundtri.tex
%{_texmfdistdir}/doc/latex/lapdf/rparams.pdf
%{_texmfdistdir}/doc/latex/lapdf/rparams.tex
%{_texmfdistdir}/doc/latex/lapdf/superell.pdf
%{_texmfdistdir}/doc/latex/lapdf/superell.tex
%{_texmfdistdir}/doc/latex/lapdf/tplot.pdf
%{_texmfdistdir}/doc/latex/lapdf/tplot.tex
%{_texmfdistdir}/doc/latex/lapdf/trochoid.pdf
%{_texmfdistdir}/doc/latex/lapdf/trochoid.tex
%{_texmfdistdir}/doc/latex/lapdf/turtle.pdf
%{_texmfdistdir}/doc/latex/lapdf/turtle.tex
%{_texmfdistdir}/doc/latex/lapdf/vector.pdf
%{_texmfdistdir}/doc/latex/lapdf/vector.tex

%files -n texlive-lapdf
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/lapdf/lapdf.sty

%package -n texlive-lastpackage
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn34481
Release:        0
License:        LPPL-1.0
Summary:        Indicates the last loaded package
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-lastpackage-doc >= %{texlive_version}
Provides:       tex(lastpackage.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source275:      lastpackage.tar.xz
Source276:      lastpackage.doc.tar.xz

%description -n texlive-lastpackage
This package may be used to define the last point where some
code shall be executed. Its provides a package name for use in
package-placing commands from the author's templatetools. Usage
examples are provided in the documentation.

%package -n texlive-lastpackage-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.1svn34481
Release:        0
Summary:        Documentation for texlive-lastpackage
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-lastpackage and texlive-alldocumentation)

%description -n texlive-lastpackage-doc
This package includes the documentation for texlive-lastpackage

%post -n texlive-lastpackage
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lastpackage
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lastpackage
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lastpackage-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/lastpackage/README
%{_texmfdistdir}/doc/latex/lastpackage/lastpackage.pdf

%files -n texlive-lastpackage
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/lastpackage/lastpackage.sty

%package -n texlive-lastpage
Version:        %{texlive_version}.%{texlive_noarch}.2.0asvn66461
Release:        0
License:        LPPL-1.0
Summary:        Reference last page for Page N of M type footers
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-lastpage-doc >= %{texlive_version}
Provides:       tex(lastpage.sty)
Provides:       tex(lastpage209.sty)
Provides:       tex(lastpage2e.sty)
Provides:       tex(lastpageclassic.sty)
Provides:       tex(lastpagemodern.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source277:      lastpage.tar.xz
Source278:      lastpage.doc.tar.xz

%description -n texlive-lastpage
Reference the number of pages in your LaTeX document through
the introduction of a new label which can be referenced like
\pageref{LastPage} to give a reference to the last page of a
document. It is particularly useful in the page footer that
says: Page N of M.

%package -n texlive-lastpage-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.0asvn66461
Release:        0
Summary:        Documentation for texlive-lastpage
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-lastpage and texlive-alldocumentation)

%description -n texlive-lastpage-doc
This package includes the documentation for texlive-lastpage

%post -n texlive-lastpage
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-lastpage
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-lastpage
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-lastpage-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/lastpage/README
%{_texmfdistdir}/doc/latex/lastpage/lastpage-example.pdf
%{_texmfdistdir}/doc/latex/lastpage/lastpage-example.tex
%{_texmfdistdir}/doc/latex/lastpage/lastpage.pdf

%files -n texlive-lastpage
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/lastpage/lastpage.sty
%{_texmfdistdir}/tex/latex/lastpage/lastpage209.sty
%{_texmfdistdir}/tex/latex/lastpage/lastpage2e.sty
%{_texmfdistdir}/tex/latex/lastpage/lastpageclassic.sty
%{_texmfdistdir}/tex/latex/lastpage/lastpagemodern.sty

%package -n texlive-latex
Version:        %{texlive_version}.%{texlive_noarch}.20221101_pl1svn65161
Release:        0
License:        LPPL-1.0
Summary:        A TeX macro package that defines LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-latex-bin >= %{texlive_version}
Requires:       texlive-latex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-latex-fonts
Requires:       texlive-latexconfig >= %{texlive_version}
#!BuildIgnore: texlive-latexconfig
Requires:       texlive-luatex >= %{texlive_version}
#!BuildIgnore: texlive-luatex
Requires:       texlive-pdftex >= %{texlive_version}
#!BuildIgnore: texlive-pdftex
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-doc >= %{texlive_version}
Provides:       tex(alltt.sty)
Provides:       tex(ansinew.def)
Provides:       tex(applemac.def)
Provides:       tex(article.cls)
Provides:       tex(article.sty)
Provides:       tex(ascii.def)
Provides:       tex(atbegshi-ltx.sty)
Provides:       tex(atveryend-ltx.sty)
Provides:       tex(bezier.sty)
Provides:       tex(bk10.clo)
Provides:       tex(bk11.clo)
Provides:       tex(bk12.clo)
Provides:       tex(book.cls)
Provides:       tex(book.sty)
Provides:       tex(cp1250.def)
Provides:       tex(cp1252.def)
Provides:       tex(cp1257.def)
Provides:       tex(cp437.def)
Provides:       tex(cp437de.def)
Provides:       tex(cp850.def)
Provides:       tex(cp852.def)
Provides:       tex(cp858.def)
Provides:       tex(cp865.def)
Provides:       tex(decmulti.def)
Provides:       tex(doc-2016-02-15.sty)
Provides:       tex(doc-2021-06-01.sty)
Provides:       tex(doc.sty)
Provides:       tex(docstrip.tex)
Provides:       tex(exscale.sty)
Provides:       tex(fix-cm.sty)
Provides:       tex(fixltx2e.sty)
Provides:       tex(flafter.sty)
Provides:       tex(fleqn.clo)
Provides:       tex(fleqn.sty)
Provides:       tex(fltrace.sty)
Provides:       tex(fontenc.sty)
Provides:       tex(fontmath.cfg)
Provides:       tex(fonttext.cfg)
Provides:       tex(graphpap.sty)
Provides:       tex(idx.tex)
Provides:       tex(ifthen.sty)
Provides:       tex(inputenc.sty)
Provides:       tex(lablst.tex)
Provides:       tex(latex209.def)
Provides:       tex(latexrelease.sty)
Provides:       tex(latexsym.sty)
Provides:       tex(latin1.def)
Provides:       tex(latin10.def)
Provides:       tex(latin2.def)
Provides:       tex(latin3.def)
Provides:       tex(latin4.def)
Provides:       tex(latin5.def)
Provides:       tex(latin9.def)
Provides:       tex(leqno.clo)
Provides:       tex(leqno.sty)
Provides:       tex(letter.cls)
Provides:       tex(letter.sty)
Provides:       tex(lppl.tex)
Provides:       tex(ltluatex.tex)
Provides:       tex(ltnews.cls)
Provides:       tex(ltxcheck.tex)
Provides:       tex(ltxdoc.cfg)
Provides:       tex(ltxdoc.cls)
Provides:       tex(ltxguide.cls)
Provides:       tex(macce.def)
Provides:       tex(makeidx.sty)
Provides:       tex(minimal.cls)
Provides:       tex(newlfont.sty)
Provides:       tex(next.def)
Provides:       tex(nfssfont.tex)
Provides:       tex(oldlfont.sty)
Provides:       tex(omlcmm.fd)
Provides:       tex(omlcmr.fd)
Provides:       tex(omlenc.def)
Provides:       tex(omllcmm.fd)
Provides:       tex(omscmr.fd)
Provides:       tex(omscmsy.fd)
Provides:       tex(omsenc.def)
Provides:       tex(omslcmsy.fd)
Provides:       tex(omxcmex.fd)
Provides:       tex(omxlcmex.fd)
Provides:       tex(openbib.sty)
Provides:       tex(ot1cmdh.fd)
Provides:       tex(ot1cmfib.fd)
Provides:       tex(ot1cmfr.fd)
Provides:       tex(ot1cmr.fd)
Provides:       tex(ot1cmss.fd)
Provides:       tex(ot1cmtt.fd)
Provides:       tex(ot1cmvtt.fd)
Provides:       tex(ot1enc.def)
Provides:       tex(ot1lcmss.fd)
Provides:       tex(ot1lcmtt.fd)
Provides:       tex(ot4enc.def)
Provides:       tex(preload.cfg)
Provides:       tex(proc.cls)
Provides:       tex(proc.sty)
Provides:       tex(report.cls)
Provides:       tex(report.sty)
Provides:       tex(sample2e.tex)
Provides:       tex(sfonts.def)
Provides:       tex(shortvrb.sty)
Provides:       tex(showidx.sty)
Provides:       tex(size10.clo)
Provides:       tex(size11.clo)
Provides:       tex(size12.clo)
Provides:       tex(slides.cls)
Provides:       tex(slides.def)
Provides:       tex(slides.sty)
Provides:       tex(small2e.tex)
Provides:       tex(source2edoc.cls)
Provides:       tex(structuredlog.sty)
Provides:       tex(syntonly.sty)
Provides:       tex(t1cmdh.fd)
Provides:       tex(t1cmfib.fd)
Provides:       tex(t1cmfr.fd)
Provides:       tex(t1cmr.fd)
Provides:       tex(t1cmss.fd)
Provides:       tex(t1cmtt.fd)
Provides:       tex(t1cmvtt.fd)
Provides:       tex(t1enc.def)
Provides:       tex(t1enc.sty)
Provides:       tex(t1lcmss.fd)
Provides:       tex(t1lcmtt.fd)
Provides:       tex(testpage.tex)
Provides:       tex(texsys.cfg)
Provides:       tex(textcomp-2018-08-11.sty)
Provides:       tex(textcomp.sty)
Provides:       tex(tracefnt.sty)
Provides:       tex(ts1cmr.fd)
Provides:       tex(ts1cmss.fd)
Provides:       tex(ts1cmtt.fd)
Provides:       tex(ts1cmvtt.fd)
Provides:       tex(ts1enc.def)
Provides:       tex(tuenc.def)
Provides:       tex(tulmdh.fd)
Provides:       tex(tulmr.fd)
Provides:       tex(tulmss.fd)
Provides:       tex(tulmssq.fd)
Provides:       tex(tulmtt.fd)
Provides:       tex(tulmvtt.fd)
Provides:       tex(ucmr.fd)
Provides:       tex(ucmss.fd)
Provides:       tex(ucmtt.fd)
Provides:       tex(ulasy.fd)
Provides:       tex(ullasy.fd)
Provides:       tex(utf8-2018.def)
Provides:       tex(utf8.def)
Requires:       tex(hypdoc.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(l3doc.cls)
Requires:       tex(multicol.sty)
Requires:       tex(url.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source279:      latex.tar.xz
Source280:      latex.doc.tar.xz

%description -n texlive-latex
LaTeX is a widely-used macro package for TeX, providing many
basic document formating commands extended by a wide range of
packages. It is a development of Leslie Lamport's LaTeX 2.09,
and superseded the older system in June 1994. The basic
distribution is catalogued separately, at latex-base; apart
from a large set of contributed packages and third-party
documentation (elsewhere on the archive), the distribution
includes: - a bunch of required packages, which LaTeX authors
are "entitled to assume" will be present on any system running
LaTeX; and - a minimal set of documentation detailing
differences from the 'old' version of LaTeX in the areas of
user commands, font selection and control, class and package
writing, font encodings, configuration options and modification
of LaTeX. For downloading details, see the linked catalogue
entries above.

%package -n texlive-latex-doc
Version:        %{texlive_version}.%{texlive_noarch}.20221101_pl1svn65161
Release:        0
Summary:        Documentation for texlive-latex
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex and texlive-alldocumentation)

%description -n texlive-latex-doc
This package includes the documentation for texlive-latex

%post -n texlive-latex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/base/README.md
%{_texmfdistdir}/doc/latex/base/alltt.pdf
%{_texmfdistdir}/doc/latex/base/bugs.txt
%{_texmfdistdir}/doc/latex/base/cfgguide.pdf
%{_texmfdistdir}/doc/latex/base/cfgguide.tex
%{_texmfdistdir}/doc/latex/base/changes.old.txt
%{_texmfdistdir}/doc/latex/base/changes.txt
%{_texmfdistdir}/doc/latex/base/classes.pdf
%{_texmfdistdir}/doc/latex/base/clsguide.pdf
%{_texmfdistdir}/doc/latex/base/clsguide.tex
%{_texmfdistdir}/doc/latex/base/cmfonts.pdf
%{_texmfdistdir}/doc/latex/base/cyrguide.pdf
%{_texmfdistdir}/doc/latex/base/cyrguide.tex
%{_texmfdistdir}/doc/latex/base/doc-code.pdf
%{_texmfdistdir}/doc/latex/base/doc-code.tex
%{_texmfdistdir}/doc/latex/base/doc.pdf
%{_texmfdistdir}/doc/latex/base/docstrip.pdf
%{_texmfdistdir}/doc/latex/base/encguide.pdf
%{_texmfdistdir}/doc/latex/base/encguide.tex
%{_texmfdistdir}/doc/latex/base/exscale.pdf
%{_texmfdistdir}/doc/latex/base/fix-cm.pdf
%{_texmfdistdir}/doc/latex/base/fntguide.pdf
%{_texmfdistdir}/doc/latex/base/fntguide.tex
%{_texmfdistdir}/doc/latex/base/graphpap.pdf
%{_texmfdistdir}/doc/latex/base/ifthen.pdf
%{_texmfdistdir}/doc/latex/base/inputenc.pdf
%{_texmfdistdir}/doc/latex/base/lamport-manual.err
%{_texmfdistdir}/doc/latex/base/lamport-manual.pdf
%{_texmfdistdir}/doc/latex/base/latexrelease.pdf
%{_texmfdistdir}/doc/latex/base/latexsym.pdf
%{_texmfdistdir}/doc/latex/base/lb2.err
%{_texmfdistdir}/doc/latex/base/lb2.pdf
%{_texmfdistdir}/doc/latex/base/legal.txt
%{_texmfdistdir}/doc/latex/base/letter.pdf
%{_texmfdistdir}/doc/latex/base/lgc2.err
%{_texmfdistdir}/doc/latex/base/lgc2.pdf
%{_texmfdistdir}/doc/latex/base/lppl-1-0.txt
%{_texmfdistdir}/doc/latex/base/lppl-1-1.txt
%{_texmfdistdir}/doc/latex/base/lppl-1-2.txt
%{_texmfdistdir}/doc/latex/base/lppl.pdf
%{_texmfdistdir}/doc/latex/base/lppl.txt
%{_texmfdistdir}/doc/latex/base/ltcmdhooks-code.pdf
%{_texmfdistdir}/doc/latex/base/ltcmdhooks-code.tex
%{_texmfdistdir}/doc/latex/base/ltcmdhooks-doc.pdf
%{_texmfdistdir}/doc/latex/base/ltcmdhooks-doc.tex
%{_texmfdistdir}/doc/latex/base/ltfilehook-code.pdf
%{_texmfdistdir}/doc/latex/base/ltfilehook-code.tex
%{_texmfdistdir}/doc/latex/base/ltfilehook-doc.pdf
%{_texmfdistdir}/doc/latex/base/ltfilehook-doc.tex
%{_texmfdistdir}/doc/latex/base/lthooks-code.pdf
%{_texmfdistdir}/doc/latex/base/lthooks-code.tex
%{_texmfdistdir}/doc/latex/base/lthooks-doc.pdf
%{_texmfdistdir}/doc/latex/base/lthooks-doc.tex
%{_texmfdistdir}/doc/latex/base/ltluatex.pdf
%{_texmfdistdir}/doc/latex/base/ltmarks-code.pdf
%{_texmfdistdir}/doc/latex/base/ltmarks-code.tex
%{_texmfdistdir}/doc/latex/base/ltmarks-doc.pdf
%{_texmfdistdir}/doc/latex/base/ltmarks-doc.tex
%{_texmfdistdir}/doc/latex/base/ltnews.pdf
%{_texmfdistdir}/doc/latex/base/ltnews.tex
%{_texmfdistdir}/doc/latex/base/ltnews01.pdf
%{_texmfdistdir}/doc/latex/base/ltnews01.tex
%{_texmfdistdir}/doc/latex/base/ltnews02.pdf
%{_texmfdistdir}/doc/latex/base/ltnews02.tex
%{_texmfdistdir}/doc/latex/base/ltnews03.pdf
%{_texmfdistdir}/doc/latex/base/ltnews03.tex
%{_texmfdistdir}/doc/latex/base/ltnews04.pdf
%{_texmfdistdir}/doc/latex/base/ltnews04.tex
%{_texmfdistdir}/doc/latex/base/ltnews05.pdf
%{_texmfdistdir}/doc/latex/base/ltnews05.tex
%{_texmfdistdir}/doc/latex/base/ltnews06.pdf
%{_texmfdistdir}/doc/latex/base/ltnews06.tex
%{_texmfdistdir}/doc/latex/base/ltnews07.pdf
%{_texmfdistdir}/doc/latex/base/ltnews07.tex
%{_texmfdistdir}/doc/latex/base/ltnews08.pdf
%{_texmfdistdir}/doc/latex/base/ltnews08.tex
%{_texmfdistdir}/doc/latex/base/ltnews09.pdf
%{_texmfdistdir}/doc/latex/base/ltnews09.tex
%{_texmfdistdir}/doc/latex/base/ltnews10.pdf
%{_texmfdistdir}/doc/latex/base/ltnews10.tex
%{_texmfdistdir}/doc/latex/base/ltnews11.pdf
%{_texmfdistdir}/doc/latex/base/ltnews11.tex
%{_texmfdistdir}/doc/latex/base/ltnews12.pdf
%{_texmfdistdir}/doc/latex/base/ltnews12.tex
%{_texmfdistdir}/doc/latex/base/ltnews13.pdf
%{_texmfdistdir}/doc/latex/base/ltnews13.tex
%{_texmfdistdir}/doc/latex/base/ltnews14.pdf
%{_texmfdistdir}/doc/latex/base/ltnews14.tex
%{_texmfdistdir}/doc/latex/base/ltnews15.pdf
%{_texmfdistdir}/doc/latex/base/ltnews15.tex
%{_texmfdistdir}/doc/latex/base/ltnews16.pdf
%{_texmfdistdir}/doc/latex/base/ltnews16.tex
%{_texmfdistdir}/doc/latex/base/ltnews17.pdf
%{_texmfdistdir}/doc/latex/base/ltnews17.tex
%{_texmfdistdir}/doc/latex/base/ltnews18.pdf
%{_texmfdistdir}/doc/latex/base/ltnews18.tex
%{_texmfdistdir}/doc/latex/base/ltnews19.pdf
%{_texmfdistdir}/doc/latex/base/ltnews19.tex
%{_texmfdistdir}/doc/latex/base/ltnews20.pdf
%{_texmfdistdir}/doc/latex/base/ltnews20.tex
%{_texmfdistdir}/doc/latex/base/ltnews21.pdf
%{_texmfdistdir}/doc/latex/base/ltnews21.tex
%{_texmfdistdir}/doc/latex/base/ltnews22.pdf
%{_texmfdistdir}/doc/latex/base/ltnews22.tex
%{_texmfdistdir}/doc/latex/base/ltnews23.pdf
%{_texmfdistdir}/doc/latex/base/ltnews23.tex
%{_texmfdistdir}/doc/latex/base/ltnews24.pdf
%{_texmfdistdir}/doc/latex/base/ltnews24.tex
%{_texmfdistdir}/doc/latex/base/ltnews25.pdf
%{_texmfdistdir}/doc/latex/base/ltnews25.tex
%{_texmfdistdir}/doc/latex/base/ltnews26.pdf
%{_texmfdistdir}/doc/latex/base/ltnews26.tex
%{_texmfdistdir}/doc/latex/base/ltnews27.pdf
%{_texmfdistdir}/doc/latex/base/ltnews27.tex
%{_texmfdistdir}/doc/latex/base/ltnews28.pdf
%{_texmfdistdir}/doc/latex/base/ltnews28.tex
%{_texmfdistdir}/doc/latex/base/ltnews29.pdf
%{_texmfdistdir}/doc/latex/base/ltnews29.tex
%{_texmfdistdir}/doc/latex/base/ltnews30.pdf
%{_texmfdistdir}/doc/latex/base/ltnews30.tex
%{_texmfdistdir}/doc/latex/base/ltnews31.pdf
%{_texmfdistdir}/doc/latex/base/ltnews31.tex
%{_texmfdistdir}/doc/latex/base/ltnews32.pdf
%{_texmfdistdir}/doc/latex/base/ltnews32.tex
%{_texmfdistdir}/doc/latex/base/ltnews33.pdf
%{_texmfdistdir}/doc/latex/base/ltnews33.tex
%{_texmfdistdir}/doc/latex/base/ltnews34.pdf
%{_texmfdistdir}/doc/latex/base/ltnews34.tex
%{_texmfdistdir}/doc/latex/base/ltnews35.pdf
%{_texmfdistdir}/doc/latex/base/ltnews35.tex
%{_texmfdistdir}/doc/latex/base/ltnews36.pdf
%{_texmfdistdir}/doc/latex/base/ltnews36.tex
%{_texmfdistdir}/doc/latex/base/ltpara-code.pdf
%{_texmfdistdir}/doc/latex/base/ltpara-code.tex
%{_texmfdistdir}/doc/latex/base/ltpara-doc.pdf
%{_texmfdistdir}/doc/latex/base/ltpara-doc.tex
%{_texmfdistdir}/doc/latex/base/ltshipout-code.pdf
%{_texmfdistdir}/doc/latex/base/ltshipout-code.tex
%{_texmfdistdir}/doc/latex/base/ltshipout-doc.pdf
%{_texmfdistdir}/doc/latex/base/ltshipout-doc.tex
%{_texmfdistdir}/doc/latex/base/ltx3info.pdf
%{_texmfdistdir}/doc/latex/base/ltx3info.tex
%{_texmfdistdir}/doc/latex/base/ltxdoc.pdf
%{_texmfdistdir}/doc/latex/base/makeindx.pdf
%{_texmfdistdir}/doc/latex/base/manifest.txt
%{_texmfdistdir}/doc/latex/base/modguide.pdf
%{_texmfdistdir}/doc/latex/base/modguide.tex
%{_texmfdistdir}/doc/latex/base/nfssfont.pdf
%{_texmfdistdir}/doc/latex/base/proc.pdf
%{_texmfdistdir}/doc/latex/base/slides.pdf
%{_texmfdistdir}/doc/latex/base/slifonts.pdf
%{_texmfdistdir}/doc/latex/base/source2e.pdf
%{_texmfdistdir}/doc/latex/base/source2e.tex
%{_texmfdistdir}/doc/latex/base/syntonly.pdf
%{_texmfdistdir}/doc/latex/base/tlc2.err
%{_texmfdistdir}/doc/latex/base/tlc2.pdf
%{_texmfdistdir}/doc/latex/base/tulm.pdf
%{_texmfdistdir}/doc/latex/base/usrguide-historic.pdf
%{_texmfdistdir}/doc/latex/base/usrguide-historic.tex
%{_texmfdistdir}/doc/latex/base/usrguide.pdf
%{_texmfdistdir}/doc/latex/base/usrguide.tex
%{_texmfdistdir}/doc/latex/base/utf8ienc.pdf
%{_texmfdistdir}/doc/latex/base/webcomp.err
%{_texmfdistdir}/doc/latex/base/webcomp.pdf

%files -n texlive-latex
%defattr(-,root,root,755)
%{_texmfdistdir}/makeindex/latex/gglo.ist
%{_texmfdistdir}/makeindex/latex/gind.ist
%{_texmfdistdir}/tex/latex/base/alltt.sty
%{_texmfdistdir}/tex/latex/base/ansinew.def
%{_texmfdistdir}/tex/latex/base/applemac.def
%{_texmfdistdir}/tex/latex/base/article.cls
%{_texmfdistdir}/tex/latex/base/article.sty
%{_texmfdistdir}/tex/latex/base/ascii.def
%{_texmfdistdir}/tex/latex/base/atbegshi-ltx.sty
%{_texmfdistdir}/tex/latex/base/atveryend-ltx.sty
%{_texmfdistdir}/tex/latex/base/bezier.sty
%{_texmfdistdir}/tex/latex/base/bk10.clo
%{_texmfdistdir}/tex/latex/base/bk11.clo
%{_texmfdistdir}/tex/latex/base/bk12.clo
%{_texmfdistdir}/tex/latex/base/book.cls
%{_texmfdistdir}/tex/latex/base/book.sty
%{_texmfdistdir}/tex/latex/base/cp1250.def
%{_texmfdistdir}/tex/latex/base/cp1252.def
%{_texmfdistdir}/tex/latex/base/cp1257.def
%{_texmfdistdir}/tex/latex/base/cp437.def
%{_texmfdistdir}/tex/latex/base/cp437de.def
%{_texmfdistdir}/tex/latex/base/cp850.def
%{_texmfdistdir}/tex/latex/base/cp852.def
%{_texmfdistdir}/tex/latex/base/cp858.def
%{_texmfdistdir}/tex/latex/base/cp865.def
%{_texmfdistdir}/tex/latex/base/decmulti.def
%{_texmfdistdir}/tex/latex/base/doc-2016-02-15.sty
%{_texmfdistdir}/tex/latex/base/doc-2021-06-01.sty
%{_texmfdistdir}/tex/latex/base/doc.sty
%{_texmfdistdir}/tex/latex/base/docstrip.tex
%{_texmfdistdir}/tex/latex/base/exscale.sty
%{_texmfdistdir}/tex/latex/base/fix-cm.sty
%{_texmfdistdir}/tex/latex/base/fixltx2e.sty
%{_texmfdistdir}/tex/latex/base/flafter.sty
%{_texmfdistdir}/tex/latex/base/fleqn.clo
%{_texmfdistdir}/tex/latex/base/fleqn.sty
%{_texmfdistdir}/tex/latex/base/fltrace.sty
%{_texmfdistdir}/tex/latex/base/fontenc.sty
%{_texmfdistdir}/tex/latex/base/fontmath.cfg
%{_texmfdistdir}/tex/latex/base/fontmath.ltx
%{_texmfdistdir}/tex/latex/base/fonttext.cfg
%{_texmfdistdir}/tex/latex/base/fonttext.ltx
%{_texmfdistdir}/tex/latex/base/graphpap.sty
%{_texmfdistdir}/tex/latex/base/hyphen.ltx
%{_texmfdistdir}/tex/latex/base/idx.tex
%{_texmfdistdir}/tex/latex/base/ifthen.sty
%{_texmfdistdir}/tex/latex/base/inputenc.sty
%{_texmfdistdir}/tex/latex/base/lablst.tex
%{_texmfdistdir}/tex/latex/base/latex.ltx
%{_texmfdistdir}/tex/latex/base/latex209.def
%{_texmfdistdir}/tex/latex/base/latexrelease.sty
%{_texmfdistdir}/tex/latex/base/latexsym.sty
%{_texmfdistdir}/tex/latex/base/latin1.def
%{_texmfdistdir}/tex/latex/base/latin10.def
%{_texmfdistdir}/tex/latex/base/latin2.def
%{_texmfdistdir}/tex/latex/base/latin3.def
%{_texmfdistdir}/tex/latex/base/latin4.def
%{_texmfdistdir}/tex/latex/base/latin5.def
%{_texmfdistdir}/tex/latex/base/latin9.def
%{_texmfdistdir}/tex/latex/base/lcyenc.dfu
%{_texmfdistdir}/tex/latex/base/leqno.clo
%{_texmfdistdir}/tex/latex/base/leqno.sty
%{_texmfdistdir}/tex/latex/base/letter.cls
%{_texmfdistdir}/tex/latex/base/letter.sty
%{_texmfdistdir}/tex/latex/base/lppl.tex
%{_texmfdistdir}/tex/latex/base/ltluatex.lua
%{_texmfdistdir}/tex/latex/base/ltluatex.tex
%{_texmfdistdir}/tex/latex/base/ltnews.cls
%{_texmfdistdir}/tex/latex/base/ltxcheck.tex
%{_texmfdistdir}/tex/latex/base/ltxdoc.cfg
%{_texmfdistdir}/tex/latex/base/ltxdoc.cls
%{_texmfdistdir}/tex/latex/base/ltxguide.cls
%{_texmfdistdir}/tex/latex/base/ly1enc.dfu
%{_texmfdistdir}/tex/latex/base/macce.def
%{_texmfdistdir}/tex/latex/base/makeidx.sty
%{_texmfdistdir}/tex/latex/base/minimal.cls
%{_texmfdistdir}/tex/latex/base/newlfont.sty
%{_texmfdistdir}/tex/latex/base/next.def
%{_texmfdistdir}/tex/latex/base/nfssfont.tex
%{_texmfdistdir}/tex/latex/base/oldlfont.sty
%{_texmfdistdir}/tex/latex/base/omlcmm.fd
%{_texmfdistdir}/tex/latex/base/omlcmr.fd
%{_texmfdistdir}/tex/latex/base/omlenc.def
%{_texmfdistdir}/tex/latex/base/omllcmm.fd
%{_texmfdistdir}/tex/latex/base/omscmr.fd
%{_texmfdistdir}/tex/latex/base/omscmsy.fd
%{_texmfdistdir}/tex/latex/base/omsenc.def
%{_texmfdistdir}/tex/latex/base/omsenc.dfu
%{_texmfdistdir}/tex/latex/base/omslcmsy.fd
%{_texmfdistdir}/tex/latex/base/omxcmex.fd
%{_texmfdistdir}/tex/latex/base/omxlcmex.fd
%{_texmfdistdir}/tex/latex/base/openbib.sty
%{_texmfdistdir}/tex/latex/base/ot1cmdh.fd
%{_texmfdistdir}/tex/latex/base/ot1cmfib.fd
%{_texmfdistdir}/tex/latex/base/ot1cmfr.fd
%{_texmfdistdir}/tex/latex/base/ot1cmr.fd
%{_texmfdistdir}/tex/latex/base/ot1cmss.fd
%{_texmfdistdir}/tex/latex/base/ot1cmtt.fd
%{_texmfdistdir}/tex/latex/base/ot1cmvtt.fd
%{_texmfdistdir}/tex/latex/base/ot1enc.def
%{_texmfdistdir}/tex/latex/base/ot1enc.dfu
%{_texmfdistdir}/tex/latex/base/ot1lcmss.fd
%{_texmfdistdir}/tex/latex/base/ot1lcmtt.fd
%{_texmfdistdir}/tex/latex/base/ot2enc.dfu
%{_texmfdistdir}/tex/latex/base/ot4enc.def
%{_texmfdistdir}/tex/latex/base/preload.cfg
%{_texmfdistdir}/tex/latex/base/preload.ltx
%{_texmfdistdir}/tex/latex/base/proc.cls
%{_texmfdistdir}/tex/latex/base/proc.sty
%{_texmfdistdir}/tex/latex/base/report.cls
%{_texmfdistdir}/tex/latex/base/report.sty
%{_texmfdistdir}/tex/latex/base/sample2e.tex
%{_texmfdistdir}/tex/latex/base/sfonts.def
%{_texmfdistdir}/tex/latex/base/shortvrb.sty
%{_texmfdistdir}/tex/latex/base/showidx.sty
%{_texmfdistdir}/tex/latex/base/size10.clo
%{_texmfdistdir}/tex/latex/base/size11.clo
%{_texmfdistdir}/tex/latex/base/size12.clo
%{_texmfdistdir}/tex/latex/base/slides.cls
%{_texmfdistdir}/tex/latex/base/slides.def
%{_texmfdistdir}/tex/latex/base/slides.sty
%{_texmfdistdir}/tex/latex/base/small2e.tex
%{_texmfdistdir}/tex/latex/base/source2edoc.cls
%{_texmfdistdir}/tex/latex/base/structuredlog.sty
%{_texmfdistdir}/tex/latex/base/syntonly.sty
%{_texmfdistdir}/tex/latex/base/t1cmdh.fd
%{_texmfdistdir}/tex/latex/base/t1cmfib.fd
%{_texmfdistdir}/tex/latex/base/t1cmfr.fd
%{_texmfdistdir}/tex/latex/base/t1cmr.fd
%{_texmfdistdir}/tex/latex/base/t1cmss.fd
%{_texmfdistdir}/tex/latex/base/t1cmtt.fd
%{_texmfdistdir}/tex/latex/base/t1cmvtt.fd
%{_texmfdistdir}/tex/latex/base/t1enc.def
%{_texmfdistdir}/tex/latex/base/t1enc.dfu
%{_texmfdistdir}/tex/latex/base/t1enc.sty
%{_texmfdistdir}/tex/latex/base/t1lcmss.fd
%{_texmfdistdir}/tex/latex/base/t1lcmtt.fd
%{_texmfdistdir}/tex/latex/base/t2aenc.dfu
%{_texmfdistdir}/tex/latex/base/t2benc.dfu
%{_texmfdistdir}/tex/latex/base/t2cenc.dfu
%{_texmfdistdir}/tex/latex/base/testpage.tex
%{_texmfdistdir}/tex/latex/base/texsys.cfg
%{_texmfdistdir}/tex/latex/base/textcomp-2018-08-11.sty
%{_texmfdistdir}/tex/latex/base/textcomp.sty
%{_texmfdistdir}/tex/latex/base/tracefnt.sty
%{_texmfdistdir}/tex/latex/base/ts1cmr.fd
%{_texmfdistdir}/tex/latex/base/ts1cmss.fd
%{_texmfdistdir}/tex/latex/base/ts1cmtt.fd
%{_texmfdistdir}/tex/latex/base/ts1cmvtt.fd
%{_texmfdistdir}/tex/latex/base/ts1enc.def
%{_texmfdistdir}/tex/latex/base/ts1enc.dfu
%{_texmfdistdir}/tex/latex/base/tuenc.def
%{_texmfdistdir}/tex/latex/base/tulmdh.fd
%{_texmfdistdir}/tex/latex/base/tulmr.fd
%{_texmfdistdir}/tex/latex/base/tulmss.fd
%{_texmfdistdir}/tex/latex/base/tulmssq.fd
%{_texmfdistdir}/tex/latex/base/tulmtt.fd
%{_texmfdistdir}/tex/latex/base/tulmvtt.fd
%{_texmfdistdir}/tex/latex/base/ucmr.fd
%{_texmfdistdir}/tex/latex/base/ucmss.fd
%{_texmfdistdir}/tex/latex/base/ucmtt.fd
%{_texmfdistdir}/tex/latex/base/ulasy.fd
%{_texmfdistdir}/tex/latex/base/ullasy.fd
%{_texmfdistdir}/tex/latex/base/utf8-2018.def
%{_texmfdistdir}/tex/latex/base/utf8.def
%{_texmfdistdir}/tex/latex/base/utf8enc.dfu
%{_texmfdistdir}/tex/latex/base/x2enc.dfu

%package -n texlive-latex-bin
Version:        %{texlive_version}.%{texlive_noarch}.svn66186
Release:        0
License:        LPPL-1.0
Summary:        LaTeX executables and man pages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Recommends:     texlive-collection-fontsrecommended >= %{texlive_version}
Recommends:     texlive-collection-genericrecommended >= %{texlive_version}
Recommends:     texlive-collection-latexrecommended >= %{texlive_version}
Requires:       texlive-atbegshi >= %{texlive_version}
#!BuildIgnore: texlive-atbegshi
Requires:       texlive-atveryend >= %{texlive_version}
#!BuildIgnore: texlive-atveryend
Requires:       texlive-babel >= %{texlive_version}
#!BuildIgnore: texlive-babel
Requires:       texlive-cm >= %{texlive_version}
#!BuildIgnore: texlive-cm
Requires:       texlive-dehyph >= %{texlive_version}
#!BuildIgnore: texlive-dehyph
Requires:       texlive-everyshi >= %{texlive_version}
#!BuildIgnore: texlive-everyshi
Requires:       texlive-firstaid >= %{texlive_version}
#!BuildIgnore: texlive-firstaid
Requires:       texlive-graphics >= %{texlive_version}
#!BuildIgnore: texlive-graphics
Requires:       texlive-hyph-utf8 >= %{texlive_version}
#!BuildIgnore: texlive-hyph-utf8
Requires:       texlive-hyphen-base >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-base
Requires:       texlive-l3backend >= %{texlive_version}
#!BuildIgnore: texlive-l3backend
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires:       texlive-l3packages >= %{texlive_version}
#!BuildIgnore: texlive-l3packages
Requires:       texlive-latex >= %{texlive_version}
#!BuildIgnore: texlive-latex
Requires(pre):  texlive-latex-bin-bin >= %{texlive_version}
#!BuildIgnore: texlive-latex-bin-bin
Requires:       texlive-latex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-latex-fonts
Requires:       texlive-latexconfig >= %{texlive_version}
#!BuildIgnore: texlive-latexconfig
Requires:       texlive-lm >= %{texlive_version}
#!BuildIgnore: texlive-lm
Requires:       texlive-luahbtex >= %{texlive_version}
#!BuildIgnore: texlive-luahbtex
Requires:       texlive-luaotfload >= %{texlive_version}
#!BuildIgnore: texlive-luaotfload
Requires:       texlive-luatex >= %{texlive_version}
#!BuildIgnore: texlive-luatex
Requires:       texlive-pdftex >= %{texlive_version}
#!BuildIgnore: texlive-pdftex
Requires:       texlive-tex-ini-files >= %{texlive_version}
#!BuildIgnore: texlive-tex-ini-files
Requires:       texlive-unicode-data >= %{texlive_version}
#!BuildIgnore: texlive-unicode-data
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(language.dat)
Requires(post): tex(language.def)
Requires(post): tex(language.dat.lua)
#!BuildIgnore:  tex(language.dat)
#!BuildIgnore:  tex(language.def)
#!BuildIgnore:  tex(language.dat.lua)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(language.dat)
Requires(postun):tex(language.def)
Requires(postun):tex(language.dat.lua)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires(posttrans):texlive-amsfonts >= %{texlive_version}
Requires(posttrans):texlive-cm >= %{texlive_version}
Requires(posttrans):texlive-cm-super >= %{texlive_version}
Requires(posttrans):texlive-ec >= %{texlive_version}
Requires(posttrans):texlive-dehyph-exptl >= %{texlive_version}
Requires(posttrans):texlive-graphics-def >= %{texlive_version}
Requires(posttrans):texlive-hyph-utf8 >= %{texlive_version}
Requires(posttrans):texlive-hyphen-base >= %{texlive_version}
Requires(posttrans):texlive-hyphen-ancientgreek >= %{texlive_version}
Requires(posttrans):texlive-hyphen-german >= %{texlive_version}
Requires(posttrans):texlive-hyphen-greek >= %{texlive_version}
Requires(posttrans):texlive-pdftex >= %{texlive_version}
Requires(posttrans):texlive-ruhyphen >= %{texlive_version}
Requires(posttrans):texlive-ukrhyph >= %{texlive_version}
Provides:       man(dvilualatex.1)
Provides:       man(latex.1)
Provides:       man(lualatex.1)
Provides:       man(pdflatex.1)
Suggests:       man(pdftex.1)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source281:      latex-bin.doc.tar.xz

%description -n texlive-latex-bin
The latex-bin package

%post -n texlive-latex-bin
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
> /var/run/texlive/run-fmtutil.dvilualatex
sed -ri 's/^\#\![[= =]]+dvilualatex\b.*/dvilualatex luatex language.dat,language.dat.lua dvilualatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.latex
sed -ri 's/^\#\![[= =]]+latex\b.*/latex pdftex language.dat -translate-file=cp227.tcx *latex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.lualatex
sed -ri 's/^\#\![[= =]]+lualatex\b.*/lualatex luahbtex language.dat,language.dat.lua lualatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.pdflatex
sed -ri 's/^\#\![[= =]]+pdflatex\b.*/pdflatex pdftex language.dat -translate-file=cp227.tcx *pdflatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :

%postun -n texlive-latex-bin
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    sed -ri 's/^(dvilualatex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/luatex/dvilualatex.*
    sed -ri 's/^(latex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/latex.*
    sed -ri 's/^(lualatex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/luahbtex/lualatex.*
    sed -ri 's/^(pdflatex\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/pdflatex.*
    exit 0
fi

%triggerin -n texlive-latex-bin -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-atveryend
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-atveryend
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-babel
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-babel
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-cm
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-cm
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-dehyph
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-dehyph
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-everyshi
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-everyshi
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-firstaid
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-firstaid
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-l3backend
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-l3backend
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-l3packages
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-l3packages
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-latex
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-latex
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerin -n texlive-latex-bin -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%triggerun -n texlive-latex-bin -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.dvilualatex
> /var/run/texlive/run-fmtutil.latex
> /var/run/texlive/run-fmtutil.lualatex
> /var/run/texlive/run-fmtutil.pdflatex

%posttrans -n texlive-latex-bin
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-bin
%defattr(-,root,root,755)
%{_mandir}/man1/dvilualatex.1*
%{_mandir}/man1/latex.1*
%{_mandir}/man1/lualatex.1*
%{_mandir}/man1/pdflatex.1*

%package -n texlive-latex-amsmath-dev
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
License:        LPPL-1.0
Summary:        Development pre-release of the LaTeX amsmath bundle
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-amsmath-dev-doc >= %{texlive_version}
Provides:       texdev(amsbsy.sty)
Provides:       texdev(amscd.sty)
Provides:       texdev(amsgen.sty)
Provides:       texdev(amsmath-2018-12-01.sty)
Provides:       texdev(amsmath.sty)
Provides:       texdev(amsopn.sty)
Provides:       texdev(amstex.sty)
Provides:       texdev(amstext.sty)
Provides:       texdev(amsxtra.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source282:      latex-amsmath-dev.tar.xz
Source283:      latex-amsmath-dev.doc.tar.xz

%description -n texlive-latex-amsmath-dev
This is a pre-release version of the standard LaTeX amsmath
bundle. It accompanies the pre-testing kernel code
(latex-base-dev), and is intended for testing by knowledgeable
users.

%package -n texlive-latex-amsmath-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
Summary:        Documentation for texlive-latex-amsmath-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-amsmath-dev and texlive-alldocumentation)
Provides:       locale(texlive-latex-amsmath-dev-doc:en)

%description -n texlive-latex-amsmath-dev-doc
This package includes the documentation for texlive-latex-amsmath-dev

%post -n texlive-latex-amsmath-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-amsmath-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-amsmath-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-amsmath-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/amsmath/README.md
%{_texmfdistdir}/doc/latex-dev/amsmath/ams-external.txt
%{_texmfdistdir}/doc/latex-dev/amsmath/ams-internal.txt
%{_texmfdistdir}/doc/latex-dev/amsmath/amsbsy.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amscd.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amsgen.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amsldoc.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amsldoc.tex
%{_texmfdistdir}/doc/latex-dev/amsmath/amsmath.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amsopn.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amstext.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/amsxtra.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/changes.txt
%{_texmfdistdir}/doc/latex-dev/amsmath/diffs-m.txt
%{_texmfdistdir}/doc/latex-dev/amsmath/manifest.txt
%{_texmfdistdir}/doc/latex-dev/amsmath/subeqn.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/subeqn.tex
%{_texmfdistdir}/doc/latex-dev/amsmath/technote.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/technote.tex
%{_texmfdistdir}/doc/latex-dev/amsmath/testmath.pdf
%{_texmfdistdir}/doc/latex-dev/amsmath/testmath.tex

%files -n texlive-latex-amsmath-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/amsmath/amsbsy.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amscd.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amsgen.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amsmath-2018-12-01.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amsmath.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amsopn.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amstex.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amstext.sty
%{_texmfdistdir}/tex/latex-dev/amsmath/amsxtra.sty

%package -n texlive-latex-base-dev
Version:        %{texlive_version}.%{texlive_noarch}.20230601_pre_release_2svn66513
Release:        0
License:        LPPL-1.0
Summary:        Development pre-release of the LaTeX kernel
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-base-dev-doc >= %{texlive_version}
Provides:       texdev(alltt.sty)
Provides:       texdev(ansinew.def)
Provides:       texdev(applemac.def)
Provides:       texdev(article.cls)
Provides:       texdev(article.sty)
Provides:       texdev(ascii.def)
Provides:       texdev(atbegshi-ltx.sty)
Provides:       texdev(atveryend-ltx.sty)
Provides:       texdev(bezier.sty)
Provides:       texdev(bk10.clo)
Provides:       texdev(bk11.clo)
Provides:       texdev(bk12.clo)
Provides:       texdev(book.cls)
Provides:       texdev(book.sty)
Provides:       texdev(cp1250.def)
Provides:       texdev(cp1252.def)
Provides:       texdev(cp1257.def)
Provides:       texdev(cp437.def)
Provides:       texdev(cp437de.def)
Provides:       texdev(cp850.def)
Provides:       texdev(cp852.def)
Provides:       texdev(cp858.def)
Provides:       texdev(cp865.def)
Provides:       texdev(decmulti.def)
Provides:       texdev(doc-2016-02-15.sty)
Provides:       texdev(doc-2021-06-01.sty)
Provides:       texdev(doc.sty)
Provides:       texdev(docstrip.tex)
Provides:       texdev(exscale.sty)
Provides:       texdev(fix-cm.sty)
Provides:       texdev(fixltx2e.sty)
Provides:       texdev(flafter.sty)
Provides:       texdev(fleqn.clo)
Provides:       texdev(fleqn.sty)
Provides:       texdev(fltrace.sty)
Provides:       texdev(fontenc.sty)
Provides:       texdev(fontmath.cfg)
Provides:       texdev(fonttext.cfg)
Provides:       texdev(graphpap.sty)
Provides:       texdev(idx.tex)
Provides:       texdev(ifthen.sty)
Provides:       texdev(inputenc.sty)
Provides:       texdev(lablst.tex)
Provides:       texdev(latex209.def)
Provides:       texdev(latexrelease.sty)
Provides:       texdev(latexsym.sty)
Provides:       texdev(latin1.def)
Provides:       texdev(latin10.def)
Provides:       texdev(latin2.def)
Provides:       texdev(latin3.def)
Provides:       texdev(latin4.def)
Provides:       texdev(latin5.def)
Provides:       texdev(latin9.def)
Provides:       texdev(leqno.clo)
Provides:       texdev(leqno.sty)
Provides:       texdev(letter.cls)
Provides:       texdev(letter.sty)
Provides:       texdev(lppl.tex)
Provides:       texdev(ltluatex.tex)
Provides:       texdev(ltnews.cls)
Provides:       texdev(ltxcheck.tex)
Provides:       texdev(ltxdoc.cfg)
Provides:       texdev(ltxdoc.cls)
Provides:       texdev(ltxguide.cls)
Provides:       texdev(macce.def)
Provides:       texdev(makeidx.sty)
Provides:       texdev(minimal.cls)
Provides:       texdev(newlfont.sty)
Provides:       texdev(next.def)
Provides:       texdev(nfssfont.tex)
Provides:       texdev(oldlfont.sty)
Provides:       texdev(omlcmm.fd)
Provides:       texdev(omlcmr.fd)
Provides:       texdev(omlenc.def)
Provides:       texdev(omllcmm.fd)
Provides:       texdev(omscmr.fd)
Provides:       texdev(omscmsy.fd)
Provides:       texdev(omsenc.def)
Provides:       texdev(omslcmsy.fd)
Provides:       texdev(omxcmex.fd)
Provides:       texdev(omxlcmex.fd)
Provides:       texdev(openbib.sty)
Provides:       texdev(ot1cmdh.fd)
Provides:       texdev(ot1cmfib.fd)
Provides:       texdev(ot1cmfr.fd)
Provides:       texdev(ot1cmr.fd)
Provides:       texdev(ot1cmss.fd)
Provides:       texdev(ot1cmtt.fd)
Provides:       texdev(ot1cmvtt.fd)
Provides:       texdev(ot1enc.def)
Provides:       texdev(ot1lcmss.fd)
Provides:       texdev(ot1lcmtt.fd)
Provides:       texdev(ot4enc.def)
Provides:       texdev(preload.cfg)
Provides:       texdev(proc.cls)
Provides:       texdev(proc.sty)
Provides:       texdev(report.cls)
Provides:       texdev(report.sty)
Provides:       texdev(sample2e.tex)
Provides:       texdev(sfonts.def)
Provides:       texdev(shortvrb.sty)
Provides:       texdev(showidx.sty)
Provides:       texdev(size10.clo)
Provides:       texdev(size11.clo)
Provides:       texdev(size12.clo)
Provides:       texdev(slides.cls)
Provides:       texdev(slides.def)
Provides:       texdev(slides.sty)
Provides:       texdev(small2e.tex)
Provides:       texdev(source2edoc.cls)
Provides:       texdev(structuredlog.sty)
Provides:       texdev(syntonly.sty)
Provides:       texdev(t1cmdh.fd)
Provides:       texdev(t1cmfib.fd)
Provides:       texdev(t1cmfr.fd)
Provides:       texdev(t1cmr.fd)
Provides:       texdev(t1cmss.fd)
Provides:       texdev(t1cmtt.fd)
Provides:       texdev(t1cmvtt.fd)
Provides:       texdev(t1enc.def)
Provides:       texdev(t1enc.sty)
Provides:       texdev(t1lcmss.fd)
Provides:       texdev(t1lcmtt.fd)
Provides:       texdev(testpage.tex)
Provides:       texdev(texsys.cfg)
Provides:       texdev(textcomp-2018-08-11.sty)
Provides:       texdev(textcomp.sty)
Provides:       texdev(tracefnt.sty)
Provides:       texdev(ts1cmr.fd)
Provides:       texdev(ts1cmss.fd)
Provides:       texdev(ts1cmtt.fd)
Provides:       texdev(ts1cmvtt.fd)
Provides:       texdev(ts1enc.def)
Provides:       texdev(tuenc.def)
Provides:       texdev(tulmdh.fd)
Provides:       texdev(tulmr.fd)
Provides:       texdev(tulmss.fd)
Provides:       texdev(tulmssq.fd)
Provides:       texdev(tulmtt.fd)
Provides:       texdev(tulmvtt.fd)
Provides:       texdev(ucmr.fd)
Provides:       texdev(ucmss.fd)
Provides:       texdev(ucmtt.fd)
Provides:       texdev(ulasy.fd)
Provides:       texdev(ullasy.fd)
Provides:       texdev(utf8-2018.def)
Provides:       texdev(utf8.def)
Requires:       tex(hypdoc.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(l3doc.cls)
Requires:       tex(url.sty)
Requires:       texdev(multicol.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source284:      latex-base-dev.tar.xz
Source285:      latex-base-dev.doc.tar.xz

%description -n texlive-latex-base-dev
This package provides a testing release for upcoming LaTeX2e
kernel changes. Testing by the LaTeX team itself suggests that
the code is stable and usable, but wider use by knowledgeable
users is required by adding these changes to the release LaTeX
kernel. Typically, the code here will be used by a TeX system
to create dedicated formats, for example pdflatex-dev, which
can then be used explicitly for testing.

%package -n texlive-latex-base-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.20230601_pre_release_2svn66513
Release:        0
Summary:        Documentation for texlive-latex-base-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-base-dev and texlive-alldocumentation)

%description -n texlive-latex-base-dev-doc
This package includes the documentation for texlive-latex-base-dev

%post -n texlive-latex-base-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-base-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-base-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-base-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/base/README.md
%{_texmfdistdir}/doc/latex-dev/base/alltt.pdf
%{_texmfdistdir}/doc/latex-dev/base/bugs.txt
%{_texmfdistdir}/doc/latex-dev/base/cfgguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/cfgguide.tex
%{_texmfdistdir}/doc/latex-dev/base/changes.old.txt
%{_texmfdistdir}/doc/latex-dev/base/changes.txt
%{_texmfdistdir}/doc/latex-dev/base/classes.pdf
%{_texmfdistdir}/doc/latex-dev/base/clsguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/clsguide.tex
%{_texmfdistdir}/doc/latex-dev/base/cmfonts.pdf
%{_texmfdistdir}/doc/latex-dev/base/cyrguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/cyrguide.tex
%{_texmfdistdir}/doc/latex-dev/base/doc-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/doc-code.tex
%{_texmfdistdir}/doc/latex-dev/base/doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/docstrip.pdf
%{_texmfdistdir}/doc/latex-dev/base/encguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/encguide.tex
%{_texmfdistdir}/doc/latex-dev/base/exscale.pdf
%{_texmfdistdir}/doc/latex-dev/base/fix-cm.pdf
%{_texmfdistdir}/doc/latex-dev/base/fntguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/fntguide.tex
%{_texmfdistdir}/doc/latex-dev/base/graphpap.pdf
%{_texmfdistdir}/doc/latex-dev/base/ifthen.pdf
%{_texmfdistdir}/doc/latex-dev/base/inputenc.pdf
%{_texmfdistdir}/doc/latex-dev/base/lamport-manual.err
%{_texmfdistdir}/doc/latex-dev/base/lamport-manual.pdf
%{_texmfdistdir}/doc/latex-dev/base/latexrelease.pdf
%{_texmfdistdir}/doc/latex-dev/base/latexsym.pdf
%{_texmfdistdir}/doc/latex-dev/base/lb2.err
%{_texmfdistdir}/doc/latex-dev/base/lb2.pdf
%{_texmfdistdir}/doc/latex-dev/base/legal.txt
%{_texmfdistdir}/doc/latex-dev/base/letter.pdf
%{_texmfdistdir}/doc/latex-dev/base/lgc2.err
%{_texmfdistdir}/doc/latex-dev/base/lgc2.pdf
%{_texmfdistdir}/doc/latex-dev/base/lppl-1-0.txt
%{_texmfdistdir}/doc/latex-dev/base/lppl-1-1.txt
%{_texmfdistdir}/doc/latex-dev/base/lppl-1-2.txt
%{_texmfdistdir}/doc/latex-dev/base/lppl.pdf
%{_texmfdistdir}/doc/latex-dev/base/lppl.txt
%{_texmfdistdir}/doc/latex-dev/base/ltcmdhooks-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltcmdhooks-code.tex
%{_texmfdistdir}/doc/latex-dev/base/ltcmdhooks-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltcmdhooks-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/ltfilehook-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltfilehook-code.tex
%{_texmfdistdir}/doc/latex-dev/base/ltfilehook-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltfilehook-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/lthooks-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/lthooks-code.tex
%{_texmfdistdir}/doc/latex-dev/base/lthooks-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/lthooks-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/ltluatex.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltmarks-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltmarks-code.tex
%{_texmfdistdir}/doc/latex-dev/base/ltmarks-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltmarks-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews01.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews01.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews02.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews02.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews03.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews03.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews04.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews04.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews05.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews05.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews06.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews06.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews07.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews07.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews08.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews08.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews09.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews09.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews10.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews10.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews11.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews11.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews12.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews12.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews13.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews13.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews14.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews14.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews15.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews15.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews16.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews16.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews17.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews17.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews18.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews18.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews19.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews19.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews20.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews20.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews21.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews21.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews22.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews22.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews23.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews23.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews24.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews24.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews25.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews25.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews26.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews26.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews27.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews27.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews28.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews28.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews29.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews29.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews30.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews30.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews31.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews31.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews32.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews32.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews33.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews33.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews34.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews34.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews35.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews35.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews36.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews36.tex
%{_texmfdistdir}/doc/latex-dev/base/ltnews37.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltnews37.tex
%{_texmfdistdir}/doc/latex-dev/base/ltpara-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltpara-code.tex
%{_texmfdistdir}/doc/latex-dev/base/ltpara-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltpara-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/ltshipout-code.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltshipout-code.tex
%{_texmfdistdir}/doc/latex-dev/base/ltshipout-doc.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltshipout-doc.tex
%{_texmfdistdir}/doc/latex-dev/base/ltx3info.pdf
%{_texmfdistdir}/doc/latex-dev/base/ltx3info.tex
%{_texmfdistdir}/doc/latex-dev/base/ltxdoc.pdf
%{_texmfdistdir}/doc/latex-dev/base/makeindx.pdf
%{_texmfdistdir}/doc/latex-dev/base/manifest.txt
%{_texmfdistdir}/doc/latex-dev/base/modguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/modguide.tex
%{_texmfdistdir}/doc/latex-dev/base/nfssfont.pdf
%{_texmfdistdir}/doc/latex-dev/base/proc.pdf
%{_texmfdistdir}/doc/latex-dev/base/slides.pdf
%{_texmfdistdir}/doc/latex-dev/base/slifonts.pdf
%{_texmfdistdir}/doc/latex-dev/base/source2e.pdf
%{_texmfdistdir}/doc/latex-dev/base/source2e.tex
%{_texmfdistdir}/doc/latex-dev/base/syntonly.pdf
%{_texmfdistdir}/doc/latex-dev/base/tlc2.err
%{_texmfdistdir}/doc/latex-dev/base/tlc2.pdf
%{_texmfdistdir}/doc/latex-dev/base/tulm.pdf
%{_texmfdistdir}/doc/latex-dev/base/usrguide-historic.pdf
%{_texmfdistdir}/doc/latex-dev/base/usrguide-historic.tex
%{_texmfdistdir}/doc/latex-dev/base/usrguide.pdf
%{_texmfdistdir}/doc/latex-dev/base/usrguide.tex
%{_texmfdistdir}/doc/latex-dev/base/utf8ienc.pdf
%{_texmfdistdir}/doc/latex-dev/base/webcomp.err
%{_texmfdistdir}/doc/latex-dev/base/webcomp.pdf

%files -n texlive-latex-base-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/base/alltt.sty
%{_texmfdistdir}/tex/latex-dev/base/ansinew.def
%{_texmfdistdir}/tex/latex-dev/base/applemac.def
%{_texmfdistdir}/tex/latex-dev/base/article.cls
%{_texmfdistdir}/tex/latex-dev/base/article.sty
%{_texmfdistdir}/tex/latex-dev/base/ascii.def
%{_texmfdistdir}/tex/latex-dev/base/atbegshi-ltx.sty
%{_texmfdistdir}/tex/latex-dev/base/atveryend-ltx.sty
%{_texmfdistdir}/tex/latex-dev/base/bezier.sty
%{_texmfdistdir}/tex/latex-dev/base/bk10.clo
%{_texmfdistdir}/tex/latex-dev/base/bk11.clo
%{_texmfdistdir}/tex/latex-dev/base/bk12.clo
%{_texmfdistdir}/tex/latex-dev/base/book.cls
%{_texmfdistdir}/tex/latex-dev/base/book.sty
%{_texmfdistdir}/tex/latex-dev/base/cp1250.def
%{_texmfdistdir}/tex/latex-dev/base/cp1252.def
%{_texmfdistdir}/tex/latex-dev/base/cp1257.def
%{_texmfdistdir}/tex/latex-dev/base/cp437.def
%{_texmfdistdir}/tex/latex-dev/base/cp437de.def
%{_texmfdistdir}/tex/latex-dev/base/cp850.def
%{_texmfdistdir}/tex/latex-dev/base/cp852.def
%{_texmfdistdir}/tex/latex-dev/base/cp858.def
%{_texmfdistdir}/tex/latex-dev/base/cp865.def
%{_texmfdistdir}/tex/latex-dev/base/decmulti.def
%{_texmfdistdir}/tex/latex-dev/base/doc-2016-02-15.sty
%{_texmfdistdir}/tex/latex-dev/base/doc-2021-06-01.sty
%{_texmfdistdir}/tex/latex-dev/base/doc.sty
%{_texmfdistdir}/tex/latex-dev/base/docstrip.tex
%{_texmfdistdir}/tex/latex-dev/base/exscale.sty
%{_texmfdistdir}/tex/latex-dev/base/fix-cm.sty
%{_texmfdistdir}/tex/latex-dev/base/fixltx2e.sty
%{_texmfdistdir}/tex/latex-dev/base/flafter.sty
%{_texmfdistdir}/tex/latex-dev/base/fleqn.clo
%{_texmfdistdir}/tex/latex-dev/base/fleqn.sty
%{_texmfdistdir}/tex/latex-dev/base/fltrace.sty
%{_texmfdistdir}/tex/latex-dev/base/fontenc.sty
%{_texmfdistdir}/tex/latex-dev/base/fontmath.cfg
%{_texmfdistdir}/tex/latex-dev/base/fontmath.ltx
%{_texmfdistdir}/tex/latex-dev/base/fonttext.cfg
%{_texmfdistdir}/tex/latex-dev/base/fonttext.ltx
%{_texmfdistdir}/tex/latex-dev/base/graphpap.sty
%{_texmfdistdir}/tex/latex-dev/base/hyphen.ltx
%{_texmfdistdir}/tex/latex-dev/base/idx.tex
%{_texmfdistdir}/tex/latex-dev/base/ifthen.sty
%{_texmfdistdir}/tex/latex-dev/base/inputenc.sty
%{_texmfdistdir}/tex/latex-dev/base/lablst.tex
%{_texmfdistdir}/tex/latex-dev/base/latex.ltx
%{_texmfdistdir}/tex/latex-dev/base/latex209.def
%{_texmfdistdir}/tex/latex-dev/base/latexrelease.sty
%{_texmfdistdir}/tex/latex-dev/base/latexsym.sty
%{_texmfdistdir}/tex/latex-dev/base/latin1.def
%{_texmfdistdir}/tex/latex-dev/base/latin10.def
%{_texmfdistdir}/tex/latex-dev/base/latin2.def
%{_texmfdistdir}/tex/latex-dev/base/latin3.def
%{_texmfdistdir}/tex/latex-dev/base/latin4.def
%{_texmfdistdir}/tex/latex-dev/base/latin5.def
%{_texmfdistdir}/tex/latex-dev/base/latin9.def
%{_texmfdistdir}/tex/latex-dev/base/lcyenc.dfu
%{_texmfdistdir}/tex/latex-dev/base/leqno.clo
%{_texmfdistdir}/tex/latex-dev/base/leqno.sty
%{_texmfdistdir}/tex/latex-dev/base/letter.cls
%{_texmfdistdir}/tex/latex-dev/base/letter.sty
%{_texmfdistdir}/tex/latex-dev/base/lppl.tex
%{_texmfdistdir}/tex/latex-dev/base/ltluatex.lua
%{_texmfdistdir}/tex/latex-dev/base/ltluatex.tex
%{_texmfdistdir}/tex/latex-dev/base/ltnews.cls
%{_texmfdistdir}/tex/latex-dev/base/ltxcheck.tex
%{_texmfdistdir}/tex/latex-dev/base/ltxdoc.cfg
%{_texmfdistdir}/tex/latex-dev/base/ltxdoc.cls
%{_texmfdistdir}/tex/latex-dev/base/ltxguide.cls
%{_texmfdistdir}/tex/latex-dev/base/ly1enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/macce.def
%{_texmfdistdir}/tex/latex-dev/base/makeidx.sty
%{_texmfdistdir}/tex/latex-dev/base/minimal.cls
%{_texmfdistdir}/tex/latex-dev/base/newlfont.sty
%{_texmfdistdir}/tex/latex-dev/base/next.def
%{_texmfdistdir}/tex/latex-dev/base/nfssfont.tex
%{_texmfdistdir}/tex/latex-dev/base/oldlfont.sty
%{_texmfdistdir}/tex/latex-dev/base/omlcmm.fd
%{_texmfdistdir}/tex/latex-dev/base/omlcmr.fd
%{_texmfdistdir}/tex/latex-dev/base/omlenc.def
%{_texmfdistdir}/tex/latex-dev/base/omllcmm.fd
%{_texmfdistdir}/tex/latex-dev/base/omscmr.fd
%{_texmfdistdir}/tex/latex-dev/base/omscmsy.fd
%{_texmfdistdir}/tex/latex-dev/base/omsenc.def
%{_texmfdistdir}/tex/latex-dev/base/omsenc.dfu
%{_texmfdistdir}/tex/latex-dev/base/omslcmsy.fd
%{_texmfdistdir}/tex/latex-dev/base/omxcmex.fd
%{_texmfdistdir}/tex/latex-dev/base/omxlcmex.fd
%{_texmfdistdir}/tex/latex-dev/base/openbib.sty
%{_texmfdistdir}/tex/latex-dev/base/ot1cmdh.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmfib.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmfr.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmr.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmss.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1cmvtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1enc.def
%{_texmfdistdir}/tex/latex-dev/base/ot1enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/ot1lcmss.fd
%{_texmfdistdir}/tex/latex-dev/base/ot1lcmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ot2enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/ot4enc.def
%{_texmfdistdir}/tex/latex-dev/base/preload.cfg
%{_texmfdistdir}/tex/latex-dev/base/preload.ltx
%{_texmfdistdir}/tex/latex-dev/base/proc.cls
%{_texmfdistdir}/tex/latex-dev/base/proc.sty
%{_texmfdistdir}/tex/latex-dev/base/report.cls
%{_texmfdistdir}/tex/latex-dev/base/report.sty
%{_texmfdistdir}/tex/latex-dev/base/sample2e.tex
%{_texmfdistdir}/tex/latex-dev/base/sfonts.def
%{_texmfdistdir}/tex/latex-dev/base/shortvrb.sty
%{_texmfdistdir}/tex/latex-dev/base/showidx.sty
%{_texmfdistdir}/tex/latex-dev/base/size10.clo
%{_texmfdistdir}/tex/latex-dev/base/size11.clo
%{_texmfdistdir}/tex/latex-dev/base/size12.clo
%{_texmfdistdir}/tex/latex-dev/base/slides.cls
%{_texmfdistdir}/tex/latex-dev/base/slides.def
%{_texmfdistdir}/tex/latex-dev/base/slides.sty
%{_texmfdistdir}/tex/latex-dev/base/small2e.tex
%{_texmfdistdir}/tex/latex-dev/base/source2edoc.cls
%{_texmfdistdir}/tex/latex-dev/base/structuredlog.sty
%{_texmfdistdir}/tex/latex-dev/base/syntonly.sty
%{_texmfdistdir}/tex/latex-dev/base/t1cmdh.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmfib.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmfr.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmr.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmss.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/t1cmvtt.fd
%{_texmfdistdir}/tex/latex-dev/base/t1enc.def
%{_texmfdistdir}/tex/latex-dev/base/t1enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/t1enc.sty
%{_texmfdistdir}/tex/latex-dev/base/t1lcmss.fd
%{_texmfdistdir}/tex/latex-dev/base/t1lcmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/t2aenc.dfu
%{_texmfdistdir}/tex/latex-dev/base/t2benc.dfu
%{_texmfdistdir}/tex/latex-dev/base/t2cenc.dfu
%{_texmfdistdir}/tex/latex-dev/base/testpage.tex
%{_texmfdistdir}/tex/latex-dev/base/texsys.cfg
%{_texmfdistdir}/tex/latex-dev/base/textcomp-2018-08-11.sty
%{_texmfdistdir}/tex/latex-dev/base/textcomp.sty
%{_texmfdistdir}/tex/latex-dev/base/tracefnt.sty
%{_texmfdistdir}/tex/latex-dev/base/ts1cmr.fd
%{_texmfdistdir}/tex/latex-dev/base/ts1cmss.fd
%{_texmfdistdir}/tex/latex-dev/base/ts1cmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ts1cmvtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ts1enc.def
%{_texmfdistdir}/tex/latex-dev/base/ts1enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/tuenc.def
%{_texmfdistdir}/tex/latex-dev/base/tulmdh.fd
%{_texmfdistdir}/tex/latex-dev/base/tulmr.fd
%{_texmfdistdir}/tex/latex-dev/base/tulmss.fd
%{_texmfdistdir}/tex/latex-dev/base/tulmssq.fd
%{_texmfdistdir}/tex/latex-dev/base/tulmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/tulmvtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ucmr.fd
%{_texmfdistdir}/tex/latex-dev/base/ucmss.fd
%{_texmfdistdir}/tex/latex-dev/base/ucmtt.fd
%{_texmfdistdir}/tex/latex-dev/base/ulasy.fd
%{_texmfdistdir}/tex/latex-dev/base/ullasy.fd
%{_texmfdistdir}/tex/latex-dev/base/utf8-2018.def
%{_texmfdistdir}/tex/latex-dev/base/utf8.def
%{_texmfdistdir}/tex/latex-dev/base/utf8enc.dfu
%{_texmfdistdir}/tex/latex-dev/base/x2enc.dfu

%package -n texlive-latex-bin-dev
Version:        %{texlive_version}.%{texlive_noarch}.svn66186
Release:        0
License:        LPPL-1.0
Summary:        LaTeX pre-release executables and formats
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-atbegshi >= %{texlive_version}
#!BuildIgnore: texlive-atbegshi
Requires:       texlive-atveryend >= %{texlive_version}
#!BuildIgnore: texlive-atveryend
Requires:       texlive-babel >= %{texlive_version}
#!BuildIgnore: texlive-babel
Requires:       texlive-cm >= %{texlive_version}
#!BuildIgnore: texlive-cm
Requires:       texlive-dehyph >= %{texlive_version}
#!BuildIgnore: texlive-dehyph
Requires:       texlive-everyshi >= %{texlive_version}
#!BuildIgnore: texlive-everyshi
Requires:       texlive-firstaid >= %{texlive_version}
#!BuildIgnore: texlive-firstaid
Requires:       texlive-hyph-utf8 >= %{texlive_version}
#!BuildIgnore: texlive-hyph-utf8
Requires:       texlive-hyphen-base >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-base
Requires:       texlive-l3backend >= %{texlive_version}
#!BuildIgnore: texlive-l3backend
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires:       texlive-l3packages >= %{texlive_version}
#!BuildIgnore: texlive-l3packages
Requires:       texlive-latex >= %{texlive_version}
#!BuildIgnore: texlive-latex
Requires:       texlive-latex-base-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-base-dev
Requires(pre):  texlive-latex-bin-dev-bin >= %{texlive_version}
#!BuildIgnore: texlive-latex-bin-dev-bin
Requires:       texlive-latex-firstaid-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-firstaid-dev
Requires:       texlive-latex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-latex-fonts
Requires:       texlive-latex-graphics-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-graphics-dev
Requires:       texlive-latexconfig >= %{texlive_version}
#!BuildIgnore: texlive-latexconfig
Requires:       texlive-lm >= %{texlive_version}
#!BuildIgnore: texlive-lm
Requires:       texlive-luahbtex >= %{texlive_version}
#!BuildIgnore: texlive-luahbtex
Requires:       texlive-luaotfload >= %{texlive_version}
#!BuildIgnore: texlive-luaotfload
Requires:       texlive-luatex >= %{texlive_version}
#!BuildIgnore: texlive-luatex
Requires:       texlive-pdftex >= %{texlive_version}
#!BuildIgnore: texlive-pdftex
Requires:       texlive-tex-ini-files >= %{texlive_version}
#!BuildIgnore: texlive-tex-ini-files
Requires:       texlive-unicode-data >= %{texlive_version}
#!BuildIgnore: texlive-unicode-data
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(post): findutils
Requires(post): grep
Requires(post): sed
Requires(post): texlive >= %{texlive_version}
Requires(post): tex(language.dat)
Requires(post): tex(language.def)
Requires(post): tex(language.dat.lua)
#!BuildIgnore:  tex(language.dat)
#!BuildIgnore:  tex(language.def)
#!BuildIgnore:  tex(language.dat.lua)
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
Requires(postun):texlive >= %{texlive_version}
Requires(postun):tex(language.dat)
Requires(postun):tex(language.def)
Requires(postun):tex(language.dat.lua)
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       man(dvilualatex-dev.1)
Provides:       man(latex-dev.1)
Provides:       man(lualatex-dev.1)
Provides:       man(pdflatex-dev.1)
Provides:       man(platex-dev.1)
Provides:       man(uplatex-dev.1)
Provides:       man(xelatex-dev.1)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source286:      latex-bin-dev.doc.tar.xz

%description -n texlive-latex-bin-dev
See the latex-base-dev package for information.

%post -n texlive-latex-bin-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
> /var/run/texlive/run-fmtutil.dvilualatex-dev
sed -ri 's/^\#\![[= =]]+dvilualatex-dev\b.*/dvilualatex-dev luatex language.dat,language.dat.lua dvilualatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.latex-dev
sed -ri 's/^\#\![[= =]]+latex-dev\b.*/latex-dev pdftex language.dat -translate-file=cp227.tcx *latex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.lualatex-dev
sed -ri 's/^\#\![[= =]]+lualatex-dev\b.*/lualatex-dev luahbtex language.dat,language.dat.lua lualatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
> /var/run/texlive/run-fmtutil.pdflatex-dev
sed -ri 's/^\#\![[= =]]+pdflatex-dev\b.*/pdflatex-dev pdftex language.dat -translate-file=cp227.tcx *pdflatex.ini/' %{_texmfconfdir}/web2c/fmtutil.cnf || :

%postun -n texlive-latex-bin-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    sed -ri 's/^(dvilualatex-dev\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/luatex/dvilualatex-dev.*
    sed -ri 's/^(latex-dev\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/latex-dev.*
    sed -ri 's/^(lualatex-dev\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/luahbtex/lualatex-dev.*
    sed -ri 's/^(pdflatex-dev\b)/\#\!\ \1/' %{_texmfconfdir}/web2c/fmtutil.cnf || :
    rm -f %{_texmfvardir}/web2c/pdftex/pdflatex-dev.*
    exit 0
fi

%triggerin -n texlive-latex-bin-dev -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-atbegshi
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-atveryend
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-atveryend
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-babel
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-babel
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-cm
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-cm
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-dehyph
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-dehyph
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-everyshi
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-everyshi
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-firstaid
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-firstaid
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-hyph-utf8
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-hyphen-base
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-l3backend
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-l3backend
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-l3kernel
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-l3packages
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-l3packages
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-latex
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-latex
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-latex-base-dev
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-latex-base-dev
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-latex-firstaid-dev
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-latex-firstaid-dev
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-latex-fonts
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-latexconfig
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-pdftex
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-pdftex
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-tex-ini-files
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerin -n texlive-latex-bin-dev -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%triggerun -n texlive-latex-bin-dev -- texlive-unicode-data
> /var/run/texlive/run-fmtutil.dvilualatex-dev
> /var/run/texlive/run-fmtutil.latex-dev
> /var/run/texlive/run-fmtutil.lualatex-dev
> /var/run/texlive/run-fmtutil.pdflatex-dev

%posttrans -n texlive-latex-bin-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-bin-dev
%defattr(-,root,root,755)
%{_mandir}/man1/dvilualatex-dev.1*
%{_mandir}/man1/latex-dev.1*
%{_mandir}/man1/lualatex-dev.1*
%{_mandir}/man1/pdflatex-dev.1*
%{_mandir}/man1/platex-dev.1*
%{_mandir}/man1/uplatex-dev.1*
%{_mandir}/man1/xelatex-dev.1*

%package -n texlive-latex-brochure
Version:        %{texlive_version}.%{texlive_noarch}.svn40612
Release:        0
License:        LPPL-1.0
Summary:        A publicity flyer for LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source287:      latex-brochure.doc.tar.xz

%description -n texlive-latex-brochure
The document is designed as a publicity flyer for LaTeX, but
also serves as an interesting showcase of what LaTeX can do.
The flyer is designed for printing, double-sided, on A3 paper,
which would then be folded once.

%post -n texlive-latex-brochure
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-brochure
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-brochure
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-brochure
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-brochure/README
%{_texmfdistdir}/doc/latex/latex-brochure/README.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-a3folderFB.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-a3folderIN.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-a4.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-ledgerfolderFB.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-ledgerfolderIN.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure-letter.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure.bib
%{_texmfdistdir}/doc/latex/latex-brochure/brochure.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/brochure.sty
%{_texmfdistdir}/doc/latex/latex-brochure/brochure.tex
%{_texmfdistdir}/doc/latex/latex-brochure/build
%{_texmfdistdir}/doc/latex/latex-brochure/diagram-crop.eps
%{_texmfdistdir}/doc/latex/latex-brochure/diagram-crop.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/fullscreen.eps
%{_texmfdistdir}/doc/latex/latex-brochure/fullscreen.png
%{_texmfdistdir}/doc/latex/latex-brochure/index.html
%{_texmfdistdir}/doc/latex/latex-brochure/sample-crop.eps
%{_texmfdistdir}/doc/latex/latex-brochure/sample-crop.pdf
%{_texmfdistdir}/doc/latex/latex-brochure/typo-degraded.eps
%{_texmfdistdir}/doc/latex/latex-brochure/typo-degraded.png

%package -n texlive-latex-course
Version:        %{texlive_version}.%{texlive_noarch}.2svn25505
Release:        0
License:        GPL-2.0-or-later
Summary:        A LaTeX course as a projected presentation
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source288:      latex-course.doc.tar.xz

%description -n texlive-latex-course
A brief Beamer-based slide presentation on LaTeX, based on
Rupprecht's LaTeX 2.09 course, which the author has translated
to English and taken to LaTeX2e/Beamer. Additional material was
taken from the Short Introduction to LaTeX.

%post -n texlive-latex-course
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-course
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-course
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-course
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-course/Graphics/Ross-Siegel.png
%{_texmfdistdir}/doc/latex/latex-course/Graphics/Thumbs.db
%{_texmfdistdir}/doc/latex/latex-course/Graphics/campus3.png
%{_texmfdistdir}/doc/latex/latex-course/LaTeX-Course.pdf
%{_texmfdistdir}/doc/latex/latex-course/LaTeX-Course.tex
%{_texmfdistdir}/doc/latex/latex-course/LaTeX-course.prj
%{_texmfdistdir}/doc/latex/latex-course/README
%{_texmfdistdir}/doc/latex/latex-course/beamercolorthemeross.sty

%package -n texlive-latex-doc-ptr
Version:        %{texlive_version}.%{texlive_noarch}.svn57311
Release:        0
License:        SUSE-Public-Domain
Summary:        A direction-finder for LaTeX resources available online
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source289:      latex-doc-ptr.doc.tar.xz

%description -n texlive-latex-doc-ptr
A brief set of recommendations for users who need online
documentation of LaTeX. The document supports the need for
documentation of LaTeX itself, in distributions. For example,
it could be used in the command texdoc latex, in the TeX Live
distribution.

%post -n texlive-latex-doc-ptr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-doc-ptr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-doc-ptr
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-doc-ptr
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-doc-ptr/LICENSE
%{_texmfdistdir}/doc/latex/latex-doc-ptr/Makefile
%{_texmfdistdir}/doc/latex/latex-doc-ptr/README
%{_texmfdistdir}/doc/latex/latex-doc-ptr/dash.sty
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.css
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.css.replacement
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.html
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.pdf
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.sty
%{_texmfdistdir}/doc/latex/latex-doc-ptr/latex-doc-ptr.tex
%{_texmfdistdir}/doc/latex/latex-doc-ptr/massage_html.awk

%package -n texlive-latex-firstaid-dev
Version:        %{texlive_version}.%{texlive_noarch}.1.0wsvn65181
Release:        0
License:        LPPL-1.0
Summary:        Development pre-release of the LaTeX firstaid package
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-firstaid-dev-doc >= %{texlive_version}
Provides:       texdev(everysel-ltx.sty)
Provides:       texdev(filehook-ltx.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source290:      latex-firstaid-dev.tar.xz
Source291:      latex-firstaid-dev.doc.tar.xz

%description -n texlive-latex-firstaid-dev
This is a pre-release version of the standard LaTeX firstaid
package. It accompanies the pre-testing kernel code
(latex-base-dev), and is intended for testing by knowledgeable
users.

%package -n texlive-latex-firstaid-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0wsvn65181
Release:        0
Summary:        Documentation for texlive-latex-firstaid-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-firstaid-dev and texlive-alldocumentation)

%description -n texlive-latex-firstaid-dev-doc
This package includes the documentation for texlive-latex-firstaid-dev

%post -n texlive-latex-firstaid-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-firstaid-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-firstaid-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-firstaid-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/firstaid/README.md
%{_texmfdistdir}/doc/latex-dev/firstaid/changes.txt
%{_texmfdistdir}/doc/latex-dev/firstaid/latex2e-first-aid-for-external-files.pdf

%files -n texlive-latex-firstaid-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/firstaid/everysel-ltx.sty
%{_texmfdistdir}/tex/latex-dev/firstaid/filehook-ltx.sty
%{_texmfdistdir}/tex/latex-dev/firstaid/latex2e-first-aid-for-external-files.ltx

%package -n texlive-latex-fonts
Version:        %{texlive_version}.%{texlive_noarch}.svn28888
Release:        0
License:        LPPL-1.0
Summary:        A collection of fonts used in LaTeX distributions
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-fonts-doc >= %{texlive_version}
Provides:       tex(icmcsc10.tfm)
Provides:       tex(icmex10.tfm)
Provides:       tex(icmmi8.tfm)
Provides:       tex(icmsy8.tfm)
Provides:       tex(icmtt8.tfm)
Provides:       tex(ilasy8.tfm)
Provides:       tex(ilcmss8.tfm)
Provides:       tex(ilcmssb8.tfm)
Provides:       tex(ilcmssi8.tfm)
Provides:       tex(lasy10.tfm)
Provides:       tex(lasy5.tfm)
Provides:       tex(lasy6.tfm)
Provides:       tex(lasy7.tfm)
Provides:       tex(lasy8.tfm)
Provides:       tex(lasy9.tfm)
Provides:       tex(lasyb10.tfm)
Provides:       tex(lcircle10.tfm)
Provides:       tex(lcirclew10.tfm)
Provides:       tex(lcmss8.tfm)
Provides:       tex(lcmssb8.tfm)
Provides:       tex(lcmssi8.tfm)
Provides:       tex(line10.tfm)
Provides:       tex(linew10.tfm)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source292:      latex-fonts.tar.xz
Source293:      latex-fonts.doc.tar.xz

%description -n texlive-latex-fonts
This is a collection of fonts for use with standard LaTeX
packages and classes. It includes 'invisible' fonts (for use
with the slides class), line and circle fonts (for use in the
picture environment) and 'LaTeX symbol' fonts. For full support
of a LaTeX installation, some Computer Modern font variants
cmbsy(6-9), cmcsc(8,9), cmex(7-9) and cmmib(5-9) from the
amsfonts distribution, are also necessary. The fonts are
available as Metafont source, and metric (tfm) files are also
provided. Most of the fonts are also available in Adobe Type 1
format, in the amsfonts distribution.

%package -n texlive-latex-fonts-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn28888
Release:        0
Summary:        Documentation for texlive-latex-fonts
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-fonts and texlive-alldocumentation)

%description -n texlive-latex-fonts-doc
This package includes the documentation for texlive-latex-fonts

%post -n texlive-latex-fonts
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-fonts
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-fonts
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-fonts-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/fonts/latex-fonts/README
%{_texmfdistdir}/doc/fonts/latex-fonts/legal.txt

%files -n texlive-latex-fonts
%defattr(-,root,root,755)
%{_texmfdistdir}/fonts/source/public/latex-fonts/circle.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/icmcsc10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/icmex10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/icmmi8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/icmsy8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/icmtt8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/ilasy8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/ilcmss8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/ilcmssb8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/ilcmssi8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy5.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy6.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy7.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasy9.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lasyb10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lcircle10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lcirclew10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lcmss8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lcmssb8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/lcmssi8.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/line.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/line10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/linew10.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/sroman.mf
%{_texmfdistdir}/fonts/source/public/latex-fonts/sromanu.mf
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/icmcsc10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/icmex10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/icmmi8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/icmsy8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/icmtt8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/ilasy8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/ilcmss8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/ilcmssb8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/ilcmssi8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy5.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy6.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy7.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasy9.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lasyb10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lcircle10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lcirclew10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lcmss8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lcmssb8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/lcmssi8.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/line10.tfm
%{_texmfdistdir}/fonts/tfm/public/latex-fonts/linew10.tfm

%package -n texlive-latex-for-undergraduates
Version:        %{texlive_version}.%{texlive_noarch}.1.0.2svn64647
Release:        0
License:        SUSE-Public-Domain
Summary:        A tutorial aimed at introducing undergraduate students to LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source294:      latex-for-undergraduates.doc.tar.xz

%description -n texlive-latex-for-undergraduates
A tutorial aimed at introducing undergraduate students to
LaTeX, including an introduction to LaTeX Workshop in Visual
Studio Code and an example package of user-defined LaTeX
commands.

%post -n texlive-latex-for-undergraduates
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-for-undergraduates
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-for-undergraduates
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-for-undergraduates
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/LaTeX_for_Undergraduates.pdf
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/LaTeX_for_Undergraduates.tex
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/README.md
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/alounsburymacros-doc.pdf
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/alounsburymacros-doc.tex
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/alounsburymacros.sty
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/M33_figure.jpeg
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/compiling.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/creatingDocument.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/directories.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/marketplace.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/perl1.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/perl2crop.png
%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images/whiteboard.jpeg

%package -n texlive-latex-git-log
Version:        %{texlive_version}.%{texlive_noarch}.1.0.0svn54010
Release:        0
License:        GPL-2.0-or-later
Summary:        Typeset git log information
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-latex-git-log-bin >= %{texlive_version}
#!BuildIgnore: texlive-latex-git-log-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-git-log-doc >= %{texlive_version}
Requires:       perl(Cwd)
#!BuildIgnore:  perl(Cwd)
Requires:       perl(File::Basename)
#!BuildIgnore:  perl(File::Basename)
Requires:       perl(Getopt::Long)
#!BuildIgnore:  perl(Getopt::Long)
Requires:       perl(IPC::System::Simple)
#!BuildIgnore:  perl(IPC::System::Simple)
Requires:       perl(Locale::Maketext::Simple)
#!BuildIgnore:  perl(Locale::Maketext::Simple)
Requires:       perl(Pod::Usage)
#!BuildIgnore:  perl(Pod::Usage)
Requires:       perl(autodie)
#!BuildIgnore:  perl(autodie)
Requires:       perl(feature)
#!BuildIgnore:  perl(feature)
Requires:       perl(open)
#!BuildIgnore:  perl(open)
Requires:       perl(strict)
#!BuildIgnore:  perl(strict)
Requires:       perl(utf8)
#!BuildIgnore:  perl(utf8)
Requires:       perl(warnings)
#!BuildIgnore:  perl(warnings)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source295:      latex-git-log.tar.xz
Source296:      latex-git-log.doc.tar.xz

%description -n texlive-latex-git-log
The program is run within a git repository, and outputs the
entire version history, as a LaTeX table. That output will
typically be redirected to a file; the author recommends
typesetting in landscape orientation.

%package -n texlive-latex-git-log-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.0.0svn54010
Release:        0
Summary:        Documentation for texlive-latex-git-log
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-git-log and texlive-alldocumentation)
Provides:       man(latex-git-log.1)

%description -n texlive-latex-git-log-doc
This package includes the documentation for texlive-latex-git-log

%post -n texlive-latex-git-log
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-git-log
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-git-log
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-git-log-doc
%defattr(-,root,root,755)
%{_mandir}/man1/latex-git-log.1*
%{_texmfdistdir}/doc/support/latex-git-log/README.md
%{_texmfdistdir}/doc/support/latex-git-log/example-output.tex
%{_texmfdistdir}/doc/support/latex-git-log/example.pdf
%{_texmfdistdir}/doc/support/latex-git-log/example.tex
%{_texmfdistdir}/doc/support/latex-git-log/po/de.po

%files -n texlive-latex-git-log
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/latex-git-log/latex-git-log

%package -n texlive-latex-graphics-companion
Version:        %{texlive_version}.%{texlive_noarch}.svn29235
Release:        0
License:        LPPL-1.0
Summary:        Examples from The LaTeX Graphics Companion
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source297:      latex-graphics-companion.doc.tar.xz

%description -n texlive-latex-graphics-companion
The source of the examples printed in the book, together with
necessary supporting files.

%post -n texlive-latex-graphics-companion
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-graphics-companion
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-graphics-companion
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-graphics-companion
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-10.pic
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-11.pic
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/1-4-9.pic
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-1-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-1-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-1-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-1-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-1-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/10-5-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/11-3-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/11-6-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-1.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-2.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-3.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-4.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/12-0-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-10.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-11.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-12.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-13.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-14.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-15.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-16.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-17.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-18.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-19.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-20.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-2-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-13.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-14.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-15.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-16.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-17.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/2-3-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-1.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-2.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-3.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-4.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-5.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-6.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-7.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-8.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-1-9.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-2-1.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-2-2.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-2-3.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-1.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-10.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-11.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-12.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-13.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-14.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-15.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-16.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-17.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-18.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-19.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-2.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-3.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-4.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-5.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-6.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-7.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-8.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-3-9.mp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/3-4-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-10-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-2-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-2-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-2-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-2-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-2-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-3-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-3-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-10.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-11.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-12.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-4-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-10.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-11.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-12.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-13.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-14.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-15.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-16.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-5-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-10.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-11.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-12.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-13.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-14.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-15.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-16.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-17.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-18.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-19.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-20.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-21.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-22.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-23.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-24.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-25.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-26.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-27.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-28.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-29.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-30.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-31.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-32.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-33.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-34.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-35.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-36.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-37.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-38.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-39.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-40.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-41.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-42.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-43.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-44.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-45.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-46.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-6-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-7-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-7-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-7-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-7-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-8-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-8-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-8-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-8-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-8-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-9-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-9-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/4-9-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-2-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-3-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-4-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-4-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-4-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-4-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-13.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-14.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-15.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-16.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-17.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-18.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-19.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-20.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-21.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-22.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-23.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-24.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-25.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-26.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-27.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-28.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-29.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-30.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-31.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-32.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-33.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-34.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-35.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/5-5-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-13.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-14.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-15.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-16.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-17.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-18.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-19.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-20.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-21.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-22.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-23.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-24.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-2-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-10.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-11.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-12.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-13.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-14.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-3-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-4-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-4-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-4-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-5-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-6-7.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-1.m4
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-2.m4
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-3.m4
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/6-7-4.m4
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-1.mx1
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-1.mx2
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-1.ptx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-5.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-2-6.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-1.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-3.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-4.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-5.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-6.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-7.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-8.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-3-9.abc
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-1.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-10.mx1
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-10.mx2
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-10.ptx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-2.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-3.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-4.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-5.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-6.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-7.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-8.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/7-4-9.mpp
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-1-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-1-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-1-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-1-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-2-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-2-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-2-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-3-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-3-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-3-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-4-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-4-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-5-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-6-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-1.acr
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-1.dwn
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-1.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-2.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-3.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/8-7-4.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-8.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-2-9.ltx
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-10.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-11.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-12.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-13.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-14.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-15.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-16.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-17.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-18.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-19.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-2.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-20.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-3.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-4.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-5.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-6.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-7.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-8.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/9-3-9.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/A-1-1.inl
%{_texmfdistdir}/doc/latex/latex-graphics-companion/Makefile
%{_texmfdistdir}/doc/latex/latex-graphics-companion/README
%{_texmfdistdir}/doc/latex/latex-graphics-companion/ages.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/bar.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/chap.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/clef.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/config.ps
%{_texmfdistdir}/doc/latex/latex-graphics-companion/decade.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/feature.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/graves.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs/graphics.cfg
%{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs/header.tex
%{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs/mfpic.sty
%{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs/ppex.cls
%{_texmfdistdir}/doc/latex/latex-graphics-companion/key.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/langs.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/langs2.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/langs3.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/macro.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/mpp.tex
%{_texmfdistdir}/doc/latex/latex-graphics-companion/note.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/notecc.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/pot.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/script.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/scriptcc.ini
%{_texmfdistdir}/doc/latex/latex-graphics-companion/showgrid.tex
%{_texmfdistdir}/doc/latex/latex-graphics-companion/stones.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/students.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/veracx.mx1
%{_texmfdistdir}/doc/latex/latex-graphics-companion/veracx.tex
%{_texmfdistdir}/doc/latex/latex-graphics-companion/yearm.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/years.dat
%{_texmfdistdir}/doc/latex/latex-graphics-companion/years.men
%{_texmfdistdir}/doc/latex/latex-graphics-companion/years.wom
%{_texmfdistdir}/doc/latex/latex-graphics-companion/yearw.dat

%package -n texlive-latex-graphics-dev
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
License:        LPPL-1.0
Summary:        Development pre-release of the LaTeX graphics bundle
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-graphics-cfg >= %{texlive_version}
#!BuildIgnore: texlive-graphics-cfg
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-graphics-dev-doc >= %{texlive_version}
Provides:       texdev(color.sty)
Provides:       texdev(dvipdf.def)
Provides:       texdev(dvipsnam.def)
Provides:       texdev(dvipsone.def)
Provides:       texdev(dviwin.def)
Provides:       texdev(emtex.def)
Provides:       texdev(epsfig.sty)
Provides:       texdev(graphics-2017-06-25.sty)
Provides:       texdev(graphics.sty)
Provides:       texdev(graphicx.sty)
Provides:       texdev(keyval.sty)
Provides:       texdev(lscape.sty)
Provides:       texdev(pctex32.def)
Provides:       texdev(pctexhp.def)
Provides:       texdev(pctexps.def)
Provides:       texdev(pctexwin.def)
Provides:       texdev(rotating.sty)
Provides:       texdev(tcidvi.def)
Provides:       texdev(trig.sty)
Provides:       texdev(truetex.def)
Requires:       texdev(ifthen.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source298:      latex-graphics-dev.tar.xz
Source299:      latex-graphics-dev.doc.tar.xz

%description -n texlive-latex-graphics-dev
This is a pre-release version of the standard LaTeX graphics
bundle. It accompanies the pre-testing kernel code
(latex-base-dev), and is intended for testing by knowledgeable
users.

%package -n texlive-latex-graphics-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
Summary:        Documentation for texlive-latex-graphics-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-graphics-dev and texlive-alldocumentation)

%description -n texlive-latex-graphics-dev-doc
This package includes the documentation for texlive-latex-graphics-dev

%post -n texlive-latex-graphics-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-graphics-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-graphics-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-graphics-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/graphics/README.md
%{_texmfdistdir}/doc/latex-dev/graphics/cat.eps
%{_texmfdistdir}/doc/latex-dev/graphics/changes.txt
%{_texmfdistdir}/doc/latex-dev/graphics/color.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/drivers.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/epsfig.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/graphics.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/graphicx.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/grfguide.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/grfguide.tex
%{_texmfdistdir}/doc/latex-dev/graphics/keyval.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/lscape.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/mathcolor.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/rotating.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/rotex.pdf
%{_texmfdistdir}/doc/latex-dev/graphics/rotex.tex
%{_texmfdistdir}/doc/latex-dev/graphics/trig.pdf

%files -n texlive-latex-graphics-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/graphics/color.sty
%{_texmfdistdir}/tex/latex-dev/graphics/dvipdf.def
%{_texmfdistdir}/tex/latex-dev/graphics/dvipsnam.def
%{_texmfdistdir}/tex/latex-dev/graphics/dvipsone.def
%{_texmfdistdir}/tex/latex-dev/graphics/dviwin.def
%{_texmfdistdir}/tex/latex-dev/graphics/emtex.def
%{_texmfdistdir}/tex/latex-dev/graphics/epsfig.sty
%{_texmfdistdir}/tex/latex-dev/graphics/graphics-2017-06-25.sty
%{_texmfdistdir}/tex/latex-dev/graphics/graphics.sty
%{_texmfdistdir}/tex/latex-dev/graphics/graphicx.sty
%{_texmfdistdir}/tex/latex-dev/graphics/keyval.sty
%{_texmfdistdir}/tex/latex-dev/graphics/lscape.sty
%{_texmfdistdir}/tex/latex-dev/graphics/mathcolor.ltx
%{_texmfdistdir}/tex/latex-dev/graphics/pctex32.def
%{_texmfdistdir}/tex/latex-dev/graphics/pctexhp.def
%{_texmfdistdir}/tex/latex-dev/graphics/pctexps.def
%{_texmfdistdir}/tex/latex-dev/graphics/pctexwin.def
%{_texmfdistdir}/tex/latex-dev/graphics/rotating.sty
%{_texmfdistdir}/tex/latex-dev/graphics/tcidvi.def
%{_texmfdistdir}/tex/latex-dev/graphics/trig.sty
%{_texmfdistdir}/tex/latex-dev/graphics/truetex.def

%package -n texlive-latex-lab
Version:        %{texlive_version}.%{texlive_noarch}.svn64892
Release:        0
License:        LPPL-1.0
Summary:        LaTeX laboratory
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-lab-doc >= %{texlive_version}
Provides:       tex(latex-lab-testphase-new-or.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source300:      latex-lab.tar.xz
Source301:      latex-lab.doc.tar.xz

%description -n texlive-latex-lab
The LaTeX laboratory provides a route for additions to the
LaTeX kernel to be stablised, whilst still allowing some
stability for adventorous users.

%package -n texlive-latex-lab-doc
Version:        %{texlive_version}.%{texlive_noarch}.svn64892
Release:        0
Summary:        Documentation for texlive-latex-lab
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-lab and texlive-alldocumentation)

%description -n texlive-latex-lab-doc
This package includes the documentation for texlive-latex-lab

%post -n texlive-latex-lab
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-lab
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-lab
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-lab-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-lab/README.md
%{_texmfdistdir}/doc/latex/latex-lab/changes.txt
%{_texmfdistdir}/doc/latex/latex-lab/documentmetadata-support-code.pdf
%{_texmfdistdir}/doc/latex/latex-lab/documentmetadata-support-code.tex
%{_texmfdistdir}/doc/latex/latex-lab/documentmetadata-support-doc.pdf
%{_texmfdistdir}/doc/latex/latex-lab/documentmetadata-support-doc.tex
%{_texmfdistdir}/doc/latex/latex-lab/latex-lab-footnotes.pdf
%{_texmfdistdir}/doc/latex/latex-lab/latex-lab-new-or.pdf
%{_texmfdistdir}/doc/latex/latex-lab/latex-lab-testphase.pdf
%{_texmfdistdir}/doc/latex/latex-lab/usage-of-footnotemark.txt
%{_texmfdistdir}/doc/latex/latex-lab/usage-of-footnotetext.txt
%{_texmfdistdir}/doc/latex/latex-lab/usage-of-kern-kern.txt

%files -n texlive-latex-lab
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/latex-lab/documentmetadata-support.ltx
%{_texmfdistdir}/tex/latex/latex-lab/latex-lab-footmisc.ltx
%{_texmfdistdir}/tex/latex/latex-lab/latex-lab-footnotes.ltx
%{_texmfdistdir}/tex/latex/latex-lab/latex-lab-testphase-new-or.sty
%{_texmfdistdir}/tex/latex/latex-lab/new-or-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex/latex-lab/phase-I-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex/latex-lab/phase-II-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex/latex-lab/tagpdf-latex-lab-testphase.ltx

%package -n texlive-latex-lab-dev
Version:        %{texlive_version}.%{texlive_noarch}.20230601_pre_release_2svn66513
Release:        0
License:        LPPL-1.0
Summary:        LaTeX laboratory: Development pre-release
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-lab-dev-doc >= %{texlive_version}
Provides:       texdev(glyphtounicode-cmex.tex)
Provides:       texdev(latex-lab-kernel-changes.sty)
Provides:       texdev(latex-lab-testphase-block-tagging.sty)
Provides:       texdev(latex-lab-testphase-math.sty)
Provides:       texdev(latex-lab-testphase-new-or-1.sty)
Provides:       texdev(latex-lab-testphase-new-or-2.sty)
Provides:       texdev(latex-lab-testphase-sec-tagging.sty)
Provides:       texdev(latex-lab-testphase-toc-tagging.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(xtemplate.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source302:      latex-lab-dev.tar.xz
Source303:      latex-lab-dev.doc.tar.xz

%description -n texlive-latex-lab-dev
This package provides a testing release for upcoming changes to
the latex-lab bundle, which provides a route for additions to
the LaTeX kernel to be stablised. It accompanies the
pre-testing kernel code (latex-base-dev), and is intended for
testing by knowledgeable users.

%package -n texlive-latex-lab-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.20230601_pre_release_2svn66513
Release:        0
Summary:        Documentation for texlive-latex-lab-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-lab-dev and texlive-alldocumentation)

%description -n texlive-latex-lab-dev-doc
This package includes the documentation for texlive-latex-lab-dev

%post -n texlive-latex-lab-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-lab-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-lab-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-lab-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/latex-lab/README.md
%{_texmfdistdir}/doc/latex-dev/latex-lab/blocks-code.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/blocks-code.tex
%{_texmfdistdir}/doc/latex-dev/latex-lab/blocks-doc.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/blocks-doc.tex
%{_texmfdistdir}/doc/latex-dev/latex-lab/changes.txt
%{_texmfdistdir}/doc/latex-dev/latex-lab/documentmetadata-support-code.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/documentmetadata-support-code.tex
%{_texmfdistdir}/doc/latex-dev/latex-lab/documentmetadata-support-doc.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/documentmetadata-support-doc.tex
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-amsmath.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-block-tagging.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-footnotes.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-mathpkg.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-mathtagging.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-mathtools.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-new-or-1.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-new-or-2.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-sec-tagging.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-testphase.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-toc-hyperref-changes.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-toc-kernel-changes.pdf
%{_texmfdistdir}/doc/latex-dev/latex-lab/latex-lab-toc-tagging-functions.pdf

%files -n texlive-latex-lab-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/latex-lab/block-tagging-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/documentmetadata-support.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/glyphtounicode-cmex.tex
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-amsmath.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-footmisc.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-footnotes.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-kernel-changes.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-mathpkg.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-mathtagging.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-mathtools.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-block-tagging.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-math.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-new-or-1.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-new-or-2.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-sec-tagging.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/latex-lab-testphase-toc-tagging.sty
%{_texmfdistdir}/tex/latex-dev/latex-lab/math-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/new-or-1-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/new-or-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/phase-I-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/phase-II-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/phase-III-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/sec-tagging-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/tagpdf-latex-lab-testphase.ltx
%{_texmfdistdir}/tex/latex-dev/latex-lab/toc-tagging-latex-lab-testphase.ltx

%package -n texlive-latex-make
Version:        %{texlive_version}.%{texlive_noarch}.2.4.3svn60874
Release:        0
License:        GPL-2.0-or-later
Summary:        Easy compiling of complex (and simple) LaTeX documents
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-make-doc >= %{texlive_version}
Provides:       tex(figlatex.cfg)
Provides:       tex(figlatex.sty)
Provides:       tex(pdfswitch.sty)
Provides:       tex(texdepends.sty)
Provides:       tex(texgraphicx.sty)
Requires:       tex(ae.sty)
Requires:       tex(aeguill.sty)
Requires:       tex(color.sty)
Requires:       tex(epstopdf.sty)
Requires:       tex(etoolbox.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifpdf.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(ifxetex.sty)
Requires:       tex(thumbpdf.sty)
Requires:       tex(xcolor.sty)
Requires:       tex(xstring.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source304:      latex-make.tar.xz
Source305:      latex-make.doc.tar.xz

%description -n texlive-latex-make
This package provides several tools that aim to simplify the
compilation of LaTeX documents: LaTeX.mk: a Makefile snippet to
help compiling LaTeX documents in DVI, PDF, PS, ... format.
Dependencies are automatically tracked: one should be able to
compile documents with a one-line Makefile containing 'include
LaTeX.mk'. Complex documents (with multiple bibliographies,
indexes, glossaries, ...) should be correctly managed.
figlatex.sty: a LaTeX package to easily insert xfig figures
(with \includegraphics{file.fig}). It can interact with
LaTeX.mk so that the latter automatically invokes transfig if
needed. And various helper tools for LaTeX.mk This package
requires GNUmake (>= 3.81).

%package -n texlive-latex-make-doc
Version:        %{texlive_version}.%{texlive_noarch}.2.4.3svn60874
Release:        0
Summary:        Documentation for texlive-latex-make
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-make and texlive-alldocumentation)

%description -n texlive-latex-make-doc
This package includes the documentation for texlive-latex-make

%post -n texlive-latex-make
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-make
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-make
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-make-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/support/latex-make/LaTeX.mk.conf
%{_texmfdistdir}/doc/support/latex-make/README
%{_texmfdistdir}/doc/support/latex-make/figlatex.pdf
%{_texmfdistdir}/doc/support/latex-make/latex-make.pdf
%{_texmfdistdir}/doc/support/latex-make/texdepends.pdf

%files -n texlive-latex-make
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/latex-make/figdepth.py
%{_texmfdistdir}/scripts/latex-make/gensubfig.py
%{_texmfdistdir}/scripts/latex-make/latexfilter.py
%{_texmfdistdir}/scripts/latex-make/svg2dev.py
%{_texmfdistdir}/scripts/latex-make/svgdepth.py
%{_texmfdistdir}/tex/latex/latex-make/figlatex.cfg
%{_texmfdistdir}/tex/latex/latex-make/figlatex.sty
%{_texmfdistdir}/tex/latex/latex-make/pdfswitch.sty
%{_texmfdistdir}/tex/latex/latex-make/texdepends.sty
%{_texmfdistdir}/tex/latex/latex-make/texgraphicx.sty

%package -n texlive-latex-mr
Version:        %{texlive_version}.%{texlive_noarch}.1.0svn55475
Release:        0
License:        LPPL-1.0
Summary:        A practical guide to LaTeX and Polyglossia for Marathi and other Indian languages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source306:      latex-mr.doc.tar.xz

%description -n texlive-latex-mr
The package provides a short guide to LaTeX and specifically to
the polyglossia package. This document aims to introduce LaTeX
and polyglossia for Indian languages. Though the document often
discusses the language Marathi, the discussion applies to other
India languages also, with some minute changes which are
described in Section 1.2. We assume that the user of this
document knows basic (La)TeX or has, at least, tried her hand
on it. This document is not very suitable for first time users.

%post -n texlive-latex-mr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-mr
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-mr
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-mr
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-mr/Leslie_Lamport.jpg
%{_texmfdistdir}/doc/latex/latex-mr/README.md
%{_texmfdistdir}/doc/latex/latex-mr/latex-mr.pdf
%{_texmfdistdir}/doc/latex/latex-mr/latex-mr.tex

%package -n texlive-latex-notes-zh-cn
Version:        %{texlive_version}.%{texlive_noarch}.1.20svn15878
Release:        0
License:        LPPL-1.0
Summary:        Chinese Introduction to TeX and LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source307:      latex-notes-zh-cn.doc.tar.xz

%description -n texlive-latex-notes-zh-cn
The document is an introduction to TeX/LaTeX, in Chinese. It
covers basic text typesetting, mathematics, graphics, tables,
Chinese language & fonts, and some miscellaneous features
(hyperlinks, long documents, bibliographies, indexes and page
layout).

%post -n texlive-latex-notes-zh-cn
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-notes-zh-cn
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-notes-zh-cn
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-notes-zh-cn
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/README
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/history.txt
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/latex-notes-zh-cn.pdf
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/license.txt
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/basics.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/dscf4684.jpg
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/arrow.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/color.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/colors.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/curve.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/dashed.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/dot.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/fill.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/label.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/line.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/loop.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/path.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/predefined.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_arc.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_arrow.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_axis.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_bezier.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_circle.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_color.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_curve.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_dot.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_fill.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_frame.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_grid.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_label.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_line.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_linestyle.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_origin.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_parabola.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_polygon.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_rput.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/pst_uput.eps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/subfig.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/subfig_left.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/subfig_right.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/transform.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples/uline.mps
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/fonts.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/graphics.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/i18n.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/introduction.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/lnotes.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/math.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/misc.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/postcript.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/preface.tex
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/reading.bib
%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/tables.tex

%package -n texlive-latex-papersize
Version:        %{texlive_version}.%{texlive_noarch}.1.63svn53131
Release:        0
License:        Apache-1.0
Summary:        Calculate LaTeX settings for any font and paper size
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-latex-papersize-bin >= %{texlive_version}
#!BuildIgnore: texlive-latex-papersize-bin
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-papersize-doc >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source308:      latex-papersize.tar.xz
Source309:      latex-papersize.doc.tar.xz

%description -n texlive-latex-papersize
The package is a Python script, whose typical use is when
preparing printed material for users with low vision. The most
effective way of doing this is to print on (notional) small
paper, and then to magnify the result; the script calculates
the settings for various font and paper sizes. More details are
to be read in the script itself.

%package -n texlive-latex-papersize-doc
Version:        %{texlive_version}.%{texlive_noarch}.1.63svn53131
Release:        0
Summary:        Documentation for texlive-latex-papersize
License:        Apache-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-papersize and texlive-alldocumentation)

%description -n texlive-latex-papersize-doc
This package includes the documentation for texlive-latex-papersize

%post -n texlive-latex-papersize
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-papersize
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-papersize
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-papersize-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/support/latex-papersize/README

%files -n texlive-latex-papersize
%defattr(-,root,root,755)
%{_texmfdistdir}/scripts/latex-papersize/latex-papersize.py

%package -n texlive-latex-refsheet
Version:        %{texlive_version}.%{texlive_noarch}.1.2svn45076
Release:        0
License:        LPPL-1.0
Summary:        LaTeX Reference Sheet for a thesis with KOMA-Script
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source310:      latex-refsheet.doc.tar.xz

%description -n texlive-latex-refsheet
This LaTeX Reference Sheet is for writing a thesis using the
KOMA-Script document classes (scrartcl, scrreprt, scrbook) and
all the packages needed for a thesis in natural sciences.

%post -n texlive-latex-refsheet
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-refsheet
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-refsheet
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-refsheet
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-refsheet/LaTeX_RefSheet.pdf
%{_texmfdistdir}/doc/latex/latex-refsheet/LaTeX_RefSheet.tex
%{_texmfdistdir}/doc/latex/latex-refsheet/README.md
%{_texmfdistdir}/doc/latex/latex-refsheet/acknowledgements.pdf
%{_texmfdistdir}/doc/latex/latex-refsheet/acknowledgements.tex
%{_texmfdistdir}/doc/latex/latex-refsheet/header-graph.pdf
%{_texmfdistdir}/doc/latex/latex-refsheet/header-graph.tex
%{_texmfdistdir}/doc/latex/latex-refsheet/layout.pdf
%{_texmfdistdir}/doc/latex/latex-refsheet/logo.png
%{_texmfdistdir}/doc/latex/latex-refsheet/thesis.bib
%{_texmfdistdir}/doc/latex/latex-refsheet/thesis.pdf
%{_texmfdistdir}/doc/latex/latex-refsheet/thesis.tex

%package -n texlive-latex-tools-dev
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
License:        LPPL-1.0
Summary:        Development pre-release of the LaTeX tools bundle
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-tools-dev-doc >= %{texlive_version}
Provides:       texdev(afterpage.sty)
Provides:       texdev(array-2016-10-06.sty)
Provides:       texdev(array-2020-02-10.sty)
Provides:       texdev(array.sty)
Provides:       texdev(bm.sty)
Provides:       texdev(calc.sty)
Provides:       texdev(dcolumn.sty)
Provides:       texdev(delarray.sty)
Provides:       texdev(e.tex)
Provides:       texdev(enumerate.sty)
Provides:       texdev(fontsmpl.sty)
Provides:       texdev(fontsmpl.tex)
Provides:       texdev(ftnright.sty)
Provides:       texdev(h.tex)
Provides:       texdev(hhline.sty)
Provides:       texdev(indentfirst.sty)
Provides:       texdev(layout.sty)
Provides:       texdev(longtable-2020-01-07.sty)
Provides:       texdev(longtable.sty)
Provides:       texdev(multicol-2017-04-11.sty)
Provides:       texdev(multicol-2019-10-01.sty)
Provides:       texdev(multicol.sty)
Provides:       texdev(q.tex)
Provides:       texdev(r.tex)
Provides:       texdev(rawfonts.sty)
Provides:       texdev(s.tex)
Provides:       texdev(shellesc.sty)
Provides:       texdev(showkeys-2014-10-28.sty)
Provides:       texdev(showkeys.sty)
Provides:       texdev(somedefs.sty)
Provides:       texdev(tabularx.sty)
Provides:       texdev(thb.sty)
Provides:       texdev(thc.sty)
Provides:       texdev(thcb.sty)
Provides:       texdev(theorem.sty)
Provides:       texdev(thm.sty)
Provides:       texdev(thmb.sty)
Provides:       texdev(thp.sty)
Provides:       texdev(trace.sty)
Provides:       texdev(varioref-2016-02-16.sty)
Provides:       texdev(varioref.sty)
Provides:       texdev(verbatim.sty)
Provides:       texdev(verbtest.tex)
Provides:       texdev(x.tex)
Provides:       texdev(xr.sty)
Provides:       texdev(xspace.sty)
Requires:       texdev(color.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source311:      latex-tools-dev.tar.xz
Source312:      latex-tools-dev.doc.tar.xz

%description -n texlive-latex-tools-dev
This is a pre-release version of the standard LaTeX tools
bundle. It accompanies the pre-testing kernel code
(latex-base-dev), and is intended for testing by knowledgeable
users.

%package -n texlive-latex-tools-dev-doc
Version:        %{texlive_version}.%{texlive_noarch}.20230501_pre_release_0svn64899
Release:        0
Summary:        Documentation for texlive-latex-tools-dev
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-tools-dev and texlive-alldocumentation)

%description -n texlive-latex-tools-dev-doc
This package includes the documentation for texlive-latex-tools-dev

%post -n texlive-latex-tools-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-tools-dev
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-tools-dev
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-tools-dev-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex-dev/tools/README.md
%{_texmfdistdir}/doc/latex-dev/tools/afterpage.pdf
%{_texmfdistdir}/doc/latex-dev/tools/array.pdf
%{_texmfdistdir}/doc/latex-dev/tools/bm.pdf
%{_texmfdistdir}/doc/latex-dev/tools/calc.pdf
%{_texmfdistdir}/doc/latex-dev/tools/changes.txt
%{_texmfdistdir}/doc/latex-dev/tools/dcolumn.pdf
%{_texmfdistdir}/doc/latex-dev/tools/delarray.pdf
%{_texmfdistdir}/doc/latex-dev/tools/enumerate.pdf
%{_texmfdistdir}/doc/latex-dev/tools/fileerr.pdf
%{_texmfdistdir}/doc/latex-dev/tools/fontsmpl.pdf
%{_texmfdistdir}/doc/latex-dev/tools/ftnright.pdf
%{_texmfdistdir}/doc/latex-dev/tools/hhline.pdf
%{_texmfdistdir}/doc/latex-dev/tools/indentfirst.pdf
%{_texmfdistdir}/doc/latex-dev/tools/layout.pdf
%{_texmfdistdir}/doc/latex-dev/tools/longtable.pdf
%{_texmfdistdir}/doc/latex-dev/tools/manifest.txt
%{_texmfdistdir}/doc/latex-dev/tools/multicol.pdf
%{_texmfdistdir}/doc/latex-dev/tools/rawfonts.pdf
%{_texmfdistdir}/doc/latex-dev/tools/shellesc.pdf
%{_texmfdistdir}/doc/latex-dev/tools/showkeys.pdf
%{_texmfdistdir}/doc/latex-dev/tools/somedefs.pdf
%{_texmfdistdir}/doc/latex-dev/tools/tabularx.pdf
%{_texmfdistdir}/doc/latex-dev/tools/theorem.pdf
%{_texmfdistdir}/doc/latex-dev/tools/tools-overview.pdf
%{_texmfdistdir}/doc/latex-dev/tools/tools-overview.tex
%{_texmfdistdir}/doc/latex-dev/tools/trace.pdf
%{_texmfdistdir}/doc/latex-dev/tools/varioref.pdf
%{_texmfdistdir}/doc/latex-dev/tools/verbatim.pdf
%{_texmfdistdir}/doc/latex-dev/tools/xr.pdf
%{_texmfdistdir}/doc/latex-dev/tools/xspace.pdf

%files -n texlive-latex-tools-dev
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex-dev/tools/.tex
%{_texmfdistdir}/tex/latex-dev/tools/afterpage.sty
%{_texmfdistdir}/tex/latex-dev/tools/array-2016-10-06.sty
%{_texmfdistdir}/tex/latex-dev/tools/array-2020-02-10.sty
%{_texmfdistdir}/tex/latex-dev/tools/array.sty
%{_texmfdistdir}/tex/latex-dev/tools/bm.sty
%{_texmfdistdir}/tex/latex-dev/tools/calc.sty
%{_texmfdistdir}/tex/latex-dev/tools/dcolumn.sty
%{_texmfdistdir}/tex/latex-dev/tools/delarray.sty
%{_texmfdistdir}/tex/latex-dev/tools/e.tex
%{_texmfdistdir}/tex/latex-dev/tools/enumerate.sty
%{_texmfdistdir}/tex/latex-dev/tools/fontsmpl.sty
%{_texmfdistdir}/tex/latex-dev/tools/fontsmpl.tex
%{_texmfdistdir}/tex/latex-dev/tools/ftnright.sty
%{_texmfdistdir}/tex/latex-dev/tools/h.tex
%{_texmfdistdir}/tex/latex-dev/tools/hhline.sty
%{_texmfdistdir}/tex/latex-dev/tools/indentfirst.sty
%{_texmfdistdir}/tex/latex-dev/tools/layout.sty
%{_texmfdistdir}/tex/latex-dev/tools/longtable-2020-01-07.sty
%{_texmfdistdir}/tex/latex-dev/tools/longtable.sty
%{_texmfdistdir}/tex/latex-dev/tools/multicol-2017-04-11.sty
%{_texmfdistdir}/tex/latex-dev/tools/multicol-2019-10-01.sty
%{_texmfdistdir}/tex/latex-dev/tools/multicol.sty
%{_texmfdistdir}/tex/latex-dev/tools/q.tex
%{_texmfdistdir}/tex/latex-dev/tools/r.tex
%{_texmfdistdir}/tex/latex-dev/tools/rawfonts.sty
%{_texmfdistdir}/tex/latex-dev/tools/s.tex
%{_texmfdistdir}/tex/latex-dev/tools/shellesc.sty
%{_texmfdistdir}/tex/latex-dev/tools/showkeys-2014-10-28.sty
%{_texmfdistdir}/tex/latex-dev/tools/showkeys.sty
%{_texmfdistdir}/tex/latex-dev/tools/somedefs.sty
%{_texmfdistdir}/tex/latex-dev/tools/tabularx.sty
%{_texmfdistdir}/tex/latex-dev/tools/thb.sty
%{_texmfdistdir}/tex/latex-dev/tools/thc.sty
%{_texmfdistdir}/tex/latex-dev/tools/thcb.sty
%{_texmfdistdir}/tex/latex-dev/tools/theorem.sty
%{_texmfdistdir}/tex/latex-dev/tools/thm.sty
%{_texmfdistdir}/tex/latex-dev/tools/thmb.sty
%{_texmfdistdir}/tex/latex-dev/tools/thp.sty
%{_texmfdistdir}/tex/latex-dev/tools/trace.sty
%{_texmfdistdir}/tex/latex-dev/tools/varioref-2016-02-16.sty
%{_texmfdistdir}/tex/latex-dev/tools/varioref.sty
%{_texmfdistdir}/tex/latex-dev/tools/verbatim.sty
%{_texmfdistdir}/tex/latex-dev/tools/verbtest.tex
%{_texmfdistdir}/tex/latex-dev/tools/x.tex
%{_texmfdistdir}/tex/latex-dev/tools/xr.sty
%{_texmfdistdir}/tex/latex-dev/tools/xspace.sty

%package -n texlive-latex-uni8
Version:        %{texlive_version}.%{texlive_noarch}.0.0.03svn49729
Release:        0
License:        LPPL-1.0
Summary:        Universal inputenc, fontenc, and babel for pdfLaTeX and LuaLaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Suggests:       texlive-latex-uni8-doc >= %{texlive_version}
Provides:       tex(uni8.sty)
Requires:       tex(babel.sty)
Requires:       tex(fontspec.sty)
Requires:       tex(lmodern.sty)
Requires:       tex(mathptmx.sty)
Requires:       tex(soul.sty)
Requires:       tex(soulutf8.sty)
Requires:       tex(tgcursor.sty)
Requires:       tex(tgheros.sty)
Requires:       tex(tgtermes.sty)
Requires:       tex(unicode-math.sty)
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source313:      latex-uni8.tar.xz
Source314:      latex-uni8.doc.tar.xz

%description -n texlive-latex-uni8
This package provides a LaTeX style file which makes it easy to
use input encoding (UTF-8 by default, can be changed),
fontspec.sty (optional), font encoding (T1 if fontspec.sty is
not used), babel (English language by default), hyphenation,
underline (with soul.sty), default text and math fonts
(Computer Modern or Times), and paper sizes correctly with both
pdfLaTeX and LuaLaTeX.

%package -n texlive-latex-uni8-doc
Version:        %{texlive_version}.%{texlive_noarch}.0.0.03svn49729
Release:        0
Summary:        Documentation for texlive-latex-uni8
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Supplements:    (texlive-latex-uni8 and texlive-alldocumentation)

%description -n texlive-latex-uni8-doc
This package includes the documentation for texlive-latex-uni8

%post -n texlive-latex-uni8
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-uni8
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-uni8
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-uni8-doc
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-uni8/README.txt
%{_texmfdistdir}/doc/latex/latex-uni8/example_fl.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_flr.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_fm.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_fmr.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_fu.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_fur.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_fut.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_futr.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_pl.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_plr.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_pm.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_pmr.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_pu.tex
%{_texmfdistdir}/doc/latex/latex-uni8/example_pur.tex

%files -n texlive-latex-uni8
%defattr(-,root,root,755)
%{_texmfdistdir}/tex/latex/latex-uni8/uni8.sty

%package -n texlive-latex-veryshortguide
Version:        %{texlive_version}.%{texlive_noarch}.0.0.7svn55228
Release:        0
License:        LPPL-1.0
Summary:        The Very Short Guide to LaTeX
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source315:      latex-veryshortguide.doc.tar.xz

%description -n texlive-latex-veryshortguide
This is a 4-page reminder of what LaTeX does. It is designed
for printing on A4 paper, double-sided, and folding once to A5.
Such an 'imposed' version of the document is provided in the
distribution, as PDF. An analogous version is provided in
'legal' format.

%post -n texlive-latex-veryshortguide
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-veryshortguide
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-veryshortguide
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-veryshortguide
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-veryshortguide/MANIFEST
%{_texmfdistdir}/doc/latex/latex-veryshortguide/README.md
%{_texmfdistdir}/doc/latex/latex-veryshortguide/VERSION
%{_texmfdistdir}/doc/latex/latex-veryshortguide/menno-a.jpg
%{_texmfdistdir}/doc/latex/latex-veryshortguide/veryshortguide-A4-imposed.pdf
%{_texmfdistdir}/doc/latex/latex-veryshortguide/veryshortguide.cls
%{_texmfdistdir}/doc/latex/latex-veryshortguide/veryshortguide.dtx
%{_texmfdistdir}/doc/latex/latex-veryshortguide/veryshortguide.ins
%{_texmfdistdir}/doc/latex/latex-veryshortguide/veryshortguide.pdf
%{_texmfdistdir}/doc/latex/latex-veryshortguide/vsg.bib
%{_texmfdistdir}/doc/latex/latex-veryshortguide/vsg.tex

%package -n texlive-latex-via-exemplos
Version:        %{texlive_version}.%{texlive_noarch}.0.0.5.8svn63374
Release:        0
License:        GPL-2.0-or-later
Summary:        A LaTeX course written in brazilian portuguese language
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source316:      latex-via-exemplos.doc.tar.xz

%description -n texlive-latex-via-exemplos
This is a LaTeX2e course written in brazilian portuguese
language.

%post -n texlive-latex-via-exemplos
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-latex-via-exemplos
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%posttrans -n texlive-latex-via-exemplos
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files -n texlive-latex-via-exemplos
%defattr(-,root,root,755)
%{_texmfdistdir}/doc/latex/latex-via-exemplos/README.md
%{_texmfdistdir}/doc/latex/latex-via-exemplos/changelog.txt
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-certificado.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-fig.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-lista-nomes.csv
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-oneside.pdf
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-oneside.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-poster.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos-slides.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos.bib
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos.pdf
%{_texmfdistdir}/doc/latex/latex-via-exemplos/latex-via-exemplos.tex
%{_texmfdistdir}/doc/latex/latex-via-exemplos/makeaux.sh
%{_texmfdistdir}/doc/latex/latex-via-exemplos/makedoc.sh

%prep
%setup -q -c -T

%build

%install
    rm -rf %{buildroot}
    mkdir -p %{buildroot}%{_texmfdistdir}
    mkdir -p %{buildroot}%{_texmfmaindir}/tlpkg/tlpostcode
    mkdir -p %{buildroot}%{_datadir}/texlive/tlpkg
    mkdir -p %{buildroot}/var/adm/update-scripts
    ln -sf ../../share/texmf        %{buildroot}%{_datadir}/texlive/texmf-dist
    ln -sf ../../share/texmf        %{buildroot}%{_datadir}/texlive/texmf
    ln -sf ../../../share/texmf/tlpkg/tlpostcode \
                                    %{buildroot}%{_datadir}/texlive/tlpkg/tlpostcode
    ln -sf tlpkg/tlpostcode         %{buildroot}%{_texmfmaindir}/tlpostcode
    tar --use-compress-program=xz -xf %{S:1} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:2} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:3} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:4} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:5} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:6} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-ipaex
    for font in %{buildroot}/%{_texmfdistdir}/fonts/truetype/public/ipaex/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-ipaex
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-ipaex/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-ipaex/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-ipaex/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-ipaex.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-ipaex    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-ipaex/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:7} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:8} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-ipaex-type1
    for font in %{buildroot}/%{_texmfdistdir}/fonts/type1/public/ipaex-type1/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-ipaex-type1
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-ipaex-type1/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-ipaex-type1/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-ipaex-type1/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-ipaex-type1.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-ipaex-type1    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-ipaex-type1/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:9} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:10} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:11} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:12} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:13} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:14} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:15} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:16} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:17} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:18} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:19} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:20} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:21} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:22} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:23} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:24} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:25} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:26} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:27} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:28} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:29} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:30} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:31} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:32} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:33} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:34} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:35} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:36} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:37} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:38} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:39} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:40} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-iwona
    for font in %{buildroot}/%{_texmfdistdir}/fonts/opentype/nowacki/iwona/*.{pf[ab],[ot]tf} \
		%{buildroot}/%{_texmfdistdir}/fonts/type1/nowacki/iwona/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-iwona
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-iwona/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-iwona/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-iwona/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-iwona.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-iwona    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-iwona/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF

    mkdir -p %{buildroot}%{_sysconfdir}/fonts/conf.d
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/55-texlive-iwona.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Disable plain Type1 font to let fontconfig       -->
	<!-- prefere the OpenType and TrueType fonts          -->
	<!-- ************************************************ -->

	<fontconfig>
	  <selectfont>
	    <rejectfont>
	      <glob>%{_datadir}/fonts/texlive-iwona/*.pf*</glob>
	    </rejectfont>
	  </selectfont>
	</fontconfig>
	EOF
    ln -sf %{_datadir}/fontconfig/conf.avail/55-texlive-iwona.conf %{buildroot}%{_sysconfdir}/fonts/conf.d/55-texlive-iwona.conf
    tar --use-compress-program=xz -xf %{S:41} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:42} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:43} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:44} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:45} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:46} -C %{buildroot}%{_datadir}/texlive
    pushd %{buildroot}%{_datadir}/texlive/texmf-dist
	patch --reject-format=unified --quoting-style=literal -f -p1 -F0 -T < %{S:47}
    popd
    tar --use-compress-program=xz -xf %{S:48} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:49} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:50} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:51} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:52} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:53} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:54} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:55} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:56} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:57} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:58} -C %{buildroot}%{_datadir}/texlive
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/jfmutil/jfmutil.pl
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:59} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:60} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:61} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:62} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:63} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:64} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:65} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:66} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:67} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:68} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:69} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:70} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:71} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:72} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:73} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:74} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:75} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:76} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-jmn
    for font in %{buildroot}/%{_texmfdistdir}/fonts/type1/jmn/hans/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-jmn
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-jmn/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-jmn/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-jmn/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-jmn.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-jmn    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-jmn/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:77} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:78} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:79} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:80} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:81} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:82} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:83} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:84} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:85} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:86} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-josefin
    for font in %{buildroot}/%{_texmfdistdir}/fonts/truetype/public/josefin/*.{pf[ab],[ot]tf} \
		%{buildroot}/%{_texmfdistdir}/fonts/type1/public/josefin/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-josefin
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-josefin/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-josefin/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-josefin/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-josefin.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-josefin    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-josefin/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF

    mkdir -p %{buildroot}%{_sysconfdir}/fonts/conf.d
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/55-texlive-josefin.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Disable plain Type1 font to let fontconfig       -->
	<!-- prefere the OpenType and TrueType fonts          -->
	<!-- ************************************************ -->

	<fontconfig>
	  <selectfont>
	    <rejectfont>
	      <glob>%{_datadir}/fonts/texlive-josefin/*.pf*</glob>
	    </rejectfont>
	  </selectfont>
	</fontconfig>
	EOF
    ln -sf %{_datadir}/fontconfig/conf.avail/55-texlive-josefin.conf %{buildroot}%{_sysconfdir}/fonts/conf.d/55-texlive-josefin.conf
    tar --use-compress-program=xz -xf %{S:87} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:88} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:89} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:90} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:91} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:92} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:93} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:94} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:95} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:96} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:97} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:98} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:99} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:100} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:101} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:102} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:103} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:104} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-junicode
    for font in %{buildroot}/%{_texmfdistdir}/fonts/truetype/public/junicode/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-junicode
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-junicode/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-junicode/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-junicode/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-junicode.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-junicode    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-junicode/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:105} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:106} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:107} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:108} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Make possible scripts usable if any
    for scr in %{_texmfdistdir}/doc/latex/jura/jura2html
    do
	test -e %{buildroot}/$scr || continue
	chmod 0755 %{buildroot}/$scr
    done
    tar --use-compress-program=xz -xf %{S:109} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:110} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:111} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:112} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:113} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:114} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:115} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:116} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:117} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:118} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:119} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:120} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:121} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:122} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:123} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:124} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:125} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:126} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:127} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:128} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:129} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:130} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:131} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:132} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:133} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:134} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:135} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:136} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:137} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:138} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:139} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:140} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:141} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:142} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:143} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:144} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:145} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-kerkis
    for font in %{buildroot}/%{_texmfdistdir}/fonts/opentype/public/kerkis/*.{pf[ab],[ot]tf} \
		%{buildroot}/%{_texmfdistdir}/fonts/type1/public/kerkis/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-kerkis
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-kerkis/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-kerkis/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-kerkis/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-kerkis.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-kerkis    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-kerkis/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF

    mkdir -p %{buildroot}%{_sysconfdir}/fonts/conf.d
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/55-texlive-kerkis.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Disable plain Type1 font to let fontconfig       -->
	<!-- prefere the OpenType and TrueType fonts          -->
	<!-- ************************************************ -->

	<fontconfig>
	  <selectfont>
	    <rejectfont>
	      <glob>%{_datadir}/fonts/texlive-kerkis/*.pf*</glob>
	    </rejectfont>
	  </selectfont>
	</fontconfig>
	EOF
    ln -sf %{_datadir}/fontconfig/conf.avail/55-texlive-kerkis.conf %{buildroot}%{_sysconfdir}/fonts/conf.d/55-texlive-kerkis.conf
    tar --use-compress-program=xz -xf %{S:146} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:147} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:148} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:149} -C %{buildroot}%{_datadir}/texlive
    # Remove files
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/setketcindykettex.bat
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/setketcindyothertex.bat
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/setketcindytexlive.bat
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/setketcindyw32J.bat
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/setwork.bat
    # Make possible scripts usable if any
    for scr in %{_texmfdistdir}/doc/support/ketcindy/forLinux/setcindyetc.sh \
	       %{_texmfdistdir}/doc/support/ketcindy/forLinux/setketcindy.sh
    do
	test -e %{buildroot}/$scr || continue
	chmod 0755 %{buildroot}/$scr
    done
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/ketcindy/ketcindy.pl
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    # Strip executable bit from non-scripts
    for txt in %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dhelpE.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylib3dhelpJ.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibhelpE.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibhelpJ.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvhelpE.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvhelpJ.txt \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketcindylibmvr.cs \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketpiccurrent.r \
	       %{_texmfdistdir}/scripts/ketcindy/ketlib/ketpiccurrent_rep2e.r \
	       %{_texmfdistdir}/scripts/ketcindy/setketcindy.txt
    do
	test -e %{buildroot}/$txt || continue
	chmod 0644 %{buildroot}/$txt
    done
    tar --use-compress-program=xz -xf %{S:150} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:151} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:152} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:153} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:154} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:155} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:156} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:157} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:158} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:159} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:160} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:161} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:162} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:163} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:164} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:165} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:166} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:167} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:168} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:169} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:170} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:171} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:172} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:173} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:174} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:175} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:176} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:177} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-knitting
    for font in %{buildroot}/%{_texmfdistdir}/fonts/type1/public/knitting/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-knitting
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-knitting/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-knitting/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-knitting/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-knitting.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-knitting    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-knitting/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:178} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:179} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:180} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:181} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:182} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:183} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:184} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:185} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:186} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:187} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:188} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:189} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/koma-script
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/koma-script/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/koma-script/doc/bin
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/koma-script/doc/english
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/koma-script/doc/ngerman
    tar --use-compress-program=xz -xf %{S:190} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:191} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:192} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:193} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:194} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:195} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:196} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:197} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:198} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:199} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:200} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:201} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:202} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:203} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:204} -C %{buildroot}%{_datadir}/texlive
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/kotex-utils/jamo-normalize.pl \
	       %{_texmfdistdir}/scripts/kotex-utils/komkindex.pl \
	       %{_texmfdistdir}/scripts/kotex-utils/ttf2kotexfont.pl
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:205} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:206} -C %{buildroot}%{_datadir}/texlive
    pushd %{buildroot}%{_datadir}/texlive/texmf-dist
	patch --reject-format=unified --quoting-style=literal -f -p1 -F0 -T < %{S:207}
    popd
    # Move configuration files
    mkdir -p %{buildroot}%{_texmfconfdir}/web2c
    mv -f  %{buildroot}%{_texmfdistdir}/web2c/fmtutil.cnf %{buildroot}%{_texmfconfdir}/web2c/
    rm -f  %{buildroot}%{_texmfdistdir}/web2c/fmtutil.cnf
    ln -sf %{_texmfconfdir}/web2c/fmtutil.cnf %{buildroot}%{_texmfdistdir}/web2c/fmtutil.cnf
    mv -f  %{buildroot}%{_texmfdistdir}/web2c/mktex.cnf %{buildroot}%{_texmfconfdir}/web2c/
    rm -f  %{buildroot}%{_texmfdistdir}/web2c/mktex.cnf
    ln -sf %{_texmfconfdir}/web2c/mktex.cnf %{buildroot}%{_texmfdistdir}/web2c/mktex.cnf
    mv -f  %{buildroot}%{_texmfdistdir}/web2c/texmf.cnf %{buildroot}%{_texmfconfdir}/web2c/
    rm -f  %{buildroot}%{_texmfdistdir}/web2c/texmf.cnf
    ln -sf %{_texmfconfdir}/web2c/texmf.cnf %{buildroot}%{_texmfdistdir}/web2c/texmf.cnf
    tar --use-compress-program=xz -xf %{S:208} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:209} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-kpfonts
    for font in %{buildroot}/%{_texmfdistdir}/fonts/type1/public/kpfonts/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-kpfonts
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-kpfonts/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-kpfonts/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-kpfonts/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-kpfonts.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-kpfonts    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-kpfonts/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:210} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:211} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-kpfonts-otf
    for font in %{buildroot}/%{_texmfdistdir}/fonts/opentype/public/kpfonts-otf/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-kpfonts-otf
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-kpfonts-otf/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-kpfonts-otf/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-kpfonts-otf/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-kpfonts-otf.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-kpfonts-otf    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-kpfonts-otf/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF
    tar --use-compress-program=xz -xf %{S:212} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:213} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:214} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:215} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:216} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:217} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:218} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:219} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:220} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:221} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:222} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move font files
    mkdir -p %{buildroot}%{_datadir}/fonts/texlive-kurier
    for font in %{buildroot}/%{_texmfdistdir}/fonts/opentype/nowacki/kurier/*.{pf[ab],[ot]tf} \
		%{buildroot}/%{_texmfdistdir}/fonts/type1/nowacki/kurier/*.{pf[ab],[ot]tf}
    do
        test -e $font || continue
        mv -f $font %{buildroot}%{_datadir}/fonts/texlive-kurier
        base=${font##*/}
        ln -sf %{_datadir}/fonts/texlive-kurier/${base} ${font}
    done
    /usr/bin/mkfontscale %{buildroot}%{_datadir}/fonts/texlive-kurier/
    /usr/bin/mkfontdir -e /usr/share/fonts/encodings/ %{buildroot}%{_datadir}/fonts/texlive-kurier/
    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/58-texlive-kurier.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Use this to disable the TeX fonts of the package -->
	<!--    texlive-kurier    -->
	<!-- Be aware that the configurations in the files    -->
	<!-- 09-texlive*.conf will not be affected by this    -->
	<!-- ************************************************ -->

	<fontconfig>
	  <rejectfont>
	    <glob>%{_datadir}/fonts/texlive-kurier/*</glob>
	  </rejectfont>
	</fontconfig>
	EOF

    mkdir -p %{buildroot}%{_sysconfdir}/fonts/conf.d
    (cat > %{buildroot}%{_datadir}/fontconfig/conf.avail/55-texlive-kurier.conf)<<-'EOF'
	<?xml version="1.0"?>
	<!DOCTYPE fontconfig SYSTEM "fonts.dtd">

	<!-- ************************************************ -->
	<!-- Disable plain Type1 font to let fontconfig       -->
	<!-- prefere the OpenType and TrueType fonts          -->
	<!-- ************************************************ -->

	<fontconfig>
	  <selectfont>
	    <rejectfont>
	      <glob>%{_datadir}/fonts/texlive-kurier/*.pf*</glob>
	    </rejectfont>
	  </selectfont>
	</fontconfig>
	EOF
    ln -sf %{_datadir}/fontconfig/conf.avail/55-texlive-kurier.conf %{buildroot}%{_sysconfdir}/fonts/conf.d/55-texlive-kurier.conf
    tar --use-compress-program=xz -xf %{S:223} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:224} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:225} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:226} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:227} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:228} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:229} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:230} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:231} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:232} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:233} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:234} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:235} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:236} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:237} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:238} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:239} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:240} -C %{buildroot}%{_datadir}/texlive
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/l3build/l3build.lua
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:241} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:242} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:243} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:244} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:245} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:246} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:247} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:248} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:249} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:250} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:251} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:252} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:253} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:254} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:255} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:256} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:257} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:258} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:259} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:260} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Move configuration files
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/lambda/config
    mv -f  %{buildroot}%{_texmfdistdir}/tex/lambda/config/language.dat %{buildroot}%{_texmfconfdir}/tex/lambda/config/
    rm -f  %{buildroot}%{_texmfdistdir}/tex/lambda/config/language.dat
    ln -sf %{_texmfconfdir}/tex/lambda/config/language.dat %{buildroot}%{_texmfdistdir}/tex/lambda/config/language.dat
    tar --use-compress-program=xz -xf %{S:261} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:262} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:263} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:264} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:265} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:266} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:267} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:268} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:269} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:270} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:271} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:272} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:273} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:274} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:275} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:276} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:277} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:278} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:279} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:280} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:281} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:282} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:283} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:284} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:285} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:286} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:287} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:288} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:289} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:290} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:291} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:292} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:293} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:294} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:295} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:296} -C %{buildroot}%{_datadir}/texlive
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/latex-git-log/latex-git-log
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:297} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:298} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:299} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:300} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:301} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:302} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:303} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:304} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:305} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/latex-make/figdepth.py \
	       %{_texmfdistdir}/scripts/latex-make/gensubfig.py \
	       %{_texmfdistdir}/scripts/latex-make/latexfilter.py \
	       %{_texmfdistdir}/scripts/latex-make/svg2dev.py \
	       %{_texmfdistdir}/scripts/latex-make/svgdepth.py
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:306} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:307} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:308} -C %{buildroot}%{_datadir}/texlive
    tar --use-compress-program=xz -xf %{S:309} -C %{buildroot}%{_datadir}/texlive
    # Correct shebang of python3 scripts if any
    for scr in %{_texmfdistdir}/scripts/latex-papersize/latex-papersize.py
    do
        test -e %{buildroot}/$scr || continue
	head -n 1 %{buildroot}/$scr | grep -q python3 && continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@python@python3@
		.
		w
		q
	EOF
    done
    # Avoid /usr/bin/env <prog>
    for scr in %{_texmfdistdir}/scripts/latex-papersize/latex-papersize.py
    do
	test -e %{buildroot}/$scr || continue
	ed %{buildroot}/${scr} <<-'EOF'
		1
		s@/env[[:blank:]]\+@/@
		.
		w
		q
	EOF
    done
    tar --use-compress-program=xz -xf %{S:310} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:311} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:312} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:313} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:314} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:315} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:316} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    # Remove this
    rm -vrf %{buildroot}%{_texmfdistdir}/tlpkg/tlpobj
    rm -vrf %{buildroot}%{_texmfmaindir}/tlpkg/tlpobj
    rm -v  %{buildroot}%{_datadir}/texlive/texmf
    rm -v  %{buildroot}%{_datadir}/texlive/texmf-dist
    rm -v  %{buildroot}%{_texmfmaindir}/tlpostcode
    rm -vr %{buildroot}%{_datadir}/texlive
    # Handle manual pages
    rm -vf %{buildroot}%{_texmfmaindir}/doc/man/Makefile
    rm -vf %{buildroot}%{_texmfmaindir}/doc/man/man*/*.pdf
    rm -vf %{buildroot}%{_texmfdistdir}/doc/man/Makefile
    rm -vf %{buildroot}%{_texmfdistdir}/doc/man/man*/*.pdf
    for path in %{buildroot}%{_texmfmaindir}/doc/man/man? \
               %{buildroot}%{_texmfdistdir}/doc/man/man?
    do
        test -d "$path" || continue
        sec=${path##*/}
        mkdir -p %{buildroot}%{_mandir}/${sec}
        for page in ${path}/*.*
        do
            test -e "$page" || continue
            mv -f $page %{buildroot}%{_mandir}/${sec}/
        done
    done
    rm -rf %{buildroot}%{_texmfmaindir}/doc/man
    rm -rf %{buildroot}%{_texmfdistdir}/doc/man
    # Handle info documents
    rm -vf  %{buildroot}%{_texmfmaindir}/doc/info/dir
    rm -vf  %{buildroot}%{_texmfdistdir}/doc/info/dir
    mkdir -p %{buildroot}%{_infodir}
    for inf in %{buildroot}%{_texmfmaindir}/doc/info/*.info \
               %{buildroot}%{_texmfdistdir}/doc/info/*.info
    do
        test -e "$inf" || continue
        mv -f $inf %{buildroot}%{_infodir}/
    done
    rm -rf %{buildroot}%{_texmfmaindir}/doc/info
    rm -rf %{buildroot}%{_texmfdistdir}/doc/info
    find %{buildroot}%{_texmfmaindir}/ %{buildroot}%{_texmfdistdir}/ \
        -type f -a -perm /g+w,o+w | xargs --no-run-if-empty chmod g-w,o-w

%changelog
